@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2015 Zabbix SIA
+** Copyright (C) 2001-2016 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -18,39 +18,37 @@
 ** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 **/
 
-
 require_once dirname(__FILE__).'/include/config.inc.php';
 
 $page['title'] = _('Configuration of icon mapping');
 $page['file'] = 'adm.iconmapping.php';
-$page['hist_arg'] = array();
 
 require_once dirname(__FILE__).'/include/page_header.php';
 
 // VAR	TYPE	OPTIONAL	FLAGS	VALIDATION	EXCEPTION
-$fields = array(
-	'iconmapid' =>		array(T_ZBX_INT, O_OPT, P_SYS,			DB_ID,	'(isset({form}) && {form} == "update") || isset({delete})'),
-	'iconmap' =>		array(T_ZBX_STR, O_OPT, null,			null,	'isset({add}) || isset({update})'),
-	'add' =>			array(T_ZBX_STR, O_OPT, P_SYS|P_ACT,	null,	null),
-	'update' =>			array(T_ZBX_STR, O_OPT, P_SYS|P_ACT,	null,	null),
-	'delete' =>			array(T_ZBX_STR, O_OPT, P_SYS|P_ACT,	null,	null),
-	'clone' =>			array(T_ZBX_STR, O_OPT, null,			null,	null),
-	'form' =>			array(T_ZBX_STR, O_OPT, P_SYS,			null,	null),
-	'form_refresh' =>	array(T_ZBX_INT, O_OPT, null,			null,	null)
-);
+$fields = [
+	'iconmapid' =>		[T_ZBX_INT, O_OPT, P_SYS,			DB_ID,	'(isset({form}) && {form} == "update") || isset({delete})'],
+	'iconmap' =>		[T_ZBX_STR, O_OPT, null,			null,	'isset({add}) || isset({update})'],
+	'add' =>			[T_ZBX_STR, O_OPT, P_SYS|P_ACT,	null,	null],
+	'update' =>			[T_ZBX_STR, O_OPT, P_SYS|P_ACT,	null,	null],
+	'delete' =>			[T_ZBX_STR, O_OPT, P_SYS|P_ACT,	null,	null],
+	'clone' =>			[T_ZBX_STR, O_OPT, null,			null,	null],
+	'form' =>			[T_ZBX_STR, O_OPT, P_SYS,			null,	null],
+	'form_refresh' =>	[T_ZBX_INT, O_OPT, null,			null,	null]
+];
 check_fields($fields);
 
 /*
  * Permissions
  */
 if (hasRequest('iconmapid')) {
-	$iconMap = API::IconMap()->get(array(
+	$iconMap = API::IconMap()->get([
 		'iconmapids' => getRequest('iconmapid'),
 		'output' => API_OUTPUT_EXTEND,
 		'editable' => true,
 		'preservekeys' => true,
 		'selectMappings' => API_OUTPUT_EXTEND,
-	));
+	]);
 	if (empty($iconMap)) {
 		access_deny();
 	}
@@ -62,7 +60,7 @@ if (hasRequest('iconmapid')) {
 if (hasRequest('add') || hasRequest('update')) {
 	$_REQUEST['iconmap']['mappings'] = isset($_REQUEST['iconmap']['mappings'])
 		? $_REQUEST['iconmap']['mappings']
-		: array();
+		: [];
 
 	$i = 0;
 	foreach ($_REQUEST['iconmap']['mappings'] as &$mapping) {
@@ -89,7 +87,7 @@ if (hasRequest('add') || hasRequest('update')) {
 	}
 }
 elseif (hasRequest('delete')) {
-	$result = API::IconMap()->delete(array(getRequest('iconmapid')));
+	$result = API::IconMap()->delete([getRequest('iconmapid')]);
 
 	if ($result) {
 		unset($_REQUEST['form']);
@@ -105,43 +103,17 @@ elseif (isset($_REQUEST['clone'])) {
 /*
  * Display
  */
-$generalComboBox = new CComboBox('configDropDown', 'adm.iconmapping.php', 'redirect(this.options[this.selectedIndex].value);');
-$generalComboBox->addItems(array(
-	'adm.gui.php' => _('GUI'),
-	'adm.housekeeper.php' => _('Housekeeping'),
-	'adm.images.php' => _('Images'),
-	'adm.iconmapping.php' => _('Icon mapping'),
-	'adm.regexps.php' => _('Regular expressions'),
-	'adm.macros.php' => _('Macros'),
-	'adm.valuemapping.php' => _('Value mapping'),
-	'adm.workingtime.php' => _('Working time'),
-	'adm.triggerseverities.php' => _('Trigger severities'),
-	'adm.triggerdisplayoptions.php' => _('Trigger displaying options'),
-	'adm.other.php' => _('Other')
-));
-$iconMapForm = new CForm();
-$iconMapForm->cleanItems();
-$iconMapForm->addItem($generalComboBox);
-
-if (!isset($_REQUEST['form'])) {
-	$iconMapForm->addItem(new CSubmit('form', _('Create icon map')));
-}
-
-$iconMapWidget = new CWidget();
-$iconMapWidget->addPageHeader(_('CONFIGURATION OF ICON MAPPING'), $iconMapForm);
-
-$data = array(
-	'form_refresh' => getRequest('form_refresh', 0),
+$data = [
 	'iconmapid' => getRequest('iconmapid'),
-	'iconList' => array(),
-	'inventoryList' => array()
-);
+	'iconList' => [],
+	'inventoryList' => []
+];
 
-$iconList = API::Image()->get(array(
-	'output' => array('imageid', 'name'),
-	'filter' => array('imagetype' => IMAGE_TYPE_ICON),
+$iconList = API::Image()->get([
+	'output' => ['imageid', 'name'],
+	'filter' => ['imagetype' => IMAGE_TYPE_ICON],
 	'preservekeys' => true
-));
+]);
 order_result($iconList, 'name');
 
 foreach ($iconList as $icon) {
@@ -154,7 +126,7 @@ foreach ($inventoryFields as $field) {
 }
 
 if (isset($_REQUEST['form'])) {
-	if ($data['form_refresh'] || ($_REQUEST['form'] === 'clone')) {
+	if (hasRequest('form_refresh') || ($_REQUEST['form'] === 'clone')) {
 		$data['iconmap'] = getRequest('iconmap');
 	}
 	elseif (isset($_REQUEST['iconmapid'])) {
@@ -163,30 +135,28 @@ if (isset($_REQUEST['form'])) {
 	else {
 		$firstIcon = reset($iconList);
 
-		$data['iconmap'] = array(
+		$data['iconmap'] = [
 			'name' => '',
 			'default_iconid' => $firstIcon['imageid'],
-			'mappings' => array()
-		);
+			'mappings' => []
+		];
 	}
 
-	$iconMapView = new CView('administration.general.iconmap.edit', $data);
+	$view = new CView('administration.general.iconmap.edit', $data);
 }
 else {
-	$iconMapWidget->addHeader(_('Icon mapping'));
-
-	$data['iconmaps'] = API::IconMap()->get(array(
+	$data['iconmaps'] = API::IconMap()->get([
 		'output' => API_OUTPUT_EXTEND,
 		'editable' => true,
 		'preservekeys' => true,
 		'selectMappings' => API_OUTPUT_EXTEND
-	));
+	]);
 	order_result($data['iconmaps'], 'name');
 
-	$iconMapView = new CView('administration.general.iconmap.list', $data);
+	$view = new CView('administration.general.iconmap.list', $data);
 }
 
-$iconMapWidget->addItem($iconMapView->render());
-$iconMapWidget->show();
+$view->render();
+$view->show();
 
 require_once dirname(__FILE__).'/include/page_footer.php';
