@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2015 Zabbix SIA
+** Copyright (C) 2001-2016 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -28,19 +28,18 @@ $page['type'] = PAGE_TYPE_IMAGE;
 require_once dirname(__FILE__).'/include/page_header.php';
 
 // VAR	TYPE	OPTIONAL	FLAGS	VALIDATION	EXCEPTION
-$fields = array(
-	'graphid' =>		array(T_ZBX_INT, O_MAND, P_SYS,		DB_ID,		null),
-	'period' =>			array(T_ZBX_INT, O_OPT, P_NZERO,	BETWEEN(ZBX_MIN_PERIOD, ZBX_MAX_PERIOD), null),
-	'stime' =>			array(T_ZBX_STR, O_OPT, P_SYS,		null,		null),
-	'profileIdx' =>		array(T_ZBX_STR, O_OPT, null,		null,		null),
-	'profileIdx2' =>	array(T_ZBX_STR, O_OPT, null,		null,		null),
-	'updateProfile' =>	array(T_ZBX_STR, O_OPT, null,		null,		null),
-	'border' =>			array(T_ZBX_INT, O_OPT, P_NZERO,	IN('0,1'),	null),
-	'width' =>			array(T_ZBX_INT, O_OPT, P_NZERO,	BETWEEN(20, 65535),	null),
-	'height' =>			array(T_ZBX_INT, O_OPT, P_NZERO,	'{}>0',		null),
-	'graph3d' =>		array(T_ZBX_INT, O_OPT, P_NZERO,	IN('0,1'),	null),
-	'legend' =>			array(T_ZBX_INT, O_OPT, P_NZERO,	IN('0,1'),	null)
-);
+$fields = [
+	'graphid' =>		[T_ZBX_INT, O_MAND, P_SYS,		DB_ID,		null],
+	'period' =>			[T_ZBX_INT, O_OPT, P_NZERO,	BETWEEN(ZBX_MIN_PERIOD, ZBX_MAX_PERIOD), null],
+	'stime' =>			[T_ZBX_STR, O_OPT, P_SYS,		null,		null],
+	'profileIdx' =>		[T_ZBX_STR, O_OPT, null,		null,		null],
+	'profileIdx2' =>	[T_ZBX_STR, O_OPT, null,		null,		null],
+	'updateProfile' =>	[T_ZBX_STR, O_OPT, null,		null,		null],
+	'width' =>			[T_ZBX_INT, O_OPT, P_NZERO,	BETWEEN(20, 65535),	null],
+	'height' =>			[T_ZBX_INT, O_OPT, P_NZERO,	'{} > 0',	null],
+	'graph3d' =>		[T_ZBX_INT, O_OPT, P_NZERO,	IN('0,1'),	null],
+	'legend' =>			[T_ZBX_INT, O_OPT, P_NZERO,	IN('0,1'),	null]
+];
 if (!check_fields($fields)) {
 	exit();
 }
@@ -48,12 +47,12 @@ if (!check_fields($fields)) {
 /*
  * Permissions
  */
-$dbGraph = API::Graph()->get(array(
+$dbGraph = API::Graph()->get([
 	'output' => API_OUTPUT_EXTEND,
-	'selectGraphItems' => array('itemid', 'calc_fnc', 'color', 'type'),
-	'selectHosts' => array('name'),
+	'selectGraphItems' => ['itemid', 'sortorder', 'color', 'calc_fnc', 'type'],
+	'selectHosts' => ['name'],
 	'graphids' => $_REQUEST['graphid']
-));
+]);
 
 if (!$dbGraph) {
 	access_deny();
@@ -65,22 +64,18 @@ else {
 /*
  * Display
  */
-$timeline = CScreenBase::calculateTime(array(
+$timeline = CScreenBase::calculateTime([
 	'profileIdx' => getRequest('profileIdx', 'web.screens'),
 	'profileIdx2' => getRequest('profileIdx2'),
 	'updateProfile' => getRequest('updateProfile', true),
 	'period' => getRequest('period'),
 	'stime' => getRequest('stime')
-));
+]);
 
 $graph = new CPieGraphDraw($dbGraph['graphtype']);
 $graph->setPeriod($timeline['period']);
 $graph->setSTime($timeline['stime']);
 
-if (isset($_REQUEST['border'])) {
-	$graph->setBorder(0);
-}
-
 $width = getRequest('width', 0);
 if ($width <= 0) {
 	$width = $dbGraph['width'];
@@ -95,10 +90,9 @@ $graph->setWidth($width);
 $graph->setHeight($height);
 
 // array sorting
-CArrayHelper::sort($dbGraph['gitems'], array(
-	array('field' => 'sortorder', 'order' => ZBX_SORT_UP),
-	array('field' => 'itemid', 'order' => ZBX_SORT_DOWN)
-));
+CArrayHelper::sort($dbGraph['gitems'], [
+	['field' => 'sortorder', 'order' => ZBX_SORT_UP]
+]);
 
 // get graph items
 foreach ($dbGraph['gitems'] as $gItem) {
