@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2015 Zabbix SIA
+** Copyright (C) 2001-2016 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -25,18 +25,17 @@ require_once dirname(__FILE__).'/include/forms.inc.php';
 
 $page['title'] = _('Host inventory overview');
 $page['file'] = 'hostinventoriesoverview.php';
-$page['hist_arg'] = array('groupid', 'hostid');
 
 require_once dirname(__FILE__).'/include/page_header.php';
 
 //		VAR			TYPE	OPTIONAL FLAGS	VALIDATION	EXCEPTION
-$fields = array(
-	'groupid' =>	array(T_ZBX_INT, O_OPT,	P_SYS,	DB_ID,	null),
-	'groupby' =>	array(T_ZBX_STR, O_OPT,	P_SYS,	null,	null),
+$fields = [
+	'groupid' =>	[T_ZBX_INT, O_OPT,	P_SYS,	DB_ID,	null],
+	'groupby' =>	[T_ZBX_STR, O_OPT,	P_SYS,	null,	null],
 	// sort and sortorder
-	'sort' =>		array(T_ZBX_STR, O_OPT, P_SYS, IN('"host_count","inventory_field"'),		null),
-	'sortorder' =>	array(T_ZBX_STR, O_OPT, P_SYS, IN('"'.ZBX_SORT_DOWN.'","'.ZBX_SORT_UP.'"'),	null)
-);
+	'sort' =>		[T_ZBX_STR, O_OPT, P_SYS, IN('"host_count","inventory_field"'),		null],
+	'sortorder' =>	[T_ZBX_STR, O_OPT, P_SYS, IN('"'.ZBX_SORT_DOWN.'","'.ZBX_SORT_UP.'"'),	null]
+];
 check_fields($fields);
 
 $sortField = getRequest('sort', CProfile::get('web.'.$page['file'].'.sort', 'host_count'));
@@ -48,7 +47,7 @@ CProfile::update('web.'.$page['file'].'.sortorder', $sortOrder, PROFILE_TYPE_STR
 /*
  * Permissions
  */
-if (getRequest('groupid') && !API::HostGroup()->isReadable(array($_REQUEST['groupid']))) {
+if (getRequest('groupid') && !API::HostGroup()->isReadable([$_REQUEST['groupid']])) {
 	access_deny();
 }
 
@@ -57,19 +56,18 @@ if ((PAGE_TYPE_JS == $page['type']) || (PAGE_TYPE_HTML_BLOCK == $page['type']))
 	exit;
 }
 
-$options = array(
-	'groups' => array(
+$options = [
+	'groups' => [
 		'real_hosts' => 1,
-	),
+	],
 	'groupid' => getRequest('groupid'),
-);
+];
 $pageFilter = new CPageFilter($options);
 $_REQUEST['groupid'] = $pageFilter->groupid;
 $_REQUEST['groupby'] = getRequest('groupby', '');
 $groupFieldTitle = '';
 
-$hostinvent_wdgt = new CWidget();
-$hostinvent_wdgt->addPageHeader(_('HOST INVENTORY OVERVIEW'));
+$hostinvent_wdgt = (new CWidget())->setTitle(_('Host inventory overview'));
 
 // getting inventory fields to make a drop down
 $inventoryFields = getHostInventories(true); // 'true' means list should be ordered by title
@@ -86,47 +84,57 @@ foreach($inventoryFields as $inventoryField){
 	}
 }
 
-$r_form = new CForm('get');
-$r_form->addItem(array(_('Group'), SPACE, $pageFilter->getGroupsCB(), SPACE));
-$r_form->addItem(array(_('Grouping by'), SPACE, $inventoryFieldsComboBox));
-$hostinvent_wdgt->addHeader(_('Hosts'), $r_form);
-$hostinvent_wdgt->addItem(BR());
+$controls = (new CList())
+	->addItem([
+		new CLabel(_('Group'), 'groupid'),
+		(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
+		$pageFilter->getGroupsCB()
+	])
+	->addItem([
+		new CLabel(_('Grouping by'), 'groupby'),
+		(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
+		$inventoryFieldsComboBox
+	]);
 
-$table = new CTableInfo(_('No hosts found.'));
-$table->setHeader(
-	array(
-		make_sorting_header($groupFieldTitle === '' ? _('Field') : $groupFieldTitle, 'inventory_field',
-			$sortField, $sortOrder
-		),
-		make_sorting_header(_('Host count'), 'host_count', $sortField, $sortOrder),
-	)
+$hostinvent_wdgt->setControls(
+	(new CForm('get'))->addItem($controls)
 );
 
+$table = (new CTableInfo())
+	->setHeader(
+		[
+			make_sorting_header($groupFieldTitle === '' ? _('Field') : $groupFieldTitle, 'inventory_field',
+				$sortField, $sortOrder
+			),
+			make_sorting_header(_('Host count'), 'host_count', $sortField, $sortOrder),
+		]
+	);
+
 // to show a report, we will need a host group and a field to aggregate
 if($pageFilter->groupsSelected && $groupFieldTitle !== ''){
 
-	$options = array(
-		'output' => array('hostid', 'name'),
-		'selectInventory' => array($_REQUEST['groupby']), // only one field is required
+	$options = [
+		'output' => ['hostid', 'name'],
+		'selectInventory' => [$_REQUEST['groupby']], // only one field is required
 		'withInventory' => true
-	);
+	];
 	if($pageFilter->groupid > 0)
 		$options['groupids'] = $pageFilter->groupid;
 
 	$hosts = API::Host()->get($options);
 
 	// aggregating data by chosen field value
-	$report = array();
+	$report = [];
 	foreach($hosts as $host) {
 		if ($host['inventory'][$_REQUEST['groupby']] !== '') {
 			// same names with different letter casing are considered the same
 			$lowerValue = mb_strtolower($host['inventory'][$_REQUEST['groupby']]);
 
 			if (!isset($report[$lowerValue])) {
-				$report[$lowerValue] = array(
+				$report[$lowerValue] = [
 					'inventory_field' => $host['inventory'][$_REQUEST['groupby']],
 					'host_count' => 1
-				);
+				];
 			}
 			else {
 				$report[$lowerValue]['host_count'] += 1;
@@ -136,12 +144,15 @@ if($pageFilter->groupsSelected && $groupFieldTitle !== ''){
 
 	order_result($report, $sortField, $sortOrder);
 
-	foreach($report as $rep){
-		$row = array(
-			new CSpan(zbx_str2links($rep['inventory_field']), 'pre'),
-			new CLink($rep['host_count'],'hostinventories.php?filter_field='.$_REQUEST['groupby'].'&filter_field_value='.urlencode($rep['inventory_field']).'&filter_set=1&filter_exact=1'.url_param('groupid')),
-		);
-		$table->addRow($row);
+	foreach ($report as $rep) {
+		$table->addRow([
+			zbx_str2links($rep['inventory_field']),
+			new CLink($rep['host_count'],
+				'hostinventories.php?filter_field='.$_REQUEST['groupby'].
+				'&filter_field_value='.urlencode($rep['inventory_field']).
+				'&filter_set=1&filter_exact=1'.url_param('groupid')
+			)
+		]);
 	}
 }
 
