@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2015 Zabbix SIA
+** Copyright (C) 2001-2016 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -26,69 +26,75 @@ require_once dirname(__FILE__).'/include/forms.inc.php';
 
 $page['title'] = _('Configuration of web monitoring');
 $page['file'] = 'httpconf.php';
-$page['hist_arg'] = array('groupid', 'hostid');
+$page['scripts'] = ['class.cviewswitcher.js'];
 
 require_once dirname(__FILE__).'/include/page_header.php';
 
 // VAR	TYPE	OPTIONAL	FLAGS	VALIDATION	EXCEPTION
-$fields = array(
-	'groupid'			=> array(T_ZBX_INT, O_OPT, P_SYS,	DB_ID,				null),
-	'new_httpstep'		=> array(T_ZBX_STR, O_OPT, null,	null,				null),
-	'sel_step'			=> array(T_ZBX_INT, O_OPT, null,	BETWEEN(0, 65534),	null),
-	'group_httptestid'	=> array(T_ZBX_INT, O_OPT, null,	DB_ID,				null),
-	'showdisabled'		=> array(T_ZBX_INT, O_OPT, P_SYS,	IN('0,1'),			null),
+$fields = [
+	'groupid'			=> [T_ZBX_INT, O_OPT, P_SYS,	DB_ID,				null],
+	'new_httpstep'		=> [T_ZBX_STR, O_OPT, null,	null,				null],
+	'sel_step'			=> [T_ZBX_INT, O_OPT, null,	BETWEEN(0, 65534),	null],
+	'group_httptestid'	=> [T_ZBX_INT, O_OPT, null,	DB_ID,				null],
 	// form
-	'hostid'          => array(T_ZBX_INT, O_OPT, P_SYS, DB_ID.NOT_ZERO,          'isset({form}) || isset({add}) || isset({update})'),
-	'applicationid'   => array(T_ZBX_INT, O_OPT, null,  DB_ID,                   null, _('Application')),
-	'httptestid'      => array(T_ZBX_INT, O_NO,  P_SYS, DB_ID,                   'isset({form}) && {form} == "update"'),
-	'name'            => array(T_ZBX_STR, O_OPT, null,  NOT_EMPTY,               'isset({add}) || isset({update})', _('Name')),
-	'delay'           => array(T_ZBX_INT, O_OPT, null,  BETWEEN(1, SEC_PER_DAY), 'isset({add}) || isset({update})', _('Update interval (in sec)')),
-	'retries'         => array(T_ZBX_INT, O_OPT, null,  BETWEEN(1, 10),          'isset({add}) || isset({update})', _('Retries')),
-	'status'          => array(T_ZBX_STR, O_OPT, null,  null,                    null),
-	'agent'           => array(T_ZBX_STR, O_OPT, null,  null,                    'isset({add}) || isset({update})'),
-	'variables'       => array(T_ZBX_STR, O_OPT, null,  null,                    'isset({add}) || isset({update})'),
-	'steps'           => array(T_ZBX_STR, O_OPT, null,  null,                    'isset({add}) || isset({update})', _('Steps')),
-	'authentication'  => array(T_ZBX_INT, O_OPT, null,  IN('0,1,2'),             'isset({add}) || isset({update})'),
-	'http_user'       => array(T_ZBX_STR, O_OPT, null,  NOT_EMPTY,               '(isset({add}) || isset({update})) && isset({authentication}) && ({authentication} == '.HTTPTEST_AUTH_BASIC.
-		' || {authentication} == '.HTTPTEST_AUTH_NTLM.')', _('User')),
-	'http_password'		=> array(T_ZBX_STR, O_OPT, P_NO_TRIM,	NOT_EMPTY,		'(isset({add}) || isset({update})) && isset({authentication}) && ({authentication} == '.HTTPTEST_AUTH_BASIC.
-		' || {authentication} == '.HTTPTEST_AUTH_NTLM.')', _('Password')),
-	'http_proxy'		=> array(T_ZBX_STR, O_OPT, null,	null,				'isset({add}) || isset({update})'),
-	'new_application'	=> array(T_ZBX_STR, O_OPT, null,	null,				null),
-	'hostname'			=> array(T_ZBX_STR, O_OPT, null,	null,				null),
-	'templated'			=> array(T_ZBX_STR, O_OPT, null,	null,				null),
-	'verify_host'		=> array(T_ZBX_STR, O_OPT, null,	null,				null),
-	'verify_peer'		=> array(T_ZBX_STR, O_OPT, null,	null,				null),
-	'headers'			=> array(T_ZBX_STR, O_OPT, null, null,					'isset({add}) || isset({update})'),
-	'ssl_cert_file'		=> array(T_ZBX_STR, O_OPT, null, null,					'isset({add}) || isset({update})'),
-	'ssl_key_file'		=> array(T_ZBX_STR, O_OPT, null, null,					'isset({add}) || isset({update})'),
-	'ssl_key_password'	=> array(T_ZBX_STR, O_OPT, P_NO_TRIM, null,				'isset({add}) || isset({update})'),
+	'hostid'          => [T_ZBX_INT, O_OPT, P_SYS, DB_ID.NOT_ZERO,          'isset({form}) || isset({add}) || isset({update})'],
+	'applicationid'   => [T_ZBX_INT, O_OPT, null,  DB_ID,                   null, _('Application')],
+	'httptestid'      => [T_ZBX_INT, O_NO,  P_SYS, DB_ID,                   'isset({form}) && {form} == "update"'],
+	'name'            => [T_ZBX_STR, O_OPT, null,  NOT_EMPTY,               'isset({add}) || isset({update})', _('Name')],
+	'delay'           => [T_ZBX_INT, O_OPT, null,  BETWEEN(1, SEC_PER_DAY), 'isset({add}) || isset({update})', _('Update interval (in sec)')],
+	'retries'         => [T_ZBX_INT, O_OPT, null,  BETWEEN(1, 10),          'isset({add}) || isset({update})',
+		_('Attempts')
+	],
+	'status'          => [T_ZBX_STR, O_OPT, null,  null,                    null],
+	'agent'           => [T_ZBX_STR, O_OPT, null, null,                     'isset({add}) || isset({update})'],
+	'agent_other'     => [T_ZBX_STR, O_OPT, null, null,
+		'(isset({add}) || isset({update})) && {agent} == '.ZBX_AGENT_OTHER
+	],
+	'variables'       => [T_ZBX_STR, O_OPT, null,  null,                    'isset({add}) || isset({update})'],
+	'steps'           => [T_ZBX_STR, O_OPT, null,  null,                    'isset({add}) || isset({update})', _('Steps')],
+	'authentication'  => [T_ZBX_INT, O_OPT, null,  IN('0,1,2'),             'isset({add}) || isset({update})'],
+	'http_user'       => [T_ZBX_STR, O_OPT, null,  NOT_EMPTY,               '(isset({add}) || isset({update})) && isset({authentication}) && ({authentication} == '.HTTPTEST_AUTH_BASIC.
+		' || {authentication} == '.HTTPTEST_AUTH_NTLM.')', _('User')],
+	'http_password'		=> [T_ZBX_STR, O_OPT, P_NO_TRIM,	NOT_EMPTY,		'(isset({add}) || isset({update})) && isset({authentication}) && ({authentication} == '.HTTPTEST_AUTH_BASIC.
+		' || {authentication} == '.HTTPTEST_AUTH_NTLM.')', _('Password')],
+	'http_proxy'		=> [T_ZBX_STR, O_OPT, null,	null,				'isset({add}) || isset({update})'],
+	'new_application'	=> [T_ZBX_STR, O_OPT, null,	null,				null],
+	'hostname'			=> [T_ZBX_STR, O_OPT, null,	null,				null],
+	'templated'			=> [T_ZBX_STR, O_OPT, null,	null,				null],
+	'verify_host'		=> [T_ZBX_STR, O_OPT, null,	null,				null],
+	'verify_peer'		=> [T_ZBX_STR, O_OPT, null,	null,				null],
+	'headers'			=> [T_ZBX_STR, O_OPT, null, null,					'isset({add}) || isset({update})'],
+	'ssl_cert_file'		=> [T_ZBX_STR, O_OPT, null, null,					'isset({add}) || isset({update})'],
+	'ssl_key_file'		=> [T_ZBX_STR, O_OPT, null, null,					'isset({add}) || isset({update})'],
+	'ssl_key_password'	=> [T_ZBX_STR, O_OPT, P_NO_TRIM, null,				'isset({add}) || isset({update})'],
+	// filter
+	'filter_set' =>			[T_ZBX_STR, O_OPT, P_SYS,	null,		null],
+	'filter_rst' =>			[T_ZBX_STR, O_OPT, P_SYS,	null,		null],
+	'filter_status' =>		[T_ZBX_INT, O_OPT, null,
+		IN([-1, HTTPTEST_STATUS_ACTIVE, HTTPTEST_STATUS_DISABLED]), null
+	],
 	// actions
-	'action'			=> array(T_ZBX_STR, O_OPT, P_SYS|P_ACT,
+	'action'			=> [T_ZBX_STR, O_OPT, P_SYS|P_ACT,
 								IN('"httptest.massclearhistory","httptest.massdelete","httptest.massdisable",'.
 									'"httptest.massenable"'
 								),
 								null
-							),
-	'clone'				=> array(T_ZBX_STR, O_OPT, P_SYS|P_ACT, null,			null),
-	'del_history'		=> array(T_ZBX_STR, O_OPT, P_SYS|P_ACT, null,			null),
-	'add'				=> array(T_ZBX_STR, O_OPT, P_SYS|P_ACT, null,			null),
-	'update'			=> array(T_ZBX_STR, O_OPT, P_SYS|P_ACT, null,			null),
-	'delete'			=> array(T_ZBX_STR, O_OPT, P_SYS|P_ACT, null,			null),
-	'cancel'			=> array(T_ZBX_STR, O_OPT, P_SYS,	null,				null),
-	'form'				=> array(T_ZBX_STR, O_OPT, P_SYS,	null,				null),
-	'form_refresh'		=> array(T_ZBX_INT, O_OPT, null,	null,				null),
+							],
+	'clone'				=> [T_ZBX_STR, O_OPT, P_SYS|P_ACT, null,			null],
+	'del_history'		=> [T_ZBX_STR, O_OPT, P_SYS|P_ACT, null,			null],
+	'add'				=> [T_ZBX_STR, O_OPT, P_SYS|P_ACT, null,			null],
+	'update'			=> [T_ZBX_STR, O_OPT, P_SYS|P_ACT, null,			null],
+	'delete'			=> [T_ZBX_STR, O_OPT, P_SYS|P_ACT, null,			null],
+	'cancel'			=> [T_ZBX_STR, O_OPT, P_SYS,	null,				null],
+	'form'				=> [T_ZBX_STR, O_OPT, P_SYS,	null,				null],
+	'form_refresh'		=> [T_ZBX_INT, O_OPT, null,	null,				null],
 	// sort and sortorder
-	'sort'				=> array(T_ZBX_STR, O_OPT, P_SYS, IN('"hostname","name","status"'),				null),
-	'sortorder'			=> array(T_ZBX_STR, O_OPT, P_SYS, IN('"'.ZBX_SORT_DOWN.'","'.ZBX_SORT_UP.'"'),	null)
-);
-$_REQUEST['showdisabled'] = getRequest('showdisabled', CProfile::get('web.httpconf.showdisabled', 1));
+	'sort'				=> [T_ZBX_STR, O_OPT, P_SYS, IN('"hostname","name","status"'),				null],
+	'sortorder'			=> [T_ZBX_STR, O_OPT, P_SYS, IN('"'.ZBX_SORT_DOWN.'","'.ZBX_SORT_UP.'"'),	null]
+];
 
 check_fields($fields);
 
-$showDisabled = getRequest('showdisabled', 1);
-CProfile::update('web.httpconf.showdisabled', $showDisabled, PROFILE_TYPE_INT);
-
 if (!empty($_REQUEST['steps'])) {
 	order_result($_REQUEST['steps'], 'no');
 }
@@ -98,7 +104,7 @@ if (!empty($_REQUEST['steps'])) {
  */
 //*
 if (isset($_REQUEST['httptestid']) || !empty($_REQUEST['group_httptestid'])) {
-	$testIds = array();
+	$testIds = [];
 	if (isset($_REQUEST['httptestid'])) {
 		$testIds[] = $_REQUEST['httptestid'];
 	}
@@ -109,13 +115,22 @@ if (isset($_REQUEST['httptestid']) || !empty($_REQUEST['group_httptestid'])) {
 		access_deny();
 	}
 }
+$hostId = getRequest('hostid');
+if ($hostId && !API::Host()->isWritable([$hostId])) {
+	access_deny();
+}
+
+$groupId = getRequest('groupid');
+if ($groupId && !API::HostGroup()->get(['groupids' => $groupId])) {
+	access_deny();
+}
 
 /*
  * Actions
  */
 // add new steps
 if (isset($_REQUEST['new_httpstep'])) {
-	$_REQUEST['steps'] = getRequest('steps', array());
+	$_REQUEST['steps'] = getRequest('steps', []);
 	$_REQUEST['new_httpstep']['no'] = count($_REQUEST['steps']) + 1;
 	array_push($_REQUEST['steps'], $_REQUEST['new_httpstep']);
 
@@ -125,7 +140,7 @@ if (isset($_REQUEST['new_httpstep'])) {
 if (hasRequest('delete') && hasRequest('httptestid')) {
 	DBstart();
 
-	$result = API::HttpTest()->delete(array(getRequest('httptestid')));
+	$result = API::HttpTest()->delete([getRequest('httptestid')]);
 
 	$result = DBend($result);
 
@@ -147,17 +162,17 @@ elseif (hasRequest('del_history') && hasRequest('httptestid')) {
 
 	$httpTestId = getRequest('httptestid');
 
-	$httpTests = API::HttpTest()->get(array(
-		'output' => array('name'),
-		'httptestids' => array($httpTestId),
-		'selectHosts' => array('name'),
+	$httpTests = API::HttpTest()->get([
+		'output' => ['name'],
+		'httptestids' => [$httpTestId],
+		'selectHosts' => ['name'],
 		'editable' => true
-	));
+	]);
 
 	if ($httpTests) {
 		DBstart();
 
-		$result = deleteHistoryByHttpTestIds(array($httpTestId));
+		$result = deleteHistoryByHttpTestIds([$httpTestId]);
 		$result = ($result && DBexecute('UPDATE httptest SET nextcheck=0 WHERE httptestid='.zbx_dbstr($httpTestId)));
 
 		if ($result) {
@@ -165,7 +180,8 @@ elseif (hasRequest('del_history') && hasRequest('httptestid')) {
 			$host = reset($httpTest['hosts']);
 
 			add_audit(AUDIT_ACTION_UPDATE, AUDIT_RESOURCE_SCENARIO,
-				'Scenario ['.$httpTest['name'].'] ['.$httpTestId.'] Host ['.$host['name'].'] history cleared'
+				_('Web scenario').' ['.$httpTest['name'].'] ['.$httpTestId.'] '.
+					_('Host').' ['.$host['name'].'] '._('History cleared')
 			);
 		}
 
@@ -175,26 +191,27 @@ elseif (hasRequest('del_history') && hasRequest('httptestid')) {
 	show_messages($result, _('History cleared'), _('Cannot clear history'));
 }
 elseif (hasRequest('add') || hasRequest('update')) {
-
 	if (hasRequest('update')) {
 		$action = AUDIT_ACTION_UPDATE;
-		$messageTrue = _('Scenario updated');
+		$messageTrue = _('Web scenario updated');
 		$messageFalse = _('Cannot update web scenario');
 	}
 	else {
 		$action = AUDIT_ACTION_ADD;
-		$messageTrue = _('Scenario added');
+		$messageTrue = _('Web scenario added');
 		$messageFalse = _('Cannot add web scenario');
 	}
 
 	try {
 		DBstart();
 
-		if (!empty($_REQUEST['applicationid']) && !empty($_REQUEST['new_application'])) {
+		$new_application = getRequest('new_application');
+
+		if (!empty($_REQUEST['applicationid']) && $new_application) {
 			throw new Exception(_('Cannot create new application, web scenario is already assigned to application.'));
 		}
 
-		$steps = getRequest('steps', array());
+		$steps = getRequest('steps', []);
 		if (!empty($steps)) {
 			$i = 1;
 			foreach ($steps as $stepNumber => &$step) {
@@ -209,7 +226,7 @@ elseif (hasRequest('add') || hasRequest('update')) {
 			unset($step);
 		}
 
-		$httpTest = array(
+		$httpTest = [
 			'hostid' => $_REQUEST['hostid'],
 			'name' => $_REQUEST['name'],
 			'authentication' => $_REQUEST['authentication'],
@@ -217,7 +234,7 @@ elseif (hasRequest('add') || hasRequest('update')) {
 			'delay' => $_REQUEST['delay'],
 			'retries' => $_REQUEST['retries'],
 			'status' => isset($_REQUEST['status']) ? 0 : 1,
-			'agent' => $_REQUEST['agent'],
+			'agent' => hasRequest('agent_other') ? getRequest('agent_other') : getRequest('agent'),
 			'variables' => $_REQUEST['variables'],
 			'http_proxy' => $_REQUEST['http_proxy'],
 			'steps' => $steps,
@@ -227,27 +244,37 @@ elseif (hasRequest('add') || hasRequest('update')) {
 			'ssl_key_file' => getRequest('ssl_key_file'),
 			'ssl_key_password' => getRequest('ssl_key_password'),
 			'headers' => getRequest('headers')
-		);
+		];
 
-		if (!empty($_REQUEST['new_application'])) {
-			$exApp = API::Application()->get(array(
-				'output' => array('applicationid'),
+		if ($new_application) {
+			$exApp = API::Application()->get([
+				'output' => ['applicationid', 'flags'],
 				'hostids' => $_REQUEST['hostid'],
-				'filter' => array('name' => $_REQUEST['new_application'])
-			));
+				'filter' => ['name' => $new_application]
+			]);
+
+			/*
+			 * If application exists and it is a discovered application, prevent adding it to web scenario. If it is
+			 * a normal application, assign it to web scenario. Otherwise create new application.
+			 */
 			if ($exApp) {
-				$httpTest['applicationid'] = $exApp[0]['applicationid'];
+				if ($exApp[0]['flags'] == ZBX_FLAG_DISCOVERY_CREATED) {
+					throw new Exception(_s('Application "%1$s" already exists.', $new_application));
+				}
+				else {
+					$httpTest['applicationid'] = $exApp[0]['applicationid'];
+				}
 			}
 			else {
-				$result = API::Application()->create(array(
-					'name' => $_REQUEST['new_application'],
+				$result = API::Application()->create([
+					'name' => $new_application,
 					'hostid' => $_REQUEST['hostid']
-				));
+				]);
 				if ($result) {
 					$httpTest['applicationid'] = reset($result['applicationids']);
 				}
 				else {
-					throw new Exception(_s('Cannot add new application "%1$s".', $_REQUEST['new_application']));
+					throw new Exception(_s('Cannot add new application "%1$s".', $new_application));
 				}
 			}
 		}
@@ -263,18 +290,18 @@ elseif (hasRequest('add') || hasRequest('update')) {
 
 		if (isset($_REQUEST['httptestid'])) {
 			// unset fields that did not change
-			$dbHttpTest = API::HttpTest()->get(array(
+			$dbHttpTest = API::HttpTest()->get([
 				'httptestids' => $_REQUEST['httptestid'],
 				'output' => API_OUTPUT_EXTEND,
 				'selectSteps' => API_OUTPUT_EXTEND
-			));
+			]);
 			$dbHttpTest = reset($dbHttpTest);
 			$dbHttpSteps = zbx_toHash($dbHttpTest['steps'], 'httpstepid');
 
-			$httpTest = CArrayHelper::unsetEqualValues($httpTest, $dbHttpTest, array('applicationid'));
+			$httpTest = CArrayHelper::unsetEqualValues($httpTest, $dbHttpTest, ['applicationid']);
 			foreach ($httpTest['steps'] as $snum => $step) {
 				if (isset($step['httpstepid']) && isset($dbHttpSteps[$step['httpstepid']])) {
-					$newStep = CArrayHelper::unsetEqualValues($step, $dbHttpSteps[$step['httpstepid']], array('httpstepid'));
+					$newStep = CArrayHelper::unsetEqualValues($step, $dbHttpSteps[$step['httpstepid']], ['httpstepid']);
 					$httpTest['steps'][$snum] = $newStep;
 				}
 			}
@@ -301,7 +328,7 @@ elseif (hasRequest('add') || hasRequest('update')) {
 
 		$host = get_host_by_hostid($_REQUEST['hostid']);
 		add_audit($action, AUDIT_RESOURCE_SCENARIO,
-			'Scenario ['.getRequest('name').'] ['.$httpTestId.'] Host ['.$host['name'].']'
+			_('Web scenario').' ['.getRequest('name').'] ['.$httpTestId.'] '._('Host').' ['.$host['name'].']'
 		);
 
 		unset($_REQUEST['form']);
@@ -318,7 +345,7 @@ elseif (hasRequest('add') || hasRequest('update')) {
 		show_messages(false, null, $messageFalse);
 	}
 }
-elseif (hasRequest('action') && str_in_array(getRequest('action'), array('httptest.massenable', 'httptest.massdisable'))
+elseif (hasRequest('action') && str_in_array(getRequest('action'), ['httptest.massenable', 'httptest.massdisable'])
 		&& hasRequest('group_httptestid') && is_array(getRequest('group_httptestid'))) {
 	$result = true;
 	$httpTestIds = getRequest('group_httptestid');
@@ -328,25 +355,25 @@ elseif (hasRequest('action') && str_in_array(getRequest('action'), array('httpte
 	$auditAction = $enable ? AUDIT_ACTION_ENABLE : AUDIT_ACTION_DISABLE;
 	$updated = 0;
 
-	$httpTests = API::HttpTest()->get(array(
-		'output' => array('httptestid', 'name', 'status'),
-		'selectHosts' => array('name'),
+	$httpTests = API::HttpTest()->get([
+		'output' => ['httptestid', 'name', 'status'],
+		'selectHosts' => ['name'],
 		'httptestids' => $httpTestIds,
 		'editable' => true
-	));
+	]);
 
 	if ($httpTests) {
-		$httpTestsToUpdate = array();
+		$httpTestsToUpdate = [];
 
 		DBstart();
 
 		foreach ($httpTests as $httpTest) {
 			// change status if it's necessary
 			if ($httpTest['status'] != $status) {
-				$httpTestsToUpdate[] = array(
+				$httpTestsToUpdate[] = [
 					'httptestid' => $httpTest['httptestid'],
 					'status' => $status
-				);
+				];
 			}
 		}
 
@@ -358,8 +385,8 @@ elseif (hasRequest('action') && str_in_array(getRequest('action'), array('httpte
 					$host = reset($httpTest['hosts']);
 
 					add_audit($auditAction, AUDIT_RESOURCE_SCENARIO,
-						'Scenario ['.$httpTest['name'].'] ['.$httpTest['httptestid'].'] '.
-							'Host ['.$host['name'].'] '.$statusName
+						_('Web scenario').' ['.$httpTest['name'].'] ['.$httpTest['httptestid'].'] '.
+							_('Host').' ['.$host['name'].'] '.$statusName
 					);
 				}
 			}
@@ -389,12 +416,12 @@ elseif (hasRequest('action') && getRequest('action') === 'httptest.massclearhist
 
 	$httpTestIds = getRequest('group_httptestid');
 
-	$httpTests = API::HttpTest()->get(array(
-		'output' => array('httptestid', 'name'),
+	$httpTests = API::HttpTest()->get([
+		'output' => ['httptestid', 'name'],
 		'httptestids' => $httpTestIds,
-		'selectHosts' => array('name'),
+		'selectHosts' => ['name'],
 		'editable' => true
-	));
+	]);
 
 	if ($httpTests) {
 		DBstart();
@@ -409,8 +436,8 @@ elseif (hasRequest('action') && getRequest('action') === 'httptest.massclearhist
 				$host = reset($httpTest['hosts']);
 
 				add_audit(AUDIT_ACTION_UPDATE, AUDIT_RESOURCE_SCENARIO,
-					'Scenario ['.$httpTest['name'].'] ['.$httpTest['httptestid'].'] '.
-						'Host ['.$host['name'].'] history cleared'
+					_('Web scenario').' ['.$httpTest['name'].'] ['.$httpTest['httptestid'].'] '.
+						_('Host').' ['.$host['name'].'] '._('History cleared')
 				);
 			}
 		}
@@ -440,19 +467,19 @@ show_messages();
  * Display
  */
 if (isset($_REQUEST['form'])) {
-	$data = array(
+	$data = [
 		'hostid' => getRequest('hostid', 0),
 		'httptestid' => getRequest('httptestid'),
 		'form' => getRequest('form'),
 		'form_refresh' => getRequest('form_refresh'),
-		'templates' => array()
-	);
+		'templates' => []
+	];
 
-	$host = API::Host()->get(array(
-		'output' => array('status'),
+	$host = API::Host()->get([
+		'output' => ['status'],
 		'hostids' => $data['hostid'],
 		'templated_hosts' => true
-	));
+	]);
 	$data['host'] = reset($host);
 
 	if (isset($data['httptestid'])) {
@@ -460,7 +487,7 @@ if (isset($_REQUEST['form'])) {
 		$httpTestId = $data['httptestid'];
 		while ($httpTestId) {
 			$dbTest = DBfetch(DBselect(
-				'SELECT h.hostid,h.name,h.status,ht.httptestid,ht.templateid'.
+				'SELECT h.hostid,h.name,ht.httptestid,ht.templateid'.
 					' FROM hosts h,httptest ht'.
 					' WHERE ht.hostid=h.hostid'.
 					' AND ht.httptestid='.zbx_dbstr($httpTestId)
@@ -469,10 +496,8 @@ if (isset($_REQUEST['form'])) {
 
 			if (!empty($dbTest)) {
 				if (!idcmp($data['httptestid'], $dbTest['httptestid'])) {
-					$data['templates'][] = new CLink(
-						$dbTest['name'],
-						'httpconf.php?form=update&httptestid='.$dbTest['httptestid'].'&hostid='.$dbTest['hostid'],
-						'highlight underline weight_normal'
+					$data['templates'][] = new CLink($dbTest['name'],
+						'httpconf.php?form=update&httptestid='.$dbTest['httptestid'].'&hostid='.$dbTest['hostid']
 					);
 					$data['templates'][] = SPACE.'&rArr;'.SPACE;
 				}
@@ -496,7 +521,18 @@ if (isset($_REQUEST['form'])) {
 		$data['delay'] = $dbHttpTest['delay'];
 		$data['retries'] = $dbHttpTest['retries'];
 		$data['status'] = $dbHttpTest['status'];
-		$data['agent'] = $dbHttpTest['agent'];
+
+		$data['agent'] = ZBX_AGENT_OTHER;
+		$data['agent_other'] = $dbHttpTest['agent'];
+
+		foreach (userAgents() as $userAgents) {
+			if (array_key_exists($dbHttpTest['agent'], $userAgents)) {
+				$data['agent'] = $dbHttpTest['agent'];
+				$data['agent_other'] = '';
+				break;
+			}
+		}
+
 		$data['variables'] = $dbHttpTest['variables'];
 		$data['authentication'] = $dbHttpTest['authentication'];
 		$data['http_user'] = $dbHttpTest['http_user'];
@@ -524,14 +560,27 @@ if (isset($_REQUEST['form'])) {
 		$data['new_application'] = getRequest('new_application', '');
 		$data['delay'] = getRequest('delay', 60);
 		$data['retries'] = getRequest('retries', 1);
-		$data['agent'] = getRequest('agent', '');
-		$data['variables'] = getRequest('variables', array());
+
+		$data['agent'] = getRequest('agent', ZBX_DEFAULT_AGENT);
+		$data['agent_other'] = getRequest('agent_other');
+
+		if ($data['agent'] == ZBX_AGENT_OTHER) {
+			foreach (userAgents() as $userAgents) {
+				if (array_key_exists($data['agent_other'], $userAgents)) {
+					$data['agent'] = $data['agent_other'];
+					$data['agent_other'] = '';
+					break;
+				}
+			}
+		}
+
+		$data['variables'] = getRequest('variables', []);
 		$data['authentication'] = getRequest('authentication', HTTPTEST_AUTH_NONE);
 		$data['http_user'] = getRequest('http_user', '');
 		$data['http_password'] = getRequest('http_password', '');
 		$data['http_proxy'] = getRequest('http_proxy', '');
 		$data['templated'] = (bool) getRequest('templated');
-		$data['steps'] = getRequest('steps', array());
+		$data['steps'] = getRequest('steps', []);
 		$data['headers'] = getRequest('headers');
 		$data['verify_peer'] = getRequest('verify_peer');
 		$data['verify_host'] = getRequest('verify_host');
@@ -540,9 +589,14 @@ if (isset($_REQUEST['form'])) {
 		$data['ssl_key_password'] = getRequest('ssl_key_password');
 	}
 
-	$data['application_list'] = array();
+	$data['application_list'] = [];
 	if (!empty($data['hostid'])) {
-		$dbApps = DBselect('SELECT a.applicationid,a.name FROM applications a WHERE a.hostid='.zbx_dbstr($data['hostid']));
+		$dbApps = DBselect(
+			'SELECT a.applicationid,a.name'.
+			' FROM applications a'.
+			' WHERE a.hostid='.zbx_dbstr($data['hostid']).
+				' AND a.flags='.ZBX_FLAG_DISCOVERY_NORMAL
+		);
 		while ($dbApp = DBfetch($dbApps)) {
 			$data['application_list'][$dbApp['applicationid']] = $dbApp['name'];
 		}
@@ -560,48 +614,57 @@ else {
 	CProfile::update('web.'.$page['file'].'.sort', $sortField, PROFILE_TYPE_STR);
 	CProfile::update('web.'.$page['file'].'.sortorder', $sortOrder, PROFILE_TYPE_STR);
 
-	$pageFilter = new CPageFilter(array(
-		'groups' => array(
+	if (hasRequest('filter_set')) {
+		CProfile::update('web.httpconf.filter_status', getRequest('filter_status', -1), PROFILE_TYPE_INT);
+	}
+	elseif (hasRequest('filter_rst')) {
+		CProfile::delete('web.httpconf.filter_status');
+	}
+
+	$pageFilter = new CPageFilter([
+		'groups' => [
 			'editable' => true
-		),
-		'hosts' => array(
+		],
+		'hosts' => [
 			'editable' => true,
 			'templated_hosts' => true
-		),
+		],
 		'hostid' => getRequest('hostid'),
 		'groupid' => getRequest('groupid')
-	));
+	]);
 
-	$data = array(
+	$data = [
 		'hostid' => $pageFilter->hostid,
 		'pageFilter' => $pageFilter,
-		'showDisabled' => $showDisabled,
-		'httpTests' => array(),
-		'httpTestsLastData' => array(),
+		'filter_status' => CProfile::get('web.httpconf.filter_status', -1),
+		'httpTests' => [],
+		'httpTestsLastData' => [],
 		'paging' => null,
 		'sort' => $sortField,
 		'sortorder' => $sortOrder
-	);
+	];
 
 	// show the error column only for hosts
 	if (getRequest('hostid') != 0) {
-		$data['showInfoColumn'] = (bool) API::Host()->get(array(
+		$data['showInfoColumn'] = (bool) API::Host()->get([
 			'hostids' => getRequest('hostid'),
-			'output' => array('status')
-		));
+			'output' => ['status']
+		]);
 	}
 	else {
 		$data['showInfoColumn'] = true;
 	}
 
 	if ($data['pageFilter']->hostsSelected) {
-		$options = array(
+		$config = select_config();
+
+		$options = [
 			'editable' => true,
-			'output' => array('httptestid', $sortField),
+			'output' => ['httptestid', $sortField],
 			'limit' => $config['search_limit'] + 1
-		);
-		if (empty($data['showDisabled'])) {
-			$options['filter']['status'] = HTTPTEST_STATUS_ACTIVE;
+		];
+		if ($data['filter_status'] != -1) {
+			$options['filter']['status'] = $data['filter_status'];
 		}
 		if ($data['pageFilter']->hostid > 0) {
 			$options['hostids'] = $data['pageFilter']->hostid;
@@ -619,14 +682,18 @@ else {
 				' LEFT JOIN applications a ON a.applicationid=ht.applicationid'.
 				' WHERE '.dbConditionInt('ht.httptestid', zbx_objectValues($httpTests, 'httptestid'))
 		);
-		$httpTests = array();
+		$httpTests = [];
 		while ($dbHttpTest = DBfetch($dbHttpTests)) {
 			$httpTests[$dbHttpTest['httptestid']] = $dbHttpTest;
 		}
 
 		order_result($httpTests, $sortField, $sortOrder);
 
-		$data['paging'] = getPagingLine($httpTests, $sortOrder);
+		$url = (new CUrl('httpconf.php'))
+			->setArgument('hostid', $data['hostid'])
+			->setArgument('groupid', $data['pageFilter']->groupid);
+
+		$data['paging'] = getPagingLine($httpTests, $sortOrder, $url);
 
 		if($data['showInfoColumn']) {
 			$httpTestsLastData = Manager::HttpTest()->getLastData(array_keys($httpTests));
@@ -639,7 +706,7 @@ else {
 			unset($lastData);
 		}
 		else {
-			$httpTestsLastData = array();
+			$httpTestsLastData = [];
 		}
 
 		$dbHttpSteps = DBselect(
