@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2015 Zabbix SIA
+** Copyright (C) 2001-2016 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -36,14 +36,14 @@ class CHttpTestManager {
 	 *
 	 * @var array
 	 */
-	protected $changedSteps = array();
+	protected $changedSteps = [];
 
 	/**
 	 * Map of parent http test id to child http test id.
 	 *
 	 * @var array
 	 */
-	protected $httpTestParents = array();
+	protected $httpTestParents = [];
 
 	/**
 	 * Save http test to db.
@@ -67,8 +67,8 @@ class CHttpTestManager {
 	 * @return array
 	 */
 	protected function findChangedStepNames(array $httpTests) {
-		$httpSteps = array();
-		$result = array();
+		$httpSteps = [];
+		$result = [];
 		foreach ($httpTests as $httpTest) {
 			if (isset($httpTest['httptestid']) && isset($httpTest['steps'])) {
 				foreach ($httpTest['steps'] as $step) {
@@ -136,24 +136,27 @@ class CHttpTestManager {
 	 */
 	public function update(array $httpTests) {
 		$httpTestIds = zbx_objectValues($httpTests, 'httptestid');
-		$dbHttpTest = API::HttpTest()->get(array(
+		$dbHttpTest = API::HttpTest()->get([
 			'output' => API_OUTPUT_EXTEND,
 			'httptestids' => $httpTestIds,
 			'selectSteps' => API_OUTPUT_EXTEND,
 			'editable' => true,
 			'preservekeys' => true
-		));
+		]);
 
-		$deleteStepItemIds = array();
+		$deleteStepItemIds = [];
+		$steps_create = [];
+		$steps_update = [];
 
-		foreach ($httpTests as $httpTest) {
-			DB::update('httptest', array(
+		foreach ($httpTests as $key => $httpTest) {
+			DB::update('httptest', [
 				'values' => $httpTest,
-				'where' => array('httptestid' => $httpTest['httptestid'])
-			));
+				'where' => ['httptestid' => $httpTest['httptestid']]
+			]);
 
-			$checkItemsUpdate = $updateFields = array();
-			$itemids = array();
+			$checkItemsUpdate = [];
+			$updateFields = [];
+			$itemids = [];
 			$dbCheckItems = DBselect(
 				'SELECT i.itemid,hi.type'.
 				' FROM items i,httptestitem hi'.
@@ -174,10 +177,10 @@ class CHttpTestManager {
 					$updateFields['delay'] = $httpTest['delay'];
 				}
 				if (!empty($updateFields)) {
-					$checkItemsUpdate[] = array(
+					$checkItemsUpdate[] = [
 						'values' => $updateFields,
-						'where' => array('itemid' => $checkitem['itemid'])
-					);
+						'where' => ['itemid' => $checkitem['itemid']]
+					];
 				}
 			}
 			DB::update('items', $checkItemsUpdate);
@@ -186,19 +189,24 @@ class CHttpTestManager {
 				$this->updateItemsApplications($itemids, $httpTest['applicationid']);
 			}
 
-			// update steps
-			if (isset($httpTest['steps'])) {
-				$stepsCreate = $stepsUpdate = array();
-				$dbSteps = zbx_toHash($dbHttpTest[$httpTest['httptestid']]['steps'], 'httpstepid');
+			if (array_key_exists('steps', $httpTest)) {
+				$db_http_test = $dbHttpTest[$httpTest['httptestid']];
+				$dbSteps = zbx_toHash($db_http_test['steps'], 'httpstepid');
+
 				foreach ($httpTest['steps'] as $webstep) {
 					if (isset($webstep['httpstepid']) && isset($dbSteps[$webstep['httpstepid']])) {
-						$stepsUpdate[] = $webstep;
+						$steps_update[$key][] = $webstep;
 						unset($dbSteps[$webstep['httpstepid']]);
 					}
 					elseif (!isset($webstep['httpstepid'])) {
-						$stepsCreate[] = $webstep;
+						$steps_create[$key][] = $webstep;
+					}
+
+					if ($db_http_test['templateid'] != 0) {
+						unset($dbSteps[$webstep['httpstepid']]);
 					}
 				}
+
 				$stepidsDelete = array_keys($dbSteps);
 
 				if (!empty($stepidsDelete)) {
@@ -210,13 +218,32 @@ class CHttpTestManager {
 						$deleteStepItemIds[] = $itemId;
 					}
 
-					DB::delete('httpstep', array('httpstepid' => $stepidsDelete));
+					DB::delete('httpstep', ['httpstepid' => $stepidsDelete]);
 				}
-				if (!empty($stepsUpdate)) {
-					$this->updateStepsReal($httpTest, $stepsUpdate);
+
+				// IF application ID was not set, use the ID from DB so new items can be linked.
+				if (!array_key_exists('applicationid', $httpTest)) {
+					$httpTest['applicationid'] = $db_http_test['applicationid'];
 				}
-				if (!empty($stepsCreate)) {
-					$this->createStepsReal($httpTest, $stepsCreate);
+				elseif (bccomp($httpTest['applicationid'], $db_http_test['applicationid'])) {
+					unset($httpTest['applicationid']);
+				}
+			}
+		}
+
+		// Old items must be deleted prior to createStepsReal() since identical items cannot be created in DB.
+		if ($deleteStepItemIds) {
+			API::Item()->delete($deleteStepItemIds, true);
+		}
+
+		foreach ($httpTests as $key => $httpTest) {
+			if (array_key_exists('steps', $httpTest)) {
+				if (array_key_exists($key, $steps_update)) {
+					$this->updateStepsReal($httpTest, $steps_update[$key]);
+				}
+
+				if (array_key_exists($key, $steps_create)) {
+					$this->createStepsReal($httpTest, $steps_create[$key]);
 				}
 			}
 			else {
@@ -241,18 +268,14 @@ class CHttpTestManager {
 								' AND hs.httptestid='.zbx_dbstr($httpTest['httptestid'])
 					), 'itemid');
 
-					DB::update('items', array(
-						'values' => array('status' => $status),
-						'where' => array('itemid' => $itemIds)
-					));
+					DB::update('items', [
+						'values' => ['status' => $status],
+						'where' => ['itemid' => $itemIds]
+					]);
 				}
 			}
 		}
 
-		if ($deleteStepItemIds) {
-			API::Item()->delete($deleteStepItemIds, true);
-		}
-
 		// TODO: REMOVE info
 		$dbCursor = DBselect(
 			'SELECT ht.name,h.name AS hostname'.
@@ -276,7 +299,7 @@ class CHttpTestManager {
 	public function link($templateId, $hostIds) {
 		$hostIds = zbx_toArray($hostIds);
 
-		$httpTests = array();
+		$httpTests = [];
 		$dbCursor = DBselect(
 			'SELECT ht.httptestid,ht.name,ht.applicationid,ht.delay,ht.status,ht.variables,ht.agent,'.
 				'ht.authentication,ht.http_user,ht.http_password,ht.http_proxy,ht.retries,ht.hostid,ht.templateid,'.
@@ -311,7 +334,7 @@ class CHttpTestManager {
 	 *
 	 * @return bool
 	 */
-	public function inherit(array $httpTests, array $hostIds = array()) {
+	public function inherit(array $httpTests, array $hostIds = []) {
 		$hostsTemplatesMap = $this->getChildHostsFromHttpTests($httpTests, $hostIds);
 		if (empty($hostsTemplatesMap)) {
 			return true;
@@ -334,8 +357,8 @@ class CHttpTestManager {
 	 *
 	 * @return array
 	 */
-	protected function getChildHostsFromHttpTests(array $httpTests, array $hostIds = array()) {
-		$hostsTemplatesMap = array();
+	protected function getChildHostsFromHttpTests(array $httpTests, array $hostIds = []) {
+		$hostsTemplatesMap = [];
 
 		$sqlWhere = $hostIds ? ' AND '.dbConditionInt('ht.hostid', $hostIds) : '';
 		$dbCursor = DBselect(
@@ -364,7 +387,7 @@ class CHttpTestManager {
 	protected function prepareInheritedHttpTests(array $httpTests, array $hostsTemplatesMap) {
 		$hostHttpTests = $this->getHttpTestsMapsByHostIds(array_keys($hostsTemplatesMap));
 
-		$result = array();
+		$result = [];
 		foreach ($httpTests as $httpTest) {
 			$httpTestId = $httpTest['httptestid'];
 			foreach ($hostHttpTests as $hostId => $hostHttpTest) {
@@ -432,10 +455,10 @@ class CHttpTestManager {
 	 * @param $childId
 	 */
 	protected function createLinkageBetweenHttpTests($parentId, $childId) {
-		DB::update('httptest', array(
-			'values' => array('templateid' => $parentId),
-			'where' => array('httptestid' => $childId)
-		));
+		DB::update('httptest', [
+			'values' => ['templateid' => $parentId],
+			'where' => ['httptestid' => $childId]
+		]);
 
 		$dbCursor = DBselect(
 			'SELECT i1.itemid AS parentid,i2.itemid AS childid'.
@@ -447,10 +470,10 @@ class CHttpTestManager {
 				' AND i1.key_=i2.key_'
 		);
 		while ($dbItems = DBfetch($dbCursor)) {
-			DB::update('items', array(
-				'values' => array('templateid' => $dbItems['parentid']),
-				'where' => array('itemid' => $dbItems['childid'])
-			));
+			DB::update('items', [
+				'values' => ['templateid' => $dbItems['parentid']],
+				'where' => ['itemid' => $dbItems['childid']]
+			]);
 		}
 
 		$dbCursor = DBselect(
@@ -465,10 +488,10 @@ class CHttpTestManager {
 				' AND i1.key_=i2.key_'
 		);
 		while ($dbItems = DBfetch($dbCursor)) {
-			DB::update('items', array(
-				'values' => array('templateid' => $dbItems['parentid']),
-				'where' => array('itemid' => $dbItems['childid'])
-			));
+			DB::update('items', [
+				'values' => ['templateid' => $dbItems['parentid']],
+				'where' => ['itemid' => $dbItems['childid']]
+			]);
 		}
 	}
 
@@ -522,9 +545,9 @@ class CHttpTestManager {
 	 * @return array
 	 */
 	protected function getHttpTestsMapsByHostIds(array $hostIds) {
-		$hostHttpTests = array();
+		$hostHttpTests = [];
 		foreach ($hostIds as $hostid) {
-			$hostHttpTests[$hostid] = array('byName' => array(), 'byTemplateId' => array());
+			$hostHttpTests[$hostid] = ['byName' => [], 'byTemplateId' => []];
 		}
 
 		$dbCursor = DBselect(
@@ -554,7 +577,7 @@ class CHttpTestManager {
 		$firstHash = '';
 		$secondHash = '';
 
-		CArrayHelper::sort($httpTest['steps'], array('no'));
+		CArrayHelper::sort($httpTest['steps'], ['no']);
 		foreach ($httpTest['steps'] as $step) {
 			$firstHash .= $step['no'].$step['name'];
 		}
@@ -565,7 +588,7 @@ class CHttpTestManager {
 			' WHERE hs.httptestid='.zbx_dbstr($exHttpTest['httptestid'])
 		));
 
-		CArrayHelper::sort($dbHttpTestSteps, array('no'));
+		CArrayHelper::sort($dbHttpTestSteps, ['no']);
 		foreach ($dbHttpTestSteps as $dbHttpStep) {
 			$secondHash .= $dbHttpStep['no'].$dbHttpStep['name'];
 		}
@@ -581,8 +604,8 @@ class CHttpTestManager {
 	 * @return array
 	 */
 	protected function save(array $httpTests) {
-		$httpTestsCreate = array();
-		$httpTestsUpdate = array();
+		$httpTestsCreate = [];
+		$httpTestsUpdate = [];
 
 		foreach ($httpTests as $httpTest) {
 			if (isset($httpTest['httptestid'])) {
@@ -594,7 +617,7 @@ class CHttpTestManager {
 		}
 
 		if (!empty($httpTestsCreate)) {
-			$newHttpTests = $this->create($httpTestsCreate, true);
+			$newHttpTests = $this->create($httpTestsCreate);
 			foreach ($newHttpTests as $num => $newHttpTest) {
 				$httpTests[$num]['httptestid'] = $newHttpTest['httptestid'];
 			}
@@ -613,7 +636,7 @@ class CHttpTestManager {
 	 * @return array
 	 */
 	protected function prepareHttpSteps(array $steps, $exHttpTestId) {
-		$exSteps = array();
+		$exSteps = [];
 		$dbCursor = DBselect(
 			'SELECT hs.httpstepid,hs.name'.
 			' FROM httpstep hs'.
@@ -623,7 +646,7 @@ class CHttpTestManager {
 			$exSteps[$dbHttpStep['name']] = $dbHttpStep['httpstepid'];
 		}
 
-		$result = array();
+		$result = [];
 		foreach ($steps as $step) {
 			$parentTestId = $this->httpTestParents[$exHttpTestId];
 			if (isset($this->changedSteps[$parentTestId][$step['name']])) {
@@ -652,32 +675,32 @@ class CHttpTestManager {
 	 * @throws Exception
 	 */
 	protected function createHttpTestItems(array $httpTest) {
-		$checkitems = array(
-			array(
+		$checkitems = [
+			[
 				'name'				=> 'Download speed for scenario "$1".',
 				'key_'				=> $this->getTestKey(HTTPSTEP_ITEM_TYPE_IN, $httpTest['name']),
 				'value_type'		=> ITEM_VALUE_TYPE_FLOAT,
 				'units'				=> 'Bps',
 				'httptestitemtype'	=> HTTPSTEP_ITEM_TYPE_IN
-			),
-			array(
+			],
+			[
 				'name'				=> 'Failed step of scenario "$1".',
 				'key_'				=> $this->getTestKey(HTTPSTEP_ITEM_TYPE_LASTSTEP, $httpTest['name']),
 				'value_type'		=> ITEM_VALUE_TYPE_UINT64,
 				'units'				=> '',
 				'httptestitemtype'	=> HTTPSTEP_ITEM_TYPE_LASTSTEP
-			),
-			array(
+			],
+			[
 				'name'				=> 'Last error message of scenario "$1".',
 				'key_'				=> $this->getTestKey(HTTPSTEP_ITEM_TYPE_LASTERROR, $httpTest['name']),
 				'value_type'		=> ITEM_VALUE_TYPE_STR,
 				'units'				=> '',
 				'httptestitemtype'	=> HTTPSTEP_ITEM_TYPE_LASTERROR
-			)
-		);
+			]
+		];
 
 		// if this is a template scenario, fetch the parent http items to link inherited items to them
-		$parentItems = array();
+		$parentItems = [];
 		if (isset($httpTest['templateid']) && $httpTest['templateid']) {
 			$parentItems = DBfetchArrayAssoc(DBselect(
 				'SELECT i.itemid,i.key_'.
@@ -687,70 +710,39 @@ class CHttpTestManager {
 			), 'key_');
 		}
 
-		$insertItems = array();
-		$updateItems = array();
-		$testItemIds = array();
-		foreach ($checkitems as $item) {
-			$dbItem = DBfetch(DBselect(
-				'SELECT i.itemid,i.templateid'.
-				' FROM items i'.
-				' WHERE i.key_='.zbx_dbstr($item['key_']).
-					' AND i.hostid='.zbx_dbstr($httpTest['hostid'])
-			));
+		$insertItems = [];
 
+		foreach ($checkitems as $item) {
 			$item['data_type'] = ITEM_DATA_TYPE_DECIMAL;
 			$item['hostid'] = $httpTest['hostid'];
 			$item['delay'] = $httpTest['delay'];
 			$item['type'] = ITEM_TYPE_HTTPTEST;
 			$item['history'] = self::ITEM_HISTORY;
 			$item['trends'] = self::ITEM_TRENDS;
-			$item['status'] = (HTTPTEST_STATUS_ACTIVE == $httpTest['status']) ? ITEM_STATUS_ACTIVE : ITEM_STATUS_DISABLED;
+			$item['status'] = (HTTPTEST_STATUS_ACTIVE == $httpTest['status'])
+				? ITEM_STATUS_ACTIVE
+				: ITEM_STATUS_DISABLED;
 
 			if (isset($parentItems[$item['key_']])) {
 				$item['templateid'] = $parentItems[$item['key_']]['itemid'];
 			}
 
-			if ($dbItem) {
-				if (!empty($dbItem['templateid'])) {
-					throw new Exception(_s('Item with key "%1$s" already exists.', $item['key_']));
-				}
-				$testItemIds[] = $dbItem['itemid'];
-				$updateItems[] = array('values' => $item, 'where' => array('itemid' => $dbItem['itemid']));
-			}
-			else {
-				$insertItems[] = $item;
-			}
+			$insertItems[] = $item;
 		}
 
-		if (!empty($insertItems)) {
-			$newTestItemIds = DB::insert('items', $insertItems);
-			$testItemIds = array_merge($testItemIds, $newTestItemIds);
-		}
-		if (!empty($updateItems)) {
-			DB::update('items', $updateItems);
+		$newTestItemIds = DB::insert('items', $insertItems);
+
+		if (array_key_exists('applicationid', $httpTest)) {
+			$this->createItemsApplications($newTestItemIds, $httpTest['applicationid']);
 		}
 
-		$itemApplications = array();
-		foreach ($testItemIds as $itemid) {
-			if (!empty($httpTest['applicationid'])) {
-				$itemApplications[] = array(
-					'applicationid' => $httpTest['applicationid'],
-					'itemid' => $itemid
-				);
-			}
-		}
-		if (!empty($itemApplications)) {
-			DB::insert('items_applications', $itemApplications);
-		}
-
-
-		$httpTestItems = array();
+		$httpTestItems = [];
 		foreach ($checkitems as $inum => $item) {
-			$httpTestItems[] = array(
+			$httpTestItems[] = [
 				'httptestid' => $httpTest['httptestid'],
-				'itemid' => $testItemIds[$inum],
+				'itemid' => $newTestItemIds[$inum],
 				'type' => $item['httptestitemtype']
-			);
+			];
 		}
 		DB::insert('httptestitem', $httpTestItems);
 	}
@@ -770,7 +762,7 @@ class CHttpTestManager {
 		$webstepids = DB::insert('httpstep', $websteps);
 
 		// if this is a template scenario, fetch the parent http items to link inherited items to them
-		$parentStepItems = array();
+		$parentStepItems = [];
 		if (isset($httpTest['templateid']) && $httpTest['templateid']) {
 			$parentStepItems = DBfetchArrayAssoc(DBselect(
 				'SELECT i.itemid,i.key_,hsi.httpstepid'.
@@ -784,29 +776,29 @@ class CHttpTestManager {
 		foreach ($websteps as $snum => $webstep) {
 			$webstepid = $webstepids[$snum];
 
-			$stepitems = array(
-				array(
+			$stepitems = [
+				[
 					'name' => 'Download speed for step "$2" of scenario "$1".',
 					'key_' => $this->getStepKey(HTTPSTEP_ITEM_TYPE_IN, $httpTest['name'], $webstep['name']),
 					'value_type' => ITEM_VALUE_TYPE_FLOAT,
 					'units' => 'Bps',
 					'httpstepitemtype' => HTTPSTEP_ITEM_TYPE_IN
-				),
-				array(
+				],
+				[
 					'name' => 'Response time for step "$2" of scenario "$1".',
 					'key_' => $this->getStepKey(HTTPSTEP_ITEM_TYPE_TIME, $httpTest['name'], $webstep['name']),
 					'value_type' => ITEM_VALUE_TYPE_FLOAT,
 					'units' => 's',
 					'httpstepitemtype' => HTTPSTEP_ITEM_TYPE_TIME
-				),
-				array(
+				],
+				[
 					'name' => 'Response code for step "$2" of scenario "$1".',
 					'key_' => $this->getStepKey(HTTPSTEP_ITEM_TYPE_RSPCODE, $httpTest['name'], $webstep['name']),
 					'value_type' => ITEM_VALUE_TYPE_UINT64,
 					'units' => '',
 					'httpstepitemtype' => HTTPSTEP_ITEM_TYPE_RSPCODE
-				)
-			);
+				]
+			];
 
 			if (!isset($httpTest['delay']) || !isset($httpTest['status'])) {
 				$dbTest = DBfetch(DBselect('SELECT ht.delay,ht.status FROM httptest ht WHERE ht.httptestid='.zbx_dbstr($httpTest['httptestid'])));
@@ -818,17 +810,10 @@ class CHttpTestManager {
 				$status = $httpTest['status'];
 			}
 
-			$insertItems = array();
-			$updateItems = array();
-			$stepItemids = array();
-			foreach ($stepitems as $item) {
-				$dbItem = DBfetch(DBselect(
-					'SELECT i.itemid,i.templateid'.
-					' FROM items i'.
-					' WHERE i.key_='.zbx_dbstr($item['key_']).
-						' AND i.hostid='.zbx_dbstr($httpTest['hostid'])
-				));
+			$insertItems = [];
+			$stepItemids = [];
 
+			foreach ($stepitems as $item) {
 				$item['hostid'] = $httpTest['hostid'];
 				$item['delay'] = $delay;
 				$item['type'] = ITEM_TYPE_HTTPTEST;
@@ -841,46 +826,24 @@ class CHttpTestManager {
 					$item['templateid'] = $parentStepItems[$item['key_']]['itemid'];
 				}
 
-				if ($dbItem) {
-					if (!empty($dbItem['templateid'])) {
-						throw new Exception(_s('Item with key "%1$s" already exists.', $item['key_']));
-					}
-					$stepItemids[] = $dbItem['itemid'];
-					$updateItems[] = array('values' => $item, 'where' => array('itemid' => $dbItem['itemid']));
-				}
-				else {
-					$insertItems[] = $item;
+				$insertItems[] = $item;
+			}
+
+			if ($insertItems) {
+				$stepItemids = DB::insert('items', $insertItems);
+
+				if (array_key_exists('applicationid', $httpTest)) {
+					$this->createItemsApplications($stepItemids, $httpTest['applicationid']);
 				}
 			}
 
-			if (!empty($insertItems)) {
-				$newStepItemIds = DB::insert('items', $insertItems);
-				$stepItemids = array_merge($stepItemids, $newStepItemIds);
-			}
-			if (!empty($updateItems)) {
-				DB::update('items', $updateItems);
-			}
-
-			$itemApplications = array();
-			foreach ($stepItemids as $itemid) {
-				if (!empty($httpTest['applicationid'])) {
-					$itemApplications[] = array(
-						'applicationid' => $httpTest['applicationid'],
-						'itemid' => $itemid
-					);
-				}
-			}
-			if (!empty($itemApplications)) {
-				DB::insert('items_applications', $itemApplications);
-			}
-
-			$webstepitems = array();
+			$webstepitems = [];
 			foreach ($stepitems as $inum => $item) {
-				$webstepitems[] = array(
+				$webstepitems[] = [
 					'httpstepid' => $webstepid,
 					'itemid' => $stepItemids[$inum],
 					'type' => $item['httpstepitemtype']
-				);
+				];
 			}
 			DB::insert('httpstepitem', $webstepitems);
 		}
@@ -895,6 +858,8 @@ class CHttpTestManager {
 	 * @throws Exception
 	 */
 	protected function updateStepsReal($httpTest, $websteps) {
+		$item_key_parser = new CItemKey();
+
 		// get all used keys
 		$webstepids = zbx_objectValues($websteps, 'httpstepid');
 		$dbKeys = DBfetchArrayAssoc(DBselect(
@@ -906,14 +871,14 @@ class CHttpTestManager {
 		);
 
 		foreach ($websteps as $webstep) {
-			DB::update('httpstep', array(
+			DB::update('httpstep', [
 				'values' => $webstep,
-				'where' => array('httpstepid' => $webstep['httpstepid'])
-			));
+				'where' => ['httpstepid' => $webstep['httpstepid']]
+			]);
 
 			// update item keys
-			$itemids = array();
-			$stepitemsUpdate = $updateFields = array();
+			$itemids = [];
+			$stepitemsUpdate = $updateFields = [];
 			$dbStepItems = DBselect(
 				'SELECT i.itemid,i.key_,hi.type'.
 				' FROM items i,httpstepitem hi'.
@@ -925,13 +890,12 @@ class CHttpTestManager {
 
 				if (isset($httpTest['name']) || isset($webstep['name'])) {
 					if (!isset($httpTest['name']) || !isset($webstep['name'])) {
-						$key = new CItemKey($stepitem['key_']);
-						$params = $key->getParameters();
+						$item_key_parser->parse($stepitem['key_']);
 						if (!isset($httpTest['name'])) {
-							$httpTest['name'] = $params[0];
+							$httpTest['name'] = $item_key_parser->getParam(0);
 						}
 						if (!isset($webstep['name'])) {
-							$webstep['name'] = $params[1];
+							$webstep['name'] = $item_key_parser->getParam(1);
 						}
 					}
 
@@ -947,15 +911,18 @@ class CHttpTestManager {
 					$updateFields['delay'] = $httpTest['delay'];
 				}
 				if (!empty($updateFields)) {
-					$stepitemsUpdate[] = array(
+					$stepitemsUpdate[] = [
 						'values' => $updateFields,
-						'where' => array('itemid' => $stepitem['itemid'])
-					);
+						'where' => ['itemid' => $stepitem['itemid']]
+					];
 				}
 			}
-			DB::update('items', $stepitemsUpdate);
 
-			if (isset($httpTest['applicationid'])) {
+			if ($stepitemsUpdate) {
+				DB::update('items', $stepitemsUpdate);
+			}
+
+			if (array_key_exists('applicationid', $httpTest)) {
 				$this->updateItemsApplications($itemids, $httpTest['applicationid']);
 			}
 		}
@@ -964,34 +931,45 @@ class CHttpTestManager {
 	/**
 	 * Update web item application linkage.
 	 *
-	 * @param array  $itemIds
-	 * @param string $appId
+	 * @param array  $itemids
+	 * @param string $applicationid
 	 */
-	protected function updateItemsApplications(array $itemIds, $appId) {
-		if (empty($appId)) {
-			DB::delete('items_applications', array('itemid' => $itemIds));
+	protected function updateItemsApplications(array $itemids, $applicationid) {
+		if ($applicationid == 0) {
+			DB::delete('items_applications', ['itemid' => $itemids]);
 		}
 		else {
-			$linkedItemIds = DBfetchColumn(
-				DBselect('SELECT ia.itemid FROM items_applications ia WHERE '.dbConditionInt('ia.itemid', $itemIds)),
+			$linked_itemids = DBfetchColumn(
+				DBselect('SELECT ia.itemid FROM items_applications ia WHERE '.dbConditionInt('ia.itemid', $itemids)),
 				'itemid'
 			);
 
-			if (!empty($linkedItemIds)) {
-				DB::update('items_applications', array(
-					'values' => array('applicationid' => $appId),
-					'where' => array('itemid' => $linkedItemIds)
-				));
+			if ($linked_itemids) {
+				DB::update('items_applications', [
+					'values' => ['applicationid' => $applicationid],
+					'where' => ['itemid' => $linked_itemids]
+				]);
 			}
 
-			$notLinkedItemIds = array_diff($itemIds, $linkedItemIds);
-			if (!empty($notLinkedItemIds)) {
-				$insert = array();
-				foreach ($notLinkedItemIds as $itemId) {
-					$insert[] = array('itemid' => $itemId, 'applicationid' => $appId);
-				}
-				DB::insert('items_applications', $insert);
+			$this->createItemsApplications(array_diff($itemids, $linked_itemids), $applicationid);
+		}
+	}
+
+	/**
+	 * Create web item application linkage.
+	 *
+	 * @param array  $itemids
+	 * @param string $applicationid
+	 */
+	protected function createItemsApplications(array $itemids, $applicationid) {
+		if ($applicationid != 0 && $itemids) {
+			$insert = [];
+
+			foreach ($itemids as $itemid) {
+				$insert[] = ['itemid' => $itemid, 'applicationid' => $applicationid];
 			}
+
+			DB::insert('items_applications', $insert);
 		}
 	}
 
@@ -1063,16 +1041,16 @@ class CHttpTestManager {
 
 		$history = Manager::History()->getLast($httpItems);
 
-		$data = array();
+		$data = [];
 
 		foreach ($httpItems as $httpItem) {
 			if (isset($history[$httpItem['itemid']])) {
 				if (!isset($data[$httpItem['httptestid']])) {
-					$data[$httpItem['httptestid']] = array(
+					$data[$httpItem['httptestid']] = [
 						'lastcheck' => null,
 						'lastfailedstep' => null,
 						'error' => null
-					);
+					];
 				}
 
 				$itemHistory = $history[$httpItem['itemid']][0];
@@ -1089,4 +1067,20 @@ class CHttpTestManager {
 
 		return $data;
 	}
+
+	/**
+	 * Get httptest step items by "httptestid".
+	 *
+	 * @param string $httptestid		ID of a web scenario
+	 *
+	 * @return array
+	 */
+	public function getHttpStepItems($httptestid) {
+		return DBfetchArray(DBselect(
+			'SELECT hi.itemid'.
+			' FROM httpstepitem hi,httpstep hs'.
+			' WHERE hi.httpstepid=hs.httpstepid'.
+				' AND hs.httptestid='.zbx_dbstr($httptestid)
+		));
+	}
 }
