@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2015 Zabbix SIA
+** Copyright (C) 2001-2016 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@ class CHttpTest extends CApiService {
 
 	protected $tableName = 'httptest';
 	protected $tableAlias = 'ht';
-	protected $sortColumns = array('httptestid', 'name');
+	protected $sortColumns = ['httptestid', 'name'];
 
 	/**
 	 * Get data about web scenarios.
@@ -37,21 +37,21 @@ class CHttpTest extends CApiService {
 	 *
 	 * @return array
 	 */
-	public function get($options = array()) {
-		$result = array();
+	public function get($options = []) {
+		$result = [];
 		$userType = self::$userData['type'];
 		$userid = self::$userData['userid'];
 
-		$sqlParts = array(
-			'select'	=> array('httptests' => 'ht.httptestid'),
-			'from'		=> array('httptest' => 'httptest ht'),
-			'where'		=> array(),
-			'group'		=> array(),
-			'order'		=> array(),
+		$sqlParts = [
+			'select'	=> ['httptests' => 'ht.httptestid'],
+			'from'		=> ['httptest' => 'httptest ht'],
+			'where'		=> [],
+			'group'		=> [],
+			'order'		=> [],
 			'limit'		=> null
-		);
+		];
 
-		$defOptions = array(
+		$defOptions = [
 			'httptestids'    => null,
 			'applicationids' => null,
 			'hostids'        => null,
@@ -80,7 +80,7 @@ class CHttpTest extends CApiService {
 			'sortfield'      => '',
 			'sortorder'      => '',
 			'limit'          => null
-		);
+		];
 		$options = zbx_array_merge($defOptions, $options);
 
 		// editable + PERMISSION CHECK
@@ -236,7 +236,7 @@ class CHttpTest extends CApiService {
 				$result = resolveHttpTestMacros($result, $expandName, $expandStepName);
 			}
 
-			$result = $this->unsetExtraFields($result, array('hostid'), $options['output']);
+			$result = $this->unsetExtraFields($result, ['hostid'], $options['output']);
 		}
 
 		// removing keys (hash -> array)
@@ -261,24 +261,12 @@ class CHttpTest extends CApiService {
 			self::exception(ZBX_API_ERROR_PARAMETERS, _('Empty input parameters.'));
 		}
 
-		// find hostid by applicationid
+		// Check and set default values, and find "hostid" by "applicationid".
 		foreach ($httpTests as &$httpTest) {
-			unset($httpTest['templateid']);
-
-			if (empty($httpTest['hostid']) && !empty($httpTest['applicationid'])) {
-				$dbHostId = DBfetch(DBselect('SELECT a.hostid'.
-						' FROM applications a'.
-						' WHERE a.applicationid='.zbx_dbstr($httpTest['applicationid'])));
-				$httpTest['hostid'] = $dbHostId['hostid'];
-			}
-		}
-		unset($httpTest);
-
-		foreach($httpTests as &$httpTest) {
-			$defaultValues = array(
+			$defaultValues = [
 				'verify_peer' => HTTPTEST_VERIFY_PEER_OFF,
 				'verify_host' => HTTPTEST_VERIFY_HOST_OFF
-			);
+			];
 
 			check_db_fields($defaultValues, $httpTest);
 		}
@@ -288,7 +276,7 @@ class CHttpTest extends CApiService {
 
 		$httpTests = Manager::HttpTest()->persist($httpTests);
 
-		return array('httptestids' => zbx_objectValues($httpTests, 'httptestid'));
+		return ['httptestids' => zbx_objectValues($httpTests, 'httptestid')];
 	}
 
 	/**
@@ -313,7 +301,7 @@ class CHttpTest extends CApiService {
 
 		$httpTests = zbx_toHash($httpTests, 'httptestid');
 
-		$dbHttpTests = array();
+		$dbHttpTests = [];
 		$dbCursor = DBselect(
 			'SELECT ht.httptestid,ht.hostid,ht.templateid,ht.name,'.
 				'ht.ssl_cert_file,ht.ssl_key_file,ht.ssl_key_password,ht.verify_peer,ht.verify_host'.
@@ -337,7 +325,7 @@ class CHttpTest extends CApiService {
 
 		Manager::HttpTest()->persist($httpTests);
 
-		return array('httptestids' => array_keys($httpTests));
+		return ['httptestids' => array_keys($httpTests)];
 	}
 
 	/**
@@ -353,13 +341,13 @@ class CHttpTest extends CApiService {
 			return true;
 		}
 
-		$delHttpTests = $this->get(array(
+		$delHttpTests = $this->get([
 			'httptestids' => $httpTestIds,
 			'output' => API_OUTPUT_EXTEND,
 			'editable' => true,
 			'selectHosts' => API_OUTPUT_EXTEND,
 			'preservekeys' => true
-		));
+		]);
 		if (!$nopermissions) {
 			foreach ($httpTestIds as $httpTestId) {
 				if (!empty($delHttpTests[$httpTestId]['templateid'])) {
@@ -372,28 +360,28 @@ class CHttpTest extends CApiService {
 		}
 
 		$parentHttpTestIds = $httpTestIds;
-		$childHttpTestIds = array();
+		$childHttpTestIds = [];
 		do {
 			$dbTests = DBselect('SELECT ht.httptestid FROM httptest ht WHERE '.dbConditionInt('ht.templateid', $parentHttpTestIds));
-			$parentHttpTestIds = array();
+			$parentHttpTestIds = [];
 			while ($dbTest = DBfetch($dbTests)) {
 				$parentHttpTestIds[] = $dbTest['httptestid'];
 				$childHttpTestIds[$dbTest['httptestid']] = $dbTest['httptestid'];
 			}
 		} while (!empty($parentHttpTestIds));
 
-		$options = array(
+		$options = [
 			'httptestids' => $childHttpTestIds,
 			'output' => API_OUTPUT_EXTEND,
 			'nopermissions' => true,
 			'preservekeys' => true,
 			'selectHosts' => API_OUTPUT_EXTEND
-		);
+		];
 		$delHttpTestChilds = $this->get($options);
 		$delHttpTests = zbx_array_merge($delHttpTests, $delHttpTestChilds);
 		$httpTestIds = array_merge($httpTestIds, $childHttpTestIds);
 
-		$itemidsDel = array();
+		$itemidsDel = [];
 		$dbTestItems = DBselect(
 			'SELECT hsi.itemid'.
 			' FROM httptestitem hsi'.
@@ -417,7 +405,7 @@ class CHttpTest extends CApiService {
 			API::Item()->delete($itemidsDel, true);
 		}
 
-		DB::delete('httptest', array('httptestid' => $httpTestIds));
+		DB::delete('httptest', ['httptestid' => $httpTestIds]);
 
 		// TODO: REMOVE
 		foreach ($delHttpTests as $httpTest) {
@@ -425,11 +413,12 @@ class CHttpTest extends CApiService {
 
 			info(_s('Deleted: Web scenario "%1$s" on "%2$s".', $httpTest['name'], $host['host']));
 			add_audit(AUDIT_ACTION_DELETE, AUDIT_RESOURCE_SCENARIO,
-				'Web scenario ['.$httpTest['name'].'] ['.$httpTest['httptestid'].'] Host ['.$host['name'].']'
+				_('Web scenario').' ['.$httpTest['name'].'] ['.$httpTest['httptestid'].'] '.
+				_('Host').' ['.$host['name'].']'
 			);
 		}
 
-		return array('httptestids' => $httpTestIds);
+		return ['httptestids' => $httpTestIds];
 	}
 
 	/**
@@ -440,10 +429,15 @@ class CHttpTest extends CApiService {
 	 * @param array $httpTests
 	 */
 	protected function validateCreate(array $httpTests) {
+		$required_fields = ['name', 'hostid', 'steps'];
+
 		foreach ($httpTests as $httpTest) {
-			$missingKeys = checkRequiredKeys($httpTest, array('name', 'hostid', 'steps'));
-			if (!empty($missingKeys)) {
-				self::exception(ZBX_API_ERROR_PARAMETERS, _s('Web scenario missing parameters: %1$s', implode(', ', $missingKeys)));
+			$missing_keys = array_diff($required_fields, array_keys($httpTest));
+
+			if ($missing_keys) {
+				self::exception(ZBX_API_ERROR_PARAMETERS,
+					_s('Web scenario missing parameters: %1$s', implode(', ', $missing_keys))
+				);
 			}
 		}
 
@@ -468,11 +462,11 @@ class CHttpTest extends CApiService {
 		}
 
 		// check input array for duplicate names
-		$collectionValidator = new CCollectionValidator(array(
+		$collectionValidator = new CCollectionValidator([
 			'uniqueField' => 'name',
 			'uniqueField2' => 'hostid',
 			'messageDuplicate' => _('Web scenario "%1$s" already exists.')
-		));
+		]);
 		$this->checkValidator($httpTests, $collectionValidator);
 
 		// check database for duplicate names
@@ -498,9 +492,12 @@ class CHttpTest extends CApiService {
 			self::exception(ZBX_API_ERROR_PARAMETERS, _('No permissions to referred object or it does not exist!'));
 		}
 
-		$httpTests = $this->extendFromObjects($httpTests, $dbHttpTests, array(
+		$httpTests = $this->extendFromObjects($httpTests, $dbHttpTests, [
 			'ssl_key_file', 'ssl_cert_file', 'ssl_key_password', 'verify_host', 'verify_peer'
-		));
+		]);
+
+		// Required fields for steps.
+		$required_fields = ['httpstepid'];
 
 		foreach ($httpTests as &$httpTest) {
 			$dbHttpTest = $dbHttpTests[$httpTest['httptestid']];
@@ -515,12 +512,33 @@ class CHttpTest extends CApiService {
 
 			if (array_key_exists('steps', $httpTest) && is_array($httpTest['steps'])) {
 				foreach ($httpTest['steps'] as &$httpTestStep) {
+					if ($dbHttpTest && $dbHttpTest['templateid'] != 0) {
+						/*
+						 * Handle templated webscenario steps first by checking the keys and then check name before
+						 * populating the name field from parent.
+						 */
+
+						$missing_keys = array_diff($required_fields, array_keys($httpTestStep));
+
+						if ($missing_keys) {
+							self::exception(ZBX_API_ERROR_PARAMETERS,
+								_s('Web scenario step is missing parameters: %1$s', implode(', ', $missing_keys))
+							);
+						}
+
+						if (array_key_exists('name', $httpTestStep)) {
+							self::exception(ZBX_API_ERROR_PARAMETERS,
+								_s('Cannot update step name for a templated web scenario "%1$s".', $httpTest['name'])
+							);
+						}
+					}
+
 					if (isset($httpTestStep['httpstepid'])
 							&& ($dbHttpTest['templateid'] || !isset($httpTestStep['name']))) {
 						$httpTestStep['name'] = $dbHttpTest['steps'][$httpTestStep['httpstepid']]['name'];
 					}
 
-					if ($dbHttpTest['templateid']) {
+					if ($dbHttpTest['templateid'] != 0) {
 						unset($httpTestStep['no']);
 					}
 
@@ -542,11 +560,11 @@ class CHttpTest extends CApiService {
 		unset($httpTest);
 
 		// check input array for duplicate names
-		$collectionValidator = new CCollectionValidator(array(
+		$collectionValidator = new CCollectionValidator([
 			'uniqueField' => 'name',
 			'uniqueField2' => 'hostid',
 			'messageDuplicate' => _('Web scenario "%1$s" already exists.')
-		));
+		]);
 		$this->checkValidator($httpTests, $collectionValidator);
 
 		// check database for duplicate names
@@ -565,8 +583,8 @@ class CHttpTest extends CApiService {
 	 * @param array $httpTests		array of web screnarios
 	 * @param array $dbHttpTests	array of DB web screnarios
 	 */
-	protected function checkDuplicates(array $httpTests, array $dbHttpTests = array()) {
-		$httpTestNames = array();
+	protected function checkDuplicates(array $httpTests, array $dbHttpTests = []) {
+		$httpTestNames = [];
 
 		foreach ($httpTests as $httpTest) {
 			if (isset($httpTest['name'])) {
@@ -582,11 +600,11 @@ class CHttpTest extends CApiService {
 
 		if ($httpTestNames) {
 			foreach ($httpTestNames as $hostId => $httpTestName) {
-				$nameExists = API::getApiService()->select($this->tableName(), array(
-					'output' => array('name'),
-					'filter' => array('name' => $httpTestName, 'hostid' => $hostId),
+				$nameExists = API::getApiService()->select($this->tableName(), [
+					'output' => ['name'],
+					'filter' => ['name' => $httpTestName, 'hostid' => $hostId],
 					'limit' => 1
-				));
+				]);
 
 				if ($nameExists) {
 					$nameExists = reset($nameExists);
@@ -604,27 +622,42 @@ class CHttpTest extends CApiService {
 	 * @param array $httpTests
 	 */
 	protected function checkApplicationHost(array $httpTests) {
-		$appIds = zbx_objectValues($httpTests, 'applicationid');
-		$appIds = zbx_toHash($appIds);
-		unset($appIds['0']);
+		// applications containing 0 in ID, will be removed from web scenario
+		foreach ($httpTests as $httpTestId => $httpTest) {
+			if (array_key_exists('applicationid', $httpTest) && $httpTest['applicationid'] == 0) {
+				unset($httpTests[$httpTestId]);
+			}
+		}
 
-		if (!empty($appIds)) {
-			$appHostIds = array();
+		$applicationids = zbx_objectValues($httpTests, 'applicationid');
 
-			$dbCursor = DBselect(
-				'SELECT a.hostid,a.applicationid'.
-				' FROM applications a'.
-				' WHERE '.dbConditionInt('a.applicationid', $appIds)
-			);
-			while ($dbApp = DBfetch($dbCursor)) {
-				$appHostIds[$dbApp['applicationid']] = $dbApp['hostid'];
+		if ($applicationids) {
+			$applications = API::getApiService()->select('applications', [
+				'output' => ['applicationid', 'hostid', 'name', 'flags'],
+				'applicationids' => $applicationids,
+				'preservekeys' => true
+			]);
+
+			// check if applications exist and are normal applications
+			foreach ($applicationids as $applicationid) {
+				if (!array_key_exists($applicationid, $applications)) {
+					self::exception(ZBX_API_ERROR_PERMISSIONS,
+						_('No permissions to referred object or it does not exist!')
+					);
+				}
+				elseif ($applications[$applicationid]['flags'] == ZBX_FLAG_DISCOVERY_CREATED) {
+					self::exception(ZBX_API_ERROR_PARAMETERS, _s(
+						'Cannot add a discovered application "%1$s" to a web scenario.',
+						$applications[$applicationid]['name']
+					));
+				}
 			}
 
 			foreach ($httpTests as $httpTest) {
-				if (isset($httpTest['applicationid'])) {
-					if (!idcmp($appHostIds[$httpTest['applicationid']], $httpTest['hostid'])) {
-						self::exception(ZBX_API_ERROR_PARAMETERS, _('The web scenario application belongs to a different host than the web scenario host.'));
-					}
+				if (!idcmp($applications[$httpTest['applicationid']]['hostid'], $httpTest['hostid'])) {
+					self::exception(ZBX_API_ERROR_PARAMETERS,
+						_('The web scenario application belongs to a different host than the web scenario host.')
+					);
 				}
 			}
 		}
@@ -640,27 +673,44 @@ class CHttpTest extends CApiService {
 	 * @param array $httpTest
 	 * @param array $dbHttpTest
 	 */
-	protected function checkSteps(array $httpTest, array $dbHttpTest = array()) {
+	protected function checkSteps(array $httpTest, array $dbHttpTest = []) {
 		if (array_key_exists('steps', $httpTest)
 				&& (!is_array($httpTest['steps']) || (count($httpTest['steps']) == 0))) {
 			self::exception(ZBX_API_ERROR_PARAMETERS, _('Web scenario must have at least one step.'));
 		}
 
-		$stepNames = zbx_objectValues($httpTest['steps'], 'name');
-		if (!empty($stepNames) && !preg_grep('/'.ZBX_PREG_PARAMS.'/i', $stepNames)) {
-			self::exception(ZBX_API_ERROR_PARAMETERS, _('Web scenario step name should contain only printable characters.'));
+		// Check if step still exists on update.
+		if ($dbHttpTest) {
+			foreach ($httpTest['steps'] as $step) {
+				$dbHttpTest['steps'] = zbx_toHash($dbHttpTest['steps'], 'httpstepid');
+
+				if (array_key_exists('httpstepid', $step)
+						&& !array_key_exists($step['httpstepid'], $dbHttpTest['steps'])) {
+					self::exception(ZBX_API_ERROR_PARAMETERS,
+						_('No permissions to referred object or it does not exist!')
+					);
+				}
+			}
 		}
 
-		$followRedirectsValidator = new CLimitedSetValidator(array(
-				'values' => array(HTTPTEST_STEP_FOLLOW_REDIRECTS_OFF, HTTPTEST_STEP_FOLLOW_REDIRECTS_ON)
-			)
+		$followRedirectsValidator = new CLimitedSetValidator([
+				'values' => [HTTPTEST_STEP_FOLLOW_REDIRECTS_OFF, HTTPTEST_STEP_FOLLOW_REDIRECTS_ON]
+			]
 		);
 
-		$retrieveModeValidator = new CLimitedSetValidator(array(
-				'values' => array(HTTPTEST_STEP_RETRIEVE_MODE_CONTENT, HTTPTEST_STEP_RETRIEVE_MODE_HEADERS)
-			)
+		$retrieveModeValidator = new CLimitedSetValidator([
+				'values' => [HTTPTEST_STEP_RETRIEVE_MODE_CONTENT, HTTPTEST_STEP_RETRIEVE_MODE_HEADERS]
+			]
 		);
 
+		if ($dbHttpTest && $dbHttpTest['templateid'] != 0) {
+			$httpTest['steps'] = zbx_toHash($httpTest['steps'], 'httpstepid');
+
+			if (count($httpTest['steps']) != count($dbHttpTest['steps'])) {
+				self::exception(ZBX_API_ERROR_PARAMETERS, _('Incorrect templated web scenario step count.'));
+			}
+		}
+
 		foreach ($httpTest['steps'] as $step) {
 			if ((isset($step['httpstepid']) && array_key_exists('name', $step) && zbx_empty($step['name']))
 					|| (!isset($step['httpstepid']) && (!array_key_exists('name', $step) || zbx_empty($step['name'])))) {
@@ -691,7 +741,7 @@ class CHttpTest extends CApiService {
 
 			if (isset($step['retrieve_mode'])) {
 				$retrieveModeValidator->messageInvalid = _s(
-					'Incorrect retrieve mode value for step "%1$s" of web scenario "%2$".',
+					'Incorrect retrieve mode value for step "%1$s" of web scenario "%2$s".',
 					$step['name'],
 					$httpTest['name']
 				);
@@ -699,17 +749,6 @@ class CHttpTest extends CApiService {
 				$this->checkValidator($step['retrieve_mode'], $retrieveModeValidator);
 			}
 		}
-
-		// check if step still exists on update
-		if ($dbHttpTest) {
-			foreach ($httpTest['steps'] as $step) {
-				if (isset($step['httpstepid']) && !isset($dbHttpTest['steps'][$step['httpstepid']])) {
-					self::exception(ZBX_API_ERROR_PARAMETERS,
-						_('No permissions to referred object or it does not exist!')
-					);
-				}
-			}
-		}
 	}
 
 	/**
@@ -720,9 +759,16 @@ class CHttpTest extends CApiService {
 	 * @param array $httpTest
 	 * @param array $dbHttpTest
 	 */
-	protected function checkDuplicateSteps(array $httpTest, array $dbHttpTest = array()) {
+	protected function checkDuplicateSteps(array $httpTest, array $dbHttpTest = []) {
+		if ($dbHttpTest) {
+			$httpTest['steps'] = zbx_toHash($httpTest['steps'], 'httpstepid');
+			$httpTest['steps'] = $this->extendFromObjects($httpTest['steps'], $dbHttpTest['steps'], ['name']);
+		}
+
 		if ($duplicate = CArrayHelper::findDuplicate($httpTest['steps'], 'name')) {
-			self::exception(ZBX_API_ERROR_PARAMETERS, _s('Web scenario step "%1$s" already exists.', $duplicate['name']));
+			self::exception(ZBX_API_ERROR_PARAMETERS,
+				_s('Web scenario step "%1$s" already exists.', $duplicate['name'])
+			);
 		}
 	}
 
@@ -739,7 +785,9 @@ class CHttpTest extends CApiService {
 	 * @return bool
 	 */
 	protected  function checkStatusCode($statusCodeRange) {
-		if ($statusCodeRange === '' || preg_match('/^'.ZBX_PREG_EXPRESSION_USER_MACROS.'$/', $statusCodeRange)) {
+		$user_macro_parser = new CUserMacroParser();
+
+		if ($statusCodeRange === '' || $user_macro_parser->parse($statusCodeRange) == CParser::PARSE_SUCCESS) {
 			return true;
 		}
 		else {
@@ -777,10 +825,10 @@ class CHttpTest extends CApiService {
 
 		$ids = array_unique($ids);
 
-		$count = $this->get(array(
+		$count = $this->get([
 			'httptestids' => $ids,
 			'countOutput' => true
-		));
+		]);
 
 		return (count($ids) == $count);
 	}
@@ -799,11 +847,11 @@ class CHttpTest extends CApiService {
 
 		$ids = array_unique($ids);
 
-		$count = $this->get(array(
+		$count = $this->get([
 			'httptestids' => $ids,
 			'editable' => true,
 			'countOutput' => true
-		));
+		]);
 
 		return (count($ids) == $count);
 	}
@@ -829,27 +877,27 @@ class CHttpTest extends CApiService {
 		// adding hosts
 		if ($options['selectHosts'] !== null && $options['selectHosts'] != API_OUTPUT_COUNT) {
 			$relationMap = $this->createRelationMap($result, 'httptestid', 'hostid');
-			$hosts = API::Host()->get(array(
+			$hosts = API::Host()->get([
 				'output' => $options['selectHosts'],
 				'hostid' => $relationMap->getRelatedIds(),
 				'nopermissions' => true,
 				'templated_hosts' => true,
 				'preservekeys' => true
-			));
+			]);
 			$result = $relationMap->mapMany($result, $hosts, 'hosts');
 		}
 
 		// adding steps
 		if ($options['selectSteps'] !== null) {
 			if ($options['selectSteps'] != API_OUTPUT_COUNT) {
-				$httpSteps = API::getApiService()->select('httpstep', array(
-					'output' => $this->outputExtend($options['selectSteps'], array('httptestid', 'httpstepid')),
-					'filters' => array('httptestid' => $httpTestIds),
+				$httpSteps = API::getApiService()->select('httpstep', [
+					'output' => $this->outputExtend($options['selectSteps'], ['httptestid', 'httpstepid']),
+					'filters' => ['httptestid' => $httpTestIds],
 					'preservekeys' => true
-				));
+				]);
 				$relationMap = $this->createRelationMap($httpSteps, 'httptestid', 'httpstepid');
 
-				$httpSteps = $this->unsetExtraFields($httpSteps, array('httptestid', 'httpstepid'), $options['selectSteps']);
+				$httpSteps = $this->unsetExtraFields($httpSteps, ['httptestid', 'httpstepid'], $options['selectSteps']);
 
 				$result = $relationMap->mapMany($result, $httpSteps, 'steps');
 			}
@@ -879,19 +927,19 @@ class CHttpTest extends CApiService {
 	protected function checkSslParameters($httpTest) {
 
 		$verifyPeerValidator = new CLimitedSetValidator(
-			array(
-				'values' => array(HTTPTEST_VERIFY_PEER_ON, HTTPTEST_VERIFY_PEER_OFF),
+			[
+				'values' => [HTTPTEST_VERIFY_PEER_ON, HTTPTEST_VERIFY_PEER_OFF],
 				'messageInvalid' => _('Incorrect SSL verify peer value for web scenario "%1$s".')
-			)
+			]
 		);
 		$verifyPeerValidator->setObjectName($httpTest['name']);
 		$this->checkValidator($httpTest['verify_peer'], $verifyPeerValidator);
 
 		$verifyHostValidator = new CLimitedSetValidator(
-			array(
-				'values' => array(HTTPTEST_VERIFY_HOST_ON, HTTPTEST_VERIFY_HOST_OFF),
+			[
+				'values' => [HTTPTEST_VERIFY_HOST_ON, HTTPTEST_VERIFY_HOST_OFF],
 				'messageInvalid' => _('Incorrect SSL verify host value for web scenario "%1$s".')
-			)
+			]
 		);
 
 		$verifyHostValidator->setObjectName($httpTest['name']);
