@@ -469,7 +469,8 @@ class CMap extends CMapElement {
 
 				foreach ($map['users'] as $share) {
 					// Check required parameters.
-					$missing_keys = checkRequiredKeys($share, $required_fields);
+					$missing_keys = array_diff($required_fields, array_keys($share));
+
 					if ($missing_keys) {
 						self::exception(ZBX_API_ERROR_PARAMETERS, _s(
 							'User sharing is missing parameters: %1$s for map "%2$s".',
@@ -543,7 +544,8 @@ class CMap extends CMapElement {
 
 				foreach ($map['userGroups'] as $share) {
 					// Check required parameters.
-					$missing_keys = checkRequiredKeys($share, $required_fields);
+					$missing_keys = array_diff($required_fields, array_keys($share));
+
 					if ($missing_keys) {
 						self::exception(ZBX_API_ERROR_PARAMETERS, _s(
 							'User group sharing is missing parameters: %1$s for map "%2$s".',
@@ -890,7 +892,8 @@ class CMap extends CMapElement {
 
 				foreach ($map['users'] as $share) {
 					// Check required parameters.
-					$missing_keys = checkRequiredKeys($share, $required_fields);
+					$missing_keys = array_diff($required_fields, array_keys($share));
+
 					if ($missing_keys) {
 						self::exception(ZBX_API_ERROR_PARAMETERS, _s(
 							'User sharing is missing parameters: %1$s for map "%2$s".',
@@ -963,7 +966,8 @@ class CMap extends CMapElement {
 
 				foreach ($map['userGroups'] as $share) {
 					// Check required parameters.
-					$missing_keys = checkRequiredKeys($share, $required_fields);
+					$missing_keys = array_diff($required_fields, array_keys($share));
+
 					if ($missing_keys) {
 						self::exception(ZBX_API_ERROR_PARAMETERS, _s(
 							'User group sharing is missing parameters: %1$s for map "%2$s".',
