@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2015 Zabbix SIA
+** Copyright (C) 2001-2016 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@ class CUserGroup extends CApiService {
 
 	protected $tableName = 'usrgrp';
 	protected $tableAlias = 'g';
-	protected $sortColumns = array('usrgrpid', 'name');
+	protected $sortColumns = ['usrgrpid', 'name'];
 
 	/**
 	 * Get user groups.
@@ -46,19 +46,19 @@ class CUserGroup extends CApiService {
 	 *
 	 * @return array
 	 */
-	public function get($options = array()) {
-		$result = array();
+	public function get($options = []) {
+		$result = [];
 		$userType = self::$userData['type'];
 
-		$sqlParts = array(
-			'select'	=> array('usrgrp' => 'g.usrgrpid'),
-			'from'		=> array('usrgrp' => 'usrgrp g'),
-			'where'		=> array(),
-			'order'		=> array(),
+		$sqlParts = [
+			'select'	=> ['usrgrp' => 'g.usrgrpid'],
+			'from'		=> ['usrgrp' => 'usrgrp g'],
+			'where'		=> [],
+			'order'		=> [],
 			'limit'		=> null
-		);
+		];
 
-		$defOptions = array(
+		$defOptions = [
 			'usrgrpids'					=> null,
 			'userids'					=> null,
 			'status'					=> null,
@@ -74,18 +74,19 @@ class CUserGroup extends CApiService {
 			'editable'					=> null,
 			'output'					=> API_OUTPUT_EXTEND,
 			'selectUsers'				=> null,
+			'selectRights'				=> null,
 			'countOutput'				=> null,
 			'preservekeys'				=> null,
 			'sortfield'					=> '',
 			'sortorder'					=> '',
 			'limit'						=> null
-		);
+		];
 
 		$options = zbx_array_merge($defOptions, $options);
 
 		// permissions
 		if ($userType != USER_TYPE_SUPER_ADMIN) {
-			if ($options['editable'] === null && self::$userData['type'] == USER_TYPE_ZABBIX_ADMIN) {
+			if (!$options['editable']) {
 				$sqlParts['where'][] = 'g.usrgrpid IN ('.
 					'SELECT uug.usrgrpid'.
 					' FROM users_groups uug'.
@@ -93,7 +94,7 @@ class CUserGroup extends CApiService {
 				')';
 			}
 			else {
-				return array();
+				return [];
 			}
 		}
 
@@ -166,63 +167,6 @@ class CUserGroup extends CApiService {
 		return $result;
 	}
 
-	/**
-	 * Get user groups by name.
-	 *
-	 * @deprecated	As of version 2.4, use get method instead.
-	 *
-	 * @param array  $groupData
-	 * @param string $groupData['name']
-	 *
-	 * @return array
-	 */
-	public function getObjects(array $groupData) {
-		$this->deprecated('usergroup.getobjects method is deprecated.');
-
-		$result = array();
-		$usrgrpids = array();
-
-		$res = DBselect(
-			'SELECT g.usrgrpid'.
-			' FROM usrgrp g'.
-			' WHERE g.name='.zbx_dbstr($groupData['name'])
-		);
-
-		while ($group = DBfetch($res)) {
-			$usrgrpids[$group['usrgrpid']] = $group['usrgrpid'];
-		}
-
-		if ($usrgrpids) {
-			$result = $this->get(array(
-				'output' => API_OUTPUT_EXTEND,
-				'usrgrpids' => $usrgrpids
-			));
-		}
-
-		return $result;
-	}
-
-	/**
-	 * Check if user group exists.
-	 *
-	 * @deprecated	As of version 2.4, use get method instead.
-	 *
-	 * @param array	$object
-	 *
-	 * @return bool
-	 */
-	public function exists(array $object) {
-		$this->deprecated('usergroup.exists method is deprecated.');
-
-		$userGroup = $this->get(array(
-			'output' => array('usrgrpid'),
-			'filter' => array('name' => $object['name']),
-			'limit' => 1,
-		));
-
-		return (bool) $userGroup;
-	}
-
 	/**
 	 * Create UserGroups.
 	 *
@@ -235,21 +179,21 @@ class CUserGroup extends CApiService {
 		}
 
 		$usrgrps = zbx_toArray($usrgrps);
-		$insert = array();
+		$insert = [];
 
 		foreach ($usrgrps as $gnum => $usrgrp) {
-			$usrgrpDbFields = array(
+			$usrgrpDbFields = [
 				'name' => null,
-			);
+			];
 			if (!check_db_fields($usrgrpDbFields, $usrgrp)) {
 				self::exception(ZBX_API_ERROR_PARAMETERS, _('Incorrect parameters for user group.'));
 			}
 
-			$userGroupExists = $this->get(array(
-				'output' => array('usrgrpid'),
-				'filter' => array('name' => $usrgrp['name']),
+			$userGroupExists = $this->get([
+				'output' => ['usrgrpid'],
+				'filter' => ['name' => $usrgrp['name']],
 				'limit' => 1
-			));
+			]);
 			if ($userGroupExists) {
 				self::exception(ZBX_API_ERROR_PARAMETERS, _s('User group "%1$s" already exists.', $usrgrp['name']));
 			}
@@ -259,7 +203,7 @@ class CUserGroup extends CApiService {
 
 
 		foreach ($usrgrps as $gnum => $usrgrp) {
-			$massAdd = array();
+			$massAdd = [];
 			if (isset($usrgrp['userids'])) {
 				$massAdd['userids'] = $usrgrp['userids'];
 			}
@@ -273,7 +217,7 @@ class CUserGroup extends CApiService {
 			}
 		}
 
-		return array('usrgrpids' => $usrgrpids);
+		return ['usrgrpids' => $usrgrpids];
 	}
 
 	/**
@@ -294,7 +238,7 @@ class CUserGroup extends CApiService {
 
 		foreach ($usrgrps as $usrgrp) {
 			// checks if usergroup id is present
-			$groupDbFields = array('usrgrpid' => null);
+			$groupDbFields = ['usrgrpid' => null];
 			if (!check_db_fields($groupDbFields, $usrgrp)) {
 				self::exception(ZBX_API_ERROR_PARAMETERS, _('Incorrect parameters for user group.'));
 			}
@@ -306,7 +250,7 @@ class CUserGroup extends CApiService {
 			}
 		}
 
-		return array('usrgrpids'=> zbx_objectValues($usrgrps, 'usrgrpid'));
+		return ['usrgrpids'=> zbx_objectValues($usrgrps, 'usrgrpid')];
 	}
 
 	public function massAdd($data) {
@@ -319,10 +263,10 @@ class CUserGroup extends CApiService {
 		$rights = (isset($data['rights']) && !is_null($data['rights'])) ? zbx_toArray($data['rights']) : null;
 
 		if (!is_null($userids)) {
-			$options = array(
+			$options = [
 				'usrgrpids' => $usrgrpids,
 				'output' => API_OUTPUT_EXTEND,
-			);
+			];
 			$usrgrps = $this->get($options);
 			foreach ($usrgrps as $usrgrp) {
 				if ((($usrgrp['gui_access'] == GROUP_GUI_ACCESS_DISABLED)
@@ -332,25 +276,25 @@ class CUserGroup extends CApiService {
 				}
 			}
 
-			$linkedUsers = array();
+			$linkedUsers = [];
 			$sql = 'SELECT usrgrpid, userid'.
 				' FROM users_groups'.
 				' WHERE '.dbConditionInt('usrgrpid', $usrgrpids).
 				' AND '.dbConditionInt('userid', $userids);
 			$linkedUsersDb = DBselect($sql);
 			while ($link = DBfetch($linkedUsersDb)) {
-				if (!isset($linkedUsers[$link['usrgrpid']])) $linkedUsers[$link['usrgrpid']] = array();
+				if (!isset($linkedUsers[$link['usrgrpid']])) $linkedUsers[$link['usrgrpid']] = [];
 				$linkedUsers[$link['usrgrpid']][$link['userid']] = 1;
 			}
 
-			$usersInsert = array();
+			$usersInsert = [];
 			foreach ($usrgrpids as $usrgrpid) {
 				foreach ($userids as $userid) {
 					if (!isset($linkedUsers[$usrgrpid][$userid])) {
-						$usersInsert[] = array(
+						$usersInsert[] = [
 							'usrgrpid' => $usrgrpid,
 							'userid' => $userid,
-						);
+						];
 					}
 				}
 			}
@@ -358,33 +302,33 @@ class CUserGroup extends CApiService {
 		}
 
 		if (!is_null($rights)) {
-			$linkedRights = array();
+			$linkedRights = [];
 			$sql = 'SELECT groupid,id'.
 				' FROM rights'.
 				' WHERE '.dbConditionInt('groupid', $usrgrpids).
 					' AND '.dbConditionInt('id', zbx_objectValues($rights, 'id'));
 			$linkedRightsDb = DBselect($sql);
 			while ($link = DBfetch($linkedRightsDb)) {
-				if (!isset($linkedRights[$link['groupid']])) $linkedRights[$link['groupid']] = array();
+				if (!isset($linkedRights[$link['groupid']])) $linkedRights[$link['groupid']] = [];
 				$linkedRights[$link['groupid']][$link['id']] = 1;
 			}
 
-			$rightInsert = array();
+			$rightInsert = [];
 			foreach ($usrgrpids as $usrgrpid) {
 				foreach ($rights as $right) {
 					if (!isset($linkedRights[$usrgrpid][$right['id']])) {
-						$rightInsert[] = array(
+						$rightInsert[] = [
 							'groupid' => $usrgrpid,
 							'permission' => $right['permission'],
 							'id' => $right['id']
-						);
+						];
 					}
 				}
 			}
 			DB::insert('rights', $rightInsert);
 		}
 
-		return array('usrgrpids' => $usrgrpids);
+		return ['usrgrpids' => $usrgrpids];
 	}
 
 	/**
@@ -423,11 +367,11 @@ class CUserGroup extends CApiService {
 			}
 			else {
 				// check if there already is hostgroup with this name, except current hostgroup
-				$groupExists = $this->get(array(
-					'filter' => array('name' => $data['name']),
-					'output' => array('usrgrpid'),
+				$groupExists = $this->get([
+					'filter' => ['name' => $data['name']],
+					'output' => ['usrgrpid'],
 					'limit' => 1
-				));
+				]);
 				$groupExists = reset($groupExists);
 				if ($groupExists && (bccomp($groupExists['usrgrpid'], $usrgrpids[0]) != 0) ) {
 					self::exception(ZBX_API_ERROR_PARAMETERS, _s('User group "%s" already exists.', $data['name']));
@@ -440,10 +384,10 @@ class CUserGroup extends CApiService {
 		unset($usrgrpTableUpdateData['usrgrpids'], $usrgrpTableUpdateData['userids'], $usrgrpTableUpdateData['rights']);
 		if (!empty($usrgrpTableUpdateData)) {
 			foreach ($usrgrpids as $usrgrpid) {
-				DB::update('usrgrp', array(
+				DB::update('usrgrp', [
 					'values' => $usrgrpTableUpdateData,
-					'where' => array('usrgrpid' => $usrgrpid),
-				));
+					'where' => ['usrgrpid' => $usrgrpid],
+				]);
 			}
 		}
 
@@ -453,10 +397,12 @@ class CUserGroup extends CApiService {
 			$userids = zbx_toArray($data['userids']);
 
 			// check whether user tries to add himself to a disabled user group
-			$usrgrps = $this->get(array(
+			$usrgrps = $this->get([
+				'output' => ['usrgrpid', 'gui_access', 'users_status'],
 				'usrgrpids' => $usrgrpids,
-				'output' => API_OUTPUT_EXTEND,
-			));
+				'selectUsers' => ['userid'],
+				'preservekeys' => true
+			]);
 			if (uint_in_array(self::$userData['userid'], $userids)) {
 				foreach ($usrgrps as $usrgrp) {
 					if (($usrgrp['gui_access'] == GROUP_GUI_ACCESS_DISABLED)
@@ -466,34 +412,32 @@ class CUserGroup extends CApiService {
 				}
 			}
 
-			// get already linked users
-			$linkedUsers = array();
-			$sql = 'SELECT usrgrpid,userid'.
-				' FROM users_groups'.
-				' WHERE '.dbConditionInt('usrgrpid', $usrgrpids);
-			$linkedUsersDb = DBselect($sql);
-			while ($link = DBfetch($linkedUsersDb)) {
-				if (!isset($linkedUsers[$link['usrgrpid']])) {
-					$linkedUsers[$link['usrgrpid']] = array();
-				}
-				$linkedUsers[$link['usrgrpid']][$link['userid']] = 1;
-			}
+			$userUsergroupLinksToInsert = [];
+			$amount_of_usrgrps_to_unlink = [];
 
-			// get user-userGroup links to insert and get user ids to unlink
-			$userUsergroupLinksToInsert = array();
-			$userIdsToUnlink = array();
-			foreach ($usrgrpids as $usrgrpid) {
-				foreach ($userids as $userid) {
-					if (!isset($linkedUsers[$usrgrpid][$userid])) {
-						$userUsergroupLinksToInsert[] = array(
-							'usrgrpid' => $usrgrpid,
-							'userid' => $userid,
-						);
-					}
-					unset($linkedUsers[$usrgrpid][$userid]);
+			foreach ($usrgrps as $usrgrpid => $usrgrp) {
+				$usrgrp_userids = [];
+
+				foreach ($usrgrp['users'] as $user) {
+					$usrgrp_userids[$user['userid']] = true;
 				}
-				if (isset($linkedUsers[$usrgrpid]) && !empty($linkedUsers[$usrgrpid])) {
-					$userIdsToUnlink = array_merge($userIdsToUnlink, array_keys($linkedUsers[$usrgrpid]));
+
+				foreach ($userids as $userid) {
+					if (!array_key_exists($userid, $usrgrp_userids)) {
+						$userUsergroupLinksToInsert[] = [
+							'usrgrpid' => $usrgrpid,
+							'userid' => $userid
+						];
+					}
+					else {
+						unset($usrgrp_userids[$userid]);
+					}
+				}
+
+				foreach ($usrgrp_userids as $userid => $value) {
+					$amount_of_usrgrps_to_unlink[$userid] = array_key_exists($userid, $amount_of_usrgrps_to_unlink)
+						? $amount_of_usrgrps_to_unlink[$userid] + 1
+						: 1;
 				}
 			}
 
@@ -502,12 +446,29 @@ class CUserGroup extends CApiService {
 				DB::insert('users_groups', $userUsergroupLinksToInsert);
 			}
 
-			// unlink users from user groups
-			if (!empty($userIdsToUnlink)) {
-				DB::delete('users_groups', array(
-					'userid' => $userIdsToUnlink,
-					'usrgrpid' => $usrgrpids,
-				));
+			if ($amount_of_usrgrps_to_unlink) {
+				// Unlink users from user groups.
+
+				$userids_to_unlink = array_keys($amount_of_usrgrps_to_unlink);
+
+				$db_users = API::User()->get([
+					'output' => ['userid', 'alias'],
+					'userids' => $userids_to_unlink,
+					'selectUsrgrps' => ['usrgrps']
+				]);
+
+				foreach ($db_users as $user) {
+					if (count($user['usrgrps']) <= $amount_of_usrgrps_to_unlink[$user['userid']]) {
+						self::exception(ZBX_API_ERROR_PARAMETERS,
+							_s('User "%1$s" cannot be without user group.', $user['alias'])
+						);
+					}
+				}
+
+				DB::delete('users_groups', [
+					'userid' => $userids_to_unlink,
+					'usrgrpid' => $usrgrpids
+				]);
 			}
 		}
 
@@ -518,14 +479,14 @@ class CUserGroup extends CApiService {
 			$rights = zbx_toArray($data['rights']);
 
 			// get already linked rights
-			$linkedRights = array();
+			$linkedRights = [];
 			$sql = 'SELECT groupid,permission,id'.
 				' FROM rights'.
 				' WHERE '.dbConditionInt('groupid', $usrgrpids);
 			$linkedRightsDb = DBselect($sql);
 			while ($link = DBfetch($linkedRightsDb)) {
 				if (!isset($linkedRights[$link['groupid']])) {
-					$linkedRights[$link['groupid']] = array();
+					$linkedRights[$link['groupid']] = [];
 				}
 				$linkedRights[$link['groupid']][$link['id']] = $link['permission'];
 			}
@@ -533,23 +494,23 @@ class CUserGroup extends CApiService {
 			// get right-userGroup links to insert
 			// get right-userGroup links to update permissions
 			// get rightIds to unlink rights from user groups
-			$rightUsergroupLinksToInsert = array();
-			$rightUsergroupLinksToUpdate = array();
-			$rightIdsToUnlink = array();
+			$rightUsergroupLinksToInsert = [];
+			$rightUsergroupLinksToUpdate = [];
+			$rightIdsToUnlink = [];
 			foreach ($usrgrpids as $usrgrpid) {
 				foreach ($rights as $right) {
 					if (!isset($linkedRights[$usrgrpid][$right['id']])) {
-						$rightUsergroupLinksToInsert[] = array(
+						$rightUsergroupLinksToInsert[] = [
 							'groupid' => $usrgrpid,
 							'id' => $right['id'],
 							'permission' => $right['permission'],
-						);
+						];
 					}
 					elseif ($linkedRights[$usrgrpid][$right['id']] != $right['permission']) {
-						$rightUsergroupLinksToUpdate[] = array(
-							'values' => array('permission' => $right['permission']),
-							'where' => array('groupid' => $usrgrpid, 'id' => $right['id']),
-						);
+						$rightUsergroupLinksToUpdate[] = [
+							'values' => ['permission' => $right['permission']],
+							'where' => ['groupid' => $usrgrpid, 'id' => $right['id']],
+						];
 					}
 					unset($linkedRights[$usrgrpid][$right['id']]);
 				}
@@ -566,10 +527,10 @@ class CUserGroup extends CApiService {
 
 			// unlink rights from user groups
 			if (!empty($rightIdsToUnlink)) {
-				DB::delete('rights', array(
+				DB::delete('rights', [
 					'id' => $rightIdsToUnlink,
 					'groupid' => $usrgrpids,
-				));
+				]);
 			}
 
 			// update right-userGroup permissions
@@ -578,47 +539,47 @@ class CUserGroup extends CApiService {
 			}
 		}
 
-		return array('usrgrpids' => $usrgrpids);
+		return ['usrgrpids' => $usrgrpids];
 	}
 
 	/**
 	 * Delete user groups.
 	 *
-	 * @param array $userGroupIds
+	 * @param array $usergroupids
 	 *
 	 * @return array
 	 */
-	public function delete(array $userGroupIds) {
-		$this->validateDelete($userGroupIds);
+	public function delete(array $usergroupids) {
+		$this->validateDelete($usergroupids);
 
-		$operationIds = $delelteOperationIds = array();
-
-		$dbOperations = DBselect(
+		$db_operations = DBFetchArray(DBselect(
 			'SELECT DISTINCT om.operationid'.
 			' FROM opmessage_grp om'.
-			' WHERE '.dbConditionInt('om.usrgrpid', $userGroupIds)
-		);
-		while ($dbOperation = DBfetch($dbOperations)) {
-			$operationIds[$dbOperation['operationid']] = $dbOperation['operationid'];
-		}
+			' WHERE '.dbConditionInt('om.usrgrpid', $usergroupids)
+		));
 
-		$dbOperations = DBselect(
-			'SELECT DISTINCT o.operationid'.
+		DB::delete('opmessage_grp', ['usrgrpid' => $usergroupids]);
+
+		// delete empty operations
+		$del_operations = DBFetchArray(DBselect(
+			'SELECT DISTINCT o.operationid,o.actionid'.
 			' FROM operations o'.
-			' WHERE '.dbConditionInt('o.operationid', $operationIds).
-				' AND NOT EXISTS(SELECT om.opmessage_grpid FROM opmessage_grp om WHERE om.operationid=o.operationid)'
-		);
-		while ($dbOperation = DBfetch($dbOperations)) {
-			$delelteOperationIds[$dbOperation['operationid']] = $dbOperation['operationid'];
+			' WHERE '.dbConditionInt('o.operationid', zbx_objectValues($db_operations, 'operationid')).
+				' AND NOT EXISTS(SELECT NULL FROM opmessage_grp omg WHERE omg.operationid=o.operationid)'.
+				' AND NOT EXISTS(SELECT NULL FROM opmessage_usr omu WHERE omu.operationid=o.operationid)'
+		));
+
+		DB::delete('operations', ['operationid' => zbx_objectValues($del_operations, 'operationid')]);
+		DB::delete('rights', ['groupid' => $usergroupids]);
+		DB::delete('users_groups', ['usrgrpid' => $usergroupids]);
+		DB::delete('usrgrp', ['usrgrpid' => $usergroupids]);
+
+		$actionids = zbx_objectValues($del_operations, 'actionid');
+		if ($actionids) {
+			$this->disableActionsWithoutOperations($actionids);
 		}
 
-		DB::delete('opmessage_grp', array('usrgrpid' => $userGroupIds));
-		DB::delete('operations', array('operationid' => $delelteOperationIds));
-		DB::delete('rights', array('groupid' => $userGroupIds));
-		DB::delete('users_groups', array('usrgrpid' => $userGroupIds));
-		DB::delete('usrgrp', array('usrgrpid' => $userGroupIds));
-
-		return array('usrgrpids' => $userGroupIds);
+		return ['usrgrpids' => $usergroupids];
 	}
 
 	/**
@@ -637,18 +598,18 @@ class CUserGroup extends CApiService {
 			self::exception(ZBX_API_ERROR_PARAMETERS, _('Empty input parameter.'));
 		}
 
-		$dbUserGroups = $this->get(array(
-			'output' => array('usrgrpid', 'name'),
+		$dbUserGroups = $this->get([
+			'output' => ['usrgrpid', 'name'],
 			'usrgrpids' => $userGroupIds,
 			'preservekeys' => true
-		));
+		]);
 
 		// check if user group is used in scripts
-		$dbScripts = API::Script()->get(array(
-			'output' => array('scriptid', 'name', 'usrgrpid'),
+		$dbScripts = API::Script()->get([
+			'output' => ['scriptid', 'name', 'usrgrpid'],
 			'usrgrpids' => $userGroupIds,
 			'nopermissions' => true
-		));
+		]);
 
 		foreach ($dbScripts as $dbScript) {
 			if ($dbScript['usrgrpid'] == 0) {
@@ -673,21 +634,23 @@ class CUserGroup extends CApiService {
 		}
 
 		// check if user group is used in users with 1 user group
-		$dbUsers = API::User()->get(array(
-			'output' => array('userid', 'usrgrpid', 'alias'),
+		$dbUsers = API::User()->get([
+			'output' => ['userid', 'usrgrpid', 'alias'],
 			'usrgrpids' => $userGroupIds,
-			'selectUsrgrps' => array('usrgrpid')
-		));
+			'selectUsrgrps' => ['usrgrpid']
+		]);
 
 		foreach ($dbUsers as $dbUser) {
-			if (count($dbUser['usrgrps']) == 1) {
-				$dbGroup = reset($dbUser['usrgrps']);
+			$db_usrgrpids = [];
 
-				self::exception(ZBX_API_ERROR_PARAMETERS, _s(
-					'User group "%1$s" is the only group that user "%2$s" belongs to.',
-					$dbUserGroups[$dbGroup['usrgrpid']]['name'],
-					$dbUser['alias']
-				));
+			foreach ($dbUser['usrgrps'] as $usrgrp) {
+				$db_usrgrpids[] = $usrgrp['usrgrpid'];
+			}
+
+			if (!array_diff($db_usrgrpids, $userGroupIds)) {
+				self::exception(ZBX_API_ERROR_PARAMETERS,
+					_s('User "%1$s" cannot be without user group.', $dbUser['alias'])
+				);
 			}
 		}
 	}
@@ -702,10 +665,10 @@ class CUserGroup extends CApiService {
 
 		$ids = array_unique($ids);
 
-		$count = $this->get(array(
+		$count = $this->get([
 			'usrgrpids' => $ids,
 			'countOutput' => true
-		));
+		]);
 
 		return (count($ids) == $count);
 	}
@@ -720,11 +683,11 @@ class CUserGroup extends CApiService {
 
 		$ids = array_unique($ids);
 
-		$count = $this->get(array(
+		$count = $this->get([
 			'usrgrpids' => $ids,
 			'editable' => true,
 			'countOutput' => true
-		));
+		]);
 
 		return (count($ids) == $count);
 	}
@@ -736,16 +699,91 @@ class CUserGroup extends CApiService {
 		if ($options['selectUsers'] !== null && $options['selectUsers'] != API_OUTPUT_COUNT) {
 			$relationMap = $this->createRelationMap($result, 'usrgrpid', 'userid', 'users_groups');
 
-			$dbUsers = API::User()->get(array(
+			$dbUsers = API::User()->get([
 				'output' => $options['selectUsers'],
 				'userids' => $relationMap->getRelatedIds(),
 				'getAccess' => ($options['selectUsers'] == API_OUTPUT_EXTEND) ? true : null,
 				'preservekeys' => true
-			));
+			]);
 
 			$result = $relationMap->mapMany($result, $dbUsers, 'users');
 		}
 
+		// adding usergroup rights
+		if ($options['selectRights'] !== null && $options['selectRights'] != API_OUTPUT_COUNT) {
+			$relationMap = $this->createRelationMap($result, 'groupid', 'rightid', 'rights');
+
+			if (is_array($options['selectRights'])) {
+				$pk_field = $this->pk('rights');
+
+				$output_fields = [
+					$pk_field => $this->fieldId($pk_field, 'r')
+				];
+
+				foreach ($options['selectRights'] as $field) {
+					if ($this->hasField($field, 'rights')) {
+						$output_fields[$field] = $this->fieldId($field, 'r');
+					}
+				}
+
+				$output_fields = implode(',', $output_fields);
+			}
+			else {
+				$output_fields = 'r.*';
+			}
+
+			$db_rights = DBfetchArray(DBselect(
+				'SELECT '.$output_fields.
+				' FROM rights r'.
+				' WHERE '.dbConditionInt('r.rightid', $relationMap->getRelatedIds()).
+					((self::$userData['type'] == USER_TYPE_SUPER_ADMIN) ? '' : ' AND r.permission>'.PERM_DENY)
+			));
+			$db_rights = zbx_toHash($db_rights, 'rightid');
+
+			foreach ($db_rights as &$db_right) {
+				unset($db_right['rightid'], $db_right['groupid']);
+			}
+			unset($db_right);
+
+			$result = $relationMap->mapMany($result, $db_rights, 'rights');
+		}
+
 		return $result;
 	}
+
+	/**
+	 * Disable actions that do not have operations.
+	 */
+	protected function disableActionsWithoutOperations(array $actionids) {
+		$actions = DBFetchArray(DBselect(
+			'SELECT DISTINCT a.actionid'.
+			' FROM actions a'.
+			' WHERE NOT EXISTS (SELECT NULL FROM operations o WHERE o.actionid=a.actionid)'.
+				' AND '.dbConditionInt('a.actionid', $actionids)
+		));
+
+		$actions_without_operations = zbx_objectValues($actions, 'actionid');
+		if ($actions_without_operations) {
+			$this->disableActions($actions_without_operations);
+		}
+	}
+
+	/**
+	 * Disable actions.
+	 *
+	 * @param array $actionids
+	 */
+	protected function disableActions(array $actionids) {
+		$update = [
+			'values' => ['status' => ACTION_STATUS_DISABLED],
+			'where' => ['actionid' => $actionids]
+		];
+		DB::update('actions', $update);
+
+		foreach($actionids as $actionid) {
+			add_audit_details(AUDIT_ACTION_DISABLE, AUDIT_RESOURCE_ACTION, $actionid, '',
+				_('Action disabled due to deletion of user group.'), null
+			);
+		}
+	}
 }
