@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2018 Zabbix SIA
+** Copyright (C) 2001-2016 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -21,16 +21,17 @@
 
 class CConfigurationExportBuilder {
 
-	const EXPORT_VERSION = '2.0';
-
 	/**
 	 * @var array
 	 */
-	protected $data = array();
+	protected $data = [];
 
+	/**
+	 * @param $version  current export version
+	 */
 	public function __construct() {
-		$this->data['version'] = self::EXPORT_VERSION;
-		$this->data['date'] = date('Y-m-d\TH:i:s\Z', time() - date('Z'));
+		$this->data['version'] = ZABBIX_EXPORT_VERSION;
+		$this->data['date'] = date(DATE_TIME_FORMAT_SECONDS_XML, time() - date('Z'));
 	}
 
 	/**
@@ -39,7 +40,7 @@ class CConfigurationExportBuilder {
 	 * @return array
 	 */
 	public function getExport() {
-		return array('zabbix_export' => $this->data);
+		return ['zabbix_export' => $this->data];
 	}
 
 	/**
@@ -57,13 +58,15 @@ class CConfigurationExportBuilder {
 	 * @param array $templates
 	 */
 	public function buildTemplates(array $templates) {
-		order_result($templates, 'host');
-		$this->data['templates'] = array();
+		$this->data['templates'] = [];
+
+		CArrayHelper::sort($templates, ['host']);
 
 		foreach ($templates as $template) {
-			$this->data['templates'][] = array(
+			$this->data['templates'][] = [
 				'template' => $template['host'],
 				'name' => $template['name'],
+				'description' => $template['description'],
 				'groups' => $this->formatGroups($template['groups']),
 				'applications' => $this->formatApplications($template['applications']),
 				'items' => $this->formatItems($template['items']),
@@ -71,7 +74,7 @@ class CConfigurationExportBuilder {
 				'macros' => $this->formatMacros($template['macros']),
 				'templates' => $this->formatTemplateLinkage($template['parentTemplates']),
 				'screens' => $this->formatScreens($template['screens'])
-			);
+			];
 		}
 	}
 
@@ -80,22 +83,30 @@ class CConfigurationExportBuilder {
 	 *
 	 * @param $hosts
 	 */
-	public function buildHosts($hosts) {
-		order_result($hosts, 'host');
-		$this->data['hosts'] = array();
+	public function buildHosts(array $hosts) {
+		$this->data['hosts'] = [];
+
+		CArrayHelper::sort($hosts, ['host']);
 
 		foreach ($hosts as $host) {
 			$host = $this->createInterfaceReferences($host);
 
-			$this->data['hosts'][] = array(
+			$this->data['hosts'][] = [
 				'host' => $host['host'],
 				'name' => $host['name'],
+				'description' => $host['description'],
 				'proxy' => $host['proxy'],
 				'status' => $host['status'],
 				'ipmi_authtype' => $host['ipmi_authtype'],
 				'ipmi_privilege' => $host['ipmi_privilege'],
 				'ipmi_username' => $host['ipmi_username'],
 				'ipmi_password' => $host['ipmi_password'],
+				'tls_connect' => $host['tls_connect'],
+				'tls_accept' => $host['tls_accept'],
+				'tls_issuer' => $host['tls_issuer'],
+				'tls_subject' => $host['tls_subject'],
+				'tls_psk_identity' => $host['tls_psk_identity'],
+				'tls_psk' => $host['tls_psk'],
 				'templates' => $this->formatTemplateLinkage($host['parentTemplates']),
 				'groups' => $this->formatGroups($host['groups']),
 				'interfaces' => $this->formatHostInterfaces($host['interfaces']),
@@ -104,7 +115,7 @@ class CConfigurationExportBuilder {
 				'discovery_rules' => $this->formatDiscoveryRules($host['discoveryRules']),
 				'macros' => $this->formatMacros($host['macros']),
 				'inventory' => $this->formatHostInventory($host['inventory'])
-			);
+			];
 		}
 	}
 
@@ -141,14 +152,14 @@ class CConfigurationExportBuilder {
 	 * @param array $images
 	 */
 	public function buildImages(array $images) {
-		$this->data['images'] = array();
+		$this->data['images'] = [];
 
 		foreach ($images as $image) {
-			$this->data['images'][] = array(
+			$this->data['images'][] = [
 				'name' => $image['name'],
 				'imagetype' => $image['imagetype'],
 				'encodedImage' => $image['encodedImage']
-			);
+			];
 		}
 	}
 
@@ -158,11 +169,13 @@ class CConfigurationExportBuilder {
 	 * @param array $maps
 	 */
 	public function buildMaps(array $maps) {
-		order_result($maps, 'name');
-		$this->data['maps'] = array();
+		$this->data['maps'] = [];
+
+		CArrayHelper::sort($maps, ['name']);
 
 		foreach ($maps as $map) {
-			$this->data['maps'][] = array(
+			$tmpSelements = $this->formatMapElements($map['selements']);
+			$this->data['maps'][] = [
 				'name' => $map['name'],
 				'width' => $map['width'],
 				'height' => $map['height'],
@@ -191,9 +204,49 @@ class CConfigurationExportBuilder {
 				'background' => $map['backgroundid'],
 				'iconmap' => $map['iconmap'],
 				'urls' => $this->formatMapUrls($map['urls']),
-				'selements' => $this->formatMapElements($map['selements']),
-				'links' => $this->formatMapLinks($map['links'])
-			);
+				'selements' => $tmpSelements,
+				'links' => $this->formatMapLinks($map['links'], $tmpSelements)
+			];
+		}
+	}
+
+	/**
+	 * Format mappings.
+	 *
+	 * @param array $mappings
+	 *
+	 * @return array
+	 */
+	protected function formatMappings(array $mappings) {
+		$result = [];
+
+		CArrayHelper::sort($mappings, ['value']);
+
+		foreach ($mappings as $mapping) {
+			$result[] = [
+				'value' => $mapping['value'],
+				'newvalue' => $mapping['newvalue']
+			];
+		}
+
+		return $result;
+	}
+
+	/**
+	 * Format value maps.
+	 *
+	 * @param array $valuemaps
+	 */
+	public function buildValueMaps(array $valuemaps) {
+		$this->data['value_maps'] = [];
+
+		CArrayHelper::sort($valuemaps, ['name']);
+
+		foreach ($valuemaps as $valuemap) {
+			$this->data['value_maps'][] = [
+				'name' => $valuemap['name'],
+				'mappings' => $this->formatMappings($valuemap['mappings'])
+			];
 		}
 	}
 
@@ -206,10 +259,10 @@ class CConfigurationExportBuilder {
 	 * @return array
 	 */
 	protected function createInterfaceReferences(array $host) {
-		$references = array(
+		$references = [
 			'num' => 1,
-			'refs' => array()
-		);
+			'refs' => []
+		];
 
 		// create interface references
 		foreach ($host['interfaces'] as &$interface) {
@@ -252,11 +305,12 @@ class CConfigurationExportBuilder {
 	 * @return array
 	 */
 	protected function formatDiscoveryRules(array $discoveryRules) {
-		$result = array();
-		order_result($discoveryRules, 'name');
+		$result = [];
+
+		CArrayHelper::sort($discoveryRules, ['key_']);
 
 		foreach ($discoveryRules as $discoveryRule) {
-			$data = array(
+			$data = [
 				'name' => $discoveryRule['name'],
 				'type' => $discoveryRule['type'],
 				'snmp_community' => $discoveryRule['snmp_community'],
@@ -288,10 +342,12 @@ class CConfigurationExportBuilder {
 				'trigger_prototypes' => $this->formatTriggers($discoveryRule['triggerPrototypes']),
 				'graph_prototypes' => $this->formatGraphs($discoveryRule['graphPrototypes']),
 				'host_prototypes' => $this->formatHostPrototypes($discoveryRule['hostPrototypes'])
-			);
+			];
+
 			if (isset($discoveryRule['interface_ref'])) {
 				$data['interface_ref'] = $discoveryRule['interface_ref'];
 			}
+
 			$result[] = $data;
 		}
 
@@ -307,6 +363,7 @@ class CConfigurationExportBuilder {
 	 */
 	protected function formatHostInventory(array $inventory) {
 		unset($inventory['hostid']);
+
 		return $inventory;
 	}
 
@@ -318,11 +375,12 @@ class CConfigurationExportBuilder {
 	 * @return array
 	 */
 	protected function formatGraphs(array $graphs) {
-		$result = array();
-		order_result($graphs, 'name');
+		$result = [];
+
+		CArrayHelper::sort($graphs, ['name']);
 
 		foreach ($graphs as $graph) {
-			$result[] = array(
+			$result[] = [
 				'name' => $graph['name'],
 				'width' => $graph['width'],
 				'height' => $graph['height'],
@@ -340,7 +398,7 @@ class CConfigurationExportBuilder {
 				'ymin_item_1' => $graph['ymin_itemid'],
 				'ymax_item_1' => $graph['ymax_itemid'],
 				'graph_items' => $this->formatGraphItems($graph['gitems'])
-			);
+			];
 		}
 
 		return $result;
@@ -354,18 +412,19 @@ class CConfigurationExportBuilder {
 	 * @return array
 	 */
 	protected function formatHostPrototypes(array $hostPrototypes) {
-		$result = array();
-		order_result($hostPrototypes, 'host');
+		$result = [];
+
+		CArrayHelper::sort($hostPrototypes, ['host']);
 
 		foreach ($hostPrototypes as $hostPrototype) {
-			$result[] = array(
+			$result[] = [
 				'host' => $hostPrototype['host'],
 				'name' => $hostPrototype['name'],
 				'status' => $hostPrototype['status'],
 				'group_links' => $this->formatGroupLinks($hostPrototype['groupLinks']),
 				'group_prototypes' => $this->formatGroupPrototypes($hostPrototype['groupPrototypes']),
 				'templates' => $this->formatTemplateLinkage($hostPrototype['templates'])
-			);
+			];
 		}
 
 		return $result;
@@ -379,12 +438,14 @@ class CConfigurationExportBuilder {
 	 * @return array
 	 */
 	protected function formatGroupLinks(array $groupLinks) {
-		$result = array();
+		$result = [];
+
+		CArrayHelper::sort($groupLinks, ['name']);
 
 		foreach ($groupLinks as $groupLink) {
-			$result[] = array(
+			$result[] = [
 				'group' => $groupLink['groupid'],
-			);
+			];
 		}
 
 		return $result;
@@ -398,12 +459,14 @@ class CConfigurationExportBuilder {
 	 * @return array
 	 */
 	protected function formatGroupPrototypes(array $groupPrototypes) {
-		$result = array();
+		$result = [];
+
+		CArrayHelper::sort($groupPrototypes, ['name']);
 
 		foreach ($groupPrototypes as $groupPrototype) {
-			$result[] = array(
+			$result[] = [
 				'name' => $groupPrototype['name']
-			);
+			];
 		}
 
 		return $result;
@@ -417,13 +480,14 @@ class CConfigurationExportBuilder {
 	 * @return array
 	 */
 	protected function formatTemplateLinkage(array $templates) {
-		$result = array();
-		order_result($templates, 'host');
+		$result = [];
+
+		CArrayHelper::sort($templates, ['host']);
 
 		foreach ($templates as $template) {
-			$result[] = array(
+			$result[] = [
 				'name' => $template['host']
-			);
+			];
 		}
 
 		return $result;
@@ -437,24 +501,21 @@ class CConfigurationExportBuilder {
 	 * @return array
 	 */
 	protected function formatTriggers(array $triggers) {
-		order_result($triggers, 'description');
+		$result = [];
+
+		CArrayHelper::sort($triggers, ['description', 'expression']);
 
-		$result = array();
 		foreach ($triggers as $trigger) {
-			$tr = array(
+			$result[] = [
 				'expression' => $trigger['expression'],
 				'name' => $trigger['description'],
 				'url' => $trigger['url'],
 				'status' => $trigger['status'],
 				'priority' => $trigger['priority'],
 				'description' => $trigger['comments'],
-				'type' => $trigger['type']
-			);
-			if (isset($trigger['dependencies'])) {
-				$tr['dependencies'] = $this->formatDependencies($trigger['dependencies']);
-			}
-
-			$result[] = $tr;
+				'type' => $trigger['type'],
+				'dependencies' => $this->formatDependencies($trigger['dependencies'])
+			];
 		}
 
 		return $result;
@@ -468,19 +529,21 @@ class CConfigurationExportBuilder {
 	 * @return array
 	 */
 	protected function formatHostInterfaces(array $interfaces) {
-		$result = array();
-		order_result($interfaces, 'ip');
+		$result = [];
+
+		CArrayHelper::sort($interfaces, ['type', 'ip', 'dns', 'port']);
 
 		foreach ($interfaces as $interface) {
-			$result[] = array(
+			$result[] = [
 				'default' => $interface['main'],
 				'type' => $interface['type'],
 				'useip' => $interface['useip'],
 				'ip' => $interface['ip'],
 				'dns' => $interface['dns'],
 				'port' => $interface['port'],
+				'bulk' => $interface['bulk'],
 				'interface_ref' => $interface['interface_ref']
-			);
+			];
 		}
 
 		return $result;
@@ -494,13 +557,14 @@ class CConfigurationExportBuilder {
 	 * @return array
 	 */
 	protected function formatGroups(array $groups) {
-		$result = array();
-		order_result($groups, 'name');
+		$result = [];
+
+		CArrayHelper::sort($groups, ['name']);
 
 		foreach ($groups as $group) {
-			$result[] = array(
+			$result[] = [
 				'name' => $group['name']
-			);
+			];
 		}
 
 		return $result;
@@ -514,11 +578,12 @@ class CConfigurationExportBuilder {
 	 * @return array
 	 */
 	protected function formatItems(array $items) {
-		$result = array();
-		order_result($items, 'name');
+		$result = [];
+
+		CArrayHelper::sort($items, ['key_']);
 
 		foreach ($items as $item) {
-			$data = array(
+			$data = [
 				'name' => $item['name'],
 				'type' => $item['type'],
 				'snmp_community' => $item['snmp_community'],
@@ -556,10 +621,16 @@ class CConfigurationExportBuilder {
 				'applications' => $this->formatApplications($item['applications']),
 				'valuemap' => $item['valuemap'],
 				'logtimefmt' => $item['logtimefmt']
-			);
+			];
+
+			if ($item['flags'] == ZBX_FLAG_DISCOVERY_PROTOTYPE) {
+				$data['application_prototypes'] = $this->formatApplications($item['applicationPrototypes']);
+			}
+
 			if (isset($item['interface_ref'])) {
 				$data['interface_ref'] = $item['interface_ref'];
 			}
+
 			$result[] = $data;
 		}
 
@@ -574,13 +645,14 @@ class CConfigurationExportBuilder {
 	 * @return array
 	 */
 	protected function formatApplications(array $applications) {
-		$result = array();
-		order_result($applications, 'name');
+		$result = [];
+
+		CArrayHelper::sort($applications, ['name']);
 
 		foreach ($applications as $application) {
-			$result[] = array(
+			$result[] = [
 				'name' => $application['name']
-			);
+			];
 		}
 
 		return $result;
@@ -594,14 +666,15 @@ class CConfigurationExportBuilder {
 	 * @return array
 	 */
 	protected function formatMacros(array $macros) {
-		$result = array();
+		$result = [];
+
 		$macros = order_macros($macros, 'macro');
 
 		foreach ($macros as $macro) {
-			$result[] = array(
+			$result[] = [
 				'macro' => $macro['macro'],
 				'value' => $macro['value']
-			);
+			];
 		}
 
 		return $result;
@@ -615,16 +688,17 @@ class CConfigurationExportBuilder {
 	 * @return array
 	 */
 	protected function formatScreens(array $screens) {
-		$result = array();
-		order_result($screens, 'name');
+		$result = [];
+
+		CArrayHelper::sort($screens, ['name']);
 
 		foreach ($screens as $screen) {
-			$result[] = array(
+			$result[] = [
 				'name' => $screen['name'],
 				'hsize' => $screen['hsize'],
 				'vsize' => $screen['vsize'],
 				'screen_items' => $this->formatScreenItems($screen['screenitems'])
-			);
+			];
 		}
 
 		return $result;
@@ -638,13 +712,15 @@ class CConfigurationExportBuilder {
 	 * @return array
 	 */
 	protected function formatDependencies(array $dependencies) {
-		$result = array();
+		$result = [];
+
+		CArrayHelper::sort($dependencies, ['description', 'expression']);
 
 		foreach ($dependencies as $dependency) {
-			$result[] = array(
+			$result[] = [
 				'name' => $dependency['description'],
 				'expression' => $dependency['expression']
-			);
+			];
 		}
 
 		return $result;
@@ -658,10 +734,12 @@ class CConfigurationExportBuilder {
 	 * @return array
 	 */
 	protected function formatScreenItems(array $screenItems) {
-		$result = array();
+		$result = [];
+
+		CArrayHelper::sort($screenItems, ['y', 'x']);
 
 		foreach ($screenItems as $screenItem) {
-			$result[] = array(
+			$result[] = [
 				'resourcetype' => $screenItem['resourcetype'],
 				'width' => $screenItem['width'],
 				'height' => $screenItem['height'],
@@ -677,8 +755,9 @@ class CConfigurationExportBuilder {
 				'dynamic' => $screenItem['dynamic'],
 				'sort_triggers' => $screenItem['sort_triggers'],
 				'resource' => $screenItem['resourceid'],
+				'max_columns' => $screenItem['max_columns'],
 				'application' => $screenItem['application']
-			);
+			];
 		}
 
 		return $result;
@@ -692,10 +771,12 @@ class CConfigurationExportBuilder {
 	 * @return array
 	 */
 	protected function formatGraphItems(array $graphItems) {
-		$result = array();
+		$result = [];
+
+		CArrayHelper::sort($graphItems, ['sortorder']);
 
 		foreach ($graphItems as $graphItem) {
-			$result[] = array(
+			$result[] = [
 				'sortorder'=> $graphItem['sortorder'],
 				'drawtype'=> $graphItem['drawtype'],
 				'color'=> $graphItem['color'],
@@ -703,7 +784,7 @@ class CConfigurationExportBuilder {
 				'calc_fnc'=> $graphItem['calc_fnc'],
 				'type'=> $graphItem['type'],
 				'item'=> $graphItem['itemid']
-			);
+			];
 		}
 
 		return $result;
@@ -717,13 +798,16 @@ class CConfigurationExportBuilder {
 	 * @return array
 	 */
 	protected function formatMapUrls(array $urls) {
-		$result = array();
+		$result = [];
+
+		CArrayHelper::sort($urls, ['name', 'url']);
+
 		foreach ($urls as $url) {
-			$result[] = array(
+			$result[] = [
 				'name' => $url['name'],
 				'url' => $url['url'],
 				'elementtype' => $url['elementtype']
-			);
+			];
 		}
 
 		return $result;
@@ -737,13 +821,15 @@ class CConfigurationExportBuilder {
 	 * @return array
 	 */
 	protected function formatMapElementUrls(array $urls) {
-		$result = array();
+		$result = [];
+
+		CArrayHelper::sort($urls, ['name', 'url']);
 
 		foreach ($urls as $url) {
-			$result[] = array(
+			$result[] = [
 				'name' => $url['name'],
 				'url' => $url['url']
-			);
+			];
 		}
 
 		return $result;
@@ -752,22 +838,46 @@ class CConfigurationExportBuilder {
 	/**
 	 * Format map links.
 	 *
-	 * @param array $links
+	 * @param array $links			Map links
+	 * @param array $selements		Map elements
 	 *
 	 * @return array
 	 */
-	protected function formatMapLinks(array $links) {
-		$result = array();
+	protected function formatMapLinks(array $links, array $selements) {
+		$result = [];
+
+		// Get array where key is selementid and value is sort position.
+		$flipped_selements = [];
+		$selements = array_values($selements);
+
+		foreach ($selements as $key => $item) {
+			if (array_key_exists('selementid', $item)) {
+				$flipped_selements[$item['selementid']] = $key;
+			}
+		}
+
+		foreach ($links as &$link) {
+			$link['selementpos1'] = $flipped_selements[$link['selementid1']];
+			$link['selementpos2'] = $flipped_selements[$link['selementid2']];
+
+			// Sort selements positons asc.
+			if ($link['selementpos2'] < $link['selementpos1']) {
+				zbx_swap($link['selementpos1'], $link['selementpos2']);
+			}
+		}
+		unset($link);
+
+		CArrayHelper::sort($links, ['selementpos1', 'selementpos2']);
 
 		foreach ($links as $link) {
-			$result[] = array(
+			$result[] = [
 				'drawtype' => $link['drawtype'],
 				'color' => $link['color'],
 				'label' => $link['label'],
 				'selementid1' => $link['selementid1'],
 				'selementid2' => $link['selementid2'],
 				'linktriggers' => $this->formatMapLinkTriggers($link['linktriggers'])
-			);
+			];
 		}
 
 		return $result;
@@ -781,14 +891,22 @@ class CConfigurationExportBuilder {
 	 * @return array
 	 */
 	protected function formatMapLinkTriggers(array $linktriggers) {
-		$result = array();
+		$result = [];
+
+		foreach ($linktriggers as &$linktrigger) {
+			$linktrigger['description'] = $linktrigger['triggerid']['description'];
+			$linktrigger['expression'] = $linktrigger['triggerid']['expression'];
+		}
+		unset($linktrigger);
+
+		CArrayHelper::sort($linktriggers, ['description', 'expression']);
 
 		foreach ($linktriggers as $linktrigger) {
-			$result[] = array(
+			$result[] = [
 				'drawtype' => $linktrigger['drawtype'],
 				'color' => $linktrigger['color'],
 				'trigger' => $linktrigger['triggerid']
-			);
+			];
 		}
 
 		return $result;
@@ -802,9 +920,12 @@ class CConfigurationExportBuilder {
 	 * @return array
 	 */
 	protected function formatMapElements(array $elements) {
-		$result = array();
+		$result = [];
+
+		CArrayHelper::sort($elements, ['y', 'x']);
+
 		foreach ($elements as $element) {
-			$result[] = array(
+			$result[] = [
 				'elementtype' => $element['elementtype'],
 				'label' => $element['label'],
 				'label_location' => $element['label_location'],
@@ -822,8 +943,9 @@ class CConfigurationExportBuilder {
 				'icon_on' => $element['iconid_on'],
 				'icon_disabled' => $element['iconid_disabled'],
 				'icon_maintenance' => $element['iconid_maintenance'],
+				'application' => $element['application'],
 				'urls' => $this->formatMapElementUrls($element['urls'])
-			);
+			];
 		}
 
 		return $result;
