@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2015 Zabbix SIA
+** Copyright (C) 2001-2016 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -21,11 +21,14 @@
 
 class CButtonCancel extends CButton {
 
-	public function __construct($vars = null, $action = null, $class = null) {
-		parent::__construct('cancel', _('Cancel'), $action, $class);
+	public function __construct($vars = null, $action = null) {
+		parent::__construct('cancel', _('Cancel'));
 		if (is_null($action)) {
 			$this->setVars($vars);
 		}
+		if ($action !== null) {
+			$this->onClick($action);
+		}
 	}
 
 	public function setVars($value = null) {
@@ -35,6 +38,7 @@ class CButtonCancel extends CButton {
 		}
 		$uri = new CUrl($url);
 		$url = $uri->getUrl();
-		return $this->setAttribute('onclick', "javascript: return redirect('".$url."');");
+		$this->onClick("javascript: return redirect('".$url."');");
+		return $this;
 	}
 }
