@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2015 Zabbix SIA
+** Copyright (C) 2001-2016 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -21,33 +21,23 @@
 
 class CCol extends CTag {
 
-	public function __construct($item = null, $class = null, $colspan = null, $width = null) {
-		parent::__construct('td', 'yes');
+	public function __construct($item = null) {
+		parent::__construct('td', true);
 		$this->addItem($item);
-		$this->attr('class', $class);
-		if (!empty($colspan)) {
-			$this->attr('colspan', $colspan);
-		}
-		if (!empty($width)) {
-			$this->attr('width', $width);
-		}
-	}
-
-	public function setAlign($value) {
-		$this->attr('align', strval($value));
 	}
 
 	public function setRowSpan($value) {
-		$this->attr('rowspan', strval($value));
+		$this->setAttribute('rowspan', $value);
+		return $this;
 	}
 
 	public function setColSpan($value) {
-		$this->attr('colspan', strval($value));
+		$this->setAttribute('colspan', $value);
+		return $this;
 	}
 
 	public function setWidth($value) {
-		if (is_string($value)) {
-			$this->attr('width', $value);
-		}
+		$this->setAttribute('width', $value);
+		return $this;
 	}
 }
