@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2015 Zabbix SIA
+** Copyright (C) 2001-2016 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -21,14 +21,9 @@
 
 class CListBox extends CComboBox {
 
-	public function __construct($name = 'listbox', $value = null, $size = 5, $action = null) {
-		parent::__construct($name, null, $action);
-		$this->attr('multiple', 'multiple');
-		$this->attr('size', $size);
-		$this->setValue($value);
-	}
-
-	public function setSize($value) {
-		$this->attr('size', $value);
+	public function __construct($name = 'listbox', $value = null, $size = 5, $action = null, array $items = []) {
+		parent::__construct($name, $value, $action, $items);
+		$this->setAttribute('multiple', 'multiple');
+		$this->setAttribute('size', $size);
 	}
 }
