@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2015 Zabbix SIA
+** Copyright (C) 2001-2016 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -21,10 +21,8 @@
 
 class CListItem extends CTag {
 
-	public function __construct($value, $class = null, $id = null) {
-		parent::__construct('li', 'yes');
+	public function __construct($value) {
+		parent::__construct('li', true);
 		$this->addItem($value);
-		$this->addClass($class);
-		$this->attr('id', $id);
 	}
 }
