@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2018 Zabbix SIA
+** Copyright (C) 2001-2016 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -29,7 +29,12 @@ class CJsonImportReader extends CImportReader {
 	 * @return array
 	 */
 	public function read($string) {
-		$json = new CJSON;
-		return $json->decode($string, true);
+		$data = (new CJson)->decode($string, true);
+
+		if ($data === null){
+			throw new Exception(_s('Cannot read JSON: %1$s.', json_last_error_msg()));
+		}
+
+		return $data;
 	}
 }
