@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2015 Zabbix SIA
+** Copyright (C) 2001-2016 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -121,6 +121,27 @@ class CScreenBase {
 	 */
 	public $dataId;
 
+	/**
+	 * Page number.
+	 *
+	 * @var array
+	 */
+	public $page;
+
+	/**
+	 * Screen parameters with default values.
+	 *
+	 * @var array
+	 */
+	public $parameters;
+
+	/**
+	 * Screen parameters config.
+	 *
+	 * @var array
+	 */
+	public $required_parameters;
+
 	/**
 	 * Init screen data.
 	 *
@@ -144,77 +165,168 @@ class CScreenBase {
 	 * @param array		$options['timeline']
 	 * @param string	$options['dataId']
 	 */
-	public function __construct(array $options = array()) {
-		$this->isFlickerfree = isset($options['isFlickerfree']) ? $options['isFlickerfree'] : true;
-		$this->mode = isset($options['mode']) ? $options['mode'] : SCREEN_MODE_SLIDESHOW;
-		$this->timestamp = !empty($options['timestamp']) ? $options['timestamp'] : time();
-		$this->resourcetype = isset($options['resourcetype']) ? $options['resourcetype'] : null;
-		$this->isTemplatedScreen = isset($options['isTemplatedScreen']) ? $options['isTemplatedScreen'] : false;
-		$this->screenid = !empty($options['screenid']) ? $options['screenid'] : null;
-		$this->action = !empty($options['action']) ? $options['action'] : null;
-		$this->groupid = !empty($options['groupid']) ? $options['groupid'] : null;
-		$this->hostid = isset($options['hostid']) ? $options['hostid'] : 0;
-		$this->dataId = !empty($options['dataId']) ? $options['dataId'] : null;
+	public function __construct(array $options = []) {
+		$this->parameters = [
+			'isFlickerfree'		=> true,
+			'mode'				=> SCREEN_MODE_SLIDESHOW,
+			'timestamp'			=> time(),
+			'resourcetype'		=> null,
+			'isTemplatedScreen'	=> false,
+			'screenid'			=> null,
+			'action'			=> null,
+			'groupid'			=> null,
+			'hostid'			=> 0,
+			'pageFile'			=> null,
+			'profileIdx'		=> '',
+			'profileIdx2'		=> null,
+			'updateProfile'		=> true,
+			'timeline'			=> null,
+			'dataId'			=> null,
+			'page'				=> 1
+		];
 
-		// get page file
-		if (!empty($options['pageFile'])) {
-			$this->pageFile = $options['pageFile'];
+		$this->resourcetype = array_key_exists('resourcetype', $options) ? $options['resourcetype'] : null;
+
+		$this->required_parameters = [
+			'isFlickerfree'		=> true,
+			'mode'				=> true,
+			'timestamp'			=> true,
+			'resourcetype'		=> true,
+			'dataId'			=> true
+		];
+
+		switch ($this->resourcetype) {
+			case SCREEN_RESOURCE_HTTPTEST_DETAILS:
+				$this->required_parameters += [
+					'isTemplatedScreen'	=> false,
+					'screenid'			=> false,
+					'action'			=> false,
+					'groupid'			=> false,
+					'hostid'			=> false,
+					'pageFile'			=> false,
+					'profileIdx'		=> false,
+					'profileIdx2'		=> true,
+					'updateProfile'		=> false,
+					'timeline'			=> false,
+					'page'				=> false
+				];
+				break;
+
+			case SCREEN_RESOURCE_DISCOVERY:
+				$this->required_parameters += [
+					'isTemplatedScreen'	=> false,
+					'screenid'			=> false,
+					'action'			=> false,
+					'groupid'			=> false,
+					'hostid'			=> false,
+					'pageFile'			=> false,
+					'profileIdx'		=> false,
+					'profileIdx2'		=> false,
+					'updateProfile'		=> false,
+					'timeline'			=> false,
+					'page'				=> false
+				];
+				break;
+
+			case SCREEN_RESOURCE_HTTPTEST:
+				$this->required_parameters += [
+					'isTemplatedScreen'	=> false,
+					'screenid'			=> false,
+					'action'			=> false,
+					'groupid'			=> true,
+					'hostid'			=> true,
+					'pageFile'			=> false,
+					'profileIdx'		=> false,
+					'profileIdx2'		=> false,
+					'updateProfile'		=> false,
+					'timeline'			=> false,
+					'page'				=> true
+				];
+				break;
+
+			default:
+				$this->required_parameters += [
+					'isTemplatedScreen'	=> true,
+					'screenid'			=> true,
+					'action'			=> true,
+					'groupid'			=> true,
+					'hostid'			=> true,
+					'pageFile'			=> true,
+					'profileIdx'		=> true,
+					'profileIdx2'		=> true,
+					'updateProfile'		=> true,
+					'timeline'			=> true,
+					'page'				=> false
+				];
 		}
-		else {
+
+		// Get screenitem if its required or resource type is null.
+		$this->screenitem = [];
+		if (array_key_exists('screenitem', $options) && is_array($options['screenitem'])) {
+			$this->screenitem = $options['screenitem'];
+		}
+		elseif (array_key_exists('screenitemid', $options) && $options['screenitemid'] > 0) {
+			$screenitem_output = ['screenitemid', 'screenid', 'resourcetype', 'resourceid', 'width', 'height',
+				'elements', 'halign', 'valign', 'style', 'url', 'dynamic', 'sort_triggers', 'application',
+				'max_columns'
+			];
+
+			if ($this->hostid != 0) {
+				$this->screenitem = API::TemplateScreenItem()->get([
+					'output' => $screenitem_output,
+					'screenitemids' => $options['screenitemid'],
+					'hostids' => $this->hostid
+				]);
+			}
+			else {
+				$this->screenitem = API::ScreenItem()->get([
+					'output' => $screenitem_output,
+					'screenitemids' => $options['screenitemid']
+				]);
+			}
+
+			if ($this->screenitem) {
+				$this->screenitem = reset($this->screenitem);
+			}
+		}
+
+		// Get resourcetype.
+		if ($this->resourcetype === null && array_key_exists('resourcetype',$this->screenitem)) {
+			$this->resourcetype = $this->screenitem['resourcetype'];
+		}
+
+		foreach ($this->parameters as $pname => $default_value) {
+			if ($this->required_parameters[$pname]) {
+				$this->$pname = array_key_exists($pname, $options) ? $options[$pname] : $default_value;
+			}
+		}
+
+		// Get page file.
+		if ($this->required_parameters['pageFile'] && $this->pageFile === null) {
 			global $page;
 			$this->pageFile = $page['file'];
 		}
 
-		// calculate timeline
-		$this->profileIdx = !empty($options['profileIdx']) ? $options['profileIdx'] : '';
-		$this->profileIdx2 = !empty($options['profileIdx2']) ? $options['profileIdx2'] : null;
-		$this->updateProfile = isset($options['updateProfile']) ? $options['updateProfile'] : true;
-		$this->timeline = !empty($options['timeline']) ? $options['timeline'] : null;
-		if (empty($this->timeline)) {
-			$this->timeline = $this->calculateTime(array(
+		// Calculate timeline.
+		if ($this->required_parameters['timeline'] && $this->timeline === null) {
+			$this->timeline = $this->calculateTime([
 				'profileIdx' => $this->profileIdx,
 				'profileIdx2' => $this->profileIdx2,
 				'updateProfile' => $this->updateProfile,
-				'period' => !empty($options['period']) ? $options['period'] : null,
-				'stime' => !empty($options['stime']) ? $options['stime'] : null
-			));
+				'period' => array_key_exists('period', $options) ? $options['period'] : null,
+				'stime' => array_key_exists('stime', $options) ? $options['stime'] : null
+			]);
 		}
 
-		// get screenitem
-		if (!empty($options['screenitem'])) {
-			$this->screenitem = $options['screenitem'];
-		}
-		elseif (!empty($options['screenitemid'])) {
-			if ($this->hostid != 0) {
-				$this->screenitem = API::TemplateScreenItem()->get(array(
-					'screenitemids' => $options['screenitemid'],
-					'hostids' => $this->hostid,
-					'output' => API_OUTPUT_EXTEND
-				));
-			}
-			else {
-				$this->screenitem = API::ScreenItem()->get(array(
-					'screenitemids' => $options['screenitemid'],
-					'output' => API_OUTPUT_EXTEND
-				));
-			}
-
-			$this->screenitem = reset($this->screenitem);
-		}
-
-		// get screenid
-		if (empty($this->screenid) && !empty($this->screenitem)) {
+		// Get screenid.
+		if ($this->required_parameters['screenid'] && $this->screenid === null && $this->screenitem) {
 			$this->screenid = $this->screenitem['screenid'];
 		}
 
-		// get resourcetype
-		if (is_null($this->resourcetype) && !empty($this->screenitem['resourcetype'])) {
-			$this->resourcetype = $this->screenitem['resourcetype'];
-		}
-
-		// create action url
-		if (empty($this->action)) {
-			$this->action = 'screenedit.php?form=update&screenid='.$this->screenid.'&screenitemid='.$this->screenitem['screenitemid'];
+		// Create action URL.
+		if ($this->required_parameters['action'] && $this->action === null && $this->screenitem) {
+			$this->action = 'screenedit.php?form=update&screenid='.$this->screenid.'&screenitemid='.
+				$this->screenitem['screenitemid'];
 		}
 	}
 
@@ -224,8 +336,10 @@ class CScreenBase {
 	 * @return string
 	 */
 	public function getDataId() {
-		if (empty($this->dataId)) {
-			$this->dataId = !empty($this->screenitem) ? $this->screenitem['screenitemid'].'_'.$this->screenitem['screenid'] : 1;
+		if ($this->dataId === null) {
+			$this->dataId = $this->screenitem
+				? $this->screenitem['screenitemid'].'_'.$this->screenitem['screenid']
+				: 1;
 		}
 
 		return $this->dataId;
@@ -246,7 +360,8 @@ class CScreenBase {
 	 * @return string
 	 */
 	public function getProfileUrlParams() {
-		return '&updateProfile='.(int) $this->updateProfile.'&profileIdx='.$this->profileIdx.'&profileIdx2='.$this->profileIdx2;
+		return '&updateProfile='.(int) $this->updateProfile.'&profileIdx='.$this->profileIdx.'&profileIdx2='.
+			$this->profileIdx2;
 	}
 
 	/**
@@ -258,20 +373,23 @@ class CScreenBase {
 	 *
 	 * @return CDiv
 	 */
-	public function getOutput($item = null, $insertFlickerfreeJs = true, $flickerfreeData = array()) {
+	public function getOutput($item = null, $insertFlickerfreeJs = true, $flickerfreeData = []) {
 		if ($insertFlickerfreeJs) {
 			$this->insertFlickerfreeJs($flickerfreeData);
 		}
 
-		if ($this->mode == SCREEN_MODE_EDIT) {
-			$div = new CDiv(array($item, BR(), new CLink(_('Change'), $this->action)), 'flickerfreescreen', $this->getScreenId());
-		}
-		else {
-			$div = new CDiv($item, 'flickerfreescreen', $this->getScreenId());
-		}
+		$div = (new CDiv($item))
+			->addClass('flickerfreescreen')
+			->setAttribute('data-timestamp', $this->timestamp)
+			->setId($this->getScreenId());
 
-		$div->setAttribute('data-timestamp', $this->timestamp);
-		$div->addStyle('position: relative;');
+		if ($this->mode == SCREEN_MODE_EDIT) {
+			$div->addItem(
+				(new CDiv([
+					new CLink(_('Change'), $this->action)
+				]))->addClass(ZBX_STYLE_CENTER)
+			);
+		}
 
 		return $div;
 	}
@@ -281,25 +399,38 @@ class CScreenBase {
 	 *
 	 * @param array $data
 	 */
-	public function insertFlickerfreeJs($data = array()) {
-		$jsData = array(
+	public function insertFlickerfreeJs(array $data = []) {
+		$jsData = [
 			'id' => $this->getDataId(),
-			'isFlickerfree' => $this->isFlickerfree,
-			'pageFile' => $this->pageFile,
-			'resourcetype' => $this->resourcetype,
-			'mode' => $this->mode,
-			'timestamp' => $this->timestamp,
-			'interval' => CWebUser::$data['refresh'],
-			'screenitemid' => !empty($this->screenitem['screenitemid']) ? $this->screenitem['screenitemid'] : null,
-			'screenid' => !empty($this->screenitem['screenid']) ? $this->screenitem['screenid'] : $this->screenid,
-			'groupid' => $this->groupid,
-			'hostid' => $this->hostid,
-			'timeline' => $this->timeline,
-			'profileIdx' => $this->profileIdx,
-			'profileIdx2' => $this->profileIdx2,
-			'updateProfile' => $this->updateProfile,
-			'data' => !empty($data) ? $data : null
-		);
+			'interval' => CWebUser::$data['refresh']
+		];
+
+		$parameters = $this->parameters;
+
+		// unset redundant parameters
+		unset($parameters['isTemplatedScreen'], $parameters['action'], $parameters['dataId']);
+
+		foreach ($parameters as $pname => $default_value) {
+			if ($this->required_parameters[$pname]) {
+				$jsData[$pname] = $this->$pname;
+			}
+		}
+
+		if ($this->screenitem) {
+			$jsData['screenitemid'] = array_key_exists('screenitemid', $this->screenitem)
+				? $this->screenitem['screenitemid']
+				: null;
+		}
+
+		if ($this->required_parameters['screenid']) {
+			$jsData['screenid'] = array_key_exists('screenid', $this->screenitem)
+				? $this->screenitem['screenid']
+				: $this->screenid;
+		}
+
+		if ($data) {
+			$jsData['data'] = $data;
+		}
 
 		zbx_add_post_js('window.flickerfreeScreen.add('.zbx_jsvalue($jsData).');');
 	}
@@ -318,7 +449,7 @@ class CScreenBase {
 	 *
 	 * @return array
 	 */
-	public static function calculateTime(array $options = array()) {
+	public static function calculateTime(array $options = []) {
 		if (!array_key_exists('updateProfile', $options)) {
 			$options['updateProfile'] = true;
 		}
@@ -326,7 +457,7 @@ class CScreenBase {
 			$options['profileIdx2'] = 0;
 		}
 
-		// show only latest data without update is set only period
+		// Show only latest data without update is set only period.
 		if (!empty($options['period']) && empty($options['stime'])) {
 			$options['updateProfile'] = false;
 			$options['profileIdx'] = '';
@@ -340,13 +471,17 @@ class CScreenBase {
 		}
 		else {
 			if ($options['period'] < ZBX_MIN_PERIOD) {
-				show_message(_n('Minimum time period to display is %1$s hour.',
-						'Minimum time period to display is %1$s hours.', (int) ZBX_MIN_PERIOD / SEC_PER_HOUR));
+				show_error_message(_n('Minimum time period to display is %1$s minute.',
+					'Minimum time period to display is %1$s minutes.',
+					(int) ZBX_MIN_PERIOD / SEC_PER_MIN
+				));
 				$options['period'] = ZBX_MIN_PERIOD;
 			}
 			elseif ($options['period'] > ZBX_MAX_PERIOD) {
-				show_message(_n('Maximum time period to display is %1$s day.',
-						'Maximum time period to display is %1$s days.', (int) ZBX_MAX_PERIOD / SEC_PER_DAY));
+				show_error_message(_n('Maximum time period to display is %1$s day.',
+					'Maximum time period to display is %1$s days.',
+					(int) ZBX_MAX_PERIOD / SEC_PER_DAY
+				));
 				$options['period'] = ZBX_MAX_PERIOD;
 			}
 		}
@@ -364,7 +499,7 @@ class CScreenBase {
 			$stimeUnix = zbxDateToTime($options['stime']);
 
 			if ($stimeUnix > $time || zbxAddSecondsToUnixtime($options['period'], $stimeUnix) > $time) {
-				$stimeNow = $options['stime'];
+				$stimeNow = zbxAddSecondsToUnixtime(SEC_PER_YEAR, $options['stime']);
 				$options['stime'] = date(TIMESTAMP_FORMAT, $time - $options['period']);
 				$usertime = date(TIMESTAMP_FORMAT, $time);
 				$isNow = 1;
@@ -410,35 +545,15 @@ class CScreenBase {
 			}
 		}
 
-		return array(
+		return [
 			'period' => $options['period'],
-			'stime' => $options['stime'],
-			'stimeNow' => !empty($stimeNow) ? $stimeNow : $options['stime'],
+			'stime' => date(TIMESTAMP_FORMAT, zbxDateToTime($options['stime'])),
+			'stimeNow' => ($stimeNow === null)
+				? date(TIMESTAMP_FORMAT, zbxAddSecondsToUnixtime(SEC_PER_YEAR, $options['stime']))
+				: $stimeNow,
 			'starttime' => date(TIMESTAMP_FORMAT, $time - ZBX_MAX_PERIOD),
 			'usertime' => $usertime,
 			'isNow' => $isNow
-		);
-	}
-
-	/**
-	 * Easy way to view time data.
-	 *
-	 * @static
-	 *
-	 * @param array		$options
-	 * @param int		$options['period']
-	 * @param string	$options['stime']
-	 * @param string	$options['stimeNow']
-	 * @param string	$options['starttime']
-	 * @param string	$options['usertime']
-	 * @param int		$options['isNow']
-	 */
-	public static function debugTime(array $time = array()) {
-		return 'period='.zbx_date2age(0, $time['period']).', ('.$time['period'].')<br/>'.
-				'starttime='.date('F j, Y, g:i a', zbxDateToTime($time['starttime'])).', ('.$time['starttime'].')<br/>'.
-				'stime='.date('F j, Y, g:i a', zbxDateToTime($time['stime'])).', ('.$time['stime'].')<br/>'.
-				'stimeNow='.date('F j, Y, g:i a', zbxDateToTime($time['stimeNow'])).', ('.$time['stimeNow'].')<br/>'.
-				'usertime='.date('F j, Y, g:i a', zbxDateToTime($time['usertime'])).', ('.$time['usertime'].')<br/>'.
-				'isnow='.$time['isNow'].'<br/>';
+		];
 	}
 }
