@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2015 Zabbix SIA
+** Copyright (C) 2001-2016 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -61,11 +61,11 @@ class CScreenHistory extends CScreenBase {
 	public $plaintext;
 
 	/**
-	 * Items data
+	 * Items ids.
 	 *
 	 * @var array
 	 */
-	public $items;
+	public $itemids;
 
 	/**
 	 * Init screen data.
@@ -75,9 +75,9 @@ class CScreenHistory extends CScreenBase {
 	 * @param int		$options['filterTask']
 	 * @param int		$options['markColor']
 	 * @param boolean	$options['plaintext']
-	 * @param array		$options['items']
+	 * @param array		$options['itemids']
 	 */
-	public function __construct(array $options = array()) {
+	public function __construct(array $options = []) {
 		parent::__construct($options);
 
 		$this->resourcetype = SCREEN_RESOURCE_HISTORY;
@@ -89,7 +89,7 @@ class CScreenHistory extends CScreenBase {
 		$this->graphType = isset($options['graphtype']) ? $options['graphtype'] : GRAPH_TYPE_NORMAL;
 
 		// optional
-		$this->items = isset($options['items']) ? $options['items'] : null;
+		$this->itemids = array_key_exists('itemids', $options) ?  $options['itemids'] : [];
 		$this->plaintext = isset($options['plaintext']) ? $options['plaintext'] : false;
 	}
 
@@ -99,63 +99,76 @@ class CScreenHistory extends CScreenBase {
 	 * @return CDiv (screen inside container)
 	 */
 	public function get() {
-		$output = array();
+		$output = [];
+
+		$items = API::Item()->get([
+			'output' => ['itemid', 'hostid', 'name', 'key_', 'value_type', 'valuemapid'],
+			'selectHosts' => ['name'],
+			'itemids' => $this->itemids,
+			'webitems' => true,
+			'preservekeys' => true
+		]);
+
+		$items = CMacrosResolverHelper::resolveItemNames($items);
 
 		$stime = zbxDateToTime($this->timeline['stime']);
-		$itemIds = zbx_objectValues($this->items, 'itemid');
-		$firstItem = reset($this->items);
+		$firstItem = reset($items);
 
-		$iv_string = array(
+		$iv_string = [
 			ITEM_VALUE_TYPE_LOG => 1,
 			ITEM_VALUE_TYPE_TEXT => 1
-		);
-		$iv_numeric = array(
+		];
+		$iv_numeric = [
 			ITEM_VALUE_TYPE_FLOAT => 1,
 			ITEM_VALUE_TYPE_UINT64 => 1
-		);
+		];
 
 		if ($this->action == HISTORY_VALUES || $this->action == HISTORY_LATEST) {
-			$options = array(
+			$options = [
 				'history' => $firstItem['value_type'],
-				'itemids' => $itemIds,
+				'itemids' => $this->itemids,
 				'output' => API_OUTPUT_EXTEND,
 				'sortorder' => ZBX_SORT_DOWN
-			);
+			];
 			if ($this->action == HISTORY_LATEST) {
 				$options['limit'] = 500;
 			}
 			elseif ($this->action == HISTORY_VALUES) {
 				$config = select_config();
 
-				$options['time_from'] = $stime - 10; // some seconds to allow script to execute
+				// interval start value is non-inclusive, hence the + 1 second
+				$options['time_from'] = $stime + 1;
 				$options['time_till'] = $stime + $this->timeline['period'];
 				$options['limit'] = $config['search_limit'];
 			}
 
 			// text log
 			if (isset($iv_string[$firstItem['value_type']])) {
-				$isManyItems = (count($this->items) > 1);
+				$isManyItems = (count($items) > 1);
 				$useLogItem = ($firstItem['value_type'] == ITEM_VALUE_TYPE_LOG);
 				$useEventLogItem = (strpos($firstItem['key_'], 'eventlog[') === 0);
 
 				if (empty($this->plaintext)) {
-					$historyTable = new CTableInfo(_('No values found.'));
-					$historyTable->setHeader(
-						array(
-							_('Timestamp'),
+					$historyTable = (new CTableInfo())
+						->setHeader([
+							(new CColHeader(_('Timestamp')))->addClass(ZBX_STYLE_CELL_WIDTH),
 							$isManyItems ? _('Item') : null,
-							$useLogItem ? _('Local time') : null,
-							($useEventLogItem && $useLogItem) ? _('Source') : null,
-							($useEventLogItem && $useLogItem) ? _('Severity') : null,
-							($useEventLogItem && $useLogItem) ? _('Event ID') : null,
+							$useLogItem ? (new CColHeader(_('Local time')))->addClass(ZBX_STYLE_CELL_WIDTH) : null,
+							($useEventLogItem && $useLogItem)
+								? (new CColHeader(_('Source')))->addClass(ZBX_STYLE_CELL_WIDTH)
+								: null,
+							($useEventLogItem && $useLogItem)
+								? (new CColHeader(_('Severity')))->addClass(ZBX_STYLE_CELL_WIDTH)
+								: null,
+							($useEventLogItem && $useLogItem)
+								? (new CColHeader(_('Event ID')))->addClass(ZBX_STYLE_CELL_WIDTH)
+								: null,
 							_('Value')
-						),
-						'header'
-					);
+						]);
 				}
 
-				if ($this->filter !== '' && in_array($this->filterTask, array(FILTER_TASK_SHOW, FILTER_TASK_HIDE))) {
-					$options['search'] = array('value' => $this->filter);
+				if ($this->filter !== '' && in_array($this->filterTask, [FILTER_TASK_SHOW, FILTER_TASK_HIDE])) {
+					$options['search'] = ['value' => $this->filter];
 					if ($this->filterTask == FILTER_TASK_HIDE) {
 						$options['excludeSearch'] = 1;
 					}
@@ -165,10 +178,10 @@ class CScreenHistory extends CScreenBase {
 				$historyData = API::History()->get($options);
 
 				foreach ($historyData as $data) {
-					$data['value'] = trim($data['value'], "\r\n");
+					$data['value'] = rtrim($data['value'], " \t\r\n");
 
 					if (empty($this->plaintext)) {
-						$item = $this->items[$data['itemid']];
+						$item = $items[$data['itemid']];
 						$host = reset($item['hosts']);
 						$color = null;
 
@@ -186,50 +199,60 @@ class CScreenHistory extends CScreenBase {
 
 							switch ($color) {
 								case MARK_COLOR_RED:
-									$color = 'red';
+									$color = ZBX_STYLE_RED;
 									break;
 								case MARK_COLOR_GREEN:
-									$color = 'green';
+									$color = ZBX_STYLE_GREEN;
 									break;
 								case MARK_COLOR_BLUE:
-									$color = 'blue';
+									$color = ZBX_STYLE_BLUE;
 									break;
 							}
 						}
 
-						$row = array(nbsp(zbx_date2str(DATE_TIME_FORMAT_SECONDS, $data['clock'])));
+						$row = [];
+
+						$row[] = (new CCol(zbx_date2str(DATE_TIME_FORMAT_SECONDS, $data['clock'])))
+							->addClass(ZBX_STYLE_NOWRAP)
+							->addClass($color);
 
 						if ($isManyItems) {
-							$row[] = $host['name'].NAME_DELIMITER.$item['name_expanded'];
+							$row[] = (new CCol($host['name'].NAME_DELIMITER.$item['name_expanded']))
+								->addClass($color);
 						}
 
 						if ($useLogItem) {
-							$row[] = ($data['timestamp'] == 0)
-								? '-'
-								: zbx_date2str(DATE_TIME_FORMAT_SECONDS, $data['timestamp']);
+							$row[] = ($data['timestamp'] != 0)
+								? (new CCol(zbx_date2str(DATE_TIME_FORMAT_SECONDS, $data['timestamp'])))
+									->addClass(ZBX_STYLE_NOWRAP)
+									->addClass($color)
+								: '';
 
 							// if this is a eventLog item, showing additional info
 							if ($useEventLogItem) {
-								$row[] = ($data['source'] === '') ? '-' : $data['source'];
-								$row[] = ($data['severity'] == 0)
-								? '-'
-								: new CCol(get_item_logtype_description($data['severity']), get_item_logtype_style($data['severity']));
-								$row[] = ($data['logeventid'] == 0) ? '-' : $data['logeventid'];
+								$row[] = (new CCol($data['source']))
+									->addClass(ZBX_STYLE_NOWRAP)
+									->addClass($color);
+								$row[] = ($data['severity'] != 0)
+									? (new CCol(get_item_logtype_description($data['severity'])))
+										->addClass(ZBX_STYLE_NOWRAP)
+										->addClass(get_item_logtype_style($data['severity']))
+									: '';
+								$row[] = ($data['logeventid'] != 0)
+									? (new CCol($data['logeventid']))
+										->addClass(ZBX_STYLE_NOWRAP)
+										->addClass($color)
+									: '';
 							}
 						}
 
-						$row[] = new CCol($data['value'], 'pre');
+						$row[] = (new CCol(new CPre(zbx_nl2br($data['value']))))->addClass($color);
 
-						$newRow = new CRow($row);
-						if (!is_null($color)) {
-							$newRow->setAttribute('class', $color);
-						}
-
-						$historyTable->addRow($newRow);
+						$historyTable->addRow($row);
 					}
 					else {
-						$output[] = zbx_date2str(DATE_TIME_FORMAT_SECONDS, $data['clock']);
-						$output[] = "\t".$data['clock']."\t".htmlspecialchars($data['value'])."\n";
+						$output[] = zbx_date2str(DATE_TIME_FORMAT_SECONDS, $data['clock']).' '. $data['clock'].' '.
+							htmlspecialchars($data['value']);
 					}
 				}
 
@@ -241,16 +264,18 @@ class CScreenHistory extends CScreenBase {
 			// numeric, float
 			else {
 				if (empty($this->plaintext)) {
-					$historyTable = new CTableInfo(_('No values found.'));
-					$historyTable->setHeader(array(_('Timestamp'), _('Value')));
+					$historyTable = (new CTableInfo())->setHeader([
+						(new CColHeader(_('Timestamp')))->addClass(ZBX_STYLE_CELL_WIDTH),
+						_('Value')
+					]);
 				}
 
-				$options['sortfield'] = array('itemid', 'clock');
+				$options['sortfield'] = ['itemid', 'clock'];
 				$historyData = API::History()->get($options);
 
 				foreach ($historyData as $data) {
-					$item = $this->items[$data['itemid']];
-					$value = $data['value'];
+					$item = $items[$data['itemid']];
+					$value = rtrim($data['value'], " \t\r\n");
 
 					// format the value as float
 					if ($item['value_type'] == ITEM_VALUE_TYPE_FLOAT) {
@@ -263,15 +288,16 @@ class CScreenHistory extends CScreenBase {
 							$value = applyValueMap($value, $item['valuemapid']);
 						}
 
-						$historyTable->addRow(array(
-							zbx_date2str(DATE_TIME_FORMAT_SECONDS, $data['clock']),
-							zbx_nl2br($value)
-						));
+						$historyTable->addRow([
+							(new CCol(zbx_date2str(DATE_TIME_FORMAT_SECONDS, $data['clock'])))
+								->addClass(ZBX_STYLE_NOWRAP),
+							new CPre(zbx_nl2br($value))
+						]);
 					}
 					// plain text
 					else {
-						$output[] = zbx_date2str(DATE_TIME_FORMAT_SECONDS, $data['clock']);
-						$output[] = "\t".$data['clock']."\t".htmlspecialchars($value)."\n";
+						$output[] = zbx_date2str(DATE_TIME_FORMAT_SECONDS, $data['clock']).' '.$data['clock'].' '.
+							htmlspecialchars($value);
 					}
 				}
 
@@ -282,25 +308,27 @@ class CScreenHistory extends CScreenBase {
 		}
 
 		// time control
-		if (!$this->plaintext && str_in_array($this->action, array(HISTORY_VALUES, HISTORY_GRAPH, HISTORY_BATCH_GRAPH))) {
+		if (!$this->plaintext && str_in_array($this->action, [HISTORY_VALUES, HISTORY_GRAPH, HISTORY_BATCH_GRAPH])) {
 			$graphDims = getGraphDims();
 
 			$this->timeline['starttime'] = date(TIMESTAMP_FORMAT, get_min_itemclock_by_itemid($firstItem['itemid']));
 
 			$this->dataId = 'historyGraph';
 
-			$timeControlData = array(
+			$timeControlData = [
 				'periodFixed' => CProfile::get('web.history.timelinefixed', 1),
 				'sliderMaximumTimePeriod' => ZBX_MAX_PERIOD
-			);
+			];
 
 			if (($this->action == HISTORY_GRAPH || $this->action == HISTORY_BATCH_GRAPH) && !isset($iv_string[$firstItem['value_type']])) {
 				$containerId = 'graph_cont1';
-				$output[] = new CDiv(null, 'center', $containerId);
+				$output[] = (new CDiv())
+					->addClass('center')
+					->setId($containerId);
 
 				$timeControlData['id'] = $this->getDataId();
 				$timeControlData['containerid'] = $containerId;
-				$timeControlData['src'] = $this->getGraphUrl($itemIds);
+				$timeControlData['src'] = $this->getGraphUrl($this->itemids);
 				$timeControlData['objDims'] = $graphDims;
 				$timeControlData['loadSBox'] = 1;
 				$timeControlData['loadImage'] = 1;
@@ -326,13 +354,13 @@ class CScreenHistory extends CScreenBase {
 		}
 		else {
 			if ($this->mode != SCREEN_MODE_JS) {
-				$flickerfreeData = array(
-					'itemids' => $itemIds,
+				$flickerfreeData = [
+					'itemids' => $this->itemids,
 					'action' => ($this->action == HISTORY_BATCH_GRAPH) ? HISTORY_GRAPH : $this->action,
 					'filter' => $this->filter,
 					'filterTask' => $this->filterTask,
 					'markColor' => $this->markColor
-				);
+				];
 
 				return $this->getOutput($output, true, $flickerfreeData);
 			}
