@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2015 Zabbix SIA
+** Copyright (C) 2001-2016 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -38,13 +38,13 @@ class CScreenPlainText extends CScreenBase {
 		}
 
 		if ($this->screenitem['resourceid'] == 0) {
-			$table = new CTableInfo(_('No values found.'));
-			$table->setHeader(array(_('Timestamp'), _('Item')));
+			$table = (new CTableInfo())
+				->setHeader([_('Timestamp'), _('Item')]);
 
 			return $this->getOutput($table);
 		}
 
-		$items = CMacrosResolverHelper::resolveItemNames(array(get_item_by_itemid($this->screenitem['resourceid'])));
+		$items = CMacrosResolverHelper::resolveItemNames([get_item_by_itemid($this->screenitem['resourceid'])]);
 		$item = reset($items);
 
 		switch ($item['value_type']) {
@@ -55,17 +55,17 @@ class CScreenPlainText extends CScreenBase {
 			case ITEM_VALUE_TYPE_FLOAT:
 			case ITEM_VALUE_TYPE_UINT64:
 			default:
-				$orderField = array('itemid', 'clock');
+				$orderField = ['itemid', 'clock'];
 		}
 
 		$host = get_host_by_itemid($this->screenitem['resourceid']);
 
-		$table = new CTableInfo(_('No values found.'));
-		$table->setHeader(array(_('Timestamp'), $host['name'].NAME_DELIMITER.$item['name_expanded']));
+		$table = (new CTableInfo())
+			->setHeader([_('Timestamp'), _('Value')]);
 
 		$stime = zbxDateToTime($this->timeline['stime']);
 
-		$histories = API::History()->get(array(
+		$histories = API::History()->get([
 			'history' => $item['value_type'],
 			'itemids' => $this->screenitem['resourceid'],
 			'output' => API_OUTPUT_EXTEND,
@@ -74,7 +74,7 @@ class CScreenPlainText extends CScreenBase {
 			'limit' => $this->screenitem['elements'],
 			'time_from' => $stime,
 			'time_till' => $stime + $this->timeline['period']
-		));
+		]);
 		foreach ($histories as $history) {
 			switch ($item['value_type']) {
 				case ITEM_VALUE_TYPE_FLOAT:
@@ -94,11 +94,20 @@ class CScreenPlainText extends CScreenBase {
 				$value = applyValueMap($value, $item['valuemapid']);
 			}
 
-			$class = $this->screenitem['style'] ? null : 'pre';
+			if ($this->screenitem['style'] == 0) {
+				$value = new CPre($value);
+			}
 
-			$table->addRow(array(zbx_date2str(DATE_TIME_FORMAT_SECONDS, $history['clock']), new CCol($value, $class)));
+			$table->addRow([zbx_date2str(DATE_TIME_FORMAT_SECONDS, $history['clock']), $value]);
 		}
 
-		return $this->getOutput($table);
+		$footer = (new CList())
+			->addItem(_s('Updated: %s', zbx_date2str(TIME_FORMAT_SECONDS)))
+			->addClass(ZBX_STYLE_DASHBRD_WIDGET_FOOT);
+
+		return $this->getOutput(
+			(new CUiWidget(uniqid(), [$table, $footer]))
+				->setHeader($host['name'].NAME_DELIMITER.$item['name_expanded'])
+		);
 	}
 }
