@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2018 Zabbix SIA
+** Copyright (C) 2001-2016 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -48,7 +48,7 @@ class CDecimalStringValidator extends CValidator {
 		}
 
 		if (!$isValid) {
-			$this->error($this->messageInvalid, $value);
+			$this->error($this->messageInvalid, $this->stringify($value));
 		}
 
 		return $isValid;
