@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2015 Zabbix SIA
+** Copyright (C) 2001-2016 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@ class CLimitedSetValidator extends CValidator {
 	 *
 	 * @var array
 	 */
-	public $values = array();
+	public $values = [];
 
 	/**
 	 * Error message if the value is invalid or is not of an acceptable type.
