@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2018 Zabbix SIA
+** Copyright (C) 2001-2016 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -56,7 +56,7 @@ class CTimePeriodValidator extends CValidator {
 			$periods = explode(';', $periods);
 		}
 		else {
-			$periods = array($periods);
+			$periods = [$periods];
 		}
 
 		foreach ($periods as $period) {
