@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2015 Zabbix SIA
+** Copyright (C) 2001-2016 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -36,12 +36,12 @@ class CHostNormalValidator extends CValidator {
 	 * @return bool
 	 */
 	public function validate($hostIds) {
-		$hosts = API::Host()->get(array(
-			'output' => array('host'),
+		$hosts = API::Host()->get([
+			'output' => ['host'],
 			'hostids' => $hostIds,
-			'filter' => array('flags' => ZBX_FLAG_DISCOVERY_CREATED),
+			'filter' => ['flags' => ZBX_FLAG_DISCOVERY_CREATED],
 			'limit' => 1
-		));
+		]);
 
 		if ($hosts) {
 			$host = reset($hosts);
