@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2015 Zabbix SIA
+** Copyright (C) 2001-2016 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -21,14 +21,14 @@
 
 include('include/views/js/configuration.httpconf.popup.js.php');
 
-$httpPopupWidget = new CWidget(null, 'httptest-popup');
+$httpPopupWidget = new CWidget();
 
 $result = false;
 if (hasRequest('add') || hasRequest('update')) {
 	$result = true;
 	if ((!hasRequest('stepid') || (hasRequest('stepid') && getRequest('name') !== getRequest('old_name')))
 			&& hasRequest('steps_names')) {
-		foreach (getRequest('steps_names', array()) as $name) {
+		foreach (getRequest('steps_names', []) as $name) {
 			if ($name === getRequest('name')) {
 				show_error_message(_s('Step with name "%1$s" already exists.', $name));
 				$result = false;
@@ -48,19 +48,19 @@ else {
 
 if ((hasRequest('add') || hasRequest('update')) && $result) {
 
-	$httpStepForJs = array(
+	$httpStepForJs = [
 		'stepid' => getRequest('stepid'),
 		'name' => getRequest('name'),
 		'timeout' => getRequest('timeout'),
 		'url' => getRequest('url'),
-		'posts'  => getRequest('posts'),
+		'posts' => getRequest('posts'),
 		'variables' => getRequest('variables'),
 		'required' => getRequest('required'),
 		'status_codes' => getRequest('status_codes'),
 		'headers' => getRequest('headers'),
 		'follow_redirects' => getRequest('follow_redirects', HTTPTEST_STEP_FOLLOW_REDIRECTS_OFF),
-		'retrieve_mode'  => getRequest('retrieve_mode', HTTPTEST_STEP_RETRIEVE_MODE_CONTENT)
-	);
+		'retrieve_mode' => getRequest('retrieve_mode', HTTPTEST_STEP_RETRIEVE_MODE_CONTENT)
+	];
 
 	if (!hasRequest('stepid')) {
 		insert_js('add_httpstep('.CJs::encodeJson(getRequest('dstfrm')).','.
@@ -74,49 +74,60 @@ if ((hasRequest('add') || hasRequest('update')) && $result) {
 	}
 }
 else {
-	$httpPopupForm = new CForm();
-	$httpPopupForm->addVar('dstfrm', getRequest('dstfrm'));
-	$httpPopupForm->addVar('stepid', getRequest('stepid'));
-	$httpPopupForm->addVar('list_name', getRequest('list_name'));
-	$httpPopupForm->addVar('templated', getRequest('templated'));
-	$httpPopupForm->addVar('old_name', getRequest('old_name'));
-	$httpPopupForm->addVar('steps_names', getRequest('steps_names'));
+	$httpPopupForm = (new CForm())
+		->addVar('dstfrm', getRequest('dstfrm'))
+		->addVar('stepid', getRequest('stepid'))
+		->addVar('list_name', getRequest('list_name'))
+		->addVar('templated', getRequest('templated'))
+		->addVar('old_name', getRequest('old_name'))
+		->addVar('steps_names', getRequest('steps_names'));
 
-	$httpPopupFormList = new CFormList('httpPopupFormList');
-	$httpPopupFormList->addRow(_('Name'), new CTextBox('name', getRequest('name', ''), ZBX_TEXTBOX_STANDARD_SIZE, (bool) getRequest('templated'), 64));
-	$httpPopupFormList->addRow(_('URL'), new CTextBox('url', getRequest('url', ''), ZBX_TEXTBOX_STANDARD_SIZE, false, null));
-	$httpPopupFormList->addRow(_('Post'), new CTextArea('posts', getRequest('posts', '')));
-	$httpPopupFormList->addRow(_('Variables'), new CTextArea('variables', getRequest('variables', '')));
-
-	$httpPopupFormList->addRow(_('Headers'), new CTextArea('headers', getRequest('headers', '')));
-
-	$httpPopupFormList->addRow(_('Follow redirects'), new CCheckBox('follow_redirects', $followRedirects, null, true));
-
-	$httpPopupFormList->addRow(_('Retrieve only headers'), new CCheckBox('retrieve_mode', $retrieveMode, null, true));
-
-	$httpPopupFormList->addRow(_('Timeout'), new CNumericBox('timeout', getRequest('timeout', 15), 5));
-	$httpPopupFormList->addRow(_('Required string'), new CTextBox('required', getRequest('required', ''), ZBX_TEXTBOX_STANDARD_SIZE));
-	$httpPopupFormList->addRow(_('Required status codes'), new CTextBox('status_codes', getRequest('status_codes', ''), ZBX_TEXTBOX_STANDARD_SIZE));
+	$httpPopupFormList = (new CFormList())
+		->addRow(_('Name'),
+			(new CTextBox('name', getRequest('name', ''), (bool) getRequest('templated'), 64))
+				->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
+		)
+		->addRow(_('URL'),
+			(new CTextBox('url', getRequest('url', ''), false, null))->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
+		)
+		->addRow(_('Post'), (new CTextArea('posts', getRequest('posts', '')))->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH))
+		->addRow(_('Variables'),
+			(new CTextArea('variables', getRequest('variables', '')))->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
+		)
+		->addRow(_('Headers'),
+			(new CTextArea('headers', getRequest('headers', '')))->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
+		)
+		->addRow(_('Follow redirects'), (new CCheckBox('follow_redirects'))->setChecked($followRedirects == 1))
+		->addRow(_('Retrieve only headers'), (new CCheckBox('retrieve_mode'))->setChecked($retrieveMode == 1))
+		->addRow(_('Timeout'),
+			(new CNumericBox('timeout', getRequest('timeout', 15), 5))->setWidth(ZBX_TEXTAREA_NUMERIC_STANDARD_WIDTH)
+		)
+		->addRow(_('Required string'),
+			(new CTextBox('required', getRequest('required', '')))->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
+		)
+		->addRow(_('Required status codes'),
+			(new CTextBox('status_codes', getRequest('status_codes', '')))->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
+		);
 
 	// append tabs to form
 	$httpPopupTab = new CTabView();
-	$httpPopupTab->addTab('scenarioStepTab', _('Step of scenario'), $httpPopupFormList);
-	$httpPopupForm->addItem($httpPopupTab);
+	$httpPopupTab->addTab('scenarioStepTab', _('Step of web scenario'), $httpPopupFormList);
 
 	// append buttons to form
 	if (hasRequest('stepid')) {
-		$httpPopupForm->addItem(makeFormFooter(
+		$httpPopupTab->setFooter(makeFormFooter(
 			new CSubmit('update', _('Update')),
-			new CButtonCancel(null, 'close_window();')
+			[new CButtonCancel(null, 'close_window();')]
 		));
 	}
 	else {
-		$httpPopupForm->addItem(makeFormFooter(
+		$httpPopupTab->setFooter(makeFormFooter(
 			new CSubmit('add', _('Add')),
-			new CButtonCancel(null, 'close_window();')
+			[new CButtonCancel(null, 'close_window();')]
 		));
 	}
 
+	$httpPopupForm->addItem($httpPopupTab);
 	$httpPopupWidget->addItem($httpPopupForm);
 }
 
