@@ -1,16 +1,21 @@
 <script type="text/x-jquery-tmpl" id="itemTpl">
 <tr id="items_#{number}" class="sortable">
 	<!-- icon + hidden -->
-	<td>
-		<span class="ui-icon ui-icon-arrowthick-2-n-s move"></span>
+	<?php if ($this->data['templates']): ?>
+		<td>
+	<?php else: ?>
+		<td class="<?= ZBX_STYLE_TD_DRAG_ICON ?>">
+			<div class="<?= ZBX_STYLE_DRAG_ICON ?>"></div>
+			<span class="ui-icon ui-icon-arrowthick-2-n-s move"></span>
+	<?php endif ?>
 		<input type="hidden" id="items_#{number}_gitemid" name="items[#{number}][gitemid]" value="#{gitemid}">
 		<input type="hidden" id="items_#{number}_graphid" name="items[#{number}][graphid]" value="#{graphid}">
 		<input type="hidden" id="items_#{number}_itemid" name="items[#{number}][itemid]" value="#{itemid}">
 		<input type="hidden" id="items_#{number}_sortorder" name="items[#{number}][sortorder]" value="#{sortorder}">
 		<input type="hidden" id="items_#{number}_flags" name="items[#{number}][flags]" value="#{flags}">
 		<?php if ($this->data['graphtype'] != GRAPH_TYPE_PIE && $this->data['graphtype'] != GRAPH_TYPE_EXPLODED): ?>
-			<input type="hidden" id="items_#{number}_type" name="items[#{number}][type]" value="<?php echo GRAPH_ITEM_SIMPLE; ?>">
-		<?php endif; ?>
+			<input type="hidden" id="items_#{number}_type" name="items[#{number}][type]" value="<?= GRAPH_ITEM_SIMPLE ?>">
+		<?php endif ?>
 	</td>
 
 	<!-- row number -->
@@ -20,96 +25,95 @@
 
 	<!-- name -->
 	<td>
-		<span id="items_#{number}_name" class="link" onclick="">#{name}</span>
+		<?php if ($this->data['templates']): ?>
+			<span id="items_#{number}_name">#{name}</span>
+		<?php else: ?>
+			<a href="javascript:void(0)"><span id="items_#{number}_name">#{name}</span></a>
+		<?php endif ?>
 	</td>
 
 	<!-- type -->
 	<?php if ($this->data['graphtype'] == GRAPH_TYPE_PIE || $this->data['graphtype'] == GRAPH_TYPE_EXPLODED): ?>
 		<td>
-			<select id="items_#{number}_type" name="items[#{number}][type]" class="input select">
-				<option value="<?php echo GRAPH_ITEM_SIMPLE; ?>"><?php echo _('Simple'); ?></option>
-				<option value="<?php echo GRAPH_ITEM_SUM; ?>"><?php echo _('Graph sum'); ?></option>
+			<select id="items_#{number}_type" name="items[#{number}][type]">
+				<option value="<?= GRAPH_ITEM_SIMPLE ?>"><?= _('Simple') ?></option>
+				<option value="<?= GRAPH_ITEM_SUM ?>"><?= _('Graph sum') ?></option>
 			</select>
 		</td>
-	<?php endif; ?>
+	<?php endif ?>
 
 	<!-- function -->
 	<td>
-		<select id="items_#{number}_calc_fnc" name="items[#{number}][calc_fnc]" class="input select">
+		<select id="items_#{number}_calc_fnc" name="items[#{number}][calc_fnc]">
 		<?php if ($this->data['graphtype'] == GRAPH_TYPE_PIE || $this->data['graphtype'] == GRAPH_TYPE_EXPLODED): ?>
-			<option value="<?php echo CALC_FNC_MIN; ?>"><?php echo _('min'); ?></option>
-			<option value="<?php echo CALC_FNC_AVG; ?>"><?php echo _('avg'); ?></option>
-			<option value="<?php echo CALC_FNC_MAX; ?>"><?php echo _('max'); ?></option>
-			<option value="<?php echo CALC_FNC_LST; ?>"><?php echo _('last'); ?></option>
+			<option value="<?= CALC_FNC_MIN ?>"><?= _('min') ?></option>
+			<option value="<?= CALC_FNC_AVG ?>"><?= _('avg') ?></option>
+			<option value="<?= CALC_FNC_MAX ?>"><?= _('max') ?></option>
+			<option value="<?= CALC_FNC_LST ?>"><?= _('last') ?></option>
 		<?php else: ?>
 			<?php if ($this->data['graphtype'] == GRAPH_TYPE_NORMAL): ?>
-				<option value="<?php echo CALC_FNC_ALL; ?>"><?php echo _('all'); ?></option>
-			<?php endif; ?>
-				<option value="<?php echo CALC_FNC_MIN; ?>"><?php echo _('min'); ?></option>
-				<option value="<?php echo CALC_FNC_AVG; ?>"><?php echo _('avg'); ?></option>
-				<option value="<?php echo CALC_FNC_MAX; ?>"><?php echo _('max'); ?></option>
-		<?php endif; ?>
+				<option value="<?= CALC_FNC_ALL ?>"><?= _('all') ?></option>
+			<?php endif ?>
+				<option value="<?= CALC_FNC_MIN ?>"><?= _('min') ?></option>
+				<option value="<?= CALC_FNC_AVG ?>"><?= _('avg') ?></option>
+				<option value="<?= CALC_FNC_MAX ?>"><?= _('max') ?></option>
+		<?php endif ?>
 		</select>
 	</td>
 
 	<!-- drawtype -->
 	<?php if ($this->data['graphtype'] == GRAPH_TYPE_NORMAL): ?>
 		<td>
-			<select id="items_#{number}_drawtype" name="items[#{number}][drawtype]" class="input select">
+			<select id="items_#{number}_drawtype" name="items[#{number}][drawtype]">
 			<?php foreach (graph_item_drawtypes() as $drawtype): ?>
-				<option value="<?php echo $drawtype; ?>"><?php echo graph_item_drawtype2str($drawtype); ?></option>
-			<?php endforeach; ?>
+				<option value="<?= $drawtype ?>"><?= graph_item_drawtype2str($drawtype) ?></option>
+			<?php endforeach ?>
 			</select>
 		</td>
 	<?php else: ?>
 		<input type="hidden" id="items_#{number}_drawtype" name="items[#{number}][drawtype]" value="#{drawtype}">
-	<?php endif; ?>
+	<?php endif ?>
 
 	<!-- yaxisside -->
 	<?php if ($this->data['graphtype'] == GRAPH_TYPE_NORMAL || $this->data['graphtype'] == GRAPH_TYPE_STACKED): ?>
 		<td>
-			<select id="items_#{number}_yaxisside" name="items[#{number}][yaxisside]" class="input select">
-				<option value="<?php echo GRAPH_YAXIS_SIDE_LEFT; ?>"><?php echo _('Left'); ?></option>
-				<option value="<?php echo GRAPH_YAXIS_SIDE_RIGHT; ?>"><?php echo _('Right'); ?></option>
+			<select id="items_#{number}_yaxisside" name="items[#{number}][yaxisside]">
+				<option value="<?= GRAPH_YAXIS_SIDE_LEFT ?>"><?= _('Left') ?></option>
+				<option value="<?= GRAPH_YAXIS_SIDE_RIGHT ?>"><?= _('Right') ?></option>
 			</select>
 		</td>
 	<?php else: ?>
 		<input type="hidden" id="items_#{number}_yaxisside" name="items[#{number}][yaxisside]" value="#{yaxisside}">
-	<?php endif; ?>
-
-	<!-- color -->
+	<?php endif ?>
 	<td>
-		<input type="text" id="items_#{number}_color" name="items[#{number}][color]" class="input text colorpicker"
-			onchange="javascript: set_color_by_name('items_#{number}_color', this.value);" maxlength="6" size="7" value="">
-		<div id="lbl_items_#{number}_color" name="lbl_items[#{number}][color]" title="#" class="pointer colorpickerLabel"
-			onclick="javascript: show_color_picker('items_#{number}_color');">&nbsp;&nbsp;&nbsp;</div>
-	</td>
-
-	<!-- remove button -->
-	<td>
-		<input type="button" class="input link_menu" id="items_#{number}_remove" data-remove="#{number}" value="<?php echo CHtml::encode(_('Remove')); ?>" onclick="removeItem(this);" />
+		<?= (new CColor('items[#{number}][color]', '000000'))->toString() ?>
 	</td>
+	<?php if (!$this->data['templates']): ?>
+		<td class="<?= ZBX_STYLE_NOWRAP ?>">
+			<button type="button" class="<?= ZBX_STYLE_BTN_LINK ?>" id="items_#{number}_remove" data-remove="#{number}" onclick="removeItem(this);"><?= _('Remove') ?></button>
+		</td>
+	<?php endif ?>
 </tr>
 </script>
 <script type="text/javascript">
 	function loadItem(number, gitemid, graphid, itemid, name, type, calc_fnc, drawtype, yaxisside, color, flags) {
 		var item = {
-			number: number,
-			number_nr: number + 1,
-			gitemid: gitemid,
-			graphid: graphid,
-			itemid: itemid,
-			type: type,
-			calc_fnc: calc_fnc,
-			drawtype: drawtype,
-			yaxisside: yaxisside,
-			color: color,
-			sortorder: number,
-			flags: flags,
-			name: name
-		};
+				number: number,
+				number_nr: number + 1,
+				gitemid: gitemid,
+				graphid: graphid,
+				itemid: itemid,
+				type: type,
+				calc_fnc: calc_fnc,
+				drawtype: drawtype,
+				yaxisside: yaxisside,
+				color: color,
+				sortorder: number,
+				flags: flags,
+				name: name
+			},
+			itemTpl = new Template(jQuery('#itemTpl').html());
 
-		var itemTpl = new Template(jQuery('#itemTpl').html());
 		jQuery('#itemButtonsRow').before(itemTpl.evaluate(item));
 		jQuery('#items_' + number + '_type').val(type);
 		jQuery('#items_' + number + '_calc_fnc').val(calc_fnc);
@@ -119,8 +123,10 @@
 		jQuery('#lbl_items_' + number + '_color').attr('title', '#' + color);
 		jQuery('#lbl_items_' + number + '_color').css('background-color', '#' + color);
 
-		incrementNextColor();
-		rewriteNameLinks();
+		colorPalette.incrementNextColor();
+		<?php if (!$this->data['templates']): ?>
+			rewriteNameLinks();
+		<?php endif ?>
 	}
 
 	function addPopupValues(list) {
@@ -131,56 +137,60 @@
 		for (var i = 0; i < list.values.length; i++) {
 			var number = jQuery('#itemsTable tr.sortable').length,
 				item = {
-				number: number,
-				number_nr: number + 1,
-				gitemid: null,
-				graphid: <?php echo $this->data['graphid']; ?>,
-				itemid: list.values[i].itemid,
-				type: null,
-				calc_fnc: null,
-				drawtype: 0,
-				yaxisside: 0,
-				sortorder: number,
-				flags: (typeof list.values[i].flags === 'undefined') ? 0 : list.values[i].flags,
-				color: getNextColor(1),
-				name: list.values[i].name
-			};
+					number: number,
+					number_nr: number + 1,
+					gitemid: null,
+					graphid: <?= $this->data['graphid'] ?>,
+					itemid: list.values[i].itemid,
+					type: null,
+					calc_fnc: null,
+					drawtype: 0,
+					yaxisside: 0,
+					sortorder: number,
+					flags: (typeof list.values[i].flags === 'undefined') ? 0 : list.values[i].flags,
+					color: colorPalette.getNextColor(),
+					name: list.values[i].name
+				},
+				itemTpl = new Template(jQuery('#itemTpl').html());
 
-			var itemTpl = new Template(jQuery('#itemTpl').html());
 			jQuery('#itemButtonsRow').before(itemTpl.evaluate(item));
-			jQuery('#items_' + item['number'] + '_calc_fnc').val(<?php echo CALC_FNC_AVG; ?>);
+			jQuery('#items_' + item['number'] + '_calc_fnc').val(<?= CALC_FNC_AVG ?>);
 			jQuery('#items_' + item['number'] + '_color').val(item['color']);
 			jQuery('#lbl_items_' + item['number'] + '_color').attr('title', '#' + item['color']);
 			jQuery('#lbl_items_' + item['number'] + '_color').css('background-color', '#' + item['color']);
 		}
 
-		activateSortable();
-		rewriteNameLinks();
+		<?php if (!$this->data['templates']): ?>
+			activateSortable();
+			rewriteNameLinks();
+		<?php endif ?>
 	}
 
 	function getOnlyHostParam() {
 		<?php if ($this->data['is_template']): ?>
-			return '&only_hostid=<?php echo $this->data['hostid']; ?>';
+			return '&only_hostid=<?= $this->data['hostid'] ?>';
 		<?php else: ?>
 			return '&real_hosts=1';
 		<?php endif ?>
 	}
 
+<?php if (!$this->data['templates']): ?>
 	function rewriteNameLinks() {
 		var size = jQuery('#itemsTable tr.sortable').length;
 
 		for (var i = 0; i < size; i++) {
 			var nameLink = 'PopUp("popup.php?writeonly=1&numeric=1&dstfrm=graphForm'
 				+ '&dstfld1=items_' + i + '_itemid&dstfld2=items_' + i + '_name'
-				+ (jQuery('#items_' + i + '_flags').val() == <?php echo ZBX_FLAG_DISCOVERY_PROTOTYPE; ?>
-					? '&srctbl=item_prototypes&parent_discoveryid=<?php echo $this->data['parent_discoveryid']; ?>'
+				+ (jQuery('#items_' + i + '_flags').val() == <?= ZBX_FLAG_DISCOVERY_PROTOTYPE ?>
+					? '&srctbl=item_prototypes&parent_discoveryid=<?= $this->data['parent_discoveryid'] ?>'
 						+ '&srcfld3=flags&dstfld3=items_' + i + '_flags'
 					: '&srctbl=items')
-				+ '<?php echo !empty($this->data['normal_only']) ? '&normal_only=1' : ''; ?>'
-				+ '&srcfld1=itemid&srcfld2=name" + getOnlyHostParam(), 800, 600)';
+				+ '<?= !empty($this->data['normal_only']) ? '&normal_only=1' : '' ?>'
+				+ '&srcfld1=itemid&srcfld2=name" + getOnlyHostParam())';
 			jQuery('#items_' + i + '_name').attr('onclick', nameLink);
 		}
 	}
+<?php endif ?>
 
 	function removeItem(obj) {
 		var number = jQuery(obj).data('remove');
@@ -189,7 +199,9 @@
 		jQuery('#items_' + number).remove();
 
 		recalculateSortOrder();
-		activateSortable();
+		<?php if (!$this->data['templates']): ?>
+			activateSortable();
+		<?php endif ?>
 	}
 
 	function recalculateSortOrder() {
@@ -259,9 +271,12 @@
 			i++;
 		});
 
-		rewriteNameLinks();
+		<?php if (!$this->data['templates']): ?>
+			rewriteNameLinks();
+		<?php endif ?>
 	}
 
+<?php if (!$this->data['templates']): ?>
 	function initSortable() {
 		var itemsTable = jQuery('#itemsTable'),
 			itemsTableWidth = itemsTable.width(),
@@ -277,7 +292,7 @@
 			items: 'tbody tr.sortable',
 			axis: 'y',
 			cursor: 'move',
-			handle: 'span.ui-icon-arrowthick-2-n-s',
+			handle: 'div.<?= ZBX_STYLE_DRAG_ICON ?>',
 			tolerance: 'pointer',
 			opacity: 0.6,
 			update: recalculateSortOrder,
@@ -313,6 +328,7 @@
 	function activateSortable() {
 		jQuery('#itemsTable').sortable({disabled: (jQuery('#itemsTable tr.sortable').length < 2)});
 	}
+<?php endif ?>
 
 	jQuery(function($) {
 		$('#tab_previewTab').click(function() {
@@ -331,7 +347,7 @@
 				<?php if ($this->data['graphtype'] == GRAPH_TYPE_NORMAL): ?>
 					src += '&percent_left=' + $('#percent_left').val()
 							+ '&percent_right=' + $('#percent_right').val();
-				<?php endif; ?>
+				<?php endif ?>
 
 				src += '&ymin_type=' + $('#ymin_type').val()
 							+ '&ymax_type=' + $('#ymax_type').val()
@@ -341,7 +357,7 @@
 							+ '&ymax_itemid=' + $('#ymax_itemid').val()
 							+ '&showworkperiod=' + ($('#show_work_period').is(':checked') ? 1 : 0)
 							+ '&showtriggers=' + ($('#show_triggers').is(':checked') ? 1 : 0);
-			<?php endif; ?>
+			<?php endif ?>
 
 			$('#itemsTable tr.sortable').find('*[name]').each(function(index, value) {
 				if (!$.isEmptyObject(value) && value.name != null) {
@@ -349,45 +365,44 @@
 				}
 			});
 
-			$('#previewTab img')
-				.attr('src', 'styles/themes/<?php echo getUserTheme(CWebUser::$data); ?>/images/preloader.gif')
-				.width(80)
-				.height(12);
+			var image = $('#previewChar img');
+
+			if (image.length != 0) {
+				image.remove();
+			}
+
+			$('#previewChar')
+				.attr('class', 'preloader');
 
 			$('<img />').attr('src', name + '?period=3600' + src).load(function() {
-				$('#previewChar img').remove();
-				$('#previewChar').append($(this));
+				$('#previewChar')
+					.removeAttr('class')
+					.append($(this));
 			});
 		});
 
 		<?php if (!empty($this->data['templateid'])): ?>
-			$('#graphTab input, #graphTab select').each(function() {
-				$(this).attr('disabled', 'disabled');
-				$('#itemsTable').sortable({disabled: true});
-			});
+			$('#itemsTable').sortable({disabled: true}).find('input').prop('readonly', true);
+			$('select', '#itemsTable').prop('disabled', true);
 
 			var size = $('#itemsTable tr.sortable').length;
 
 			for (var i = 0; i < size; i++) {
-				$('.ui-icon').attr('class', 'ui-icon ui-icon-arrowthick-2-n-s state-disabled');
-				$('#items_' + i + '_name').removeAttr('onclick');
-				$('#items_' + i + '_name').removeAttr('class');
 				$('#items_' + i + '_color').removeAttr('onchange');
 				$('#lbl_items_' + i + '_color').removeAttr('onclick');
-				$('#lbl_items_' + i + '_color').attr('class', 'colorpickerLabel');
 			}
-		<?php endif; ?>
+		<?php endif ?>
 
 		// Y axis min clean unused fields
 		$('#ymin_type').change(function() {
 			switch ($(this).val()) {
-				case '<?php echo GRAPH_YAXIS_TYPE_CALCULATED; ?>':
+				case '<?= GRAPH_YAXIS_TYPE_CALCULATED ?>':
 					$('#yaxismin').val('');
 					$('#ymin_name').val('');
 					$('#ymin_itemid').val('0');
 					break;
 
-				case '<?php echo GRAPH_YAXIS_TYPE_FIXED; ?>':
+				case '<?= GRAPH_YAXIS_TYPE_FIXED ?>':
 					$('#ymin_name').val('');
 					$('#ymin_itemid').val('0');
 					break;
@@ -402,13 +417,13 @@
 		// Y axis max clean unused fields
 		$('#ymax_type').change(function() {
 			switch ($(this).val()) {
-				case '<?php echo GRAPH_YAXIS_TYPE_CALCULATED; ?>':
+				case '<?= GRAPH_YAXIS_TYPE_CALCULATED ?>':
 					$('#yaxismax').val('');
 					$('#ymax_name').val('');
 					$('#ymax_itemid').val('0');
 					break;
 
-				case '<?php echo GRAPH_YAXIS_TYPE_FIXED; ?>':
+				case '<?= GRAPH_YAXIS_TYPE_FIXED ?>':
 					$('#ymax_name').val('');
 					$('#ymax_itemid').val('0');
 					break;
@@ -420,6 +435,8 @@
 			$('form[name="graphForm"]').submit();
 		});
 
-		initSortable();
+		<?php if (!$this->data['templates']): ?>
+			initSortable();
+		<?php endif ?>
 	});
 </script>
