@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2015 Zabbix SIA
+** Copyright (C) 2001-2016 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -70,15 +70,6 @@ CDate.prototype = {
 			mnts = this.getMinutes(),
 			sec = this.getSeconds();
 
-		/**
-		 * Transform datetime parts to two digits e.g., 2 becomes 02
-		 * @param int val
-		 * @return string
-		 */
-		var appZr = function(val) {
-			return val < 10 ? '0' + val : val;
-		}
-
 		/**
 		 * Append date suffix according to English rules e.g., 3 becomes 3rd
 		 * @param int date
@@ -99,36 +90,41 @@ CDate.prototype = {
 
 		switch(format) {
 			case 'd M Y H:i':
-				return appZr(dt) + ' ' + shortMn[mnth] + ' ' + yr + ' ' + appZr(hrs) + ':' + appZr(mnts);
+				return appendZero(dt) + ' ' + shortMn[mnth] + ' ' + yr + ' ' + appendZero(hrs) + ':' + appendZero(mnts);
 			case 'j. M Y G:i':
-				return dt + '. ' + shortMn[mnth] + ' ' + yr + ' ' + hrs + ':' + appZr(mnts);
+				return dt + '. ' + shortMn[mnth] + ' ' + yr + ' ' + hrs + ':' + appendZero(mnts);
 			case 'Y/m/d H:i':
-				return yr + '/' + appZr(mnth + 1) + '/' + appZr(dt) + ' ' + appZr(hrs) + ':' + appZr(mnts);
+				return yr + '/' + appendZero(mnth + 1) + '/' + appendZero(dt) + ' ' + appendZero(hrs) + ':' +
+					appendZero(mnts);
 			case 'Y-m-d H:i':
-				return yr + '-' + appZr(mnth + 1) + '-' + appZr(dt) + ' ' + appZr(hrs) + ':' + appZr(mnts);
+				return yr + '-' + appendZero(mnth + 1) + '-' + appendZero(dt) + ' ' + appendZero(hrs) + ':' +
+					appendZero(mnts);
 			case 'Y-m-d':
-				return yr + '-' + appZr(mnth + 1) + '-' + appZr(dt);
+				return yr + '-' + appendZero(mnth + 1) + '-' + appendZero(dt);
 			case 'H:i:s':
-				return  appZr(hrs) + ':' + appZr(mnts) + ':' + appZr(sec);
+				return  appendZero(hrs) + ':' + appendZero(mnts) + ':' + appendZero(sec);
 			case 'H:i':
-				return  appZr(hrs) + ':' + appZr(mnts);
+				return  appendZero(hrs) + ':' + appendZero(mnts);
 			case 'M jS, Y h:i A':
 				var ampm = (hrs < 12) ? 'AM' : 'PM';
-				hrs = appZr((hrs + 11) % 12 + 1);
-				return shortMn[mnth] + ' ' + appSfx(dt) + ', ' + yr + ' ' + hrs + ':' + appZr(mnts) + ' ' + ampm;
+				hrs = appendZero((hrs + 11) % 12 + 1);
+				return shortMn[mnth] + ' ' + appSfx(dt) + ', ' + yr + ' ' + hrs + ':' + appendZero(mnts) + ' ' + ampm;
 			case 'Y M d H:i':
-				return  yr + ' ' + shortMn[mnth] + ' ' +appZr(dt) + ' ' + appZr(hrs) + ':' + appZr(mnts);
+				return  yr + ' ' + shortMn[mnth] + ' ' +appendZero(dt) + ' ' + appendZero(hrs) + ':' + appendZero(mnts);
 			case 'd.m.Y H:i':
-				return appZr(dt) + '.' + appZr(mnth + 1) + '.' + yr + ' ' + appZr(hrs) + ':' + appZr(mnts);
+				return appendZero(dt) + '.' + appendZero(mnth + 1) + '.' + yr + ' ' + appendZero(hrs) + ':' +
+					appendZero(mnts);
 			case 'd. m. Y H:i':
-				return appZr(dt) + '. ' + appZr(mnth + 1) + '. ' + yr + ' ' + appZr(hrs) + ':' + appZr(mnts);
+				return appendZero(dt) + '. ' + appendZero(mnth + 1) + '. ' + yr + ' ' + appendZero(hrs) + ':' +
+					appendZero(mnts);
 			// date format used for date input fields
 			case 'd m Y H i':
-				return appZr(dt) + ' ' + appZr(mnth + 1) + ' ' + yr + ' ' + appZr(hrs) + ' ' + appZr(mnts);
+				return appendZero(dt) + ' ' + appendZero(mnth + 1) + ' ' + yr + ' ' + appendZero(hrs) + ' ' +
+					appendZero(mnts);
 			default:
 				// defaults to Y-m-d H:i:s
-				return yr + '-' + appZr(mnth + 1) + '-' + appZr(dt) + ' ' + appZr(hrs) + ':' + appZr(mnts) +
-					':' + appZr(sec);
+				return yr + '-' + appendZero(mnth + 1) + '-' + appendZero(dt) + ' ' + appendZero(hrs) + ':' +
+					appendZero(mnts) + ':' + appendZero(sec);
 		}
 	},
 
@@ -151,25 +147,14 @@ CDate.prototype = {
 	},
 
 	setZBXDate: function(strdate) {
-		this.server = 1;
-
-		var theDate = {
-			Y: strdate.toString().substr(0, 4),
-			m: strdate.toString().substr(4, 2),
-			d: strdate.toString().substr(6, 2),
-			H: strdate.toString().substr(8, 2),
-			i: strdate.toString().substr(10, 2),
-			s: strdate.toString().substr(12, 2)
-		};
-
-		this.serverDate.setFullYear(theDate.Y);
-		this.serverDate.setMonth(theDate.m - 1);
-		this.serverDate.setDate(theDate.d);
-		this.serverDate.setHours(theDate.H);
-		this.serverDate.setMinutes(theDate.i);
-		this.serverDate.setSeconds(theDate.s);
-		this.serverDate.setMilliseconds(0);
-		this.calcTZdiff();
+		this.setTimeObject(
+			strdate.toString().substr(0, 4),
+			strdate.toString().substr(4, 2) - 1,
+			strdate.toString().substr(6, 2),
+			strdate.toString().substr(8, 2),
+			strdate.toString().substr(10, 2),
+			strdate.toString().substr(12, 2)
+		);
 
 		return this.getTime();
 	},
@@ -273,15 +258,38 @@ CDate.prototype = {
 		this.calcTZdiff();
 	},
 
-	setMonth: function(arg) {
+	setTimeObject: function(y, m, d, h, i, s) {
 		this.server = 1;
-		this.serverDate.setMonth(arg);
-		this.calcTZdiff();
-	},
+		function hasAttr(arg) {
+			return (typeof(arg) != 'undefined' && arg !== null);
+		}
+
+		if (hasAttr(y)) {
+			this.serverDate.setFullYear(y);
+		}
+
+		if (hasAttr(m) && hasAttr(d)) {
+			this.serverDate.setMonth(m, d);
+		}
+		else if (hasAttr(m)) {
+			this.serverDate.setMonth(m);
+		}
+		else if (hasAttr(d)) {
+			this.serverDate.setDate(d);
+		}
+
+		if (hasAttr(h)) {
+			this.serverDate.setHours(h);
+		}
+
+		if (hasAttr(i)) {
+			this.serverDate.setMinutes(i);
+		}
+
+		if (hasAttr(s)) {
+			this.serverDate.setSeconds(s);
+		}
 
-	setFullYear: function(arg) {
-		this.server = 1;
-		this.serverDate.setFullYear(arg);
 		this.calcTZdiff();
 	},
 
