@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2015 Zabbix SIA
+** Copyright (C) 2001-2016 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -91,10 +91,10 @@ Cscreen.prototype = {
 
 		jQuery.post('screenedit.php', params, function(data) {
 			if (!isset('result', data) || !data.result) {
-				jQuery('<p>Ajax request error</p>').dialog({
-					modal: true,
-					resizable: false,
-					draggable: false
+				overlayDialogue({
+					'title': 'Error',
+					'content': jQuery('<span>').text('Ajax request error'),
+					'buttons': []
 				});
 			}
 			else {
