@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2018 Zabbix SIA
+** Copyright (C) 2001-2016 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@ function createSuggest(oid){
 return sid;
 }
 
-var CSuggest = Class.create(CDebug,{
+var CSuggest = Class.create({
 // PUBLIC
 'useLocal':			true,	// use cache to find suggests
 'useServer':		true,	// use server to find suggests
@@ -64,9 +64,8 @@ var CSuggest = Class.create(CDebug,{
 
 'mouseOverSuggest':	false,	// indicates if mouse is over suggests
 
-initialize: function($super, id, objid){
+initialize: function(id, objid){
 	this.id = id;
-	$super('CSuggest['+id+']');
 //--
 
 	this.cleanCache();
@@ -83,8 +82,6 @@ initialize: function($super, id, objid){
 },
 
 needleChange: function(e){
-	this.debug('needleChange');
-//--
 	this.hlIndex = 0;
 	this.suggestCount = 0;
 
@@ -112,8 +109,6 @@ needleChange: function(e){
 
 // SEARCH
 searchServer: function(needle){
-	this.debug('searchServer', needle);
-//---
 	if(needle != this.userNeedle) return true;
 
 	var rpcRequest = {
@@ -126,7 +121,9 @@ searchServer: function(needle){
 			'limit': this.suggestLimit
 		},
 		'onSuccess': this.serverRespond.bind(this, needle),
-		'onFailure': function(){zbx_throw('Suggest Widget: search request failed.');}
+		'onFailure': function() {
+			throw('Suggest Widget: search request failed.');
+		}
 	};
 
 	new RPC.Call(rpcRequest);
@@ -135,9 +132,6 @@ return true;
 },
 
 serverRespond: function(needle, respond){
-	this.debug('serverRespond', needle);
-//--
-
 	var params = {
 		'list': {},
 		'needle': needle
@@ -158,9 +152,6 @@ serverRespond: function(needle, respond){
 },
 
 searchClient: function(needle){
-	this.debug('searchClient', needle);
-//---
-
 	var found = false;
 	if(this.inCache(needle)){
 		this.needles[needle].list = this.cache.needle[needle];
@@ -183,8 +174,6 @@ return found;
 // CACHE
 // -----------------------------------------------------------------------
 searchCache: function(needle){
-	this.debug('searchCache', needle);
-//---
 	var fkey = needle[0];
 	if(!isset(fkey, this.cache.list)) return false;
 
@@ -207,8 +196,6 @@ return found;
 },
 
 inCache: function(needle){
-	this.debug('inCache');
-//---
 	if(this.useServer){
 		var dd = new Date();
 		if((this.cache.time + (this.cacheTimeOut*1000)) < dd.getTime()) this.cleanCache();
@@ -218,8 +205,6 @@ return isset(needle, this.cache.needle);
 },
 
 saveCache: function(needle, list){
-	this.debug('saveCache');
-//---
 	if(this.useServer){
 		var dd = new Date();
 		if((this.cache.time + (this.cacheTimeOut*1000)) < dd.getTime()) this.cleanCache();
@@ -244,9 +229,6 @@ saveCache: function(needle, list){
 },
 
 cleanCache: function(){
-	this.debug('cleanCache');
-//---
-
 	var time = new Date();
 	this.cache = {
 		'time':		time.getTime(),
@@ -267,8 +249,6 @@ onSelect: function(selection){
 // Keyboard
 // -----------------------------------------------------------------------
 searchFocus: function(e){
-	this.debug('keyPressed');
-//---
 	if(!e) e = window.event;
 
 	var elem = e.element();
@@ -283,9 +263,6 @@ searchFocus: function(e){
 },
 
 keyPressed: function(e){
-	this.debug('keyPressed');
-//---
-
 	if(!e) e = window.event;
 	var key = e.keyCode;
 
@@ -318,9 +295,6 @@ keyPressed: function(e){
 },
 
 keyUp: function(e){
-	this.debug('keyUp');
-//---
-
 	if(this.hlIndex == 0) this.hlIndex = this.suggestCount;
 	else this.hlIndex--;
 
@@ -330,8 +304,6 @@ keyUp: function(e){
 },
 
 keyDown: function(e){
-	this.debug('keyDown');
-//---
 	if(is_null(this.dom.suggest) || (this.dom.suggest.style.display == 'none')){
 		this.needleChange(e);
 		return true;
@@ -346,12 +318,10 @@ keyDown: function(e){
 },
 
 mouseOver: function(e){
-	this.debug('mouseOver');
-//---
 	this.mouseOverSuggest = true;
 
-	var row = Event.element(e).parentNode;
-	if(is_null(row) || (row.tagName.toLowerCase() != 'tr') || !isset('id',row)) return true;
+	var row = Event.element(e);
+	if(is_null(row) || (row.tagName.toLowerCase() != 'li') || !isset('id',row)) return true;
 
 	var tmp = row.id.split('_');
 	if(tmp.length != 2) return true;
@@ -363,16 +333,10 @@ mouseOver: function(e){
 },
 
 mouseOut: function(e){
-	this.debug('mouseOut');
-//---
-
 	this.mouseOverSuggest = false;
 },
 
 suggestBlur: function(e){
-	this.debug('suggestBlur');
-//---
-
 	if(this.mouseOverSuggest) Event.stop(e);
 	else this.hideSuggests(e);
 },
@@ -382,24 +346,16 @@ suggestBlur: function(e){
 // -----------------------------------------------------------------------
 
 removeHighLight: function(){
-	this.debug('rmvHighLight');
-//---
-
-	$$('tr.highlight').each( function(hlRow){hlRow.className = '';});
+	$$('li.suggest-hover').each( function(hlRow){hlRow.className = '';});
 },
 
 
 highLightSuggest: function(){
-	this.debug('highLightSuggest');
-//---
-
 	var row = $('line_'+this.hlIndex);
-	if(!is_null(row)) row.className = 'highlight';
+	if(!is_null(row)) row.className = 'suggest-hover';
 },
 
 setNeedleByHighLight: function(){
-	this.debug('setNeedleByHighLight');
-//---
 	if(this.hlIndex == 0)
 		this.dom.input.value = this.userNeedle;
 	else
@@ -407,15 +363,10 @@ setNeedleByHighLight: function(){
 },
 
 selectSuggest: function(e){
-	this.debug('selectSuggest');
-//---
-
 	this.setNeedleByHighLight(e);
 	this.hideSuggests();
 
-//SDJ(this.dom.input);
-
-	if(this.onSelect(this.dom.input.value) && !GK) this.dom.input.form.submit();
+	if(this.onSelect(this.dom.input.value)) this.dom.input.form.submit();
 },
 
 
@@ -424,84 +375,71 @@ selectSuggest: function(e){
 // -----------------------------------------------------------------------
 
 showSuggests: function(){
-	this.debug('showSuggests');
-//---
-
 	if(is_null(this.dom.suggest)){
-		this.dom.suggest = document.createElement('div');
+		this.dom.suggest = document.createElement('ul');
 		this.dom.suggest = $(this.dom.suggest);
 
 		var doc_body = document.getElementsByTagName('body')[0];
 		if(empty(doc_body)) return false;
 
 		doc_body.appendChild(this.dom.suggest);
-		this.dom.suggest.className = 'suggest';
+		this.dom.suggest.className = 'search-suggest';
 
 		this.positionSuggests();
+
+		// insert just after input
+		this.dom.input.parentNode.insertBefore(this.dom.suggest, this.dom.input.nextSibling);
 	}
 
 	this.dom.suggest.style.display = 'block';
 },
 
 hideSuggests: function(){
-	this.debug('hideSuggest');
-//--
-
 	if(!is_null(this.dom.suggest)){
 		this.dom.suggest.style.display = 'none';
 	}
 },
 
 positionSuggests: function(){
-	this.debug('positionSuggests');
-//---
-
 	if(is_null(this.dom.suggest)) return true;
 
 	var pos = jQuery(this.dom.input).offset();
 	var dims = getDimensions(this.dom.input);
 
 	this.dom.suggest.style.top = (pos.top+dims.height)+'px';
-	this.dom.suggest.style.left = pos.left+'px';
+	this.dom.suggest.style.left = '0px';
 },
 
 newSugTab: function(needle){
-	this.debug('newSugTab', needle);
-//---
 	var list = this.needles[needle].list;
 
-	var sugTab = document.createElement('table');
-	sugTab.className = 'suggest';
-
-	var sugBody = document.createElement('tbody');
-	sugTab.appendChild(sugBody);
+	var sugTab = document.createElement('div');
 
 	var count = 0;
 	for(var key in list){
 		if(empty(list[key])) continue;
 		count++;
 
-		var tr = document.createElement('tr');
-		sugBody.appendChild(tr);
+		var li = document.createElement('li');
+		li.setAttribute('id', 'line_'+count);
+		li.setAttribute('needle', list[key]);
 
-		tr.setAttribute('id', 'line_'+count);
-		tr.setAttribute('needle', list[key]);
-
-		var td = document.createElement('td');
-		tr.appendChild(td);
-
-		var bold = document.createElement('b');
+		var bold = document.createElement('span');
 		bold.appendChild(document.createTextNode(list[key].substr(0, needle.length)));
-		td.appendChild(bold);
-		td.appendChild(document.createTextNode(list[key].substr(needle.length)));
+		bold.setAttribute('class', 'suggest-found');
+		li.appendChild(bold);
+		li.appendChild(document.createTextNode(list[key].substr(needle.length)));
 
-		addListener(td, 'mouseover', this.mouseOver.bindAsEventListener(this), true);
-		addListener(td, 'mouseup', this.selectSuggest.bindAsEventListener(this), true);
-		addListener(td, 'mouseout', this.mouseOut.bindAsEventListener(this), true);
+		addListener(li, 'mouseover', this.mouseOver.bindAsEventListener(this), true);
+		addListener(li, 'mouseup', this.selectSuggest.bindAsEventListener(this), true);
+		addListener(li, 'mouseout', this.mouseOut.bindAsEventListener(this), true);
+		sugTab.appendChild(li);
 
 		if(count >= this.suggestLimit) break;
 	}
 
+	this.dom.suggest.appendChild(sugTab);
+
 	if(!is_null(this.dom.sugtab)) this.dom.sugtab.remove();
 
 	this.dom.sugtab = $(sugTab);
