@@ -1,6 +1,6 @@
 /*
  ** Zabbix
- ** Copyright (C) 2001-2015 Zabbix SIA
+ ** Copyright (C) 2001-2016 Zabbix SIA
  **
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -50,7 +50,29 @@ jQuery(function($) {
 		},
 
 		refresh: function(id, isSelfRefresh) {
-			var screen = this.screens[id];
+			var screen = this.screens[id], ajaxParams;
+
+			switch (screen.resourcetype) {
+				case 21:
+					// SCREEN_RESOURCE_HTTPTEST_DETAILS
+					ajaxParams = ['mode', 'resourcetype', 'profileIdx2'];
+					break;
+
+				case 22:
+					// SCREEN_RESOURCE_DISCOVERY
+					ajaxParams = ['mode', 'resourcetype', 'data'];
+					break;
+
+				case 23:
+					// SCREEN_RESOURCE_HTTPTEST
+					ajaxParams = ['mode', 'groupid', 'hostid', 'resourcetype', 'data', 'page'];
+					break;
+
+				default:
+					ajaxParams = ['mode', 'screenid', 'groupid', 'hostid', 'pageFile', 'profileIdx', 'profileIdx2',
+						'updateProfile', 'screenitemid'
+					];
+			}
 
 			if (empty(screen.id)) {
 				return;
@@ -66,22 +88,19 @@ jQuery(function($) {
 			var ajaxUrl = new Curl('jsrpc.php');
 			ajaxUrl.setArgument('type', 9); // PAGE_TYPE_TEXT
 			ajaxUrl.setArgument('method', 'screen.get');
-			ajaxUrl.setArgument('mode', screen.mode);
 			ajaxUrl.setArgument('timestamp', screen.timestampActual);
-			ajaxUrl.setArgument('flickerfreeScreenId', id);
-			ajaxUrl.setArgument('pageFile', screen.pageFile);
-			ajaxUrl.setArgument('screenid', screen.screenid);
-			ajaxUrl.setArgument('screenitemid', screen.screenitemid);
-			ajaxUrl.setArgument('groupid', screen.groupid);
-			ajaxUrl.setArgument('hostid', screen.hostid);
-			ajaxUrl.setArgument('profileIdx', empty(screen.profileIdx) ? null : screen.profileIdx);
-			ajaxUrl.setArgument('profileIdx2', empty(screen.profileIdx2) ? null : screen.profileIdx2);
-			ajaxUrl.setArgument('updateProfile', empty(screen.updateProfile) ? null : +screen.updateProfile);
-			ajaxUrl.setArgument('period', empty(screen.timeline.period) ? null : screen.timeline.period);
-			ajaxUrl.setArgument('stime', this.getCalculatedSTime(screen));
 
-			// SCREEN_RESOURCE_GRAPH
-			// SCREEN_RESOURCE_SIMPLE_GRAPH
+			for (var i = 0; i < ajaxParams.length; i++) {
+				ajaxUrl.setArgument(ajaxParams[i], empty(screen[ajaxParams[i]]) ? null : screen[ajaxParams[i]]);
+			}
+
+			// timeline params
+			if (jQuery.inArray(screen.resourcetype, [21, 22, 23]) === -1) {
+				ajaxUrl.setArgument('period', empty(screen.timeline.period) ? null : screen.timeline.period);
+				ajaxUrl.setArgument('stime', this.getCalculatedSTime(screen));
+			}
+
+			// SCREEN_RESOURCE_GRAPH or SCREEN_RESOURCE_SIMPLE_GRAPH
 			if (screen.resourcetype == 0 || screen.resourcetype == 1) {
 				if (isSelfRefresh || this.isRefreshAllowed(screen)) {
 					this.refreshImg(id, function() {
@@ -189,7 +208,7 @@ jQuery(function($) {
 			for (var id in this.screens) {
 				var screen = this.screens[id];
 
-				if (!empty(screen.id)) {
+				if (!empty(screen.id) && typeof screen.timeline !== 'undefined') {
 					screen.timeline.period = period;
 					screen.timeline.stime = stime;
 					screen.timeline.isNow = isNow;
@@ -556,7 +575,7 @@ jQuery(function($) {
 					}
 
 					// show loading indicator..
-					obj.append($('<div>', {'class': 'loading'})
+					obj.append($('<div>', {'class': 'preloader'})
 						.css({
 							width: '24px',
 							height: '24px',
@@ -566,15 +585,6 @@ jQuery(function($) {
 							left: item.position().left + Math.round(item.width() / 2) - 12
 						})
 					);
-					obj.find('.loading').activity({
-						segments: 12,
-						steps: 3,
-						opacity: 0.3,
-						width: 2,
-						space: 0,
-						length: 5,
-						color: '#0b0b0b'
-					});
 
 					timer.isShadowed = true;
 				}
@@ -591,7 +601,7 @@ jQuery(function($) {
 					return;
 				}
 
-				obj.find('.loading').remove();
+				obj.find('.preloader').remove();
 				obj.find('.shadow').remove();
 				obj.find(item.prop('nodeName')).fadeTo(0, 1);
 
@@ -621,10 +631,10 @@ jQuery(function($) {
 				}
 
 				// loading indicator
-				var loading = obj.find('.loading');
+				var preloader = obj.find('.preloader');
 
-				if (loading.length > 0) {
-					loading.css({
+				if (preloader.length > 0) {
+					preloader.css({
 						top: item.position().top + Math.round(item.height() / 2) - 12,
 						left: item.position().left + Math.round(item.width() / 2) - 12
 					});
