@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2015 Zabbix SIA
+** Copyright (C) 2001-2016 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -101,7 +101,7 @@ var PageRefresh = {
  * Main menu
  */
 var MMenu = {
-	menus:			{'empty': 0, 'view': 0, 'cm': 0, 'reports': 0, 'config': 0, 'admin': 0},
+	menus:			{'view': 0, 'cm': 0, 'reports': 0, 'config': 0, 'admin': 0},
 	def_label:		null,
 	sub_active: 	false,
 	timeout_reset:	null,
@@ -109,7 +109,7 @@ var MMenu = {
 
 	mouseOver: function(show_label) {
 		clearTimeout(this.timeout_reset);
-		this.timeout_change = setTimeout('MMenu.showSubMenu("' + show_label + '")', 200);
+		this.timeout_change = setTimeout('MMenu.showSubMenu("' + show_label + '")', 10);
 		PageRefresh.restart();
 	},
 
@@ -125,23 +125,24 @@ var MMenu = {
 	},
 
 	showSubMenu: function(show_label) {
-		var menu_div = $('sub_' + show_label);
-		if (!is_null(menu_div)) {
-			$(show_label).className = 'active';
-			menu_div.show();
+		var sub_menu = $('sub_' + show_label);
+		if (sub_menu !== null) {
+			$(show_label).className = 'selected';
+			sub_menu.show();
+
 			for (var key in this.menus) {
 				if (key == show_label) {
 					continue;
 				}
 
 				var menu_cell = $(key);
-				if (!is_null(menu_cell)) {
-					if (menu_cell.tagName.toLowerCase() != 'select') {
-						menu_cell.className = '';
-					}
+				if (menu_cell !== null) {
+					menu_cell.className = '';
+					jQuery('a', menu_cell).blur();
 				}
+
 				var sub_menu_cell = $('sub_' + key);
-				if (!is_null(sub_menu_cell)) {
+				if (sub_menu_cell !== null) {
 					sub_menu_cell.hide();
 				}
 			}
@@ -364,8 +365,22 @@ var jqBlink = {
  */
 var hintBox = {
 
-	createBox: function(e, target, hintText, className, isStatic) {
-		var box = jQuery('<div></div>').addClass('hintbox');
+	createBox: function(e, target, hintText, className, isStatic, styles) {
+		var box = jQuery('<div></div>').addClass('overlay-dialogue');
+
+		if (styles) {
+			// property1: value1; property2: value2; property(n): value(n)
+
+			var style_list = styles.split(';');
+
+			for (var i = 0; i < style_list.length; i++) {
+				var style_props = style_list[i].split(':');
+
+				if (style_props[1]) {
+					box.css(style_props[0].trim(), style_props[1].trim());
+				}
+			}
+		}
 
 		if (typeof hintText === 'string') {
 			hintText = hintText.replace(/\n/g, '<br />');
@@ -379,12 +394,10 @@ var hintBox = {
 		}
 
 		if (isStatic) {
-			var close_link = jQuery('<div>' + locale['S_CLOSE'] + '</div>')
-				.addClass('link')
-				.css({
-					'text-align': 'right',
-					'border-bottom': '1px #333 solid'
-				}).click(function() {
+			var close_link = jQuery('<button>', {
+					'class': 'overlay-close-btn'}
+				)
+				.click(function() {
 					hintBox.hideHint(e, target, true);
 				});
 			box.prepend(close_link);
@@ -395,14 +408,14 @@ var hintBox = {
 		return box;
 	},
 
-	HintWraper: function(e, target, hintText, className) {
+	HintWraper: function(e, target, hintText, className, styles) {
 		target.isStatic = false;
 
 		jQuery(target).on('mouseenter', function(e, d) {
 			if (d) {
 				e = d;
 			}
-			hintBox.showHint(e, target, hintText, className, false);
+			hintBox.showHint(e, target, hintText, className, false, styles);
 
 		}).on('mouseleave', function(e) {
 			hintBox.hideHint(e, target);
@@ -415,13 +428,13 @@ var hintBox = {
 		jQuery(target).trigger('mouseenter', e);
 	},
 
-	showStaticHint: function(e, target, hint, className, resizeAfterLoad) {
+	showStaticHint: function(e, target, hint, className, resizeAfterLoad, styles) {
 		var isStatic = target.isStatic;
 		hintBox.hideHint(e, target, true);
 
 		if (!isStatic) {
 			target.isStatic = true;
-			hintBox.showHint(e, target, hint, className, true);
+			hintBox.showHint(e, target, hint, className, true, styles);
 
 			if (resizeAfterLoad) {
 				hint.one('load', function(e) {
@@ -431,12 +444,12 @@ var hintBox = {
 		}
 	},
 
-	showHint: function(e, target, hintText, className, isStatic) {
+	showHint: function(e, target, hintText, className, isStatic, styles) {
 		if (target.hintBoxItem) {
 			return;
 		}
 
-		target.hintBoxItem = hintBox.createBox(e, target, hintText, className, isStatic);
+		target.hintBoxItem = hintBox.createBox(e, target, hintText, className, isStatic, styles);
 		hintBox.positionHint(e, target);
 		target.hintBoxItem.show();
 	},
@@ -446,6 +459,8 @@ var hintBox = {
 			wHeight = jQuery(window).height(),
 			scrollTop = jQuery(window).scrollTop(),
 			scrollLeft = jQuery(window).scrollLeft(),
+			hint_width = jQuery(target.hintBoxItem).outerWidth(),
+			hint_height = jQuery(target.hintBoxItem).outerHeight(),
 			top, left;
 
 		// uses stored clientX on afterload positioning when there is no event
@@ -455,25 +470,25 @@ var hintBox = {
 		}
 
 		// doesn't fit in the screen horizontally
-		if (target.hintBoxItem.width() + 10 > wWidth) {
+		if (hint_width + 10 > wWidth) {
 			left = scrollLeft + 2;
 		}
 		// 10px to right if fit
-		else if (wWidth - target.clientX - 10 > target.hintBoxItem.width()) {
+		else if (wWidth - target.clientX - 10 > hint_width) {
 			left = scrollLeft + target.clientX + 10;
 		}
 		// 10px from screen right side
 		else {
-			left = scrollLeft + wWidth - 10 - target.hintBoxItem.width();
+			left = scrollLeft + wWidth - 10 - hint_width;
 		}
 
 		// 10px below if fit
-		if (wHeight - target.clientY - target.hintBoxItem.height() - 10 > 0) {
+		if (wHeight - target.clientY - hint_height - 10 > 0) {
 			top = scrollTop + target.clientY + 10;
 		}
 		// 10px above if fit
-		else if (target.clientY - target.hintBoxItem.height() - 10 > 0) {
-			top = scrollTop + target.clientY - target.hintBoxItem.height() - 10;
+		else if (target.clientY - hint_height - 10 > 0) {
+			top = scrollTop + target.clientY - hint_height - 10;
 		}
 		// 10px below as fallback
 		else {
@@ -481,21 +496,21 @@ var hintBox = {
 		}
 
 		// fallback if doesn't fit verticaly but could fit if aligned to right or left
-		if ((top - scrollTop + target.hintBoxItem.height() > wHeight)
-				&& (target.clientX - 10 > target.hintBoxItem.width() || wWidth - target.clientX - 10 > target.hintBoxItem.width())) {
+		if ((top - scrollTop + hint_height > wHeight)
+				&& (target.clientX - 10 > hint_width || wWidth - target.clientX - 10 > hint_width)) {
 
 			// align to left if fit
-			if (wWidth - target.clientX - 10 > target.hintBoxItem.width()) {
+			if (wWidth - target.clientX - 10 > hint_width) {
 				left = scrollLeft + target.clientX + 10;
 			}
 			// align to right
 			else {
-				left = scrollLeft + target.clientX - target.hintBoxItem.width() - 10;
+				left = scrollLeft + target.clientX - hint_width - 10;
 			}
 
 			// 10px from bottom if fit
-			if (wHeight - 10 > target.hintBoxItem.height()) {
-				top = scrollTop + wHeight - target.hintBoxItem.height() - 10;
+			if (wHeight - 10 > hint_height) {
+				top = scrollTop + wHeight - hint_height - 10;
 			}
 			// 10px from top
 			else {
@@ -539,7 +554,7 @@ function hide_color_picker() {
 	}
 
 	color_picker.style.zIndex = 1000;
-	color_picker.style.visibility = 'hidden';
+	color_picker.style.display = 'none';
 	color_picker.style.left = '-' + ((color_picker.style.width) ? color_picker.style.width : 100) + 'px';
 	curr_lbl = null;
 	curr_txt = null;
@@ -557,7 +572,7 @@ function show_color_picker(id) {
 	color_picker.y = pos.top;
 	color_picker.style.left = (color_picker.x + 20) + 'px';
 	color_picker.style.top = color_picker.y + 'px';
-	color_picker.style.visibility = 'visible';
+	color_picker.style.display = 'block';
 }
 
 function create_color_picker() {
@@ -566,7 +581,7 @@ function create_color_picker() {
 	}
 
 	color_picker = document.createElement('div');
-	color_picker.setAttribute('id', 'color_picker');
+	color_picker.setAttribute('class', 'overlay-dialogue');
 	color_picker.innerHTML = color_table;
 	document.body.appendChild(color_picker);
 	hide_color_picker();
@@ -589,76 +604,69 @@ function set_color_by_name(id, color) {
 	set_color(color);
 }
 
-function add2favorites(favobj, favid) {
-	sendAjaxData({
+/**
+ * Add object to the list of favourites.
+ */
+function add2favorites(object, objectid) {
+	sendAjaxData('zabbix.php?action=favourite.create', {
 		data: {
-			favobj: favobj,
-			favid: favid,
-			favaction: 'add'
+			object: object,
+			objectid: objectid
 		}
 	});
 }
 
-function rm4favorites(favobj, favid) {
-	sendAjaxData({
+/**
+ * Remove object from the list of favourites. Remove all favourites if objectid==0.
+ */
+function rm4favorites(object, objectid) {
+	sendAjaxData('zabbix.php?action=favourite.delete', {
 		data: {
-			favobj: favobj,
-			favid: favid,
-			favaction: 'remove'
+			object: object,
+			objectid: objectid
 		}
 	});
 }
 
-
 /**
  * Toggles filter state and updates title and icons accordingly.
  *
- * @param {int} 	id					Id of filter in DOM
- * @param {string} 	titleWhenVisible	Title to set when filter is visible
- * @param {string} 	titleWhenHidden		Title to set when filter is collapsed
+ * @param {string} 	idx					User profile index
+ * @param {string} 	value_int			Integer value
+ * @param {object} 	idx2				An array of IDs
  */
-function changeFlickerState(id, titleWhenVisible, titleWhenHidden) {
-	var state = showHide(id);
-
-	switchElementClass('flicker_icon_l', 'dbl_arrow_up', 'dbl_arrow_down');
-	switchElementClass('flicker_icon_r', 'dbl_arrow_up', 'dbl_arrow_down');
-
-	var title = state ? titleWhenVisible : titleWhenHidden;
-
-	jQuery('#flicker_title').html(title);
-
-	sendAjaxData({
+function updateUserProfile(idx, value_int, idx2) {
+	sendAjaxData('zabbix.php?action=profile.update', {
 		data: {
-			filterState: state
+			idx: idx,
+			value_int: value_int,
+			idx2: idx2
 		}
 	});
-
-	// resize multiselects in the flicker
-	if (jQuery('.multiselect').length > 0 && state == 1) {
-		jQuery('.multiselect', jQuery('#' + id)).multiSelect('resize');
-	}
 }
 
-function changeWidgetState(obj, widgetId) {
+function changeWidgetState(obj, widgetId, url) {
 	var widgetObj = jQuery('#' + widgetId + '_widget'),
-		css = switchElementClass(obj, 'arrowup', 'arrowdown'),
+		css = switchElementClass(obj, 'btn-widget-collapse', 'btn-widget-expand'),
 		state = 0;
 
-	if (css === 'arrowdown') {
+	if (css === 'btn-widget-expand') {
 		jQuery('.body', widgetObj).slideUp(50);
-		jQuery('.footer', widgetObj).slideUp(50);
+		jQuery('.dashbrd-widget-foot', widgetObj).slideUp(50);
 	}
 	else {
 		jQuery('.body', widgetObj).slideDown(50);
-		jQuery('.footer', widgetObj).slideDown(50);
+		jQuery('.dashbrd-widget-foot', widgetObj).slideDown(50);
 
 		state = 1;
 	}
 
-	sendAjaxData({
+	obj.title = (state == 1) ? locale['S_COLLAPSE'] : locale['S_EXPAND'];
+
+	sendAjaxData(url, {
 		data: {
-			widgetName: widgetId,
-			widgetState: state
+			widget: widgetId,
+			state: state
 		}
 	});
 }
@@ -666,69 +674,17 @@ function changeWidgetState(obj, widgetId) {
 /**
  * Send ajax data.
  *
+ * @param string url
  * @param object options
  */
-function sendAjaxData(options) {
-	var url = new Curl(location.href);
-	url.setQuery('?output=ajax');
+function sendAjaxData(url, options) {
+	var url = new Curl(url);
+	url.setArgument('output', 'ajax');
 
-	var defaults = {
-		type: 'post',
-		url: url.getUrl()
-	};
+	options.type = 'post';
+	options.url = url.getUrl();
 
-	jQuery.ajax(jQuery.extend({}, defaults, options));
-}
-
-/**
- * Finds all elements with a 'placeholder' attribute and emulates the placeholder in IE.
- */
-function createPlaceholders() {
-	if (IE) {
-		jQuery('[placeholder]').each(function() {
-			var placeholder = jQuery(this);
-
-			if (!placeholder.data('has-placeholder-handlers')) {
-				placeholder
-					.data('has-placeholder-handlers', true)
-					.focus(function() {
-						var obj = jQuery(this);
-
-						if (!obj.attr('placeholder')) {
-							return;
-						}
-
-						if (obj.val() == obj.attr('placeholder')) {
-							obj.val('');
-							obj.removeClass('placeholder');
-						}
-					})
-					.blur(function() {
-						var obj = jQuery(this);
-
-						if (!obj.attr('placeholder')) {
-							return;
-						}
-
-						if (obj.val() == '' ||  obj.val() == obj.attr('placeholder')) {
-							obj.val(obj.attr('placeholder'));
-							obj.addClass('placeholder');
-						}
-					})
-					.blur();
-			}
-
-			jQuery('form').submit(function() {
-				jQuery('.placeholder').each(function() {
-					var obj = jQuery(this);
-
-					if (obj.val() == obj.attr('placeholder')) {
-						obj.val('');
-					}
-				});
-			});
-		});
-	}
+	jQuery.ajax(options);
 }
 
 /**
@@ -911,8 +867,6 @@ function getConditionFormula(conditions, evalType) {
 		beforeRow.before(template.evaluate(data));
 		table.data('dynamicRows').counter++;
 
-		createPlaceholders();
-
 		table.trigger('tableupdate.dynamicRows', options);
 	}
 
@@ -934,39 +888,6 @@ function getConditionFormula(conditions, evalType) {
 jQuery(function ($) {
 	var verticalHeaderTables = {};
 
-	var tablesWidthChangeChecker = function() {
-		for (var tableId in verticalHeaderTables) {
-			if (verticalHeaderTables.hasOwnProperty(tableId)) {
-				var table = verticalHeaderTables[tableId];
-
-				if (table && table.width() != table.data('last-width')) {
-					centerVerticalCellContents(table);
-				}
-			}
-		}
-		setTimeout(tablesWidthChangeChecker, 100);
-	};
-
-	var centerVerticalCellContents = function(table) {
-		var verticalCells = $('.vertical_rotation', table);
-
-		verticalCells.each(function() {
-			var cell = $(this),
-				cellWidth = cell.width();
-
-			if (cellWidth > 30) {
-				cell.children().css({
-					position: 'relative',
-					left: (cellWidth / 2 - 12) + 'px'
-				});
-			}
-		});
-
-		table.data('last-width', table.width());
-	};
-
-	tablesWidthChangeChecker();
-
 	$.fn.makeVerticalRotation = function() {
 		this.each(function(i) {
 			var table = $(this);
@@ -981,15 +902,10 @@ jQuery(function ($) {
 
 			// insert spans
 			cellsToRotate.each(function() {
-				var cell = $(this);
-
-				var text = $('<span>', {
-					text: cell.html()
-				});
-
-				if (IE) {
-					text.css({'font-family': 'monospace'});
-				}
+				var cell = $(this),
+					text = $('<span>', {
+						text: cell.html()
+					}).css({'white-space': 'nowrap'});
 
 				cell.text('').append(text);
 			});
@@ -1002,21 +918,17 @@ jQuery(function ($) {
 					width = span.width(),
 					transform = (width / 2) + 'px ' + (width / 2) + 'px';
 
-				var css = {
-					"transform-origin": transform,
-					"-webkit-transform-origin": transform,
-					"-moz-transform-origin": transform,
-					"-o-transform-origin": transform
-				};
-
-				if (IE) {
-					css['font-family'] = 'monospace';
-					css['-ms-transform-origin'] = '50% 50%';
-				}
+				var css = {};
 
 				if (IE9) {
 					css['-ms-transform-origin'] = transform;
 				}
+				else {
+					css['transform-origin'] = transform;
+					css['-webkit-transform-origin'] = transform;
+					css['-moz-transform-origin'] = transform;
+					css['-o-transform-origin'] = transform;
+				}
 
 				var divInner = $('<div>', {
 					'class': 'vertical_rotation_inner'
@@ -1037,8 +949,6 @@ jQuery(function ($) {
 				$(this).html(betterCells[i]);
 			});
 
-			centerVerticalCellContents(table);
-
 			table.on('remove', function() {
 				delete verticalHeaderTables[table.attr('id')];
 			});
