@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2015 Zabbix SIA
+** Copyright (C) 2001-2016 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -109,7 +109,7 @@ jQuery(function($) {
 				var obj = $(this);
 				var ms = $(this).data('multiSelect');
 
-				// clean input if selectedLimit = 1
+				// clean input if selectedLimit == 1
 				if (ms.options.selectedLimit == 1) {
 					for (var id in ms.values.selected) {
 						removeSelected(id, obj, ms.values, ms.options);
@@ -156,11 +156,10 @@ jQuery(function($) {
 	 * @param bool   options['addNew']				allow user to create new names (optional)
 	 * @param int    options['selectedLimit']		how many items can be selected (optional)
 	 * @param int    options['limit']				how many available items can be received from backend (optional)
-	 * @param object options['popup']				popup data {parameters, width, height, buttonClass} (optional)
+	 * @param object options['popup']				popup data {parameters, width, height} (optional)
 	 * @param string options['popup']['parameters']
 	 * @param int    options['popup']['width']
 	 * @param int    options['popup']['height']
-	 * @param string options['popup']['buttonClass'](optional)
 	 *
 	 * @return object
 	 */
@@ -185,7 +184,7 @@ jQuery(function($) {
 			addNew: false,
 			defaultValue: null,
 			disabled: false,
-			selectedLimit: null,
+			selectedLimit: 0,
 			limit: 20,
 			popup: []
 		};
@@ -231,22 +230,32 @@ jQuery(function($) {
 				'class': 'multiselect-wrapper'
 			}));
 
+			// selected
+			var selected_div = $('<div>', {
+				'class': 'selected'
+			});
+			var selected_ul = $('<ul>', {
+				'class': 'multiselect-list'
+			});
+			if (options.disabled) {
+				selected_ul.addClass('disabled');
+			}
+			obj.append(selected_div.append(selected_ul));
+
 			// search input
 			if (!options.disabled) {
 				var input = $('<input>', {
 					'class': 'input',
-					type: 'text',
-					value: '',
-					css: {width: values.width}
+					type: 'text'
 				})
+				.attr('placeholder', options.labels['type here to search'])
 				.on('keyup change', function(e) {
 					if (e.which == KEY.ESCAPE) {
 						cleanSearchInput(obj);
 						return false;
 					}
 
-					if ($('.selected li', obj).length > 0
-							&& $('.selected li', obj).length == options.selectedLimit) {
+					if (options.selectedLimit != 0 && $('.selected li', obj).length >= options.selectedLimit) {
 						setReadonly(obj);
 						return false;
 					}
@@ -307,96 +316,119 @@ jQuery(function($) {
 				.on('keypress keydown', function(e) {
 					switch (e.which) {
 						case KEY.ENTER:
-							var availableActive = $('.available li.hover', obj);
+							if (!empty(input.val())) {
+								var selected = $('.available li.suggest-hover', obj);
 
-							if (availableActive.length > 0) {
-								select(availableActive.data('id'), obj, values, options);
-							}
-
-							// stop form submit
-							cancelEvent(e);
-							return false;
-
-						case KEY.BACKSPACE:
-						case KEY.ARROW_LEFT:
-						case KEY.DELETE:
-							if (empty(input.val())) {
-								if (e.which == KEY.DELETE && $('.selected li.pressed', obj).length == 0) {
-									return;
+								if (selected.length > 0) {
+									select(selected.data('id'), obj, values, options);
 								}
 
-								if ($('.selected li', obj).length > 0) {
-									if ($('.selected li.pressed', obj).length > 0) {
-										if (e.which == KEY.BACKSPACE || e.which == KEY.DELETE) {
-											removeSelected($('.selected li.pressed', obj).data('id'), obj, values, options);
-										}
-										else {
-											var prev = $('.selected li.pressed', obj).removeClass('pressed').prev();
+								// stop form submit
+								cancelEvent(e);
+								return false;
+							}
+							break;
 
-											if (prev.length > 0) {
-												prev.addClass('pressed');
-											}
-											else {
-												$('.selected li:first-child', obj).addClass('pressed');
-											}
-										}
+						case KEY.BACKSPACE:
+							if (empty(input.val())) {
+								var selected = $('.selected li.selected', obj);
+
+								if (selected.length > 0) {
+									var prev = selected.prev();
+
+									removeSelected(selected.data('id'), obj, values, options);
+
+									if (prev.length > 0) {
+										prev.addClass('selected');
 									}
 									else {
-										$('.selected li:last-child', obj).addClass('pressed');
+										$('.selected li:first-child', obj).addClass('selected');
 									}
+								}
+								else if ($('.selected li', obj).length > 0) {
+									$('.selected li:last-child', obj).addClass('selected');
+								}
 
-									hideAvailable(obj);
+								cancelEvent(e);
+								return false;
+							}
+							break;
+
+						case KEY.DELETE:
+							if (empty(input.val())) {
+								var selected = $('.selected li.selected', obj);
+
+								if (selected.length > 0) {
+									var next = selected.next();
+
+									removeSelected(selected.data('id'), obj, values, options);
+
+									if (next.length > 0) {
+										next.addClass('selected');
+									}
+									else {
+										$('.selected li:last-child', obj).addClass('selected');
+									}
+								}
+
+								cancelEvent(e);
+								return false;
+							}
+							break;
+
+						case KEY.ARROW_LEFT:
+							if (empty(input.val())) {
+								if ($('.selected li.selected', obj).length > 0) {
+									var prev = $('.selected li.selected', obj).removeClass('selected').prev();
+
+									if (prev.length > 0) {
+										prev.addClass('selected');
+									}
+									else {
+										$('.selected li:first-child', obj).addClass('selected');
+									}
+								}
+								else if ($('.selected li', obj).length > 0) {
+									$('.selected li:last-child', obj).addClass('selected');
 								}
 							}
 							break;
 
 						case KEY.ARROW_RIGHT:
-							if ($('.selected li.pressed', obj).length > 0) {
-								var next = $('.selected li.pressed', obj).removeClass('pressed').next();
+							if ($('.selected li.selected', obj).length > 0) {
+								var next = $('.selected li.selected', obj).removeClass('selected').next();
 
 								if (next.length > 0) {
-									next.addClass('pressed');
+									next.addClass('selected');
 								}
 							}
 							break;
 
 						case KEY.ARROW_UP:
 							if ($('.available', obj).is(':visible') && $('.available li', obj).length > 0) {
-								if ($('.available li.hover', obj).length > 0) {
-									var prev = $('.available li.hover', obj).removeClass('hover').prev();
+								var selected = $('.available li.suggest-hover', obj),
+									prev = selected.prev();
 
-									if (prev.length > 0) {
-										prev.addClass('hover');
-									}
-									else {
-										$('.available li:last-child', obj).addClass('hover');
-									}
+								if (prev.length > 0) {
+									selected.removeClass('suggest-hover');
+									prev.addClass('suggest-hover');
+								}
 
-									scrollAvailable(obj);
-								}
-								else {
-									$('.available li:last-child', obj).addClass('hover');
-								}
+								scrollAvailable(obj);
 							}
 							break;
 
 						case KEY.ARROW_DOWN:
 							if ($('.available', obj).is(':visible') && $('.available li', obj).length > 0) {
-								if ($('.available li.hover', obj).length > 0) {
-									var next = $('.available li.hover', obj).removeClass('hover').next();
+								var selected = $('.available li.suggest-hover', obj),
+									next = selected.next();
 
-									if (next.length > 0) {
-										next.addClass('hover');
-									}
-									else {
-										$('.available li:first-child', obj).addClass('hover');
-									}
+								if (next.length > 0) {
+									selected.removeClass('suggest-hover');
+									next.addClass('suggest-hover');
+								}
 
-									scrollAvailable(obj);
-								}
-								else {
-									$('.available li:first-child', obj).addClass('hover');
-								}
+								scrollAvailable(obj);
 							}
 							break;
 
@@ -408,12 +440,7 @@ jQuery(function($) {
 					}
 				})
 				.focusin(function() {
-					if (options.selectedLimit > 0) {
-						if ($('.selected li', obj).length == 0) {
-							$(obj).addClass('active');
-						}
-					}
-					else {
+					if (options.selectedLimit == 0 || $('.selected li', obj).length < options.selectedLimit) {
 						$(obj).addClass('active');
 					}
 				})
@@ -424,27 +451,11 @@ jQuery(function($) {
 				obj.append(input);
 			}
 
-			// selected
-			var selectedDiv = $('<div>', {
-				'class': 'selected'
-			});
-			var selectedUl = $('<ul>', {
-				css: {width: values.width}
-			});
-			obj.append(selectedDiv.append(selectedUl));
-
 			// available
 			if (!options.disabled) {
 				var available = $('<div>', {
 					'class': 'available',
 					css: { display: 'none' }
-				})
-				.append($('<ul>'))
-				.mouseenter(function() {
-					values.isAvailableOpened = true;
-				})
-				.mouseleave(function() {
-					values.isAvailableOpened = false;
 				});
 
 				// multi select
@@ -461,21 +472,15 @@ jQuery(function($) {
 			// preload data
 			if (empty(options.data)) {
 				setDefaultValue(obj, options);
-				setPlaceholder(obj, options);
 			}
 			else {
 				loadSelected(options.data, obj, values, options);
 			}
 
-			// resize
-			resize(obj, values, options);
+			cleanLastSearch(obj);
 
 			// draw popup link
 			if (options.popup.parameters != null) {
-				var popupBlock = $('<div>', {
-					'class': 'select-popup'
-				});
-
 				var urlParameters = options.popup.parameters;
 
 				if (options.ignored) {
@@ -484,10 +489,10 @@ jQuery(function($) {
 					});
 				}
 
-				var popupButton = $('<input>', {
+				var popupButton = $('<button>', {
 					type: 'button',
-					'class': options.popup.buttonClass ? options.popup.buttonClass : 'input link_menu select-popup',
-					value: options.labels['Select']
+					'class': 'btn-grey',
+					text: options.labels['Select']
 				});
 
 				if (options.disabled) {
@@ -499,12 +504,9 @@ jQuery(function($) {
 					});
 				}
 
-				obj.parent().append($('<div class="multiselect-button"></div>').append(popupButton));
-			}
-
-			// IE browsers use default width
-			if (IE) {
-				options.defaultWidth = $('input[type="text"]', obj).width();
+				obj.parent().append($('<div>', {
+					'class': 'multiselect-button'
+				}).append(popupButton));
 			}
 		});
 	};
@@ -591,14 +593,23 @@ jQuery(function($) {
 
 		if (!empty(data)) {
 			$.each(data, function(i, item) {
-				addAvailable(item, obj, values, options);
+				if (options.limit != 0 && objectLength(values.available) < options.limit) {
+					if (typeof values.available[item.id] === 'undefined'
+							&& typeof values.selected[item.id] === 'undefined'
+							&& typeof values.ignored[item.id] === 'undefined') {
+						values.available[item.id] = item;
+					}
+				}
+				else {
+					values.isMoreMatchesFound = true;
+				}
 			});
 		}
 
 		// write empty result label
 		if (objectLength(values.available) == 0) {
 			var div = $('<div>', {
-				'class': 'label-empty-result',
+				'class': 'multiselect-matches',
 				text: options.labels['No matches found']
 			})
 			.click(function() {
@@ -607,11 +618,28 @@ jQuery(function($) {
 
 			$('.available', obj).append(div);
 		}
+		else {
+			$('.available', obj)
+				.append($('<ul>', {
+					'class': 'multiselect-suggest'
+				}))
+				.mouseenter(function() {
+					values.isAvailableOpened = true;
+				})
+				.mouseleave(function() {
+					values.isAvailableOpened = false;
+				});
+
+			$.each(values.available, function(i, item) {
+				addAvailable(item, obj, values, options);
+			});
+		}
+
 
 		// write more matches found label
 		if (values.isMoreMatchesFound) {
 			var div = $('<div>', {
-				'class': 'label-more-matches-found',
+				'class': 'multiselect-matches',
 				text: options.labels['More matches found...']
 			})
 			.click(function() {
@@ -627,51 +655,47 @@ jQuery(function($) {
 	function addSelected(item, obj, values, options) {
 		if (typeof(values.selected[item.id]) == 'undefined') {
 			removeDefaultValue(obj, options);
-
 			values.selected[item.id] = item;
 
+			var prefix = typeof(item.prefix) == 'undefined' ? '' : item.prefix;
+
 			// add hidden input
 			obj.append($('<input>', {
 				type: 'hidden',
 				name: (options.addNew && item.isNew) ? options.name + '[new]' : options.name,
 				value: item.id,
 				'data-name': item.name,
-				'data-prefix': item.prefix
+				'data-prefix': prefix
 			}));
 
-			// add list item
-			var li = $('<li>', {
-				'data-id': item.id
+			var close_btn = $('<span>', {
+				'class': 'subfilter-disable-btn'
 			});
 
-			var text = $('<span>', {
-				'class': 'text',
-				text: empty(item.prefix) ? item.name : item.prefix + item.name
-			});
-
-			$('.selected ul', obj).append(li.append(text));
-
-			resizeSelectedText(li, text, obj, options);
-
 			if (!options.disabled) {
-				var arrow = $('<span>', {
-					'class': 'arrow',
-					'data-id': item.id
-				})
-				.click(function() {
+				close_btn.click(function() {
 					removeSelected(item.id, obj, values, options);
 				});
-
-				$('.selected ul', obj).append(li.append(arrow));
 			}
 
-			removePlaceholder(obj);
+			var li = $('<li>', {
+				'data-id': item.id
+			}).append(
+				$('<span>', {
+					'class': 'subfilter-enabled'
+				})
+					.append($('<span>', {
+						text: prefix + item.name
+					}))
+					.append(close_btn)
+			);
 
-			// resize
-			resize(obj, values, options);
+			$('.selected ul', obj).append(li);
+
+			resizeSelectedText(li, obj);
 
 			// set readonly
-			if (options.selectedLimit > 0 && $('.selected li', obj).length == options.selectedLimit) {
+			if (options.selectedLimit != 0 && $('.selected li', obj).length >= options.selectedLimit) {
 				setReadonly(obj);
 			}
 		}
@@ -684,89 +708,71 @@ jQuery(function($) {
 
 		delete values.selected[id];
 
-		// resize
-		resize(obj, values, options);
-
 		// remove readonly
 		if ($('.selected li', obj).length == 0) {
 			setDefaultValue(obj, options);
-			setPlaceholder(obj, options);
-
-			if (options.selectedLimit > 0) {
-				$('input[type="text"]', obj).prop('disabled', false);
-			}
 		}
 
 		// clean
 		cleanAvailable(obj, values);
 		cleanLastSearch(obj);
 
-		if (!$('input[type="text"]', obj).prop('disabled')) {
-			$('input[type="text"]', obj).focus();
+		if (options.selectedLimit == 0 || $('.selected li', obj).length < options.selectedLimit) {
+			$('input[type="text"]', obj).css({'display': ''}).focus();
 		}
 	}
 
 	function addAvailable(item, obj, values, options) {
-		if (empty(options.limit) || (options.limit > 0 && $('.available li', obj).length < options.limit)) {
-			if (typeof values.available[item.id] === 'undefined'
-					&& typeof values.selected[item.id] === 'undefined'
-					&& typeof values.ignored[item.id] === 'undefined') {
-				values.available[item.id] = item;
+		var li = $('<li>', {
+			'data-id': item.id
+		})
+		.click(function() {
+			select(item.id, obj, values, options);
+		})
+		.hover(function() {
+			$('.available li.suggest-hover', obj).removeClass('suggest-hover');
+			li.addClass('suggest-hover');
+		});
 
-				var prefix = $('<span>', {
-					'class': 'prefix',
-					text: item.prefix
-				});
+		if (!empty(item.prefix)) {
+			li.append($('<span>', {
+				'class': 'grey',
+				text: item.prefix
+			}));
+		}
 
-				var li = $('<li>', {
-					'data-id': item.id
-				})
-				.click(function() {
-					select(item.id, obj, values, options);
-				})
-				.hover(function() {
-					$('.available li.hover', obj).removeClass('hover');
-					li.addClass('hover');
-				})
-				.append(prefix);
+		// highlight matched
+		var text = item.name.toLowerCase(),
+			search = values.search.toLowerCase(),
+			start = 0,
+			end = 0,
+			searchLength = search.length;
 
-				// highlight matched
-				var text = item.name.toLowerCase(),
-					search = values.search.toLowerCase(),
-					start = 0,
-					end = 0,
-					searchLength = search.length;
+		while (text.indexOf(search, end) > -1) {
+			end = text.indexOf(search, end);
 
-				while (text.indexOf(search, end) > -1) {
-					end = text.indexOf(search, end);
-
-					if (end > start) {
-						li.append($('<span>', {
-							text: item.name.substring(start, end)
-						}));
-					}
-
-					li.append($('<span>', {
-						'class': 'matched',
-						text: item.name.substring(end, end + searchLength)
-					}));
-
-					end += searchLength;
-					start = end;
-				}
-
-				if (end < item.name.length) {
-					li.append($('<span>', {
-						text: item.name.substring(end, item.name.length)
-					}));
-				}
-
-				$('.available ul', obj).append(li);
+			if (end > start) {
+				li.append($('<span>', {
+					text: item.name.substring(start, end)
+				}));
 			}
+
+			li.append($('<span>', {
+				'class': 'suggest-found',
+				text: item.name.substring(end, end + searchLength)
+			}));
+
+			end += searchLength;
+			start = end;
 		}
-		else {
-			values.isMoreMatchesFound = true;
+
+		if (end < item.name.length) {
+			li.append($('<span>', {
+				text: item.name.substring(end, item.name.length)
+			}));
 		}
+
+		$('.available ul', obj).append(li);
 	}
 
 	function select(id, obj, values, options) {
@@ -776,23 +782,37 @@ jQuery(function($) {
 			cleanAvailable(obj, values);
 			cleanLastSearch(obj);
 
-			if (!$('input[type="text"]', obj).prop('disabled')) {
+			if (options.selectedLimit == 0 || $('.selected li', obj).length < options.selectedLimit) {
 				$('input[type="text"]', obj).focus();
 			}
 		}
 	}
 
 	function showAvailable(obj, values) {
-		if ($('.label-empty-result', obj).length > 0 || objectLength(values.available) > 0) {
-			$(obj).addClass('active');
-			$('.available', obj).fadeIn(0);
+		var available = $('.available', obj),
+			available_paddings = available.outerWidth() - available.width();
 
-			// remove selected item pressed state
-			$('.selected li.pressed', obj).removeClass('pressed');
+		available.css({
+			'width': obj.outerWidth() - available_paddings,
+			'left': -1
+		});
+
+		available.fadeIn(0);
+		available.scrollTop(0);
+
+		if (objectLength(values.available) != 0) {
+			// remove selected item selected state
+			if ($('.selected li.selected', obj).length > 0) {
+				$('.selected li.selected', obj).removeClass('selected');
+			}
 
 			// pre-select first available
-			$('.available li.hover', obj).removeClass('hover');
-			$('.available li:first-child', obj).addClass('hover');
+			if ($('li', available).length > 0) {
+				if ($('li.suggest-hover', available).length > 0) {
+					$('li.suggest-hover', available).removeClass('suggest-hover');
+				}
+				$('li:first-child', available).addClass('suggest-hover');
+			}
 		}
 	}
 
@@ -801,165 +821,43 @@ jQuery(function($) {
 	}
 
 	function cleanAvailable(obj, values) {
-		$('.label-empty-result', obj).remove();
-		$('.label-more-matches-found', obj).remove();
-		$('.available li', obj).remove();
+		$('.multiselect-matches', obj).remove();
+		$('.available ul', obj).remove();
 		values.available = {};
 		values.isMoreMatchesFound = false;
 	}
 
 	function cleanLastSearch(obj) {
-		var input = $('input[type="text"]', obj);
-
-		input.data('lastSearch', '');
-		input.val('');
+		$('input[type="text"]', obj).data('lastSearch', '').val('');
 	}
 
 	function cleanSearchInput(obj) {
-		var input = $('input[type="text"]', obj);
-
-		if (!(IE && input.val() == input.attr('placeholder'))) {
-			input.val('');
-		}
+		$('input[type="text"]', obj).val('');
 	}
 
-	function resize(obj, values, options) {
-		if (!options.selectedLimit || $('.selected li', obj).length < options.selectedLimit) {
-			resizeSelected(obj, values, options);
-			resizeAvailable(obj);
-		}
-	}
+	function resizeSelectedText(li, obj) {
+		var	li_margins = li.outerWidth(true) - li.width(),
+			span = $('span.subfilter-enabled', li),
+			span_paddings = span.outerWidth(true) - span.width(),
+			max_width = $('.selected ul', obj).width() - li_margins - span_paddings,
+			text = $('span:first-child', span);
 
-	function resizeSelected(obj, values, options) {
-		// settings
-		var settingTopPaddingsEmpty = IE8 ? 1 : 0,
-			settingTopPaddingsExist = IE8 ? 1 : 2,
-			settingTopPaddingsInit = 2,
-			settingRightPaddings = 4,
-			settingMinimumWidth = 50,
-			settingMinimumHeight = 12,
-			settingNewLineTopPaddings = 6;
+		if (text.width() > max_width) {
+			var t = text.text();
+			var l = t.length;
 
-		// calculate
-		var top = 0,
-			left = 0,
-			height = 0;
-
-		if ($('.selected li', obj).length > 0) {
-			var lastItem = $('.selected li:last-child', obj),
-				position = lastItem.position();
-
-			top = position.top + settingTopPaddingsExist;
-			left = position.left + lastItem.width();
-			height = $('.selected li:last-child', obj).height();
-		}
-		else {
-			top = settingTopPaddingsInit + settingTopPaddingsEmpty;
-			height = 0;
-		}
-
-		if (SF) {
-			top = top * 2;
-		}
-
-		if (left + settingMinimumWidth > values.width || height > settingMinimumHeight) {
-			var topPaddings = (height > settingMinimumHeight) ? height / 2 : height;
-
-			topPaddings += settingNewLineTopPaddings;
-
-			if (SF) {
-				topPaddings = topPaddings * 2;
-			}
-
-			top += topPaddings;
-			left = 0;
-
-			$('.selected ul', obj).css({
-				'padding-bottom': topPaddings
-			});
-		}
-		else {
-			$('.selected ul', obj).css({
-				'padding-bottom': 0
-			});
-		}
-
-		if (IE) {
-			var input = $('input[type="text"]', obj);
-
-			input.css({
-				'padding-top': top,
-				'padding-left': left,
-				'width': options.defaultWidth - left
-			});
-
-			// IE8 hack to fix inline-block container resizing and poke input element value to trigger reflow
-			if (IE8) {
-				$('.multiselect-wrapper').addClass('ie8fix-inline').removeClass('ie8fix-inline');
-				var currentInputVal = input.val();
-				input.val(' ').val(currentInputVal);
-			}
-		}
-		else {
-			$('input[type="text"]', obj).css({
-				'padding-top': top,
-				'padding-left': left,
-				width: values.width - left - settingRightPaddings
-			});
-		}
-	}
-
-	function resizeAvailable(obj) {
-		var selectedHeight = $('.selected', obj).height();
-
-		$('.available', obj).css({
-			top: (selectedHeight > 0) ? selectedHeight : 20
-		});
-	}
-
-	function resizeSelectedText(item, text, obj, options) {
-		// settings
-		var settingLineHeight = 15,
-			settingArrowSpace = options.disabled ? 22 : 32,
-			settingPaddings = 3,
-			settingTextMax = 510;
-
-		// calculate
-		var maxWidth = $('.selected ul', obj).width() - settingArrowSpace;
-
-		if (text.width() > maxWidth || text.height() > settingLineHeight) {
-			var i = 0;
-
-			while (text.width() > maxWidth || text.height() > settingLineHeight) {
-				var t = text.text();
-
-				text.text(t.substring(0, t.length - 1));
-
-				i++;
-
-				if (i > settingTextMax) {
-					break;
-				}
-			}
-
-			text.text(text.text() + '...');
-
-			item.css('width', $('.selected ul', obj).width() - settingPaddings);
-		}
-		else {
-			item.css('width', '');
-
-			if (!options.disabled) {
-				text.css('padding-right', 16);
+			while (text.width() > max_width && l != 0) {
+				text.text(t.substring(0, --l) + '...');
 			}
 		}
 	}
 
 	function resizeAllSelectedTexts(obj, options, values) {
 		$('.selected li', obj).each(function() {
-			var item = $(this),
-				id = item.data('id'),
-				text = $(item.children()[0]),
+			var li = $(this),
+				id = li.data('id'),
+				span = $('span.subfilter-enabled', li),
+				text = $('span:first-child', span),
 				t = empty(values.selected[id].prefix)
 					? values.selected[id].name
 					: values.selected[id].prefix + values.selected[id].name;
@@ -967,48 +865,50 @@ jQuery(function($) {
 			// rewrite previous text to original
 			text.text(t);
 
-			resizeSelectedText(item, text, obj, options);
+			resizeSelectedText(li, obj);
 		});
 	}
 
 	function scrollAvailable(obj) {
-		var hover = $('.available li.hover', obj);
+		var selected = $('.available li.suggest-hover', obj);
 
-		if (hover.length > 0) {
-			var available = $('.available ul', obj),
-				offset = hover.position().top;
+		if (selected.length > 0) {
 
-			if (offset < 0 || offset > available.height()) {
-				if (offset < 0) {
-					offset = 0;
+			var available = $('.available', obj),
+				available_height = available.height();
+				selected_top = 0,
+				selected_height = selected.outerHeight(true);
+
+			if ($('.multiselect-matches', obj)) {
+				selected_top += $('.multiselect-matches', obj).outerHeight(true);
+			}
+
+			$('.available li', obj).each(function() {
+				var item = $(this);
+				if (item.hasClass('suggest-hover')) {
+					return false;
 				}
+				selected_top += item.outerHeight(true);
+			});
 
-				available.animate({scrollTop: offset}, 300);
+			if (selected_top < available.scrollTop()) {
+				var prev = selected.prev();
+
+				available.scrollTop((prev.length == 0) ? 0 : selected_top);
+			}
+			else if (selected_top + selected_height > available.scrollTop() + available_height) {
+				available.scrollTop(selected_top - available_height + selected_height);
 			}
 		}
 	}
 
 	function setReadonly(obj) {
-		cleanSearchInput(obj);
-		$('input[type="text"]', obj).prop('disabled', true);
+		$('input[type="text"]', obj).css({'display': 'none'});
 		$(obj).removeClass('active');
 	}
 
-	function setPlaceholder(obj, options) {
-		$('input[type="text"]', obj).attr('placeholder', options.labels['type here to search']);
-
-		createPlaceholders();
-	}
-
-	function removePlaceholder(obj) {
-		$('input[type="text"]', obj)
-			.removeAttr('placeholder')
-			.removeClass('placeholder')
-			.val('');
-	}
-
 	function getLimit(values, options) {
-		return (options.limit > 0)
+		return (options.limit != 0)
 			? options.limit + countMatches(values.selected, values.search) + countMatches(values.ignored, values.search) + 1
 			: null;
 	}
