@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2015 Zabbix SIA
+** Copyright (C) 2001-2016 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -42,13 +42,13 @@ if (isset($_GET['lang'])) {
 		textdomain('frontend');
 	}
 	// numeric Locale to default
-	setlocale(LC_NUMERIC, array('C', 'POSIX', 'en', 'en_US', 'en_US.UTF-8', 'English_United States.1252', 'en_GB', 'en_GB.UTF-8'));
+	setlocale(LC_NUMERIC, ['C', 'POSIX', 'en', 'en_US', 'en_US.UTF-8', 'English_United States.1252', 'en_GB', 'en_GB.UTF-8']);
 }
 
 require_once dirname(__FILE__).'/include/translateDefines.inc.php';
 
 // available scripts 'scriptFileName' => 'path relative to js/'
-$availableJScripts = array(
+$availableJScripts = [
 	'common.js' => '',
 	'menupopup.js' => '',
 	'gtlc.js' => '',
@@ -60,10 +60,9 @@ $availableJScripts = array(
 	'multiselect.js' => '',
 	'chkbxrange.js' => '',
 	// vendors
-	'prototype.js' => '',
-	'jquery.js' => 'jquery/',
-	'jquery-ui.js' => 'jquery/',
-	'activity-indicator.js' => 'vendors/',
+	'prototype.js' => 'vendors/',
+	'jquery.js' => 'vendors/',
+	'jquery-ui.js' => 'vendors/',
 	// classes
 	'class.bbcode.js' => '',
 	'class.calendar.js' => '',
@@ -86,10 +85,10 @@ $availableJScripts = array(
 	// page-specific scripts
 	'items.js' => 'pages/',
 	'tr_logform.js' => 'pages/',
-);
+];
 
-$tranStrings = array(
-	'gtlc.js' => array(
+$tranStrings = [
+	'gtlc.js' => [
 		'S_ALL_S' => _('All'),
 		'S_ZOOM' => _('Zoom'),
 		'S_FIXED_SMALL' => _('fixed'),
@@ -99,17 +98,18 @@ $tranStrings = array(
 		'S_MONTH_SHORT' => _x('m', 'month short'),
 		'S_DAY_SHORT' => _x('d', 'day short'),
 		'S_HOUR_SHORT' => _x('h', 'hour short'),
+		'S_MINUTE_SHORT' => _x('m', 'minute short'),
 		'S_DATE_FORMAT' => DATE_TIME_FORMAT
-	),
-	'functions.js' => array(
+	],
+	'functions.js' => [
 		'Cancel' => _('Cancel'),
 		'Execute' => _('Execute'),
-		'Execution confirmation' => _('Execution confirmation'),
-		'S_DELETE' => _('Delete'),
-		'S_DELETE_KEYWORD_Q' => _('Delete keyword?'),
-		'S_DELETE_EXPRESSION_Q' => _('Delete expression?')
-	),
-	'class.calendar.js' => array(
+		'Execution confirmation' => _('Execution confirmation')
+	],
+	'tr_logform.js' => [
+		'S_REMOVE' => _('Remove')
+	],
+	'class.calendar.js' => [
 		'S_JANUARY' => _('January'),
 		'S_FEBRUARY' => _('February'),
 		'S_MARCH' => _('March'),
@@ -132,8 +132,8 @@ $tranStrings = array(
 		'S_NOW' => _('Now'),
 		'S_DONE' => _('Done'),
 		'S_TIME' => _('Time')
-	),
-	'class.cmap.js' => array(
+	],
+	'class.cmap.js' => [
 		'S_ON' => _('On'),
 		'S_OFF' => _('Off'),
 		'S_HIDDEN' => _('Hidden'),
@@ -144,7 +144,6 @@ $tranStrings = array(
 		'S_HOST_GROUP' => _('Host group'),
 		'S_IMAGE' => _('Image'),
 		'S_DEFAULT' => _('Default'),
-		'S_CLOSE' => _('Close'),
 		'S_PLEASE_SELECT_TWO_ELEMENTS' => _('Please select two elements'),
 		'S_DOT' => _('Dot'),
 		'S_TWO_ELEMENTS_SHOULD_BE_SELECTED' => _('Two elements should be selected'),
@@ -154,39 +153,36 @@ $tranStrings = array(
 		'S_EACH_URL_SHOULD_HAVE_UNIQUE' => _('Each URL should have a unique name. Please make sure there is only one URL named'),
 		'S_DELETE_LINKS_BETWEEN_SELECTED_ELEMENTS_Q' => _('Delete links between selected elements?'),
 		'S_NO_IMAGES' => 'You need to have at least one image uploaded to create map element. Images can be uploaded in Administration->General->Images section.',
-		'S_ICONMAP_IS_NOT_ENABLED' => _('Iconmap is not enabled'),
 		'Colour "%1$s" is not correct: expecting hexadecimal colour code (6 symbols).' => _('Colour "%1$s" is not correct: expecting hexadecimal colour code (6 symbols).')
-	),
-	'class.cmessages.js' => array(
+	],
+	'class.cmessages.js' => [
 		'S_MUTE' => _('Mute'),
 		'S_UNMUTE' => _('Unmute'),
 		'S_MESSAGES' => _('Messages'),
 		'S_CLEAR' => _('Clear'),
 		'S_SNOOZE' => _('Snooze')
-	),
-	'class.cookie.js' => array(
+	],
+	'class.cookie.js' => [
 		'S_MAX_COOKIE_SIZE_REACHED' => _('We are sorry, the maximum possible number of elements to remember has been reached.')
-	),
-	'main.js' => array(
-		'S_CLOSE' => _('Close')
-	),
-	'multiselect.js' => array(
+	],
+	'main.js' => [
+		'S_EXPAND' => _('Expand'),
+		'S_COLLAPSE' => _('Collapse'),
+	],
+	'multiselect.js' => [
 		'No matches found' => _('No matches found'),
 		'More matches found...' => _('More matches found...'),
 		'type here to search' => _('type here to search'),
 		'new' => _('new'),
 		'Select' => _('Select')
-	),
-	'menupopup.js' => array(
+	],
+	'menupopup.js' => [
 		'Acknowledge' => _('Acknowledge'),
 		'Add' => _('Add'),
-		'Add child' => _('Add child'),
 		'Configuration' => _('Configuration'),
 		'Create trigger' => _('Create trigger'),
-		'Delete' => _('Delete'),
 		'Delete service "%1$s"?' => _('Delete service "%1$s"?'),
 		'Do you wish to replace the conditional expression?' => _('Do you wish to replace the conditional expression?'),
-		'Edit' => _('Edit'),
 		'Edit trigger' => _('Edit trigger'),
 		'Events' => _('Events'),
 		'Favourite graphs' => _('Favourite graphs'),
@@ -213,7 +209,6 @@ $tranStrings = array(
 		'Remove' => _('Remove'),
 		'Remove all' => _('Remove all'),
 		'Scripts' => _('Scripts'),
-		'Service "%1$s"' => _('Service "%1$s"'),
 		'Submap' => _('Submap'),
 		'Trigger' => _('Trigger'),
 		'Triggers' => _('Triggers'),
@@ -225,19 +220,18 @@ $tranStrings = array(
 		'2 minutes' => _n('%1$s minute', '%1$s minutes', 2),
 		'10 minutes' => _n('%1$s minute', '%1$s minutes', 10),
 		'15 minutes' => _n('%1$s minute', '%1$s minutes', 15)
-	),
-	'items.js' => array(
+	],
+	'items.js' => [
 		'To set a host interface select a single item type for all items' => _('To set a host interface select a single item type for all items'),
 		'No interface found' => _('No interface found')
-	)
-);
+	]
+];
 
 if (empty($_GET['files'])) {
-	$files = array(
+	$files = [
 		'prototype.js',
 		'jquery.js',
 		'jquery-ui.js',
-		'activity-indicator.js',
 		'common.js',
 		'class.cdebug.js',
 		'class.cdate.js',
@@ -251,7 +245,7 @@ if (empty($_GET['files'])) {
 		'functions.js',
 		'menupopup.js',
 		'init.js'
-	);
+	];
 
 	// load frontend messaging only for some pages
 	if (isset($_GET['showGuiMessaging']) && $_GET['showGuiMessaging']) {
