@@ -378,7 +378,7 @@ if (!$filterSet) {
 }
 
 $toggle_all = (new CColHeader(
-	(new CDiv())
+	(new CSimpleButton())
 		->addClass(ZBX_STYLE_TREEVIEW)
 		->addClass('app-list-toggle-all')
 		->addItem(new CSpan())
@@ -591,7 +591,7 @@ foreach ($applications as $appid => $dbApp) {
 
 	// add toggle row
 	$table->addRow([
-		(new CDiv())
+		(new CSimpleButton())
 			->addClass(ZBX_STYLE_TREEVIEW)
 			->addClass('app-list-toggle')
 			->setAttribute('data-app-id', $dbApp['applicationid'])
@@ -762,7 +762,7 @@ foreach ($hosts as $hostId => $dbHost) {
 
 	// add toggle row
 	$table->addRow([
-		(new CDiv())
+		(new CSimpleButton())
 			->addClass(ZBX_STYLE_TREEVIEW)
 			->addClass('app-list-toggle')
 			->setAttribute('data-host-id', $host['hostid'])
