@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2018 Zabbix SIA
+** Copyright (C) 2001-2016 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -29,607 +29,747 @@ define('ZBX_PAGE_NO_MENU', 1);
 
 require_once dirname(__FILE__).'/include/page_header.php';
 
-$operators = array(
-	'<' => '<',
-	'>' => '>',
-	'=' => '=',
-	'#' => 'NOT'
-);
-$limitedOperators = array(
-	'=' => '=',
-	'#' => 'NOT'
-);
-$metrics = array(
+$metrics = [
 	PARAM_TYPE_TIME => _('Time'),
 	PARAM_TYPE_COUNTS => _('Count')
-);
-$param1SecCount = array(
-	array(
-		'C' => _('Last of').' (T)',// caption
-		'T' => T_ZBX_INT, // type
-		'M' => $metrics // metrcis
-	),
-	array(
-		'C' => _('Time shift').' ', // caption
-		'T' => T_ZBX_INT // type
-	)
-);
-$param1Sec = array(
-	array(
-		'C' => _('Last of').' (T)', // caption
-		'T' => T_ZBX_INT // type
-	)
-);
-$param1Str = array(
-	array(
-		'C' => 'T', // caption
+];
+$param1SecCount = [
+	[
+		'C' => _('Last of').' (T)',	// caption
+		'T' => T_ZBX_INT,			// type
+		'M' => $metrics				// metrics
+	],
+	[
+		'C' => _('Time shift'),
+		'T' => T_ZBX_INT
+	]
+];
+$param1Sec = [
+	[
+		'C' => _('Last of').' (T)',
+		'T' => T_ZBX_INT
+	]
+];
+$param1Str = [
+	[
+		'C' => 'T',
 		'T' => T_ZBX_STR
-	)
-);
-$param2SecCount = array(
-	array(
-		'C' => 'V', // caption
+	]
+];
+$param2SecCount = [
+	[
+		'C' => 'V',
 		'T' => T_ZBX_STR
-	),
-	array(
-		'C' => _('Last of').' (T)', // caption
-		'T' => T_ZBX_INT, // type
-		'M' => $metrics // metrcis
-	)
-);
-$param3SecVal = array(
-	array(
-		'C' => _('Last of').' (T)', // caption
-		'T' => T_ZBX_INT, // type
-		'M' => $metrics // metrcis
-	),
-	array(
-		'C' => 'V', // caption
+	],
+	[
+		'C' => _('Last of').' (T)',
+		'T' => T_ZBX_INT,
+		'M' => $metrics
+	]
+];
+$param3SecVal = [
+	[
+		'C' => _('Last of').' (T)',
+		'T' => T_ZBX_INT,
+		'M' => $metrics
+	],
+	[
+		'C' => 'V',
 		'T' => T_ZBX_STR
-	),
-	array(
-		'C' => 'O', // caption
+	],
+	[
+		'C' => 'O',
 		'T' => T_ZBX_STR
-	),
-	array(
-		'C' => _('Time shift').' ', // caption
-		'T' => T_ZBX_INT // type
-	)
-);
-$paramSecIntCount = array(
-	array(
-		'C' => _('Last of').' (T)', // caption
-		'T' => T_ZBX_INT, // type
-		'M' => $metrics // metrics
-	),
-	array(
-		'C' => _('Mask'), // caption
+	],
+	[
+		'C' => _('Time shift'),
+		'T' => T_ZBX_INT
+	]
+];
+$param3SecPercent = [
+	[
+		'C' => _('Last of').' (T)',
+		'T' => T_ZBX_INT,
+		'M' => $metrics
+	],
+	[
+		'C' => _('Time shift'),
+		'T' => T_ZBX_INT
+	],
+	[
+		'C' => _('Percentage').' (P)',
+		'T' => T_ZBX_DBL
+	]
+];
+$paramSecIntCount = [
+	[
+		'C' => _('Last of').' (T)',
+		'T' => T_ZBX_INT,
+		'M' => $metrics
+	],
+	[
+		'C' => _('Mask'),
 		'T' => T_ZBX_STR
-	),
-	array(
-		'C' => _('Time shift').' ', // caption
-		'T' => T_ZBX_INT // type
-	)
-);
-$allowedTypesAny = array(
+	],
+	[
+		'C' => _('Time shift'),
+		'T' => T_ZBX_INT
+	]
+];
+$paramForecast = [
+	[
+		'C' => _('Last of').' (T)',
+		'T' => T_ZBX_INT,
+		'M' => $metrics
+	],
+	[
+		'C' => _('Time shift'),
+		'T' => T_ZBX_INT
+	],
+	[
+		'C' => _('Time').' (t)',
+		'T' => T_ZBX_INT
+	],
+	[
+		'C' => _('Fit'),
+		'T' => T_ZBX_STR
+	],
+	[
+		'C' => _('Mode'),
+		'T' => T_ZBX_STR
+	]
+];
+$paramTimeleft = [
+	[
+		'C' => _('Last of').' (T)',
+		'T' => T_ZBX_INT,
+		'M' => $metrics
+	],
+	[
+		'C' => _('Time shift'),
+		'T' => T_ZBX_INT
+	],
+	[
+		'C' => _('Threshold'),
+		'T' => T_ZBX_DBL
+	],
+	[
+		'C' => _('Fit'),
+		'T' => T_ZBX_STR
+	]
+];
+$allowedTypesAny = [
 	ITEM_VALUE_TYPE_FLOAT => 1,
 	ITEM_VALUE_TYPE_STR => 1,
 	ITEM_VALUE_TYPE_LOG => 1,
 	ITEM_VALUE_TYPE_UINT64 => 1,
 	ITEM_VALUE_TYPE_TEXT => 1
-);
-$allowedTypesNumeric = array(
+];
+$allowedTypesNumeric = [
 	ITEM_VALUE_TYPE_FLOAT => 1,
 	ITEM_VALUE_TYPE_UINT64 => 1
-);
-$allowedTypesStr = array(
+];
+$allowedTypesStr = [
 	ITEM_VALUE_TYPE_STR => 1,
 	ITEM_VALUE_TYPE_LOG => 1,
 	ITEM_VALUE_TYPE_TEXT => 1
-);
-$allowedTypesLog = array(
+];
+$allowedTypesLog = [
 	ITEM_VALUE_TYPE_LOG => 1
-);
-$allowedTypesInt = array(
+];
+$allowedTypesInt = [
 	ITEM_VALUE_TYPE_UINT64 => 1
-);
+];
 
-$functions = array(
-	'abschange[<]' => array(
+$functions = [
+	'abschange[<]' => [
 		'description' =>  _('Absolute difference between last and previous value is < N'),
 		'allowed_types' => $allowedTypesAny
-	),
-	'abschange[>]' => array(
+	],
+	'abschange[>]' => [
 		'description' =>  _('Absolute difference between last and previous value is > N'),
 		'allowed_types' => $allowedTypesAny
-	),
-	'abschange[=]' => array(
+	],
+	'abschange[=]' => [
 		'description' =>  _('Absolute difference between last and previous value is = N'),
 		'allowed_types' => $allowedTypesAny
-	),
-	'abschange[#]' => array(
+	],
+	'abschange[<>]' => [
 		'description' =>  _('Absolute difference between last and previous value is NOT N'),
 		'allowed_types' => $allowedTypesAny
-	),
-	'avg[<]' => array(
+	],
+	'avg[<]' => [
 		'description' =>  _('Average value of a period T is < N'),
 		'params' => $param1SecCount,
 		'allowed_types' => $allowedTypesNumeric
-	),
-	'avg[>]' => array(
+	],
+	'avg[>]' => [
 		'description' =>  _('Average value of a period T is > N'),
 		'params' => $param1SecCount,
 		'allowed_types' => $allowedTypesNumeric
-	),
-	'avg[=]' => array(
+	],
+	'avg[=]' => [
 		'description' =>  _('Average value of a period T is = N'),
 		'params' => $param1SecCount,
 		'allowed_types' => $allowedTypesNumeric
-	),
-	'avg[#]' => array(
+	],
+	'avg[<>]' => [
 		'description' =>  _('Average value of a period T is NOT N'),
 		'params' => $param1SecCount,
 		'allowed_types' => $allowedTypesNumeric
-	),
-	'delta[<]' => array(
+	],
+	'delta[<]' => [
 		'description' =>  _('Difference between MAX and MIN value of a period T is < N'),
 		'params' => $param1SecCount,
 		'allowed_types' => $allowedTypesNumeric
-	),
-	'delta[>]' => array(
+	],
+	'delta[>]' => [
 		'description' =>  _('Difference between MAX and MIN value of a period T is > N'),
 		'params' => $param1SecCount,
 		'allowed_types' => $allowedTypesNumeric
-	),
-	'delta[=]' => array(
+	],
+	'delta[=]' => [
 		'description' =>  _('Difference between MAX and MIN value of a period T is = N'),
 		'params' => $param1SecCount,
 		'allowed_types' => $allowedTypesNumeric
-	),
-	'delta[#]' => array(
+	],
+	'delta[<>]' => [
 		'description' =>  _('Difference between MAX and MIN value of a period T is NOT N'),
 		'params' => $param1SecCount,
 		'allowed_types' => $allowedTypesNumeric
-	),
-	'change[<]' => array(
+	],
+	'change[<]' => [
 		'description' =>  _('Difference between last and previous value is < N'),
 		'allowed_types' => $allowedTypesAny
-	),
-	'change[>]' => array(
+	],
+	'change[>]' => [
 		'description' =>  _('Difference between last and previous value is > N'),
 		'allowed_types' => $allowedTypesAny
-	),
-	'change[=]' => array(
+	],
+	'change[=]' => [
 		'description' =>  _('Difference between last and previous value is = N'),
 		'allowed_types' => $allowedTypesAny
-	),
-	'change[#]' => array(
+	],
+	'change[<>]' => [
 		'description' =>  _('Difference between last and previous value is NOT N'),
 		'allowed_types' => $allowedTypesAny
-	),
-	'count[<]' => array(
+	],
+	'count[<]' => [
 		'description' =>  _('Number of successfully retrieved values V (which fulfill operator O) for period T is < N'),
 		'params' => $param3SecVal,
 		'allowed_types' => $allowedTypesAny
-	),
-	'count[>]' => array(
+	],
+	'count[>]' => [
 		'description' =>  _('Number of successfully retrieved values V (which fulfill operator O) for period T is > N'),
 		'params' => $param3SecVal,
 		'allowed_types' => $allowedTypesAny
-	),
-	'count[=]' => array(
+	],
+	'count[=]' => [
 		'description' =>  _('Number of successfully retrieved values V (which fulfill operator O) for period T is = N'),
 		'params' => $param3SecVal,
 		'allowed_types' => $allowedTypesAny
-	),
-	'count[#]' => array(
+	],
+	'count[<>]' => [
 		'description' =>  _('Number of successfully retrieved values V (which fulfill operator O) for period T is NOT N'),
 		'params' => $param3SecVal,
 		'allowed_types' => $allowedTypesAny
-	),
-	'diff[=]' => array(
+	],
+	'diff[=]' => [
 		'description' =>  _('Difference between last and preceding values, then N = 1, 0 - otherwise'),
 		'allowed_types' => $allowedTypesAny
-	),
-	'diff[#]' => array(
+	],
+	'diff[<>]' => [
 		'description' =>  _('Difference between last and preceding values, then N NOT 1, 0 - otherwise'),
 		'allowed_types' => $allowedTypesAny
-	),
-	'last[<]' => array(
+	],
+	'last[<]' => [
 		'description' =>  _('Last (most recent) T value is < N'),
 		'params' => $param1SecCount,
 		'allowed_types' => $allowedTypesAny
-	),
-	'last[>]' => array(
+	],
+	'last[>]' => [
 		'description' =>  _('Last (most recent) T value is > N'),
 		'params' => $param1SecCount,
 		'allowed_types' => $allowedTypesAny
-	),
-	'last[=]' => array(
+	],
+	'last[=]' => [
 		'description' =>  _('Last (most recent) T value is = N'),
 		'params' => $param1SecCount,
 		'allowed_types' => $allowedTypesAny
-	),
-	'last[#]' => array(
+	],
+	'last[<>]' => [
 		'description' =>  _('Last (most recent) T value is NOT N'),
 		'params' => $param1SecCount,
 		'allowed_types' => $allowedTypesAny
-	),
-	'max[<]' => array(
+	],
+	'max[<]' => [
 		'description' =>  _('Maximum value for period T is < N'),
 		'params' => $param1SecCount,
 		'allowed_types' => $allowedTypesNumeric
-	),
-	'max[>]' => array(
+	],
+	'max[>]' => [
 		'description' =>  _('Maximum value for period T is > N'),
 		'params' => $param1SecCount,
 		'allowed_types' => $allowedTypesNumeric
-	),
-	'max[=]' => array(
+	],
+	'max[=]' => [
 		'description' =>  _('Maximum value for period T is = N'),
 		'params' => $param1SecCount,
 		'allowed_types' => $allowedTypesNumeric
-	),
-	'max[#]' => array(
+	],
+	'max[<>]' => [
 		'description' =>  _('Maximum value for period T is NOT N'),
 		'params' => $param1SecCount,
 		'allowed_types' => $allowedTypesNumeric
-	),
-	'min[<]' => array(
+	],
+	'min[<]' => [
 		'description' =>  _('Minimum value for period T is < N'),
 		'params' => $param1SecCount,
 		'allowed_types' => $allowedTypesNumeric
-		),
-	'min[>]' => array(
+		],
+	'min[>]' => [
 		'description' =>  _('Minimum value for period T is > N'),
 		'params' => $param1SecCount,
 		'allowed_types' => $allowedTypesNumeric
-		),
-	'min[=]' => array(
+		],
+	'min[=]' => [
 		'description' =>  _('Minimum value for period T is = N'),
 		'params' => $param1SecCount,
 		'allowed_types' => $allowedTypesNumeric
-		),
-	'min[#]' => array(
+		],
+	'min[<>]' => [
 		'description' =>  _('Minimum value for period T is NOT N'),
 		'params' => $param1SecCount,
 		'allowed_types' => $allowedTypesNumeric
-		),
-	'prev[<]' => array(
+		],
+	'percentile[<]' => [
+		'description' =>  _('Percentile P of a period T is < N'),
+		'params' => $param3SecPercent,
+		'allowed_types' => $allowedTypesNumeric
+	],
+	'percentile[>]' => [
+		'description' =>  _('Percentile P of a period T is > N'),
+		'params' => $param3SecPercent,
+		'allowed_types' => $allowedTypesNumeric
+	],
+	'percentile[=]' => [
+		'description' =>  _('Percentile P of a period T is = N'),
+		'params' => $param3SecPercent,
+		'allowed_types' => $allowedTypesNumeric
+	],
+	'percentile[<>]' => [
+		'description' =>  _('Percentile P of a period T is NOT N'),
+		'params' => $param3SecPercent,
+		'allowed_types' => $allowedTypesNumeric
+	],
+	'prev[<]' => [
 		'description' =>  _('Previous value is < N'),
 		'allowed_types' => $allowedTypesAny
-	),
-	'prev[>]' => array(
+	],
+	'prev[>]' => [
 		'description' =>  _('Previous value is > N'),
 		'allowed_types' => $allowedTypesAny
-	),
-	'prev[=]' => array(
+	],
+	'prev[=]' => [
 		'description' =>  _('Previous value is = N'),
 		'allowed_types' => $allowedTypesAny
-	),
-	'prev[#]' => array(
+	],
+	'prev[<>]' => [
 		'description' =>  _('Previous value is NOT N'),
 		'allowed_types' => $allowedTypesAny
-	),
-	'str[=]' => array(
+	],
+	'str[=]' => [
 		'description' =>  _('Find string V in last (most recent) value. N = 1 - if found, 0 - otherwise'),
 		'params' => $param2SecCount,
 		'allowed_types' => $allowedTypesAny
-	),
-	'str[#]' => array(
+	],
+	'str[<>]' => [
 		'description' =>  _('Find string V in last (most recent) value. N NOT 1 - if found, 0 - otherwise'),
 		'params' => $param2SecCount,
 		'allowed_types' => $allowedTypesAny
-	),
-	'strlen[<]' => array(
+	],
+	'strlen[<]' => [
 		'description' =>  _('Length of last (most recent) T value in characters is < N'),
 		'params' => $param1SecCount,
 		'allowed_types' => $allowedTypesStr
-	),
-	'strlen[>]' => array(
+	],
+	'strlen[>]' => [
 		'description' =>  _('Length of last (most recent) T value in characters is > N'),
 		'params' => $param1SecCount,
 		'allowed_types' => $allowedTypesStr
-	),
-	'strlen[=]' => array(
+	],
+	'strlen[=]' => [
 		'description' =>  _('Length of last (most recent) T value in characters is = N'),
 		'params' => $param1SecCount,
 		'allowed_types' => $allowedTypesStr
-	),
-	'strlen[#]' => array(
+	],
+	'strlen[<>]' => [
 		'description' =>  _('Length of last (most recent) T value in characters is NOT N'),
 		'params' => $param1SecCount,
 		'allowed_types' => $allowedTypesStr
-	),
-	'sum[<]' => array(
+	],
+	'sum[<]' => [
 		'description' =>  _('Sum of values of a period T is < N'),
 		'params' => $param1SecCount,
 		'allowed_types' => $allowedTypesNumeric
-	),
-	'sum[>]' => array(
+	],
+	'sum[>]' => [
 		'description' =>  _('Sum of values of a period T is > N'),
 		'params' => $param1SecCount,
 		'allowed_types' => $allowedTypesNumeric
-	),
-	'sum[=]' => array(
+	],
+	'sum[=]' => [
 		'description' =>  _('Sum of values of a period T is = N'),
 		'params' => $param1SecCount,
 		'allowed_types' => $allowedTypesNumeric
-	),
-	'sum[#]' => array(
+	],
+	'sum[<>]' => [
 		'description' =>  _('Sum of values of a period T is NOT N'),
 		'params' => $param1SecCount,
 		'allowed_types' => $allowedTypesNumeric
-	),
-	'date[<]' => array(
+	],
+	'date[<]' => [
 		'description' =>  _('Current date is < N'),
 		'allowed_types' => $allowedTypesAny
-	),
-	'date[>]' => array(
+	],
+	'date[>]' => [
 		'description' =>  _('Current date is > N'),
 		'allowed_types' => $allowedTypesAny
-	),
-	'date[=]' => array(
+	],
+	'date[=]' => [
 		'description' =>  _('Current date is = N'),
 		'allowed_types' => $allowedTypesAny
-	),
-	'date[#]' => array(
+	],
+	'date[<>]' => [
 		'description' =>  _('Current date is NOT N'),
 		'allowed_types' => $allowedTypesAny
-	),
-	'dayofweek[<]' => array(
+	],
+	'dayofweek[<]' => [
 		'description' =>  _('Day of week is < N'),
 		'allowed_types' => $allowedTypesAny
-	),
-	'dayofweek[>]' => array(
+	],
+	'dayofweek[>]' => [
 		'description' =>  _('Day of week is > N'),
 		'allowed_types' => $allowedTypesAny
-	),
-	'dayofweek[=]' => array(
+	],
+	'dayofweek[=]' => [
 		'description' =>  _('Day of week is = N'),
 		'allowed_types' => $allowedTypesAny
-	),
-	'dayofweek[#]' => array(
+	],
+	'dayofweek[<>]' => [
 		'description' =>  _('Day of week is NOT N'),
 		'allowed_types' => $allowedTypesAny
-	),
-	'dayofmonth[<]' => array(
+	],
+	'dayofmonth[<]' => [
 		'description' =>  _('Day of month is < N'),
 		'allowed_types' => $allowedTypesAny
-	),
-	'dayofmonth[>]' => array(
+	],
+	'dayofmonth[>]' => [
 		'description' =>  _('Day of month is > N'),
 		'allowed_types' => $allowedTypesAny
-	),
-	'dayofmonth[=]' => array(
+	],
+	'dayofmonth[=]' => [
 		'description' =>  _('Day of month is = N'),
 		'allowed_types' => $allowedTypesAny
-	),
-	'dayofmonth[#]' => array(
+	],
+	'dayofmonth[<>]' => [
 		'description' =>  _('Day of month is NOT N'),
 		'allowed_types' => $allowedTypesAny
-	),
-	'fuzzytime[=]' => array(
-		'description' =>  _('Timestamp not different from Zabbix server time for more than T seconds, then N = 1, 0 - otherwise'),
+	],
+	'fuzzytime[=]' => [
+		'description' =>  _('Difference between item timestamp value and Zabbix server timestamp is over T seconds, then N = 0, 1 - otherwise'),
 		'params' => $param1Sec,
 		'allowed_types' => $allowedTypesAny
-	),
-	'fuzzytime[#]' => array(
-		'description' =>  _('Timestamp not different from Zabbix server time for more than T seconds, then N NOT 1, 0 - otherwise'),
+	],
+	'fuzzytime[<>]' => [
+		'description' =>  _('Difference between item timestamp value and Zabbix server timestamp is over T seconds, then N NOT 0, 1 - otherwise'),
 		'params' => $param1Sec,
 		'allowed_types' => $allowedTypesAny
-	),
-	'regexp[=]' => array(
+	],
+	'regexp[=]' => [
 		'description' =>  _('Regular expression V matching last value in period T, then N = 1, 0 - otherwise'),
 		'params' => $param2SecCount,
 		'allowed_types' => $allowedTypesAny
-	),
-	'regexp[#]' => array(
+	],
+	'regexp[<>]' => [
 		'description' =>  _('Regular expression V matching last value in period T, then N NOT 1, 0 - otherwise'),
 		'params' => $param2SecCount,
 		'allowed_types' => $allowedTypesAny
-	),
-	'iregexp[=]' => array(
+	],
+	'iregexp[=]' => [
 		'description' =>  _('Regular expression V matching last value in period T, then N = 1, 0 - otherwise (non case-sensitive)'),
 		'params' => $param2SecCount,
 		'allowed_types' => $allowedTypesAny
-	),
-	'iregexp[#]' => array(
+	],
+	'iregexp[<>]' => [
 		'description' =>  _('Regular expression V matching last value in period T, then N NOT 1, 0 - otherwise (non case-sensitive)'),
 		'params' => $param2SecCount,
 		'allowed_types' => $allowedTypesAny
-	),
-	'logeventid[=]' => array(
+	],
+	'logeventid[=]' => [
 		'description' =>  _('Event ID of last log entry matching regular expression T, then N = 1, 0 - otherwise'),
 		'params' => $param1Str,
 		'allowed_types' => $allowedTypesLog
-	),
-	'logeventid[#]' => array(
+	],
+	'logeventid[<>]' => [
 		'description' =>  _('Event ID of last log entry matching regular expression T, then N NOT 1, 0 - otherwise'),
 		'params' => $param1Str,
 		'allowed_types' => $allowedTypesLog
-	),
-	'logseverity[<]' => array(
+	],
+	'logseverity[<]' => [
 		'description' =>  _('Log severity of the last log entry is < N'),
 		'allowed_types' => $allowedTypesLog
-	),
-	'logseverity[>]' => array(
+	],
+	'logseverity[>]' => [
 		'description' =>  _('Log severity of the last log entry is > N'),
 		'allowed_types' => $allowedTypesLog
-	),
-	'logseverity[=]' => array(
+	],
+	'logseverity[=]' => [
 		'description' =>  _('Log severity of the last log entry is = N'),
 		'allowed_types' => $allowedTypesLog
-	),
-	'logseverity[#]' => array(
+	],
+	'logseverity[<>]' => [
 		'description' =>  _('Log severity of the last log entry is NOT N'),
 		'allowed_types' => $allowedTypesLog
-	),
-	'logsource[=]' => array(
+	],
+	'logsource[=]' => [
 		'description' =>  _('Log source of the last log entry matching parameter T, then N = 1, 0 - otherwise'),
 		'params' => $param1Str,
 		'allowed_types' => $allowedTypesLog
-	),
-	'logsource[#]' => array(
+	],
+	'logsource[<>]' => [
 		'description' =>  _('Log source of the last log entry matching parameter T, then N NOT 1, 0 - otherwise'),
 		'params' => $param1Str,
 		'allowed_types' => $allowedTypesLog
-	),
-	'now[<]' => array(
+	],
+	'now[<]' => [
 		'description' =>  _('Number of seconds since the Epoch is < N'),
 		'allowed_types' => $allowedTypesAny
-	),
-	'now[>]' => array(
+	],
+	'now[>]' => [
 		'description' =>  _('Number of seconds since the Epoch is > N'),
 		'allowed_types' => $allowedTypesAny
-	),
-	'now[=]' => array(
+	],
+	'now[=]' => [
 		'description' =>  _('Number of seconds since the Epoch is = N'),
 		'allowed_types' => $allowedTypesAny
-	),
-	'now[#]' => array(
+	],
+	'now[<>]' => [
 		'description' =>  _('Number of seconds since the Epoch is NOT N'),
 		'allowed_types' => $allowedTypesAny
-	),
-	'time[<]' => array(
+	],
+	'time[<]' => [
 		'description' =>  _('Current time is < N'),
 		'allowed_types' => $allowedTypesAny
-	),
-	'time[>]' => array(
+	],
+	'time[>]' => [
 		'description' =>  _('Current time is > N'),
 		'allowed_types' => $allowedTypesAny
-	),
-	'time[=]' => array(
+	],
+	'time[=]' => [
 		'description' =>  _('Current time is = N'),
 		'allowed_types' => $allowedTypesAny
-	),
-	'time[#]' => array(
+	],
+	'time[<>]' => [
 		'description' =>  _('Current time is NOT N'),
 		'allowed_types' => $allowedTypesAny
-	),
-	'nodata[=]' => array(
+	],
+	'nodata[=]' => [
 		'description' =>  _('No data received during period of time T, then N = 1, 0 - otherwise'),
 		'params' => $param1Sec,
 		'allowed_types' => $allowedTypesAny
-	),
-	'nodata[#]' => array(
+	],
+	'nodata[<>]' => [
 		'description' =>  _('No data received during period of time T, then N NOT 1, 0 - otherwise'),
 		'params' => $param1Sec,
 		'allowed_types' => $allowedTypesAny
-	),
-	'band[=]' => array(
+	],
+	'band[=]' => [
 		'description' =>  _('Bitwise AND of last (most recent) T value and mask is = N'),
 		'params' => $paramSecIntCount,
 		'allowed_types' => $allowedTypesInt
-	),
-	'band[#]' => array(
+	],
+	'band[<>]' => [
 		'description' =>  _('Bitwise AND of last (most recent) T value and mask is NOT N'),
 		'params' => $paramSecIntCount,
 		'allowed_types' => $allowedTypesInt
-	)
-);
+	],
+	'forecast[<]' => [
+		'description' => _('Forecast for next t seconds based on period T is < N'),
+		'params' => $paramForecast,
+		'allowed_types' => $allowedTypesNumeric
+	],
+	'forecast[>]' => [
+		'description' => _('Forecast for next t seconds based on period T is > N'),
+		'params' => $paramForecast,
+		'allowed_types' => $allowedTypesNumeric
+	],
+	'forecast[=]' => [
+		'description' => _('Forecast for next t seconds based on period T is = N'),
+		'params' => $paramForecast,
+		'allowed_types' => $allowedTypesNumeric
+	],
+	'forecast[<>]' => [
+		'description' => _('Forecast for next t seconds based on period T is NOT N'),
+		'params' => $paramForecast,
+		'allowed_types' => $allowedTypesNumeric
+	],
+	'timeleft[<]' => [
+		'description' => _('Time to reach threshold estimated based on period T is < N'),
+		'params' => $paramTimeleft,
+		'allowed_types' => $allowedTypesNumeric
+	],
+	'timeleft[>]' => [
+		'description' => _('Time to reach threshold estimated based on period T is > N'),
+		'params' => $paramTimeleft,
+		'allowed_types' => $allowedTypesNumeric
+	],
+	'timeleft[=]' => [
+		'description' => _('Time to reach threshold estimated based on period T is = N'),
+		'params' => $paramTimeleft,
+		'allowed_types' => $allowedTypesNumeric
+	],
+	'timeleft[<>]' => [
+		'description' => _('Time to reach threshold estimated based on period T is NOT N'),
+		'params' => $paramTimeleft,
+		'allowed_types' => $allowedTypesNumeric
+	]
+];
 order_result($functions, 'description');
 
 //	VAR		TYPE	OPTIONAL FLAGS	VALIDATION	EXCEPTION
-$fields = array(
-	'dstfrm' =>				array(T_ZBX_STR, O_MAND, P_SYS, NOT_EMPTY,	null),
-	'dstfld1' =>			array(T_ZBX_STR, O_MAND, P_SYS, NOT_EMPTY,	null),
-	'expression' =>			array(T_ZBX_STR, O_OPT, null,	null,		null),
-	'itemid' =>				array(T_ZBX_INT, O_OPT, null,	null,		'isset({insert})'),
-	'parent_discoveryid' =>	array(T_ZBX_INT, O_OPT, null,	null,		null),
-	'expr_type'=>			array(T_ZBX_STR, O_OPT, null,	NOT_EMPTY,	'isset({insert})'),
-	'param' =>				array(T_ZBX_STR, O_OPT, null,	0,			'isset({insert})'),
-	'paramtype' =>			array(T_ZBX_INT, O_OPT, null,	IN(PARAM_TYPE_TIME.','.PARAM_TYPE_COUNTS), 'isset({insert})'),
-	'value' =>				array(T_ZBX_STR, O_OPT, null,	NOT_EMPTY,	'isset({insert})'),
+$fields = [
+	'dstfrm' =>				[T_ZBX_STR, O_MAND, P_SYS, NOT_EMPTY,	null],
+	'dstfld1' =>			[T_ZBX_STR, O_MAND, P_SYS, NOT_EMPTY,	null],
+	'expression' =>			[T_ZBX_STR, O_OPT, null,	null,		null],
+	'itemid' =>				[T_ZBX_INT, O_OPT, null,	null,		'isset({insert})'],
+	'parent_discoveryid' =>	[T_ZBX_INT, O_OPT, null,	null,		null],
+	'expr_type'=>			[T_ZBX_STR, O_OPT, null,	NOT_EMPTY,	'isset({insert})'],
+	'params' =>				[T_ZBX_STR, O_OPT, null,	0,			null],
+	'paramtype' =>			[T_ZBX_INT, O_OPT, null,	IN(PARAM_TYPE_TIME.','.PARAM_TYPE_COUNTS), 'isset({insert})'],
+	'value' =>				[T_ZBX_STR, O_OPT, null,	NOT_EMPTY,	'isset({insert})'],
 	// action
-	'insert' =>				array(T_ZBX_STR, O_OPT, P_SYS|P_ACT, null,	null),
-	'cancel' =>				array(T_ZBX_STR, O_OPT, P_SYS,	null,		null)
-);
+	'insert' =>				[T_ZBX_STR, O_OPT, P_SYS|P_ACT, null,	null],
+	'cancel' =>				[T_ZBX_STR, O_OPT, P_SYS,	null,		null]
+];
 check_fields($fields);
 
+$dstfrm = getRequest('dstfrm', 0);
+$dstfld1 = getRequest('dstfld1', '');
+$itemId = getRequest('itemid', 0);
+$value = getRequest('value', 0);
+$params = getRequest('params', []);
+$paramType = getRequest('paramtype');
+$exprType = getRequest('expr_type', 'last[=]');
+
+// opening the popup when editing an expression in the trigger constructor
 if (isset($_REQUEST['expression']) && $_REQUEST['dstfld1'] == 'expr_temp') {
 	$_REQUEST['expression'] = utf8RawUrlDecode($_REQUEST['expression']);
 
 	$expressionData = new CTriggerExpression();
+	$result = $expressionData->parse(getRequest('expression'));
 
-	if ($expressionData->parse($_REQUEST['expression']) && count($expressionData->expressions) == 1) {
-		$exprPart = reset($expressionData->expressions);
+	if ($result) {
+		// only one item function macro is supported in an expression
+		$functionMacroTokens = $result->getTokensByType(CTriggerExpressionParserResult::TOKEN_TYPE_FUNCTION_MACRO);
+		if (count($functionMacroTokens) == 1) {
+			$functionMacroToken = $functionMacroTokens[0];
 
-		preg_match('/\}([=><#]{1})([0-9]+['.ZBX_BYTE_SUFFIXES.ZBX_TIME_SUFFIXES.']?)$/', $_REQUEST['expression'],
-			$exprSymbols
-		);
+			// function
+			$function = $functionMacroToken['data']['functionName'];
 
-		if (isset($exprSymbols[1])) {
-			$_REQUEST['expr_type'] = $exprPart['functionName'].'['.$exprSymbols[1].']';
-		}
+			// determine param type
+			$params = $functionMacroToken['data']['functionParams'];
+			$paramNumber = in_array($function, ['regexp', 'iregexp', 'str']) ? 1 : 0;
+			if (isset($params[$paramNumber][0]) && $params[$paramNumber][0] == '#') {
+				$paramType = PARAM_TYPE_COUNTS;
+				$params[$paramNumber] = substr($params[$paramNumber], 1);
+			}
+			else {
+				$paramType = PARAM_TYPE_TIME;
+			}
 
-		$_REQUEST['description'] = $exprPart['host'].':'.$exprPart['item'];
-		$_REQUEST['param'] = $exprPart['functionParamList'];
+			// default operator
+			$operator = '=';
 
-		$paramNumber = in_array($exprPart['functionName'], array('regexp', 'iregexp', 'str')) ? 1 : 0;
+			// try to find an operator and a numeric value
+			// the value and operator can be extracted only if the immediately follow the item function macro
+			$tokens = $result->getTokens();
+			foreach ($tokens as $key => $token) {
+				if ($token['type'] == CTriggerExpressionParserResult::TOKEN_TYPE_FUNCTION_MACRO) {
+					if (isset($tokens[$key + 2])
+							&& $tokens[$key + 1]['type'] == CTriggerExpressionParserResult::TOKEN_TYPE_OPERATOR
+							&& isset($functions[$function.'['.$tokens[$key + 1]['value'].']'])
+							&& $tokens[$key + 2]['type'] == CTriggerExpressionParserResult::TOKEN_TYPE_NUMBER) {
 
-		if (isset($_REQUEST['param'][$paramNumber][0]) && $_REQUEST['param'][$paramNumber][0] == '#') {
-			$_REQUEST['paramtype'] = PARAM_TYPE_COUNTS;
-			$_REQUEST['param'][$paramNumber] = substr($_REQUEST['param'][$paramNumber], 1);
-		}
-		else {
-			$_REQUEST['paramtype'] = PARAM_TYPE_TIME;
-		}
+						$operator = $tokens[$key + 1]['value'];
+						$value = $tokens[$key + 2]['value'];
+					}
+					else {
+						break;
+					}
+				}
+			}
 
-		if (isset($exprSymbols[2])) {
-			$_REQUEST['value'] = $exprSymbols[2];
-		}
+			$exprType = $function.'['.$operator.']';
 
-		$myItem = API::Item()->get(array(
-			'filter' => array('host' => $exprPart['host'], 'key_' => $exprPart['item'], 'flags' => null),
-			'output' => array('itemid'),
-			'webitems' => true
-		));
-		$myItem = reset($myItem);
+			// find the item
+			$item = API::Item()->get([
+				'output' => ['itemid', 'hostid', 'name', 'key_', 'value_type'],
+				'selectHosts' => ['name'],
+				'webitems' => true,
+				'filter' => [
+					'host' => $functionMacroToken['data']['host'],
+					'key_' => $functionMacroToken['data']['item'],
+					'flags' => null
+				]
+			]);
+			$item = reset($item);
 
-		if (isset($myItem['itemid'])) {
-			$_REQUEST['itemid'] = $myItem['itemid'];
-		}
-		else {
-			error(_('Unknown host item, no such item in selected host'));
+			if ($item) {
+				$itemId = $item['itemid'];
+			}
+			else {
+				error(_('Unknown host item, no such item in selected host'));
+			}
 		}
 	}
 }
+// opening an empty form or switching a function
+else {
+	if (preg_match('/^([a-z]+)\[([=><]{1,2})\]$/i', $exprType, $matches)) {
+		$function = $matches[1];
+		$operator = $matches[2];
 
-$exprType = get_request('expr_type', 'last[=]');
-$exprType = array_key_exists($exprType, $functions) ? $exprType : 'last[=]';
+		if (!isset($functions[$exprType])) {
+			unset($function);
+		}
+	}
 
-if (preg_match('/^([a-z]+)\[(['.implode('', array_keys($operators)).'])\]$/i', $exprType, $exprRes)) {
-	$function = $exprRes[1];
-	$operator = $exprRes[2];
-}
-
-$dstfrm = get_request('dstfrm', 0);
-$dstfld1 = get_request('dstfld1', '');
-$itemId = get_request('itemid', 0);
-$value = get_request('value', 0);
-$param = get_request('param', 0);
-$paramType = get_request('paramtype');
-
-if ($itemId) {
-	$items = API::Item()->get(array(
-		'output' => array('itemid', 'hostid', 'name', 'key_'),
+	// fetch item
+	$item = API::Item()->get([
+		'output' => ['itemid', 'hostid', 'name', 'key_', 'value_type'],
+		'selectHosts' => ['host', 'name'],
 		'itemids' => $itemId,
 		'webitems' => true,
-		'selectHosts' => array('host'),
-		'filter' => array('flags' => null)
-	));
+		'filter' => ['flags' => null]
+	]);
+	$item = reset($item);
+}
 
-	$items = CMacrosResolverHelper::resolveItemNames($items);
+if ($itemId) {
+	$items = CMacrosResolverHelper::resolveItemNames([$item]);
+	$item = $items[0];
 
-	$item = reset($items);
+	$itemValueType = $item['value_type'];
 	$itemKey = $item['key_'];
-	$itemHost = reset($item['hosts']);
-	$itemHost = $itemHost['host'];
-	$description = $itemHost.NAME_DELIMITER.$item['name_expanded'];
+	$itemHostData = reset($item['hosts']);
+	$description = $itemHostData['name'].NAME_DELIMITER.$item['name_expanded'];
 }
 else {
-	$itemKey = $itemHost = $description = '';
+	$itemKey = '';
+	$description = '';
+	$itemValueType = null;
 }
 
 if (is_null($paramType) && isset($functions[$exprType]['params']['M'])) {
@@ -639,59 +779,30 @@ elseif (is_null($paramType)) {
 	$paramType = PARAM_TYPE_TIME;
 }
 
-if (!is_array($param)) {
-	if (isset($functions[$exprType]['params'])) {
-		$param = explode(',', $param, count($functions[$exprType]['params']));
-	}
-	else {
-		$param = array($param);
-	}
-}
-
 /*
  * Display
  */
-$data = array(
-	'parent_discoveryid' => get_request('parent_discoveryid', null),
+$data = [
+	'parent_discoveryid' => getRequest('parent_discoveryid'),
 	'dstfrm' => $dstfrm,
 	'dstfld1' => $dstfld1,
 	'itemid' => $itemId,
 	'value' => $value,
-	'param' => $param,
+	'params' => $params,
 	'paramtype' => $paramType,
 	'description' => $description,
 	'functions' => $functions,
-	'function' => $function,
-	'operator' => $operator,
-	'item_host' => $itemHost,
 	'item_key' => $itemKey,
-	'itemValueType' => null,
+	'itemValueType' => $itemValueType,
+	'selectedFunction' => null,
 	'expr_type' => $exprType,
-	'insert' => get_request('insert', null),
-	'cancel' => get_request('cancel', null)
-);
-
-// if user has already selected an item
-if ($itemId) {
-	// get item value type
-	$selectedItems = API::Item()->get(array(
-		'itemids' => array($itemId),
-		'output' => array('value_type'),
-		'filter' => array('flags' => null),
-		'webitems' => true
-	));
-
-	if ($selectedItem = reset($selectedItems)) {
-		$data['itemValueType'] = $selectedItem['value_type'];
-	}
-}
-
-$submittedFunction = $data['function'].'['.$data['operator'].']';
-$data['selectedFunction'] = null;
+	'insert' => getRequest('insert'),
+	'cancel' => getRequest('cancel')
+];
 
 // check if submitted function is usable with selected item
 foreach ($data['functions'] as $id => $f) {
-	if ((!$data['itemValueType'] || isset($f['allowed_types'][$data['itemValueType']])) && $id == $submittedFunction) {
+	if ((!$data['itemValueType'] || isset($f['allowed_types'][$data['itemValueType']])) && $id == $exprType) {
 		$data['selectedFunction'] = $id;
 		break;
 	}
@@ -699,7 +810,7 @@ foreach ($data['functions'] as $id => $f) {
 
 if ($data['selectedFunction'] === null) {
 	error(_s('Function "%1$s" cannot be used with selected item "%2$s"',
-		$data['functions'][$submittedFunction]['description'],
+		$data['functions'][$exprType]['description'],
 		$data['description']
 	));
 }
@@ -716,26 +827,26 @@ if (isset($data['insert'])) {
 	try {
 		if ($data['description']) {
 			if ($data['paramtype'] == PARAM_TYPE_COUNTS) {
-				$paramNumber = in_array($data['function'], array('regexp', 'iregexp', 'str')) ? 1 : 0;
-				$data['param'][$paramNumber] = '#'.$data['param'][$paramNumber];
+				$paramNumber = in_array($function, ['regexp', 'iregexp', 'str']) ? 1 : 0;
+				$data['params'][$paramNumber] = '#'.$data['params'][$paramNumber];
 			}
 
-			if ($data['paramtype'] == PARAM_TYPE_TIME && in_array($data['function'], array('last', 'band', 'strlen'))) {
-				$data['param'][0] = '';
+			if ($data['paramtype'] == PARAM_TYPE_TIME && in_array($function, ['last', 'band', 'strlen'])) {
+				$data['params'][0] = '';
 			}
 
 			// quote function param
-			$params = array();
-			foreach ($data['param'] as $param) {
-				$params[] = quoteFunctionParam($param);
+			$quotedParams = [];
+			foreach ($data['params'] as $param) {
+				$quotedParams[] = quoteFunctionParam($param);
 			}
 
 			$data['expression'] = sprintf('{%s:%s.%s(%s)}%s%s',
-				$data['item_host'],
+				$itemHostData['host'],
 				$data['item_key'],
-				$data['function'],
-				rtrim(implode(',', $params), ','),
-				$data['operator'],
+				$function,
+				rtrim(implode(',', $quotedParams), ','),
+				$operator,
 				$data['value']
 			);
 
@@ -746,13 +857,13 @@ if (isset($data['insert'])) {
 				$expressionData = reset($triggerExpression->expressions);
 
 				// validate trigger function
-				$triggerFunctionValidator = new CTriggerFunctionValidator();
-				$isValid = $triggerFunctionValidator->validate(array(
+				$triggerFunctionValidator = new CFunctionValidator();
+				$isValid = $triggerFunctionValidator->validate([
 					'function' => $expressionData['function'],
 					'functionName' => $expressionData['functionName'],
 					'functionParamList' => $expressionData['functionParamList'],
 					'valueType' => $data['itemValueType']
-				));
+				]);
 				if (!$isValid) {
 					unset($data['insert']);
 					throw new Exception($triggerFunctionValidator->getError());
@@ -765,8 +876,8 @@ if (isset($data['insert'])) {
 
 			// quote function param
 			if (isset($data['insert'])) {
-				foreach ($data['param'] as $pnum => $param) {
-					$data['param'][$pnum] = quoteFunctionParam($param);
+				foreach ($data['params'] as $pnum => $param) {
+					$data['params'][$pnum] = quoteFunctionParam($param);
 				}
 			}
 		}
