@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2015 Zabbix SIA
+** Copyright (C) 2001-2016 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -29,12 +29,12 @@ define('ZBX_PAGE_NO_MENU', 1);
 define('COMBO_PATTERN', 'str_in_array({},array(');
 define('COMBO_PATTERN_LENGTH', strlen(COMBO_PATTERN));
 
-$definedErrorPhrases = array(
+$definedErrorPhrases = [
 	EXPRESSION_HOST_UNKNOWN => _('Unknown host, no such host present in system'),
 	EXPRESSION_HOST_ITEM_UNKNOWN => _('Unknown host item, no such item in selected host'),
 	EXPRESSION_NOT_A_MACRO_ERROR => _('Given expression is not a macro'),
 	EXPRESSION_FUNCTION_UNKNOWN => _('Incorrect function is used')
-);
+];
 
 require_once dirname(__FILE__).'/include/page_header.php';
 
@@ -45,31 +45,33 @@ define('NO_LINK_IN_TESTING', true);
 list($outline, $eHTMLTree) = analyzeExpression($expression);
 
 // test data (create table, create check fields)
-$dataTable = new CTable(null, 'tableinfo');
-$dataTable->setAttribute('id', 'data_list');
-$dataTable->setHeader(array(_('Expression Variable Elements'), _('Result type'), _('Value')));
+$dataTable = (new CTable())
+	->setAttribute('style', 'width: 100%;')
+	->setHeader([_('Expression Variable Elements'), _('Result type'), _('Value')]);
 
-$datas = array();
-$fields = array();
-$rplcts = array();
+$datas = [];
+$fields = [];
+$rplcts = [];
 $allowedTesting = true;
 
 $expressionData = new CTriggerExpression();
 $result = $expressionData->parse($expression);
 if ($result) {
-	$macrosData = array();
+	$macrosData = [];
 
-	$supportedTokenTypes = array(
+	$supportedTokenTypes = [
 		CTriggerExpressionParserResult::TOKEN_TYPE_FUNCTION_MACRO => 1,
 		CTriggerExpressionParserResult::TOKEN_TYPE_MACRO => 1,
 		CTriggerExpressionParserResult::TOKEN_TYPE_USER_MACRO => 1,
 		CTriggerExpressionParserResult::TOKEN_TYPE_LLD_MACRO => 1
-	);
+	];
 	foreach ($result->getTokens() as $token) {
 		if (!isset($supportedTokenTypes[$token['type']]) || isset($macrosData[$token['value']])) {
 			continue;
 		}
 
+		$row = (new CRow())->addItem($token['value']);
+
 		$fname = 'test_data_'.md5($token['value']);
 		$macrosData[$token['value']] = getRequest($fname, '');
 
@@ -77,8 +79,11 @@ if ($result) {
 
 		if (!is_array($info) && isset($definedErrorPhrases[$info])) {
 			$allowedTesting = false;
-			$control = new CTextBox($fname, $macrosData[$token['value']], 30);
-			$control->setAttribute('disabled', 'disabled');
+			$row->addItem(
+				(new CCol($definedErrorPhrases[$info]))
+					->addClass(ZBX_STYLE_RED)
+					->setColspan(2)
+			);
 		}
 		else {
 			$validation = $info['validation'];
@@ -93,24 +98,23 @@ if ($result) {
 				}
 			}
 			else {
-				$control = new CTextBox($fname, $macrosData[$token['value']], 30);
+				$control = (new CTextBox($fname, $macrosData[$token['value']]))->setWidth(ZBX_TEXTAREA_SMALL_WIDTH);
 			}
 
-			$fields[$fname] = array($info['type'], O_OPT, null, $validation, 'isset({test_expression})',
+			$fields[$fname] = [$info['type'], O_OPT, null, $validation, 'isset({test_expression})',
 				$token['value']
-			);
+			];
+
+			$row->addItem($info['value_type']);
+			$row->addItem($control);
 		}
 
-		$resultType = (is_array($info) || !isset($definedErrorPhrases[$info]))
-			? $info['value_type']
-			: new CCol($definedErrorPhrases[$info], 'disaster');
-
-		$dataTable->addRow(new CRow(array($token['value'], $resultType, $control)));
+		$dataTable->addRow($row);
 	}
 }
 
 // checks
-$fields['test_expression'] = array(T_ZBX_STR, O_OPT, P_SYS|P_ACT, null, null);
+$fields['test_expression'] = [T_ZBX_STR, O_OPT, P_SYS|P_ACT, null, null];
 if (!check_fields($fields)) {
 	$test = false;
 }
@@ -125,71 +129,74 @@ else {
 }
 
 // form
-$testForm = new CFormTable(_('Test'), 'tr_testexpr.php');
-$testForm->addHelpIcon();
-$testForm->setTableClass('formlongtable formtable');
-$testForm->addVar('expression', $expression);
-$testForm->addRow(_('Test data'), $dataTable);
+$widget = (new CWidget())->setTitle(_('Test'));
 
-$resultTable = new CTable(null, 'tableinfo');
-$resultTable->setAttribute('id', 'result_list');
-$resultTable->setOddRowClass('even_row');
-$resultTable->setEvenRowClass('even_row');
-$resultTable->setHeader(array(_('Expression'), _('Result')));
+$form = (new CForm())
+	->addVar('expression', $expression);
+
+$form_list = (new CFormList())
+	->addRow(_('Test data'),
+		(new CDiv($dataTable))
+			->addClass(ZBX_STYLE_TABLE_FORMS_SEPARATOR)
+			->setAttribute('style', 'min-width: '.ZBX_TEXTAREA_BIG_WIDTH.'px;')
+	);
+
+$resultTable = (new CTable())
+	->setAttribute('style', 'width: 100%;')
+	->setHeader([_('Expression'), _('Result')]);
 
 ksort($rplcts, SORT_NUMERIC);
 
 foreach ($eHTMLTree as $e) {
-	$result = '-';
-	$style = 'text-align: center;';
+	$result = '';
+	$style = null;
 
 	if ($allowedTesting && $test && isset($e['expression'])) {
 		if (evalExpressionData($e['expression']['value'], $macrosData)) {
 			$result = 'TRUE';
-			$style = 'background-color: #ccf; color: #00f;';
+			$style = ZBX_STYLE_GREEN;
 		}
 		else {
 			$result = 'FALSE';
-			$style = 'background-color: #fcc; color: #f00;';
+			$style = ZBX_STYLE_RED;
 		}
 	}
 
-	$col = new CCol($result);
-	$col->setAttribute('style', $style);
-
-	$resultTable->addRow(new CRow(array($e['list'], $col)));
+	$resultTable->addRow([$e['list'], (new CCol($result))->addClass($style)]);
 }
 
-$result = '-';
-$style = 'text-align: center;';
+$result = '';
 
 if ($allowedTesting && $test) {
 	if (evalExpressionData($expression, $macrosData)) {
 		$result = 'TRUE';
-		$style = 'background-color: #ccf; color: #00f;';
+		$style = ZBX_STYLE_GREEN;
 	}
 	else {
 		$result = 'FALSE';
-		$style = 'background-color: #fcc; color: #f00;';
+		$style = ZBX_STYLE_RED;
 	}
 }
 
-$col = new CCol($result);
-$col->setAttribute('style', $style);
+$resultTable->setFooter([$outline, (new CCol($result))->addClass($style)]);
 
-$resultTable->setFooter(array($outline, $col), $resultTable->headerClass);
+$form_list->addRow(_('Result'),
+	(new CDiv($resultTable))
+		->addClass(ZBX_STYLE_TABLE_FORMS_SEPARATOR)
+		->setAttribute('style', 'min-width: '.ZBX_TEXTAREA_BIG_WIDTH.'px;')
+);
 
-$testForm->addRow(_('Result'), $resultTable);
+$tab = (new CTabView())->addTab('test_tab', null, $form_list);
 
-// action buttons
-$testButton = new CSubmit('test_expression', _('Test'));
-if (!$allowedTesting) {
-	$testButton->setAttribute('disabled', 'disabled');
-}
+$tab->setFooter(makeFormFooter(
+	(new CSubmit('test_expression', _('Test')))->setEnabled($allowedTesting),
+	[(new CButton('close', _('Close')))->onClick('javascript: self.close();')]
+));
 
-$testForm->addItemToBottomRow($testButton);
-$testForm->addItemToBottomRow(SPACE);
-$testForm->addItemToBottomRow(new CButton('close', _('Close'), 'javascript: self.close();'));
-$testForm->show();
+$form->addItem($tab);
+
+$widget
+	->addItem($form)
+	->show();
 
 require_once dirname(__FILE__).'/include/page_footer.php';
