@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2015 Zabbix SIA
+** Copyright (C) 2001-2016 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -36,7 +36,11 @@
 #define	ZBX_CFG_NOT_STRICT	0
 #define	ZBX_CFG_STRICT		1
 
+#define ZBX_PROXY_HEARTBEAT_FREQUENCY_MAX	SEC_PER_HOUR
+
 extern char	*CONFIG_FILE;
+extern char	*CONFIG_LOG_TYPE_STR;
+extern int	CONFIG_LOG_TYPE;
 extern char	*CONFIG_LOG_FILE;
 extern int	CONFIG_ALLOW_ROOT;
 extern int	CONFIG_TIMEOUT;
@@ -53,4 +57,7 @@ struct cfg_line
 
 int	parse_cfg_file(const char *cfg_file, struct cfg_line *cfg, int optional, int strict);
 
+int	check_cfg_feature_int(const char *parameter, int value, const char *feature);
+int	check_cfg_feature_str(const char *parameter, const char *value, const char *feature);
+
 #endif
