@@ -799,9 +799,11 @@ ZBX_TASK_EX;
 
 char	*string_replace(const char *str, const char *sub_str1, const char *sub_str2);
 
-int	is_double_suffix(const char *str);
+#define ZBX_FLAG_DOUBLE_PLAIN	0x00
+#define ZBX_FLAG_DOUBLE_SUFFIX	0x01
+int	is_double_suffix(const char *str, unsigned char flags);
 int	is_double(const char *c);
-int	is_uint_suffix(const char *c, unsigned int *value);
+int	is_time_suffix(const char *c, int *value);
 int	is_int_prefix(const char *c);
 int	is_uint_n_range(const char *str, size_t n, void *value, size_t size, zbx_uint64_t min, zbx_uint64_t max);
 int	is_hex_n_range(const char *str, size_t n, void *value, size_t size, zbx_uint64_t min, zbx_uint64_t max);
@@ -988,6 +990,12 @@ int	int_in_list(char *list, int value);
 int	ip_in_list(const char *list, const char *ip);
 
 /* IP range support */
+#define ZBX_IPRANGE_V4	0
+#define ZBX_IPRANGE_V6	1
+
+#define ZBX_IPRANGE_GROUPS_V4	4
+#define ZBX_IPRANGE_GROUPS_V6	8
+
 typedef struct
 {
 	int	from;
@@ -997,17 +1005,19 @@ zbx_range_t;
 
 typedef struct
 {
-	zbx_range_t	range[8];
+	/* contains groups of ranges for either ZBX_IPRANGE_V4 or ZBX_IPRANGE_V46 */
+	/* ex. 127-127.0-0.0-0.2-254 (from-to.from-to.from-to.from-to)            */
+	/*                                  0       1       2       3             */
+	zbx_range_t	range[ZBX_IPRANGE_GROUPS_V6];
+
 	/* range type - ZBX_IPRANGE_V4 or ZBX_IPRANGE_V6 */
 	unsigned char	type;
+
 	/* 1 if the range was defined with network mask, 0 otherwise */
 	unsigned char   mask;
 }
 zbx_iprange_t;
 
-#define ZBX_IPRANGE_V4	0
-#define ZBX_IPRANGE_V6	1
-
 int	iprange_parse(zbx_iprange_t *range, const char *address);
 void	iprange_first(const zbx_iprange_t *range, int *address);
 int	iprange_next(const zbx_iprange_t *range, int *address);
@@ -1104,7 +1114,6 @@ int	get_item_key(char **exp, char **key);
 
 int	parse_host(char **exp, char **host);
 int	parse_key(char **exp);
-int	parse_function(char **exp, char **func, char **params);
 
 int	parse_host_key(char *exp, char **host, char **key);
 
@@ -1146,23 +1155,22 @@ char	*zbx_dyn_escape_shell_single_quote(const char *text);
 #define HOST_TLS_PSK_LEN_MAX		(HOST_TLS_PSK_LEN + 1)
 #define HOST_TLS_PSK_LEN_MIN		32				/* for 16 hex-encoded bytes (128-bit PSK) */
 
-typedef struct
-{
-	char	*name;
-	char	**params;
-	int	nparam;
-}
-zbx_function_t;
+void	zbx_function_param_parse(const char *expr, size_t *param_pos, size_t *length, size_t *sep_pos);
+char	*zbx_function_param_unquote_dyn(const char *param, size_t len, int *quoted);
+int	zbx_function_param_quote(char **param, int forced);
+int	zbx_function_validate(const char *expr, size_t *par_l, size_t *par_r);
+int	zbx_function_find(const char *expr, size_t *func_pos, size_t *par_l, size_t *par_r);
 
-void	zbx_function_clean(zbx_function_t *func);
-int	zbx_function_parse(zbx_function_t *func, const char *expr, size_t *length);
-int	zbx_function_tostr(const zbx_function_t *func, const char *expr, size_t expr_len, char **out);
+void	zbx_alarm_flag_set(void);
+void	zbx_alarm_flag_clear(void);
 
 #ifndef _WINDOWS
 unsigned int	zbx_alarm_on(unsigned int seconds);
 unsigned int	zbx_alarm_off(void);
 #endif
 
+int	zbx_alarm_timed_out(void);
+
 #define zbx_bsearch(key, base, nmemb, size, compar)	(0 == (nmemb) ? NULL : bsearch(key, base, nmemb, size, compar))
 
 #endif
