@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2015 Zabbix SIA
+** Copyright (C) 2001-2016 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -25,22 +25,16 @@
 #	define ZBX_MUTEX		HANDLE
 #	define ZBX_MUTEX_NULL		NULL
 
-#	define ZBX_MUTEX_ERROR		0
-#	define ZBX_MUTEX_OK		1
-
 #	define ZBX_MUTEX_NAME		wchar_t *
 
-#	define ZBX_MUTEX_LOG		TEXT("ZBX_MUTEX_LOG")
-#	define ZBX_MUTEX_PERFSTAT	TEXT("ZBX_MUTEX_PERFSTAT")
+#	define ZBX_MUTEX_LOG		zbx_mutex_create_per_process_name(L"ZBX_MUTEX_LOG")
+#	define ZBX_MUTEX_PERFSTAT	zbx_mutex_create_per_process_name(L"ZBX_MUTEX_PERFSTAT")
 
 #else	/* not _WINDOWS */
 
 #	define ZBX_MUTEX		int
 #	define ZBX_MUTEX_NULL		-1
 
-#	define ZBX_MUTEX_ERROR		-1
-#	define ZBX_MUTEX_OK		1
-
 #	define ZBX_MUTEX_NAME		int
 
 #	define ZBX_NO_MUTEX		-1
@@ -56,7 +50,8 @@
 #	define ZBX_MUTEX_VALUECACHE	9
 #	define ZBX_MUTEX_VMWARE		10
 #	define ZBX_MUTEX_SQLITE3	11
-#	define ZBX_MUTEX_COUNT		12
+#	define ZBX_MUTEX_PROCSTAT	12
+#	define ZBX_MUTEX_COUNT		13
 
 #	define ZBX_MUTEX_MAX_TRIES	20	/* seconds */
 
@@ -72,4 +67,8 @@ void	__zbx_mutex_lock(const char *filename, int line, ZBX_MUTEX *mutex);
 void	__zbx_mutex_unlock(const char *filename, int line, ZBX_MUTEX *mutex);
 int	zbx_mutex_destroy(ZBX_MUTEX *mutex);
 
+#ifdef _WINDOWS
+ZBX_MUTEX_NAME	zbx_mutex_create_per_process_name(const ZBX_MUTEX_NAME prefix);
+#endif
+
 #endif	/* ZABBIX_MUTEXS_H */
