@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2015 Zabbix SIA
+** Copyright (C) 2001-2016 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -54,6 +54,10 @@
 #	include <Iphlpapi.h>
 #endif
 
+#ifdef HAVE_NETIOAPI_H
+#	include <Netioapi.h>
+#endif
+
 #ifdef HAVE_WINDOWS_H
 /* to speed build process and reduce size of the Win32 header files */
 #	define WIN32_LEAN_AND_MEAN	1
@@ -161,10 +165,6 @@
 #	include <kstat.h>
 #endif
 
-#ifdef HAVE_LDAP
-#	include <ldap.h>
-#endif
-
 #ifdef HAVE_WINLDAP_H
 #	undef SEC_I_INCOMPLETE_CREDENTIALS
 #	undef SEC_E_INCOMPLETE_CREDENTIALS
@@ -328,10 +328,6 @@
 #	include <unistd.h>
 #endif
 
-#ifdef HAVE_LBER_H
-#	include <lber.h>
-#endif
-
 #ifdef HAVE_SYS_IPC_H
 #	include <sys/ipc.h>
 #endif
@@ -385,36 +381,17 @@
 #	if 0x071004 >= LIBCURL_VERSION_NUM	/* version 7.16.4 */
 #		define CURLOPT_KEYPASSWD	CURLOPT_SSLKEYPASSWD
 #	endif
+#	if 0x071400 <= LIBCURL_VERSION_NUM	/* version 7.20.0 */
+#		define HAVE_SMTP_AUTHENTICATION	1
+#	endif
 #	define ZBX_CURLOPT_MAXREDIRS	10L
 #endif
 
-/* Net-SNMP is used */
-#ifdef HAVE_NETSNMP
-#	define SNMP_NO_DEBUGGING		/* disabling debugging messages from Net-SNMP library */
-#	include <net-snmp/net-snmp-config.h>
-#	include <net-snmp/net-snmp-includes.h>
-#endif
-
-/* LIBXML2 is used */
-#ifdef HAVE_LIBXML2
-#	include <libxml/parser.h>
-#	include <libxml/tree.h>
-#	include <libxml/xpath.h>
-#endif
-
 /* Required for advanced sigaction */
 #ifdef HAVE_SYS_UCONTEXT_H
 #	include <sys/ucontext.h>
 #endif
 
-#ifdef HAVE_ICONV
-#	include <iconv.h>
-#endif
-
-#ifdef HAVE_SSH2
-#	include <libssh2.h>
-#endif
-
 #ifdef HAVE_IO_H
 #	include <io.h>
 #endif
@@ -431,4 +408,9 @@
 #	include <dlfcn.h>
 #endif
 
+#ifdef HAVE_ZONE_H
+#	include <zone.h>
+#	include <utmpx.h>
+#endif
+
 #endif
