@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2018 Zabbix SIA
+** Copyright (C) 2001-2016 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -32,32 +32,37 @@
 #define ZBX_PTR_SIZE		sizeof(void *)
 
 #if defined(_WINDOWS)
+#	include <strsafe.h>
 
 #	define zbx_stat(path, buf)		__zbx_stat(path, buf)
 #	define zbx_open(pathname, flags)	__zbx_open(pathname, flags | O_BINARY)
 
-#	include <strsafe.h>
-#	define zbx_wsnprintf	StringCchPrintf
-#	define zbx_strlen	wcslen
-#	define zbx_strchr	wcschr
-#	define zbx_strstr	wcsstr
-#	define zbx_fullpath	_wfullpath
-
 #	ifndef __UINT64_C
 #		define __UINT64_C(x)	x
 #	endif
 
+#	ifndef __INT64_C
+#		define __INT64_C(x)	x
+#	endif
+
 #	define zbx_uint64_t	unsigned __int64
 #	define ZBX_FS_UI64	"%I64u"
 #	define ZBX_FS_UO64	"%I64o"
 #	define ZBX_FS_UX64	"%I64x"
 
+#	define zbx_int64_t	__int64
+#	define ZBX_FS_I64	"%I64d"
+#	define ZBX_FS_O64	"%I64o"
+#	define ZBX_FS_X64	"%I64x"
+
 #	define snprintf		_snprintf
 
 #	define alloca		_alloca
 
 #	ifndef uint32_t
-#		define uint32_t	unsigned __int32
+typedef unsigned __int32	zbx_uint32_t;
+#	else
+typedef uint32_t		zbx_uint32_t;
 #	endif
 
 #	ifndef PATH_SEPARATOR
@@ -82,6 +87,14 @@ typedef __int64	zbx_offset_t;
 #		endif
 #	endif
 
+#	ifndef __INT64_C
+#		ifdef INT64_C
+#			define __INT64_C(c)	(INT64_C(c))
+#		else
+#			define __INT64_C(c)	(c ## LL)
+#		endif
+#	endif
+
 #	define zbx_uint64_t	uint64_t
 #	if __WORDSIZE == 64
 #		define ZBX_FS_UI64	"%lu"
@@ -99,6 +112,25 @@ typedef __int64	zbx_offset_t;
 #		endif
 #	endif
 
+#	define zbx_int64_t	int64_t
+#	if __WORDSIZE == 64
+#		define ZBX_FS_I64	"%ld"
+#		define ZBX_FS_O64	"%lo"
+#		define ZBX_FS_X64	"%lx"
+#	else
+#		ifdef HAVE_LONG_LONG_QU
+#			define ZBX_FS_I64	"%qd"
+#			define ZBX_FS_O64	"%qo"
+#			define ZBX_FS_X64	"%qx"
+#		else
+#			define ZBX_FS_I64	"%lld"
+#			define ZBX_FS_O64	"%llo"
+#			define ZBX_FS_X64	"%llx"
+#		endif
+#	endif
+
+typedef uint32_t	zbx_uint32_t;
+
 #	ifndef PATH_SEPARATOR
 #		define PATH_SEPARATOR	'/'
 #	endif
@@ -109,7 +141,9 @@ typedef off_t	zbx_offset_t;
 #endif	/* _WINDOWS */
 
 #define ZBX_FS_SIZE_T		ZBX_FS_UI64
+#define ZBX_FS_SSIZE_T		ZBX_FS_I64
 #define zbx_fs_size_t		zbx_uint64_t	/* use this type only in calls to printf() for formatting size_t */
+#define zbx_fs_ssize_t		zbx_int64_t	/* use this type only in calls to printf() for formatting ssize_t */
 
 #ifndef S_ISREG
 #	define S_ISREG(x) (((x) & S_IFMT) == S_IFREG)
@@ -135,4 +169,9 @@ typedef struct
 }
 zbx_uint128_t;
 
+#define ZBX_SIZE_T_ALIGN8(size)	(((size) + 7) & ~(size_t)7)
+
+/* macro to test if a signed value has been assigned to unsigned type (char, short, int, long long) */
+#define ZBX_IS_TOP_BIT_SET(x)	(0 != ((__UINT64_C(1) << ((sizeof(x) << 3) - 1)) & (x)))
+
 #endif
