@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2015 Zabbix SIA
+** Copyright (C) 2001-2016 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -54,16 +54,31 @@ static void	swap(zbx_binary_heap_t *heap, int index_1, int index_2)
 
 static void	__binary_heap_ensure_free_space(zbx_binary_heap_t *heap)
 {
+	int	tmp_elems_alloc = heap->elems_alloc;
+
+	/* In order to prevent memory corruption heap->elems_alloc is set only after successful allocation. */
+	/* Otherwise, in case of shared memory, other processes might read or write past the actually       */
+	/* allocated memory.                                                                                */
+
 	if (NULL == heap->elems)
 	{
 		heap->elems_num = 0;
-		heap->elems_alloc = 32;
-		heap->elems = heap->mem_malloc_func(NULL, heap->elems_alloc * sizeof(zbx_binary_heap_elem_t));
+		tmp_elems_alloc = 32;
 	}
 	else if (heap->elems_num == heap->elems_alloc)
+		tmp_elems_alloc = MAX(heap->elems_alloc + 1, heap->elems_alloc * ARRAY_GROWTH_FACTOR);
+
+	if (heap->elems_num != tmp_elems_alloc)
 	{
-		heap->elems_alloc = MAX(heap->elems_alloc + 1, heap->elems_alloc * ARRAY_GROWTH_FACTOR);
-		heap->elems = heap->mem_realloc_func(heap->elems, heap->elems_alloc * sizeof(zbx_binary_heap_elem_t));
+		heap->elems = heap->mem_realloc_func(heap->elems, tmp_elems_alloc * sizeof(zbx_binary_heap_elem_t));
+
+		if (NULL == heap->elems)
+		{
+			THIS_SHOULD_NEVER_HAPPEN;
+			exit(EXIT_FAILURE);
+		}
+
+		heap->elems_alloc = tmp_elems_alloc;
 	}
 }
 
