@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2015 Zabbix SIA
+** Copyright (C) 2001-2016 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -134,7 +134,7 @@ void	zbx_vector_ ## __id ## _uniq(zbx_vector_ ## __id ## _t *vector, zbx_compare
 	}													\
 }														\
 														\
-int	zbx_vector_ ## __id ## _nearestindex(zbx_vector_ ## __id ## _t *vector, __type value,			\
+int	zbx_vector_ ## __id ## _nearestindex(const zbx_vector_ ## __id ## _t *vector, const __type value,	\
 									zbx_compare_func_t compare_func)	\
 {														\
 	int	lo = 0, hi = vector->values_num, mid, c;							\
@@ -160,12 +160,12 @@ int	zbx_vector_ ## __id ## _nearestindex(zbx_vector_ ## __id ## _t *vector, __ty
 	return hi;												\
 }														\
 														\
-int	zbx_vector_ ## __id ## _bsearch(zbx_vector_ ## __id ## _t *vector, __type value,			\
+int	zbx_vector_ ## __id ## _bsearch(const zbx_vector_ ## __id ## _t *vector, const __type value,		\
 									zbx_compare_func_t compare_func)	\
 {														\
 	__type	*ptr;												\
 														\
-	ptr = (__type *)bsearch(&value, vector->values, vector->values_num, sizeof(__type), compare_func);	\
+	ptr = (__type *)zbx_bsearch(&value, vector->values, vector->values_num, sizeof(__type), compare_func);	\
 														\
 	if (NULL != ptr)											\
 		return (int)(ptr - vector->values);								\
@@ -173,7 +173,7 @@ int	zbx_vector_ ## __id ## _bsearch(zbx_vector_ ## __id ## _t *vector, __type va
 		return FAIL;											\
 }														\
 														\
-int	zbx_vector_ ## __id ## _lsearch(zbx_vector_ ## __id ## _t *vector, __type value, int *index,		\
+int	zbx_vector_ ## __id ## _lsearch(const zbx_vector_ ## __id ## _t *vector, const __type value, int *index,\
 									zbx_compare_func_t compare_func)	\
 {														\
 	while (*index < vector->values_num)									\
@@ -196,7 +196,7 @@ int	zbx_vector_ ## __id ## _lsearch(zbx_vector_ ## __id ## _t *vector, __type va
 	return FAIL;												\
 }														\
 														\
-int	zbx_vector_ ## __id ## _search(zbx_vector_ ## __id ## _t *vector, __type value,				\
+int	zbx_vector_ ## __id ## _search(const zbx_vector_ ## __id ## _t *vector, const __type value,		\
 									zbx_compare_func_t compare_func)	\
 {														\
 	int	index;												\
@@ -208,6 +208,42 @@ int	zbx_vector_ ## __id ## _search(zbx_vector_ ## __id ## _t *vector, __type val
 	}													\
 														\
 	return FAIL;												\
+}														\
+														\
+														\
+void	zbx_vector_ ## __id ## _setdiff(zbx_vector_ ## __id ## _t *left, const zbx_vector_ ## __id ## _t *right,\
+									zbx_compare_func_t compare_func)	\
+{														\
+	int	c, block_start, deleted = 0, left_index = 0, right_index = 0;					\
+														\
+	while (left_index < left->values_num && right_index < right->values_num)				\
+	{													\
+		c = compare_func(&left->values[left_index], &right->values[right_index]);			\
+														\
+		if (0 >= c)											\
+			left_index++;										\
+														\
+		if (0 <= c)											\
+			right_index++;										\
+														\
+		if (0 != c)											\
+			continue;										\
+														\
+		if (0 < deleted++)										\
+		{												\
+			memmove(&left->values[block_start - deleted + 1], &left->values[block_start],		\
+							(left_index - 1 - block_start) * sizeof(__type));	\
+		}												\
+														\
+		block_start = left_index;									\
+	}													\
+														\
+	if (0 < deleted)											\
+	{													\
+		memmove(&left->values[block_start - deleted], &left->values[block_start],			\
+							(left->values_num - block_start) * sizeof(__type));	\
+		left->values_num -= deleted;									\
+	}													\
 }														\
 														\
 void	zbx_vector_ ## __id ## _reserve(zbx_vector_ ## __id ## _t *vector, size_t size)				\
@@ -221,12 +257,23 @@ void	zbx_vector_ ## __id ## _reserve(zbx_vector_ ## __id ## _t *vector, size_t s
 														\
 void	zbx_vector_ ## __id ## _clear(zbx_vector_ ## __id ## _t *vector)					\
 {														\
-	if (NULL != vector->values)										\
+	vector->values_num = 0;											\
+}
+
+#define	ZBX_PTR_VECTOR_IMPL(__id, __type)									\
+														\
+ZBX_VECTOR_IMPL(__id, __type);											\
+														\
+void	zbx_vector_ ## __id ## _clear_ext(zbx_vector_ ## __id ## _t *vector, zbx_clean_func_t clean_func)	\
+{														\
+	if (0 != vector->values_num)										\
 	{													\
-		vector->mem_free_func(vector->values);								\
-		vector->values = NULL;										\
+		int	index;											\
+														\
+		for (index = 0; index < vector->values_num; index++)						\
+			clean_func(vector->values[index]);							\
+														\
 		vector->values_num = 0;										\
-		vector->values_alloc = 0;									\
 	}													\
 }
 
