@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2015 Zabbix SIA
+** Copyright (C) 2001-2016 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -46,10 +46,10 @@ static int	telnet_waitsocket(ZBX_SOCKET socket_fd, int mode)
 
 	rc = select((int)(socket_fd + 1), readfd, writefd, NULL, &tv);
 
-	if (ZBX_TCP_ERROR == rc)
+	if (ZBX_PROTO_ERROR == rc)
 	{
 		zabbix_log(LOG_LEVEL_DEBUG, "%s() rc:%d errno:%d error:[%s]", __function_name, rc,
-				zbx_sock_last_error(), strerror_from_system(zbx_sock_last_error()));
+				zbx_socket_last_error(), strerror_from_system(zbx_socket_last_error()));
 	}
 
 	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%d", __function_name, rc);
@@ -65,9 +65,9 @@ static ssize_t	telnet_socket_read(ZBX_SOCKET socket_fd, void *buf, size_t count)
 
 	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __function_name);
 
-	while (ZBX_TCP_ERROR == (rc = ZBX_TCP_READ(socket_fd, buf, count)))
+	while (ZBX_PROTO_ERROR == (rc = ZBX_TCP_READ(socket_fd, buf, count)))
 	{
-		error = zbx_sock_last_error();	/* zabbix_log() resets the error code */
+		error = zbx_socket_last_error();	/* zabbix_log() resets the error code */
 		zabbix_log(LOG_LEVEL_DEBUG, "%s() rc:%d errno:%d error:[%s]",
 				__function_name, rc, error, strerror_from_system(error));
 #ifdef _WINDOWS
@@ -90,7 +90,7 @@ static ssize_t	telnet_socket_read(ZBX_SOCKET socket_fd, void *buf, size_t count)
 	/* when ZBX_TCP_READ returns 0, it means EOF - let's consider it a permanent error */
 	/* note that if telnet_waitsocket() is zero, it is not a permanent condition */
 	if (0 == rc)
-		rc = ZBX_TCP_ERROR;
+		rc = ZBX_PROTO_ERROR;
 ret:
 	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%d", __function_name, rc);
 
@@ -105,9 +105,9 @@ static ssize_t	telnet_socket_write(ZBX_SOCKET socket_fd, const void *buf, size_t
 
 	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __function_name);
 
-	while (ZBX_TCP_ERROR == (rc = ZBX_TCP_WRITE(socket_fd, buf, count)))
+	while (ZBX_PROTO_ERROR == (rc = ZBX_TCP_WRITE(socket_fd, buf, count)))
 	{
-		error = zbx_sock_last_error();	/* zabbix_log() resets the error code */
+		error = zbx_socket_last_error();	/* zabbix_log() resets the error code */
 		zabbix_log(LOG_LEVEL_DEBUG, "%s() rc:%d errno:%d error:[%s]",
 				__function_name, rc, error, strerror_from_system(error));
 #ifdef _WINDOWS
@@ -132,7 +132,7 @@ static ssize_t	telnet_read(ZBX_SOCKET socket_fd, char *buf, size_t *buf_left, si
 {
 	const char	*__function_name = "telnet_read";
 	unsigned char	c, c1, c2, c3;
-	ssize_t		rc = ZBX_TCP_ERROR;
+	ssize_t		rc = ZBX_PROTO_ERROR;
 
 	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __function_name);
 
@@ -149,7 +149,7 @@ static ssize_t	telnet_read(ZBX_SOCKET socket_fd, char *buf, size_t *buf_left, si
 				while (0 == (rc = telnet_socket_read(socket_fd, &c2, 1)))
 					;
 
-				if (ZBX_TCP_ERROR == rc)
+				if (ZBX_PROTO_ERROR == rc)
 					goto end;
 
 				zabbix_log(LOG_LEVEL_DEBUG, "%s() c2:%x", __function_name, c2);
@@ -170,7 +170,7 @@ static ssize_t	telnet_read(ZBX_SOCKET socket_fd, char *buf, size_t *buf_left, si
 						while (0 == (rc = telnet_socket_read(socket_fd, &c3, 1)))
 							;
 
-						if (ZBX_TCP_ERROR == rc)
+						if (ZBX_PROTO_ERROR == rc)
 							goto end;
 
 						zabbix_log(LOG_LEVEL_DEBUG, "%s() c3:%x", __function_name, c3);
@@ -320,16 +320,16 @@ int	telnet_test_login(ZBX_SOCKET socket_fd)
 
 	sz = sizeof(buf);
 	offset = 0;
-	while (ZBX_TCP_ERROR != (rc = telnet_read(socket_fd, buf, &sz, &offset)))
+	while (ZBX_PROTO_ERROR != (rc = telnet_read(socket_fd, buf, &sz, &offset)))
 	{
 		if (':' == telnet_lastchar(buf, offset))
 			break;
 	}
 
 	convert_telnet_to_unix_eol(buf, &offset);
-	zabbix_log(LOG_LEVEL_DEBUG, "%s() login prompt:'%.*s'", __function_name, offset, buf);
+	zabbix_log(LOG_LEVEL_DEBUG, "%s() login prompt:'%.*s'", __function_name, (int)offset, buf);
 
-	if (ZBX_TCP_ERROR != rc)
+	if (ZBX_PROTO_ERROR != rc)
 		ret = SUCCEED;
 
 	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%s", __function_name, zbx_result_string(ret));
@@ -348,16 +348,16 @@ int	telnet_login(ZBX_SOCKET socket_fd, const char *username, const char *passwor
 
 	sz = sizeof(buf);
 	offset = 0;
-	while (ZBX_TCP_ERROR != (rc = telnet_read(socket_fd, buf, &sz, &offset)))
+	while (ZBX_PROTO_ERROR != (rc = telnet_read(socket_fd, buf, &sz, &offset)))
 	{
 		if (':' == telnet_lastchar(buf, offset))
 			break;
 	}
 
 	convert_telnet_to_unix_eol(buf, &offset);
-	zabbix_log(LOG_LEVEL_DEBUG, "%s() login prompt:'%.*s'", __function_name, offset, buf);
+	zabbix_log(LOG_LEVEL_DEBUG, "%s() login prompt:'%.*s'", __function_name, (int)offset, buf);
 
-	if (ZBX_TCP_ERROR == rc)
+	if (ZBX_PROTO_ERROR == rc)
 	{
 		SET_MSG_RESULT(result, zbx_strdup(NULL, "No login prompt."));
 		goto fail;
@@ -368,16 +368,16 @@ int	telnet_login(ZBX_SOCKET socket_fd, const char *username, const char *passwor
 
 	sz = sizeof(buf);
 	offset = 0;
-	while (ZBX_TCP_ERROR != (rc = telnet_read(socket_fd, buf, &sz, &offset)))
+	while (ZBX_PROTO_ERROR != (rc = telnet_read(socket_fd, buf, &sz, &offset)))
 	{
 		if (':' == telnet_lastchar(buf, offset))
 			break;
 	}
 
 	convert_telnet_to_unix_eol(buf, &offset);
-	zabbix_log(LOG_LEVEL_DEBUG, "%s() password prompt:'%.*s'", __function_name, offset, buf);
+	zabbix_log(LOG_LEVEL_DEBUG, "%s() password prompt:'%.*s'", __function_name, (int)offset, buf);
 
-	if (ZBX_TCP_ERROR == rc)
+	if (ZBX_PROTO_ERROR == rc)
 	{
 		SET_MSG_RESULT(result, zbx_strdup(NULL, "No password prompt."));
 		goto fail;
@@ -388,7 +388,7 @@ int	telnet_login(ZBX_SOCKET socket_fd, const char *username, const char *passwor
 
 	sz = sizeof(buf);
 	offset = 0;
-	while (ZBX_TCP_ERROR != (rc = telnet_read(socket_fd, buf, &sz, &offset)))
+	while (ZBX_PROTO_ERROR != (rc = telnet_read(socket_fd, buf, &sz, &offset)))
 	{
 		if ('$' == (c = telnet_lastchar(buf, offset)) || '#' == c || '>' == c || '%' == c)
 		{
@@ -398,9 +398,9 @@ int	telnet_login(ZBX_SOCKET socket_fd, const char *username, const char *passwor
 	}
 
 	convert_telnet_to_unix_eol(buf, &offset);
-	zabbix_log(LOG_LEVEL_DEBUG, "%s() prompt:'%.*s'", __function_name, offset, buf);
+	zabbix_log(LOG_LEVEL_DEBUG, "%s() prompt:'%.*s'", __function_name, (int)offset, buf);
 
-	if (ZBX_TCP_ERROR == rc)
+	if (ZBX_PROTO_ERROR == rc)
 	{
 		SET_MSG_RESULT(result, zbx_strdup(NULL, "Login failed."));
 		goto fail;
@@ -440,19 +440,19 @@ int	telnet_execute(ZBX_SOCKET socket_fd, const char *command, AGENT_RESULT *resu
 
 	sz = sizeof(buf);
 	offset = 0;
-	while (ZBX_TCP_ERROR != (rc = telnet_read(socket_fd, buf, &sz, &offset)))
+	while (ZBX_PROTO_ERROR != (rc = telnet_read(socket_fd, buf, &sz, &offset)))
 	{
 		if (prompt_char == telnet_lastchar(buf, offset))
 			break;
 	}
 
 	convert_telnet_to_unix_eol(buf, &offset);
-	zabbix_log(LOG_LEVEL_DEBUG, "%s() command output:'%.*s'", __function_name, offset, buf);
+	zabbix_log(LOG_LEVEL_DEBUG, "%s() command output:'%.*s'", __function_name, (int)offset, buf);
 
-	if (ZBX_TCP_ERROR == rc)
+	if (ZBX_PROTO_ERROR == rc)
 	{
 		SET_MSG_RESULT(result, zbx_dsprintf(NULL, "Cannot find prompt after command execution: %s",
-				strerror_from_system(zbx_sock_last_error())));
+				strerror_from_system(zbx_socket_last_error())));
 		goto fail;
 	}
 
@@ -480,7 +480,7 @@ int	telnet_execute(ZBX_SOCKET socket_fd, const char *command, AGENT_RESULT *resu
 	telnet_rm_echo(buf, &offset, "\n", 1);
 	telnet_rm_prompt(buf, &offset);
 
-	zabbix_log(LOG_LEVEL_DEBUG, "%s() stripped command output:'%.*s'", __function_name, offset, buf);
+	zabbix_log(LOG_LEVEL_DEBUG, "%s() stripped command output:'%.*s'", __function_name, (int)offset, buf);
 
 	if (MAX_BUFFER_LEN == offset)
 		offset--;
