@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2015 Zabbix SIA
+** Copyright (C) 2001-2016 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -738,6 +738,11 @@ static void	lld_validate_graph_field(zbx_lld_graph_t *graph, char **field, char
 		*error = zbx_strdcatf(*error, "Cannot %s graph: value \"%s\" is too long.\n",
 				(0 != graph->graphid ? "update" : "create"), *field);
 	}
+	else if (ZBX_FLAG_LLD_GRAPH_UPDATE_NAME == flag && '\0' == **field)
+	{
+		*error = zbx_strdcatf(*error, "Cannot %s graph: name is empty.\n",
+				(0 != graph->graphid ? "update" : "create"));
+	}
 	else
 		return;
 
