@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2015 Zabbix SIA
+** Copyright (C) 2001-2016 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -21,6 +21,7 @@
 #include "log.h"
 #include "mutexs.h"
 #include "threads.h"
+#include "cfg.h"
 #ifdef _WINDOWS
 #	include "messages.h"
 #	include "service.h"
@@ -29,18 +30,29 @@ static HANDLE		system_log_handle = INVALID_HANDLE_VALUE;
 
 static char		log_filename[MAX_STRING_LEN];
 static int		log_type = LOG_TYPE_UNDEFINED;
-static ZBX_MUTEX	log_file_access = ZBX_MUTEX_NULL;
-#ifdef DEBUG
-static int		log_level = LOG_LEVEL_DEBUG;
-#else
+static ZBX_MUTEX	log_access = ZBX_MUTEX_NULL;
 static int		log_level = LOG_LEVEL_WARNING;
-#endif
+
+#define LOCK_LOG	zbx_mutex_lock(&log_access)
+#define UNLOCK_LOG	zbx_mutex_unlock(&log_access)
 
 #define ZBX_MESSAGE_BUF_SIZE	1024
 
 #define ZBX_CHECK_LOG_LEVEL(level)	\
 		((LOG_LEVEL_INFORMATION != level && (level > log_level || LOG_LEVEL_EMPTY == level)) ? FAIL : SUCCEED)
 
+#ifdef _WINDOWS
+#	define STDIN_FILENO	_fileno(stdin)
+#	define STDOUT_FILENO	_fileno(stdout)
+#	define STDERR_FILENO	_fileno(stderr)
+
+#	define ZBX_DEV_NULL	"NUL"
+
+#	define dup2(fd1, fd2)	_dup2(fd1, fd2)
+#else
+#	define ZBX_DEV_NULL	"/dev/null"
+#endif
+
 const char	*zabbix_get_log_level_string(void)
 {
 	switch (log_level)
@@ -83,40 +95,179 @@ int	zabbix_decrease_log_level(void)
 	return SUCCEED;
 }
 
-#if !defined(_WINDOWS)
-void	redirect_std(const char *filename)
+void	zbx_redirect_stdio(const char *filename)
 {
 	int		fd;
-	const char	default_file[] = "/dev/null";
-	const char	*out_file = default_file;
+	const char	default_file[] = ZBX_DEV_NULL;
 	int		open_flags = O_WRONLY;
 
-	close(STDIN_FILENO);
-	open(default_file, O_RDONLY);	/* stdin, normally fd==0 */
-
 	if (NULL != filename && '\0' != *filename)
-	{
-		out_file = filename;
 		open_flags |= O_CREAT | O_APPEND;
-	}
-
-	if (-1 != (fd = open(out_file, open_flags, 0666)))
-	{
-		if (-1 == dup2(fd, STDERR_FILENO))
-			zbx_error("cannot redirect stderr to [%s]", filename);
-
-		if (-1 == dup2(fd, STDOUT_FILENO))
-			zbx_error("cannot redirect stdout to [%s]", filename);
-
-		close(fd);
-	}
 	else
+		filename = default_file;
+
+	if (-1 == (fd = open(filename, open_flags, 0666)))
 	{
-		zbx_error("cannot open [%s]: %s", filename, zbx_strerror(errno));
+		zbx_error("cannot open \"%s\": %s", filename, zbx_strerror(errno));
 		exit(EXIT_FAILURE);
 	}
+
+	fflush(stdout);
+	if (-1 == dup2(fd, STDOUT_FILENO))
+		zbx_error("cannot redirect stdout to \"%s\": %s", filename, zbx_strerror(errno));
+
+	fflush(stderr);
+	if (-1 == dup2(fd, STDERR_FILENO))
+		zbx_error("cannot redirect stderr to \"%s\": %s", filename, zbx_strerror(errno));
+
+	close(fd);
+
+	if (-1 == (fd = open(default_file, O_RDONLY)))
+	{
+		zbx_error("cannot open \"%s\": %s", default_file, zbx_strerror(errno));
+		exit(EXIT_FAILURE);
+	}
+
+	if (-1 == dup2(fd, STDIN_FILENO))
+		zbx_error("cannot redirect stdin to \"%s\": %s", default_file, zbx_strerror(errno));
+
+	close(fd);
+}
+
+static void	rotate_log(const char *filename)
+{
+	zbx_stat_t		buf;
+	zbx_uint64_t		new_size;
+	static zbx_uint64_t	old_size = ZBX_MAX_UINT64;
+
+	if (0 == CONFIG_LOG_FILE_SIZE || NULL == filename || '\0' == *filename)
+	{
+		/* redirect only once if log file wasn't specified or there is no log file size limit */
+		if (ZBX_MAX_UINT64 == old_size)
+		{
+			old_size = 0;
+			zbx_redirect_stdio(filename);
+		}
+
+		return;
+	}
+
+	if (0 != zbx_stat(filename, &buf))
+		return;
+
+	new_size = buf.st_size;
+
+	if ((zbx_uint64_t)CONFIG_LOG_FILE_SIZE * ZBX_MEBIBYTE < new_size)
+	{
+		char	filename_old[MAX_STRING_LEN];
+
+		strscpy(filename_old, filename);
+		zbx_strlcat(filename_old, ".old", MAX_STRING_LEN);
+		remove(filename_old);
+
+		if (0 != rename(filename, filename_old))
+		{
+			FILE	*log_file = NULL;
+
+			if (NULL != (log_file = fopen(filename, "w")))
+			{
+				long		milliseconds;
+				struct tm	tm;
+
+				zbx_get_time(&tm, &milliseconds, NULL);
+
+				fprintf(log_file, "%6li:%.4d%.2d%.2d:%.2d%.2d%.2d.%03ld"
+						" cannot rename log file \"%s\" to \"%s\": %s\n",
+						zbx_get_thread_id(),
+						tm.tm_year + 1900,
+						tm.tm_mon + 1,
+						tm.tm_mday,
+						tm.tm_hour,
+						tm.tm_min,
+						tm.tm_sec,
+						milliseconds,
+						filename,
+						filename_old,
+						zbx_strerror(errno));
+
+				fprintf(log_file, "%6li:%.4d%.2d%.2d:%.2d%.2d%.2d.%03ld"
+						" Logfile \"%s\" size reached configured limit"
+						" LogFileSize but moving it to \"%s\" failed. The logfile"
+						" was truncated.\n",
+						zbx_get_thread_id(),
+						tm.tm_year + 1900,
+						tm.tm_mon + 1,
+						tm.tm_mday,
+						tm.tm_hour,
+						tm.tm_min,
+						tm.tm_sec,
+						milliseconds,
+						filename,
+						filename_old);
+
+				zbx_fclose(log_file);
+
+				new_size = 0;
+			}
+		}
+		else
+			new_size = 0;
+	}
+
+	if (old_size > new_size)
+		zbx_redirect_stdio(filename);
+
+	old_size = new_size;
+}
+
+#ifndef _WINDOWS
+static sigset_t	orig_mask;
+
+static void	lock_log(void)
+{
+	sigset_t	mask;
+
+	sigemptyset(&mask);
+	sigaddset(&mask, SIGUSR1);
+	sigaddset(&mask, SIGTERM);	/* block SIGTERM, SIGINT to prevent deadlock on log file mutex */
+	sigaddset(&mask, SIGINT);
+
+	if (0 > sigprocmask(SIG_BLOCK, &mask, &orig_mask))
+		zbx_error("cannot set sigprocmask to block the user signal");
+
+	LOCK_LOG;
+}
+
+static void	unlock_log(void)
+{
+	UNLOCK_LOG;
+
+	if (0 > sigprocmask(SIG_SETMASK, &orig_mask, NULL))
+		zbx_error("cannot restore sigprocmask");
+}
+#else
+static void	lock_log(void)
+{
+	LOCK_LOG;
+}
+
+static void	unlock_log(void)
+{
+	UNLOCK_LOG;
+}
+#endif
+
+void	zbx_handle_log(void)
+{
+	if (LOG_TYPE_FILE != log_type)
+		return;
+
+	lock_log();
+
+	rotate_log(log_filename);
+
+	unlock_log();
 }
-#endif	/* not _WINDOWS */
 
 int	zabbix_open_log(int type, int level, const char *filename)
 {
@@ -124,14 +275,11 @@ int	zabbix_open_log(int type, int level, const char *filename)
 #ifdef _WINDOWS
 	wchar_t	*wevent_source;
 #endif
+	log_type = type;
 	log_level = level;
 
-	if (LOG_TYPE_FILE == type && NULL == filename)
-		type = LOG_TYPE_SYSLOG;
-
-	if (LOG_TYPE_SYSLOG == type)
+	if (LOG_TYPE_SYSTEM == type)
 	{
-		log_type = LOG_TYPE_SYSLOG;
 #ifdef _WINDOWS
 		wevent_source = zbx_utf8_to_unicode(ZABBIX_EVENT_SOURCE);
 		system_log_handle = RegisterEventSource(NULL, wevent_source);
@@ -148,7 +296,7 @@ int	zabbix_open_log(int type, int level, const char *filename)
 			exit(EXIT_FAILURE);
 		}
 
-		if (ZBX_MUTEX_ERROR == zbx_mutex_create_force(&log_file_access, ZBX_MUTEX_LOG))
+		if (FAIL == zbx_mutex_create_force(&log_access, ZBX_MUTEX_LOG))
 		{
 			zbx_error("unable to create mutex for log file");
 			exit(EXIT_FAILURE);
@@ -160,17 +308,28 @@ int	zabbix_open_log(int type, int level, const char *filename)
 			exit(EXIT_FAILURE);
 		}
 
-		log_type = LOG_TYPE_FILE;
 		strscpy(log_filename, filename);
 		zbx_fclose(log_file);
 	}
+	else if (LOG_TYPE_CONSOLE == type)
+	{
+		if (FAIL == zbx_mutex_create_force(&log_access, ZBX_MUTEX_LOG))
+		{
+			zbx_error("unable to create mutex for standard output");
+			exit(EXIT_FAILURE);
+		}
+
+		fflush(stderr);
+		if (-1 == dup2(STDOUT_FILENO, STDERR_FILENO))
+			zbx_error("cannot redirect stderr to stdout: %s", zbx_strerror(errno));
+	}
 
 	return SUCCEED;
 }
 
 void	zabbix_close_log(void)
 {
-	if (LOG_TYPE_SYSLOG == log_type)
+	if (LOG_TYPE_SYSTEM == log_type)
 	{
 #ifdef _WINDOWS
 		if (NULL != system_log_handle)
@@ -179,9 +338,9 @@ void	zabbix_close_log(void)
 		closelog();
 #endif
 	}
-	else if (LOG_TYPE_FILE == log_type)
+	else if (LOG_TYPE_FILE == log_type || LOG_TYPE_CONSOLE == log_type)
 	{
-		zbx_mutex_destroy(&log_file_access);
+		zbx_mutex_destroy(&log_access);
 	}
 }
 
@@ -249,125 +408,85 @@ int	zabbix_check_log_level(int level)
 
 void	__zbx_zabbix_log(int level, const char *fmt, ...)
 {
-	FILE			*log_file = NULL;
-	char			message[MAX_BUFFER_LEN], filename_old[MAX_STRING_LEN];
-	long			milliseconds;
-	static zbx_uint64_t	old_size = 0;
-	va_list			args;
-	struct tm		*tm;
-	zbx_stat_t		buf;
+	FILE		*log_file = NULL;
+	char		message[MAX_BUFFER_LEN];
+	va_list		args;
 #ifdef _WINDOWS
-	struct _timeb		current_time;
-	WORD			wType;
-	wchar_t			thread_id[20], *strings[2];
-#else
-	struct timeval		current_time;
+	WORD		wType;
+	wchar_t		thread_id[20], *strings[2];
 #endif
 	if (SUCCEED != ZBX_CHECK_LOG_LEVEL(level))
 		return;
 
 	if (LOG_TYPE_FILE == log_type)
 	{
-		zbx_mutex_lock(&log_file_access);
+		lock_log();
 
-		if (0 != CONFIG_LOG_FILE_SIZE && 0 == zbx_stat(log_filename, &buf))
+		rotate_log(log_filename);
+
+		if (NULL != (log_file = fopen(log_filename, "a+")))
 		{
-			if (CONFIG_LOG_FILE_SIZE * ZBX_MEBIBYTE < buf.st_size)
-			{
-				strscpy(filename_old, log_filename);
-				zbx_strlcat(filename_old, ".old", MAX_STRING_LEN);
-				remove(filename_old);
+			long		milliseconds;
+			struct tm	tm;
 
-				if (0 != rename(log_filename, filename_old))
-				{
-					log_file = fopen(log_filename, "w");
+			zbx_get_time(&tm, &milliseconds, NULL);
 
-					if (NULL != log_file)
-					{
-#ifdef _WINDOWS
-						_ftime(&current_time);
-						tm = localtime(&current_time.time);
-						milliseconds = current_time.millitm;
-#else
-						gettimeofday(&current_time,NULL);
-						tm = localtime(&current_time.tv_sec);
-						milliseconds = current_time.tv_usec / 1000;
-#endif
-						fprintf(log_file, "%6li:%.4d%.2d%.2d:%.2d%.2d%.2d.%03ld"
-								" cannot rename log file \"%s\" to \"%s\": %s\n",
-								zbx_get_thread_id(),
-								tm->tm_year + 1900,
-								tm->tm_mon + 1,
-								tm->tm_mday,
-								tm->tm_hour,
-								tm->tm_min,
-								tm->tm_sec,
-								milliseconds,
-								log_filename,
-								filename_old,
-								zbx_strerror(errno));
-
-						fprintf(log_file, "%6li:%.4d%.2d%.2d:%.2d%.2d%.2d.%03ld"
-								" Logfile \"%s\" size reached configured limit"
-								" LogFileSize. Renaming the logfile to \"%s\" and"
-								" starting a new logfile failed. The logfile"
-								" was truncated and started from beginning.\n",
-								zbx_get_thread_id(),
-								tm->tm_year + 1900,
-								tm->tm_mon + 1,
-								tm->tm_mday,
-								tm->tm_hour,
-								tm->tm_min,
-								tm->tm_sec,
-								milliseconds,
-								log_filename,
-								filename_old);
-
-						zbx_fclose(log_file);
-					}
-				}
-			}
-
-			if (old_size > (zbx_uint64_t)buf.st_size)
-				redirect_std(log_filename);
-
-			old_size = (zbx_uint64_t)buf.st_size;
-		}
-
-		log_file = fopen(log_filename,"a+");
-
-		if (NULL != log_file)
-		{
-#ifdef _WINDOWS
-		        _ftime(&current_time);
-			tm = localtime(&current_time.time);
-			milliseconds = current_time.millitm;
-#else
-			gettimeofday(&current_time,NULL);
-			tm = localtime(&current_time.tv_sec);
-			milliseconds = current_time.tv_usec / 1000;
-#endif
 			fprintf(log_file,
-				"%6li:%.4d%.2d%.2d:%.2d%.2d%.2d.%03ld ",
-				zbx_get_thread_id(),
-				tm->tm_year + 1900,
-				tm->tm_mon + 1,
-				tm->tm_mday,
-				tm->tm_hour,
-				tm->tm_min,
-				tm->tm_sec,
-				milliseconds
-				);
+					"%6li:%.4d%.2d%.2d:%.2d%.2d%.2d.%03ld ",
+					zbx_get_thread_id(),
+					tm.tm_year + 1900,
+					tm.tm_mon + 1,
+					tm.tm_mday,
+					tm.tm_hour,
+					tm.tm_min,
+					tm.tm_sec,
+					milliseconds
+					);
 
 			va_start(args, fmt);
 			vfprintf(log_file, fmt, args);
 			va_end(args);
 
 			fprintf(log_file, "\n");
+
 			zbx_fclose(log_file);
 		}
 
-		zbx_mutex_unlock(&log_file_access);
+		unlock_log();
+
+		return;
+	}
+
+	if (LOG_TYPE_CONSOLE == log_type)
+	{
+		long		milliseconds;
+		struct tm	tm;
+
+		lock_log();
+
+		zbx_get_time(&tm, &milliseconds, NULL);
+
+		fprintf(stdout,
+				"%6li:%.4d%.2d%.2d:%.2d%.2d%.2d.%03ld ",
+				zbx_get_thread_id(),
+				tm.tm_year + 1900,
+				tm.tm_mon + 1,
+				tm.tm_mday,
+				tm.tm_hour,
+				tm.tm_min,
+				tm.tm_sec,
+				milliseconds
+				);
+
+		va_start(args, fmt);
+		vfprintf(stdout, fmt, args);
+		va_end(args);
+
+		fprintf(stdout, "\n");
+
+		fflush(stdout);
+
+		unlock_log();
 
 		return;
 	}
@@ -376,7 +495,7 @@ void	__zbx_zabbix_log(int level, const char *fmt, ...)
 	zbx_vsnprintf(message, sizeof(message), fmt, args);
 	va_end(args);
 
-	if (LOG_TYPE_SYSLOG == log_type)
+	if (LOG_TYPE_SYSTEM == log_type)
 	{
 #ifdef _WINDOWS
 		switch (level)
@@ -425,6 +544,7 @@ void	__zbx_zabbix_log(int level, const char *fmt, ...)
 				syslog(LOG_WARNING, "%s", message);
 				break;
 			case LOG_LEVEL_DEBUG:
+			case LOG_LEVEL_TRACE:
 				syslog(LOG_DEBUG, "%s", message);
 				break;
 			case LOG_LEVEL_INFORMATION:
@@ -439,7 +559,7 @@ void	__zbx_zabbix_log(int level, const char *fmt, ...)
 	}	/* LOG_TYPE_SYSLOG */
 	else	/* LOG_TYPE_UNDEFINED == log_type */
 	{
-		zbx_mutex_lock(&log_file_access);
+		lock_log();
 
 		switch (level)
 		{
@@ -455,15 +575,57 @@ void	__zbx_zabbix_log(int level, const char *fmt, ...)
 			case LOG_LEVEL_DEBUG:
 				zbx_error("DEBUG: %s", message);
 				break;
+			case LOG_LEVEL_TRACE:
+				zbx_error("TRACE: %s", message);
+				break;
 			default:
 				zbx_error("%s", message);
 				break;
 		}
 
-		zbx_mutex_unlock(&log_file_access);
+		unlock_log();
 	}
 }
 
+int	zbx_get_log_type(const char *logtype)
+{
+	const char	*logtypes[] = {ZBX_OPTION_LOGTYPE_SYSTEM, ZBX_OPTION_LOGTYPE_FILE, ZBX_OPTION_LOGTYPE_CONSOLE};
+	size_t		i;
+
+	for (i = 0; i < ARRSIZE(logtypes); i++)
+	{
+		if (0 == strcmp(logtype, logtypes[i]))
+			return i + 1;
+	}
+
+	return LOG_TYPE_UNDEFINED;
+}
+
+int	zbx_validate_log_parameters(ZBX_TASK_EX *task)
+{
+	if (LOG_TYPE_UNDEFINED == CONFIG_LOG_TYPE)
+	{
+		zabbix_log(LOG_LEVEL_CRIT, "invalid \"LogType\" configuration parameter: '%s'", CONFIG_LOG_TYPE_STR);
+		return FAIL;
+	}
+
+	if (LOG_TYPE_CONSOLE == CONFIG_LOG_TYPE && 0 == (task->flags & ZBX_TASK_FLAG_FOREGROUND) &&
+			ZBX_TASK_START == task->task)
+	{
+		zabbix_log(LOG_LEVEL_CRIT, "\"LogType\" \"console\" parameter can only be used with the"
+				" -f (--foreground) command line option");
+		return FAIL;
+	}
+
+	if (LOG_TYPE_FILE == CONFIG_LOG_TYPE && (NULL == CONFIG_LOG_FILE || '\0' == *CONFIG_LOG_FILE))
+	{
+		zabbix_log(LOG_LEVEL_CRIT, "\"LogType\" \"file\" parameter requires \"LogFile\" parameter to be set");
+		return FAIL;
+	}
+
+	return SUCCEED;
+}
+
 /******************************************************************************
  *                                                                            *
  * Comments: replace strerror to print also the error number                  *
