@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2015 Zabbix SIA
+** Copyright (C) 2001-2016 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -91,8 +91,8 @@
  *                                                                            *
  ******************************************************************************/
 
-#define LOCK_INFO	if (info->use_lock) zbx_mutex_lock(&info->mem_lock)
-#define UNLOCK_INFO	if (info->use_lock) zbx_mutex_unlock(&info->mem_lock)
+#define LOCK_INFO	if (1 == info->use_lock) zbx_mutex_lock(&info->mem_lock)
+#define UNLOCK_INFO	if (1 == info->use_lock) zbx_mutex_unlock(&info->mem_lock)
 
 static void	*ALIGN4(void *ptr);
 static void	*ALIGN8(void *ptr);
@@ -614,7 +614,7 @@ void	zbx_mem_create(zbx_mem_info_t **info, key_t shm_key, int lock_name, zbx_uin
 	{
 		(*info)->use_lock = 1;
 
-		if (ZBX_MUTEX_ERROR == zbx_mutex_create_force(&((*info)->mem_lock), lock_name))
+		if (FAIL == zbx_mutex_create_force(&((*info)->mem_lock), lock_name))
 		{
 			zabbix_log(LOG_LEVEL_CRIT, "cannot create mutex for %s", descr);
 			exit(EXIT_FAILURE);
@@ -653,7 +653,7 @@ void	zbx_mem_destroy(zbx_mem_info_t *info)
 
 	zabbix_log(LOG_LEVEL_DEBUG, "In %s() descr:'%s'", __function_name, info->mem_descr);
 
-	if (info->use_lock)
+	if (1 == info->use_lock)
 		zbx_mutex_destroy(&info->mem_lock);
 
 	if (-1 == shmctl(info->shm_id, IPC_RMID, 0))
