@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2015 Zabbix SIA
+** Copyright (C) 2001-2016 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -47,8 +47,8 @@ zbx_selfmon_collector_t;
 static zbx_selfmon_collector_t	*collector = NULL;
 static int			shm_id;
 
-#	define	LOCK_SM		zbx_mutex_lock(&sm_lock)
-#	define	UNLOCK_SM	zbx_mutex_unlock(&sm_lock)
+#	define LOCK_SM		zbx_mutex_lock(&sm_lock)
+#	define UNLOCK_SM	zbx_mutex_unlock(&sm_lock)
 
 static ZBX_MUTEX	sm_lock = ZBX_MUTEX_NULL;
 #endif
@@ -238,22 +238,6 @@ int	get_process_type_by_name(const char *proc_type_str)
 	return ZBX_PROCESS_TYPE_UNKNOWN;
 }
 
-const char	*get_daemon_type_string(unsigned char daemon_type)
-{
-	switch (daemon_type)
-	{
-		case ZBX_DAEMON_TYPE_SERVER:
-			return "server";
-		case ZBX_DAEMON_TYPE_PROXY_ACTIVE:
-		case ZBX_DAEMON_TYPE_PROXY_PASSIVE:
-			return "proxy";
-		case ZBX_DAEMON_TYPE_AGENT:
-			return "agent";
-		default:
-			return "unknown";
-	}
-}
-
 #ifndef _WINDOWS
 /******************************************************************************
  *                                                                            *
@@ -292,7 +276,7 @@ void	init_selfmon_collector(void)
 		exit(EXIT_FAILURE);
 	}
 
-	if (ZBX_MUTEX_ERROR == zbx_mutex_create_force(&sm_lock, ZBX_MUTEX_SELFMON))
+	if (FAIL == zbx_mutex_create_force(&sm_lock, ZBX_MUTEX_SELFMON))
 	{
 		zbx_error("unable to create mutex for a self-monitoring collector");
 		exit(EXIT_FAILURE);
@@ -573,8 +557,28 @@ void	zbx_sleep_loop(int sleeptime)
 	update_selfmon_counter(ZBX_PROCESS_STATE_BUSY);
 }
 
+void	zbx_sleep_forever(void)
+{
+	sleep_remains = 1;
+
+	update_selfmon_counter(ZBX_PROCESS_STATE_IDLE);
+
+	do
+	{
+		sleep(1);
+	}
+	while (0 != sleep_remains);
+
+	update_selfmon_counter(ZBX_PROCESS_STATE_BUSY);
+}
+
 void	zbx_wakeup(void)
 {
 	sleep_remains = 0;
 }
+
+int	zbx_sleep_get_remainder(void)
+{
+	return sleep_remains;
+}
 #endif
