@@ -20,12 +20,6 @@
 #ifndef ZABBIX_EVALFUNC_H
 #define ZABBIX_EVALFUNC_H
 
-#include "common.h"
-#include "db.h"
-
-#define ZBX_FLAG_SEC	0
-#define ZBX_FLAG_VALUES	1
-
 int	evaluate_macro_function(char *value, const char *host, const char *key,
 		const char *function, const char *parameter);
 
