@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2015 Zabbix SIA
+** Copyright (C) 2001-2016 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -37,13 +37,6 @@ ZBX_METRIC	parameters_agent[] =
 
 static int	AGENT_HOSTNAME(AGENT_REQUEST *request, AGENT_RESULT *result)
 {
-	if (NULL == CONFIG_HOSTNAME)
-	{
-		SET_MSG_RESULT(result, zbx_strdup(NULL, "Hostname parameter is not supported"
-					" in the zabbix_agent configuration file."));
-		return SYSINFO_RET_FAIL;
-	}
-
 	SET_STR_RESULT(result, zbx_strdup(NULL, CONFIG_HOSTNAME));
 
 	return SYSINFO_RET_OK;
