@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2015 Zabbix SIA
+** Copyright (C) 2001-2016 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -48,6 +48,11 @@ static int	get_fs_size_stat(const char *fs, zbx_uint64_t *total, zbx_uint64_t *f
 		return SYSINFO_RET_FAIL;
 	}
 
+	/* Available space could be negative (top bit set) if we hit disk space */
+	/* reserved for non-privileged users. Treat it as 0.                    */
+	if (0 != ZBX_IS_TOP_BIT_SET(s.f_bavail))
+		s.f_bavail = 0;
+
 	if (NULL != total)
 		*total = (zbx_uint64_t)s.f_blocks * s.ZBX_BSIZE;
 
@@ -60,8 +65,7 @@ static int	get_fs_size_stat(const char *fs, zbx_uint64_t *total, zbx_uint64_t *f
 	if (NULL != pfree)
 	{
 		if (0 != s.f_blocks - s.f_bfree + s.f_bavail)
-			*pfree = (double)(100.0 * s.f_bavail) /
-					(s.f_blocks - s.f_bfree + s.f_bavail);
+			*pfree = (double)(100.0 * s.f_bavail) / (s.f_blocks - s.f_bfree + s.f_bavail);
 		else
 			*pfree = 0;
 	}
@@ -69,8 +73,7 @@ static int	get_fs_size_stat(const char *fs, zbx_uint64_t *total, zbx_uint64_t *f
 	if (NULL != pused)
 	{
 		if (0 != s.f_blocks - s.f_bfree + s.f_bavail)
-			*pused = 100.0 - (double)(100.0 * s.f_bavail) /
-					(s.f_blocks - s.f_bfree + s.f_bavail);
+			*pused = 100.0 - (double)(100.0 * s.f_bavail) / (s.f_blocks - s.f_bfree + s.f_bavail);
 		else
 			*pused = 0;
 	}
@@ -124,7 +127,6 @@ static int	VFS_FS_TOTAL(const char *fs, AGENT_RESULT *result)
 	SET_UI64_RESULT(result, value);
 
 	return SYSINFO_RET_OK;
-
 }
 
 static int	VFS_FS_PFREE(const char *fs, AGENT_RESULT *result)
@@ -159,10 +161,9 @@ static int	VFS_FS_PUSED(const char *fs, AGENT_RESULT *result)
 	return SYSINFO_RET_OK;
 }
 
-int	VFS_FS_SIZE(AGENT_REQUEST *request, AGENT_RESULT *result)
+static int	vfs_fs_size(AGENT_REQUEST *request, AGENT_RESULT *result)
 {
 	char	*fsname, *mode;
-	int	ret = SYSINFO_RET_FAIL;
 
 	if (2 < request->nparam)
 	{
@@ -179,32 +180,34 @@ int	VFS_FS_SIZE(AGENT_REQUEST *request, AGENT_RESULT *result)
 		return SYSINFO_RET_FAIL;
 	}
 
-	if (NULL == mode || '\0' == *mode || 0 == strcmp(mode, "total"))
-		ret = VFS_FS_TOTAL(fsname, result);
-	else if (0 == strcmp(mode, "free"))
-		ret = VFS_FS_FREE(fsname, result);
-	else if (0 == strcmp(mode, "pfree"))
-		ret = VFS_FS_PFREE(fsname, result);
-	else if (0 == strcmp(mode, "used"))
-		ret = VFS_FS_USED(fsname, result);
-	else if (0 == strcmp(mode, "pused"))
-		ret = VFS_FS_PUSED(fsname, result);
-	else
-	{
-		SET_MSG_RESULT(result, zbx_strdup(NULL, "Invalid second parameter."));
-		return SYSINFO_RET_FAIL;
-	}
+	if (NULL == mode || '\0' == *mode || 0 == strcmp(mode, "total"))	/* default parameter */
+		return VFS_FS_TOTAL(fsname, result);
+	if (0 == strcmp(mode, "free"))
+		return VFS_FS_FREE(fsname, result);
+	if (0 == strcmp(mode, "pfree"))
+		return VFS_FS_PFREE(fsname, result);
+	if (0 == strcmp(mode, "used"))
+		return VFS_FS_USED(fsname, result);
+	if (0 == strcmp(mode, "pused"))
+		return VFS_FS_PUSED(fsname, result);
 
-	return ret;
+	SET_MSG_RESULT(result, zbx_strdup(NULL, "Invalid second parameter."));
+
+	return SYSINFO_RET_FAIL;
+}
+
+int	VFS_FS_SIZE(AGENT_REQUEST *request, AGENT_RESULT *result)
+{
+	return zbx_execute_threaded_metric(vfs_fs_size, request, result);
 }
 
 static const char	*zbx_get_vfs_name_by_type(int type)
 {
 	extern struct vfs_ent	*getvfsbytype(int type);
 
-	struct vfs_ent	*vfs;
-	static char	**vfs_names = NULL;
-	static size_t	vfs_names_alloc = 0;
+	struct vfs_ent		*vfs;
+	static char		**vfs_names = NULL;
+	static size_t		vfs_names_alloc = 0;
 
 	if (type + 1 > vfs_names_alloc)
 	{
