@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2018 Zabbix SIA
+** Copyright (C) 2001-2016 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -19,7 +19,6 @@
 
 #include "common.h"
 #include "sysinfo.h"
-#include "log.h"
 
 #ifdef _WINDOWS
 #	include "perfmon.h"
@@ -29,19 +28,15 @@
 int	SYSTEM_LOCALTIME(AGENT_REQUEST *request, AGENT_RESULT *result)
 {
 	char		*type, buf[32];
-	struct tm	*tm;
-	size_t		offset;
-	int		gmtoff, ms;
-	unsigned short	h, m;
-#ifdef _WINDOWS
-        struct _timeb	tv;
-#else
-	struct timeval	tv;
-	struct timezone	tz;
-#endif
+	long		milliseconds;
+	struct tm	tm;
+	zbx_timezone_t	tz;
 
 	if (1 < request->nparam)
+	{
+		SET_MSG_RESULT(result, zbx_strdup(NULL, "Too many parameters."));
 		return SYSINFO_RET_FAIL;
+	}
 
 	type = get_rparam(request, 0);
 
@@ -51,43 +46,20 @@ int	SYSTEM_LOCALTIME(AGENT_REQUEST *request, AGENT_RESULT *result)
 	}
 	else if (0 == strcmp(type, "local"))
 	{
-#ifdef _WINDOWS
-	        _ftime(&tv);
-		tm = localtime(&tv.time);
-		ms = tv.millitm;
-#else
-		gettimeofday(&tv, &tz);
-		tm = localtime(&tv.tv_sec);
-		ms = (int)(tv.tv_usec / 1000);
-#endif
-		offset = zbx_snprintf(buf, sizeof(buf), "%04d-%02d-%02d,%02d:%02d:%02d.%03d,",
-				1900 + tm->tm_year, 1 + tm->tm_mon, tm->tm_mday,
-				tm->tm_hour, tm->tm_min, tm->tm_sec, ms);
+		zbx_get_time(&tm, &milliseconds, &tz);
 
-		/* timezone offset */
-#if defined(HAVE_TM_TM_GMTOFF)
-		gmtoff = tm->tm_gmtoff;
-#else
-		gmtoff = -timezone;
-#endif
-#ifdef _WINDOWS
-		if (0 < tm->tm_isdst)		/* daylight saving time */
-			gmtoff += SEC_PER_HOUR;	/* assume DST is one hour */
-#endif
-		h = (unsigned short)(abs(gmtoff) / SEC_PER_HOUR);
-		m = (unsigned short)((abs(gmtoff) - h * SEC_PER_HOUR) / SEC_PER_MIN);
-
-		if (0 <= gmtoff)
-			offset += zbx_snprintf(buf + offset, sizeof(buf) - offset, "+");
-		else
-			offset += zbx_snprintf(buf + offset, sizeof(buf) - offset, "-");
-
-		offset += zbx_snprintf(buf + offset, sizeof(buf) - offset, "%02d:%02d", (int)h, (int)m);
+		zbx_snprintf(buf, sizeof(buf), "%04d-%02d-%02d,%02d:%02d:%02d.%03ld,%01c%02d:%02d",
+				1900 + tm.tm_year, 1 + tm.tm_mon, tm.tm_mday,
+				tm.tm_hour, tm.tm_min, tm.tm_sec, milliseconds,
+				tz.tz_sign, tz.tz_hour, tz.tz_min);
 
 		SET_STR_RESULT(result, strdup(buf));
 	}
 	else
+	{
+		SET_MSG_RESULT(result, zbx_strdup(NULL, "Invalid first parameter."));
 		return SYSINFO_RET_FAIL;
+	}
 
 	return SYSINFO_RET_OK;
 }
