@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2018 Zabbix SIA
+** Copyright (C) 2001-2016 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -20,9 +20,10 @@
 #include "common.h"
 #include "sysinfo.h"
 #include "zbxjson.h"
+#include "log.h"
 
 static int	get_fs_size_stat(const char *fs, zbx_uint64_t *total, zbx_uint64_t *free,
-		zbx_uint64_t *used, double *pfree, double *pused)
+		zbx_uint64_t *used, double *pfree, double *pused, char **error)
 {
 #ifdef HAVE_SYS_STATVFS_H
 #	define ZBX_STATFS	statvfs
@@ -33,30 +34,38 @@ static int	get_fs_size_stat(const char *fs, zbx_uint64_t *total, zbx_uint64_t *f
 #endif
 	struct ZBX_STATFS	s;
 
-	assert(fs);
-
 	if (0 != ZBX_STATFS(fs, &s))
+	{
+		*error = zbx_dsprintf(NULL, "Cannot obtain filesystem information: %s", zbx_strerror(errno));
 		return SYSINFO_RET_FAIL;
+	}
 
-	if (total)
+	/* Available space could be negative (top bit set) if we hit disk space */
+	/* reserved for non-privileged users. Treat it as 0.                    */
+	if (0 != ZBX_IS_TOP_BIT_SET(s.f_bavail))
+		s.f_bavail = 0;
+
+	if (NULL != total)
 		*total = (zbx_uint64_t)s.f_blocks * s.ZBX_BSIZE;
-	if (free)
+
+	if (NULL != free)
 		*free = (zbx_uint64_t)s.f_bavail * s.ZBX_BSIZE;
-	if (used)
+
+	if (NULL != used)
 		*used = (zbx_uint64_t)(s.f_blocks - s.f_bfree) * s.ZBX_BSIZE;
-	if (pfree)
+
+	if (NULL != pfree)
 	{
 		if (0 != s.f_blocks - s.f_bfree + s.f_bavail)
-			*pfree = (double)(100.0 * s.f_bavail) /
-					(s.f_blocks - s.f_bfree + s.f_bavail);
+			*pfree = (double)(100.0 * s.f_bavail) / (s.f_blocks - s.f_bfree + s.f_bavail);
 		else
 			*pfree = 0;
 	}
-	if (pused)
+
+	if (NULL != pused)
 	{
 		if (0 != s.f_blocks - s.f_bfree + s.f_bavail)
-			*pused = 100.0 - (double)(100.0 * s.f_bavail) /
-					(s.f_blocks - s.f_bfree + s.f_bavail);
+			*pused = 100.0 - (double)(100.0 * s.f_bavail) / (s.f_blocks - s.f_bfree + s.f_bavail);
 		else
 			*pused = 0;
 	}
@@ -66,10 +75,14 @@ static int	get_fs_size_stat(const char *fs, zbx_uint64_t *total, zbx_uint64_t *f
 
 static int	VFS_FS_USED(const char *fs, AGENT_RESULT *result)
 {
-	zbx_uint64_t	value = 0;
+	zbx_uint64_t	value;
+	char		*error;
 
-	if (SYSINFO_RET_OK != get_fs_size_stat(fs, NULL, NULL, &value, NULL, NULL))
+	if (SYSINFO_RET_OK != get_fs_size_stat(fs, NULL, NULL, &value, NULL, NULL, &error))
+	{
+		SET_MSG_RESULT(result, error);
 		return SYSINFO_RET_FAIL;
+	}
 
 	SET_UI64_RESULT(result, value);
 
@@ -78,10 +91,14 @@ static int	VFS_FS_USED(const char *fs, AGENT_RESULT *result)
 
 static int	VFS_FS_FREE(const char *fs, AGENT_RESULT *result)
 {
-	zbx_uint64_t	value = 0;
+	zbx_uint64_t	value;
+	char		*error;
 
-	if (SYSINFO_RET_OK != get_fs_size_stat(fs, NULL, &value, NULL, NULL, NULL))
+	if (SYSINFO_RET_OK != get_fs_size_stat(fs, NULL, &value, NULL, NULL, NULL, &error))
+	{
+		SET_MSG_RESULT(result, error);
 		return SYSINFO_RET_FAIL;
+	}
 
 	SET_UI64_RESULT(result, value);
 
@@ -90,23 +107,30 @@ static int	VFS_FS_FREE(const char *fs, AGENT_RESULT *result)
 
 static int	VFS_FS_TOTAL(const char *fs, AGENT_RESULT *result)
 {
-	zbx_uint64_t	value = 0;
+	zbx_uint64_t	value;
+	char		*error;
 
-	if (SYSINFO_RET_OK != get_fs_size_stat(fs, &value, NULL, NULL, NULL, NULL))
+	if (SYSINFO_RET_OK != get_fs_size_stat(fs, &value, NULL, NULL, NULL, NULL, &error))
+	{
+		SET_MSG_RESULT(result, error);
 		return SYSINFO_RET_FAIL;
+	}
 
 	SET_UI64_RESULT(result, value);
 
 	return SYSINFO_RET_OK;
-
 }
 
 static int	VFS_FS_PFREE(const char *fs, AGENT_RESULT *result)
 {
-	double	value = 0;
+	double	value;
+	char	*error;
 
-	if (SYSINFO_RET_OK != get_fs_size_stat(fs, NULL, NULL, NULL, &value, NULL))
+	if (SYSINFO_RET_OK != get_fs_size_stat(fs, NULL, NULL, NULL, &value, NULL, &error))
+	{
+		SET_MSG_RESULT(result, error);
 		return SYSINFO_RET_FAIL;
+	}
 
 	SET_DBL_RESULT(result, value);
 
@@ -115,10 +139,14 @@ static int	VFS_FS_PFREE(const char *fs, AGENT_RESULT *result)
 
 static int	VFS_FS_PUSED(const char *fs, AGENT_RESULT *result)
 {
-	double	value = 0;
+	double	value;
+	char	*error;
 
-	if (SYSINFO_RET_OK != get_fs_size_stat(fs, NULL, NULL, NULL, NULL, &value))
+	if (SYSINFO_RET_OK != get_fs_size_stat(fs, NULL, NULL, NULL, NULL, &value, &error))
+	{
+		SET_MSG_RESULT(result, error);
 		return SYSINFO_RET_FAIL;
+	}
 
 	SET_DBL_RESULT(result, value);
 
@@ -128,31 +156,36 @@ static int	VFS_FS_PUSED(const char *fs, AGENT_RESULT *result)
 static int	vfs_fs_size(AGENT_REQUEST *request, AGENT_RESULT *result)
 {
 	char	*fsname, *mode;
-	int	ret = SYSINFO_RET_FAIL;
 
 	if (2 < request->nparam)
+	{
+		SET_MSG_RESULT(result, zbx_strdup(NULL, "Too many parameters."));
 		return SYSINFO_RET_FAIL;
+	}
 
 	fsname = get_rparam(request, 0);
 	mode = get_rparam(request, 1);
 
 	if (NULL == fsname || '\0' == *fsname)
+	{
+		SET_MSG_RESULT(result, zbx_strdup(NULL, "Invalid first parameter."));
 		return SYSINFO_RET_FAIL;
+	}
 
-	if (NULL == mode || '\0' == *mode || 0 == strcmp(mode, "total"))
-		ret = VFS_FS_TOTAL(fsname, result);
-	else if (0 == strcmp(mode, "free"))
-		ret = VFS_FS_FREE(fsname, result);
-	else if (0 == strcmp(mode, "pfree"))
-		ret = VFS_FS_PFREE(fsname, result);
-	else if (0 == strcmp(mode, "used"))
-		ret = VFS_FS_USED(fsname, result);
-	else if (0 == strcmp(mode, "pused"))
-		ret = VFS_FS_PUSED(fsname, result);
-	else
-		ret = SYSINFO_RET_FAIL;
+	if (NULL == mode || '\0' == *mode || 0 == strcmp(mode, "total"))	/* default parameter */
+		return VFS_FS_TOTAL(fsname, result);
+	if (0 == strcmp(mode, "free"))
+		return VFS_FS_FREE(fsname, result);
+	if (0 == strcmp(mode, "pfree"))
+		return VFS_FS_PFREE(fsname, result);
+	if (0 == strcmp(mode, "used"))
+		return VFS_FS_USED(fsname, result);
+	if (0 == strcmp(mode, "pused"))
+		return VFS_FS_PUSED(fsname, result);
 
-	return ret;
+	SET_MSG_RESULT(result, zbx_strdup(NULL, "Invalid second parameter."));
+
+	return SYSINFO_RET_FAIL;
 }
 
 int	VFS_FS_SIZE(AGENT_REQUEST *request, AGENT_RESULT *result)
@@ -162,37 +195,37 @@ int	VFS_FS_SIZE(AGENT_REQUEST *request, AGENT_RESULT *result)
 
 int	VFS_FS_DISCOVERY(AGENT_REQUEST *request, AGENT_RESULT *result)
 {
-	int		ret = SYSINFO_RET_FAIL;
 	struct mntent	*mt;
 	FILE		*f;
 	struct zbx_json	j;
 
+	/* opening the mounted filesystems file */
+	if (NULL == (f = setmntent(MNT_MNTTAB, "r")))
+	{
+		SET_MSG_RESULT(result, zbx_dsprintf(NULL, "Cannot obtain system information: %s", zbx_strerror(errno)));
+		return SYSINFO_RET_FAIL;
+	}
+
 	zbx_json_init(&j, ZBX_JSON_STAT_BUF_LEN);
 
 	zbx_json_addarray(&j, ZBX_PROTO_TAG_DATA);
 
-	/* opening the mounted filesystems file */
-	if (NULL != (f = setmntent(MNT_MNTTAB, "r")))
+	/* fill mnttab structure from file */
+	while (NULL != (mt = getmntent(f)))
 	{
-		/* fill mnttab structure from file */
-		while (NULL != (mt = getmntent(f)))
-		{
-			zbx_json_addobject(&j, NULL);
-			zbx_json_addstring(&j, "{#FSNAME}", mt->mnt_dir, ZBX_JSON_TYPE_STRING);
-			zbx_json_addstring(&j, "{#FSTYPE}", mt->mnt_type, ZBX_JSON_TYPE_STRING);
-			zbx_json_close(&j);
-		}
-
-		endmntent(f);
-
-		ret = SYSINFO_RET_OK;
+		zbx_json_addobject(&j, NULL);
+		zbx_json_addstring(&j, "{#FSNAME}", mt->mnt_dir, ZBX_JSON_TYPE_STRING);
+		zbx_json_addstring(&j, "{#FSTYPE}", mt->mnt_type, ZBX_JSON_TYPE_STRING);
+		zbx_json_close(&j);
 	}
 
+	endmntent(f);
+
 	zbx_json_close(&j);
 
 	SET_STR_RESULT(result, zbx_strdup(NULL, j.buffer));
 
 	zbx_json_free(&j);
 
-	return ret;
+	return SYSINFO_RET_OK;
 }
