@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2015 Zabbix SIA
+** Copyright (C) 2001-2016 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
 #include "sysinfo.h"
 #include "zbxregexp.h"
 
-#if defined(KERNEL_2_4)
+#ifdef KERNEL_2_4
 #define DEVICE_DIR	"/proc/sys/dev/sensors"
 #else
 #define DEVICE_DIR	"/sys/class/hwmon"
@@ -46,7 +46,7 @@ static void	count_sensor(int do_task, const char *filename, double *aggr, int *c
 
 	zbx_fclose(f);
 
-#if defined(KERNEL_2_4)
+#ifdef KERNEL_2_4
 	if (1 == sscanf(line, "%*f\t%*f\t%lf\n", &value))
 	{
 #else
@@ -75,6 +75,7 @@ static void	count_sensor(int do_task, const char *filename, double *aggr, int *c
 	}
 }
 
+#ifndef KERNEL_2_4
 /*********************************************************************************
  *                                                                               *
  * Function: sysfs_read_attr                                                     *
@@ -251,12 +252,13 @@ out:
 
 	return ret;
 }
+#endif
 
 static void	get_device_sensors(int do_task, const char *device, const char *name, double *aggr, int *cnt)
 {
 	char	sensorname[MAX_STRING_LEN];
 
-#if defined(KERNEL_2_4)
+#ifdef KERNEL_2_4
 	if (ZBX_DO_ONE == do_task)
 	{
 		zbx_snprintf(sensorname, sizeof(sensorname), "%s/%s/%s", DEVICE_DIR, device, name);
@@ -355,7 +357,7 @@ static void	get_device_sensors(int do_task, const char *device, const char *name
 				zbx_snprintf(regex, sizeof(regex), "%s[0-9]*_input", name);
 
 				if (NULL == (sensordir = opendir(devicepath)))
-					return;
+					goto out;
 
 				while (NULL != (sensorent = readdir(sensordir)))
 				{
@@ -374,6 +376,7 @@ static void	get_device_sensors(int do_task, const char *device, const char *name
 			}
 		}
 	}
+out:
 	closedir(devicedir);
 #endif
 }
