@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2000-2011 Zabbix SIA
+** Copyright (C) 2001-2016 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -9,7 +9,7 @@
 **
 ** This program is distributed in the hope that it will be useful,
 ** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 ** GNU General Public License for more details.
 **
 ** You should have received a copy of the GNU General Public License
@@ -20,30 +20,18 @@
 #include "common.h"
 #include "sysinfo.h"
 
-int	SYSTEM_UPTIME(const char *cmd, const char *param, unsigned flags, AGENT_RESULT *result)
+int	SYSTEM_UPTIME(AGENT_REQUEST *request, AGENT_RESULT *result)
 {
-	kstat_ctl_t	*kc;
-	kstat_t		*kp;
-	kstat_named_t	*kn;
-	time_t		now;
-	int		ret = SYSINFO_RET_FAIL;
-
-	if (NULL == (kc = kstat_open()))
-		return ret;
-
-	if (NULL != (kp = kstat_lookup(kc, "unix", 0, "system_misc")))
+	if (SYSINFO_RET_OK == SYSTEM_BOOTTIME(request, result))
 	{
-		if (-1 != kstat_read(kc, kp, 0))
-		{
-			if (NULL != (kn = (kstat_named_t*)kstat_data_lookup(kp, "boot_time")))
-			{
-				time(&now);
-				SET_UI64_RESULT(result, difftime(now, (time_t) kn->value.ul));
-				ret = SYSINFO_RET_OK;
-			}
-		}
-	}
-	kstat_close(kc);
+		time_t	now;
 
-	return ret;
+		time(&now);
+
+		result->ui64 = now - result->ui64;
+
+		return SYSINFO_RET_OK;
+	}
+
+	return SYSINFO_RET_FAIL;
 }
