@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2015 Zabbix SIA
+** Copyright (C) 2001-2016 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 #include "sysinfo.h"
 #include "zbxjson.h"
 
-int	VFS_FS_SIZE(AGENT_REQUEST *request, AGENT_RESULT *result)
+static int	vfs_fs_size(AGENT_REQUEST *request, AGENT_RESULT *result)
 {
 	char		*path, *mode;
 	wchar_t 	*wpath;
@@ -71,6 +71,35 @@ int	VFS_FS_SIZE(AGENT_REQUEST *request, AGENT_RESULT *result)
 	return SYSINFO_RET_OK;
 }
 
+int	VFS_FS_SIZE(AGENT_REQUEST *request, AGENT_RESULT *result)
+{
+	return zbx_execute_threaded_metric(vfs_fs_size, request, result);
+}
+
+static const char	*get_drive_type_string(UINT type)
+{
+	switch (type)
+	{
+		case DRIVE_UNKNOWN:
+			return "unknown";
+		case DRIVE_NO_ROOT_DIR:
+			return "norootdir";
+		case DRIVE_REMOVABLE:
+			return "removable";
+		case DRIVE_FIXED:
+			return "fixed";
+		case DRIVE_REMOTE:
+			return "remote";
+		case DRIVE_CDROM:
+			return "cdrom";
+		case DRIVE_RAMDISK:
+			return "ramdisk";
+		default:
+			THIS_SHOULD_NEVER_HAPPEN;
+			return "unknown";
+	}
+}
+
 int	VFS_FS_DISCOVERY(AGENT_REQUEST *request, AGENT_RESULT *result)
 {
 	wchar_t		fsName[MAX_PATH + 1];
@@ -125,6 +154,8 @@ int	VFS_FS_DISCOVERY(AGENT_REQUEST *request, AGENT_RESULT *result)
 		else
 			zbx_json_addstring(&j, "{#FSTYPE}", "UNKNOWN", ZBX_JSON_TYPE_STRING);
 
+		zbx_json_addstring(&j, "{#FSDRIVETYPE}", get_drive_type_string(GetDriveType(p)), ZBX_JSON_TYPE_STRING);
+
 		zbx_json_close(&j);
 	}
 
