@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2015 Zabbix SIA
+** Copyright (C) 2001-2016 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -75,14 +75,12 @@ lbl_err:
 
 int	PROC_NUM(AGENT_REQUEST *request, AGENT_RESULT *result)
 {
-	HANDLE	hProcessSnap, hProcess;
-	PROCESSENTRY32	pe32;
-	int	proccount,
-		proc_ok;
-	char	*procName,
-		*userName,
-		baseName[MAX_PATH],
-		uname[MAX_NAME];
+	HANDLE			hProcessSnap, hProcess;
+	PROCESSENTRY32		pe32;
+	DWORD			access;
+	const OSVERSIONINFOEX	*vi;
+	int			proccount, proc_ok;
+	char			*procName, *userName, baseName[MAX_PATH], uname[MAX_NAME];
 
 	if (2 < request->nparam)
 	{
@@ -99,6 +97,20 @@ int	PROC_NUM(AGENT_REQUEST *request, AGENT_RESULT *result)
 		return SYSINFO_RET_FAIL;
 	}
 
+	if (NULL == (vi = zbx_win_getversion()))
+	{
+		SET_MSG_RESULT(result, zbx_strdup(NULL, "Cannot retrieve system version."));
+		return SYSINFO_RET_FAIL;
+	}
+
+	if (6 > vi->dwMajorVersion)
+	{
+		/* PROCESS_QUERY_LIMITED_INFORMATION is not supported on Windows Server 2003 and XP */
+		access = PROCESS_QUERY_INFORMATION;
+	}
+	else
+		access = PROCESS_QUERY_LIMITED_INFORMATION;
+
 	pe32.dwSize = sizeof(PROCESSENTRY32);
 
 	if (FALSE == Process32First(hProcessSnap, &pe32))
@@ -124,7 +136,7 @@ int	PROC_NUM(AGENT_REQUEST *request, AGENT_RESULT *result)
 
 		if (0 != proc_ok && NULL != userName && '\0' != *userName)
 		{
-			hProcess = OpenProcess(PROCESS_QUERY_INFORMATION, FALSE, pe32.th32ProcessID);
+			hProcess = OpenProcess(access, FALSE, pe32.th32ProcessID);
 
 			if (NULL == hProcess || SUCCEED != zbx_get_process_username(hProcess, uname) ||
 					0 != stricmp(uname, userName))
@@ -156,124 +168,118 @@ int	PROC_NUM(AGENT_REQUEST *request, AGENT_RESULT *result)
 
 static double ConvertProcessTime(FILETIME *lpft)
 {
-   __int64 i;
-
-   memcpy(&i,lpft,sizeof(__int64));
-   i/=10000;      /* Convert 100-nanosecond units to milliseconds */
-   return (double)i;
+	/* Convert 100-nanosecond units to milliseconds */
+	return (double)((((__int64)lpft->dwHighDateTime << 32) | lpft->dwLowDateTime) / 10000);
 }
 
 /*
  * Get specific process attribute
  */
 
-static int	GetProcessAttribute(HANDLE hProcess,int attr,int type,int count,double *lastValue)
+static int	GetProcessAttribute(HANDLE hProcess, int attr, int type, int count, double *lastValue)
 {
-   double value;
-   PROCESS_MEMORY_COUNTERS mc;
-   IO_COUNTERS ioCounters;
-   FILETIME ftCreate,ftExit,ftKernel,ftUser;
+	double			value;
+	PROCESS_MEMORY_COUNTERS	mc;
+	IO_COUNTERS		ioCounters;
+	FILETIME		ftCreate, ftExit, ftKernel, ftUser;
 
-   /* Get value for current process instance */
-   switch(attr)
-   {
-      case 0:        /* vmsize */
-         GetProcessMemoryInfo(hProcess,&mc,sizeof(PROCESS_MEMORY_COUNTERS));
-         value=(double)mc.PagefileUsage/1024;   /* Convert to Kbytes */
-         break;
-      case 1:        /* wkset */
-         GetProcessMemoryInfo(hProcess,&mc,sizeof(PROCESS_MEMORY_COUNTERS));
-         value=(double)mc.WorkingSetSize/1024;   /* Convert to Kbytes */
-         break;
-      case 2:        /* pf */
-         GetProcessMemoryInfo(hProcess,&mc,sizeof(PROCESS_MEMORY_COUNTERS));
-         value=(double)mc.PageFaultCount;
-         break;
-      case 3:        /* ktime */
-      case 4:        /* utime */
-         GetProcessTimes(hProcess,&ftCreate,&ftExit,&ftKernel,&ftUser);
-         value = ConvertProcessTime(attr==3 ? &ftKernel : &ftUser);
-         break;
+	/* Get value for current process instance */
+	switch (attr)
+	{
+		case 0:        /* vmsize */
+			GetProcessMemoryInfo(hProcess, &mc, sizeof(PROCESS_MEMORY_COUNTERS));
+			value = (double)mc.PagefileUsage / 1024;   /* Convert to Kbytes */
+			break;
+		case 1:        /* wkset */
+			GetProcessMemoryInfo(hProcess, &mc, sizeof(PROCESS_MEMORY_COUNTERS));
+			value = (double)mc.WorkingSetSize / 1024;   /* Convert to Kbytes */
+			break;
+		case 2:        /* pf */
+			GetProcessMemoryInfo(hProcess, &mc, sizeof(PROCESS_MEMORY_COUNTERS));
+			value = (double)mc.PageFaultCount;
+			break;
+		case 3:        /* ktime */
+		case 4:        /* utime */
+			GetProcessTimes(hProcess, &ftCreate, &ftExit, &ftKernel, &ftUser);
+			value = ConvertProcessTime(3 == attr ? &ftKernel : &ftUser);
+			break;
+		case 5:        /* gdiobj */
+		case 6:        /* userobj */
+			if (NULL == zbx_GetGuiResources)
+				return SYSINFO_RET_FAIL;
 
-      case 5:        /* gdiobj */
-      case 6:        /* userobj */
-         if(NULL == zbx_GetGuiResources)
-	     return SYSINFO_RET_FAIL;
+			value = (double)zbx_GetGuiResources(hProcess, 5 == attr ? 0 : 1);
+			break;
+		case 7:        /* io_read_b */
+			if (NULL == zbx_GetProcessIoCounters)
+				return SYSINFO_RET_FAIL;
 
-         value = (double)zbx_GetGuiResources(hProcess,attr==5 ? 0 : 1);
-         break;
+			zbx_GetProcessIoCounters(hProcess, &ioCounters);
+			value = (double)((__int64)ioCounters.ReadTransferCount);
+			break;
+		case 8:        /* io_read_op */
+			if (NULL == zbx_GetProcessIoCounters)
+				return SYSINFO_RET_FAIL;
 
-      case 7:        /* io_read_b */
-         if(NULL == zbx_GetProcessIoCounters)
-	     return SYSINFO_RET_FAIL;
+			zbx_GetProcessIoCounters(hProcess, &ioCounters);
+			value = (double)((__int64)ioCounters.ReadOperationCount);
+			break;
+		case 9:        /* io_write_b */
+			if (NULL == zbx_GetProcessIoCounters)
+				return SYSINFO_RET_FAIL;
 
-         zbx_GetProcessIoCounters(hProcess,&ioCounters);
-         value=(double)((__int64)ioCounters.ReadTransferCount);
-         break;
-      case 8:        /* io_read_op */
-         if(NULL == zbx_GetProcessIoCounters)
-	     return SYSINFO_RET_FAIL;
+			zbx_GetProcessIoCounters(hProcess, &ioCounters);
+			value = (double)((__int64)ioCounters.WriteTransferCount);
+			break;
+		case 10:       /* io_write_op */
+			if (NULL == zbx_GetProcessIoCounters)
+				return SYSINFO_RET_FAIL;
 
-         zbx_GetProcessIoCounters(hProcess,&ioCounters);
-         value=(double)((__int64)ioCounters.ReadOperationCount);
-         break;
-      case 9:        /* io_write_b */
-         if(NULL == zbx_GetProcessIoCounters)
-	     return SYSINFO_RET_FAIL;
+			zbx_GetProcessIoCounters(hProcess, &ioCounters);
+			value = (double)((__int64)ioCounters.WriteOperationCount);
+			break;
+		case 11:       /* io_other_b */
+			if (NULL == zbx_GetProcessIoCounters)
+				return SYSINFO_RET_FAIL;
 
-         zbx_GetProcessIoCounters(hProcess,&ioCounters);
-         value=(double)((__int64)ioCounters.WriteTransferCount);
-         break;
-      case 10:       /* io_write_op */
-         if(NULL == zbx_GetProcessIoCounters)
-	     return SYSINFO_RET_FAIL;
+			zbx_GetProcessIoCounters(hProcess, &ioCounters);
+			value = (double)((__int64)ioCounters.OtherTransferCount);
+			break;
+		case 12:       /* io_other_op */
+			if (NULL == zbx_GetProcessIoCounters)
+				return SYSINFO_RET_FAIL;
 
-         zbx_GetProcessIoCounters(hProcess,&ioCounters);
-         value=(double)((__int64)ioCounters.WriteOperationCount);
-         break;
-      case 11:       /* io_other_b */
-         if(NULL == zbx_GetProcessIoCounters)
-	     return SYSINFO_RET_FAIL;
-
-         zbx_GetProcessIoCounters(hProcess,&ioCounters);
-         value=(double)((__int64)ioCounters.OtherTransferCount);
-         break;
-      case 12:       /* io_other_op */
-         if(NULL == zbx_GetProcessIoCounters)
-	     return SYSINFO_RET_FAIL;
-
-         zbx_GetProcessIoCounters(hProcess,&ioCounters);
-         value=(double)((__int64)ioCounters.OtherOperationCount);
-         break;
-
-      default:       /* Unknown attribute */
-         return SYSINFO_RET_FAIL;
-   }
+			zbx_GetProcessIoCounters(hProcess, &ioCounters);
+			value = (double)((__int64)ioCounters.OtherOperationCount);
+			break;
+		default:       /* Unknown attribute */
+			return SYSINFO_RET_FAIL;
+	}
 
 	/* Recalculate final value according to selected type */
-	switch (type) {
-	case 0:	/* min */
-		if (count == 0 || value < *lastValue)
-			*lastValue = value;
-		break;
-	case 1:	/* max */
-		if (count == 0 || value > *lastValue)
-			*lastValue = value;
-		break;
-	case 2:	/* avg */
-		*lastValue = (*lastValue * count + value) / (count + 1);
-		break;
-	case 3:	/* sum */
-		*lastValue += value;
-		break;
-	default:
-		return SYSINFO_RET_FAIL;
+	switch (type)
+	{
+		case 0:	/* min */
+			if (0 == count || value < *lastValue)
+				*lastValue = value;
+			break;
+		case 1:	/* max */
+			if (0 == count || value > *lastValue)
+				*lastValue = value;
+			break;
+		case 2:	/* avg */
+			*lastValue = (*lastValue * count + value) / (count + 1);
+			break;
+		case 3:	/* sum */
+			*lastValue += value;
+			break;
+		default:
+			return SYSINFO_RET_FAIL;
 	}
 
 	return SYSINFO_RET_OK;
 }
 
-
 /*
  * Get process-specific information
  * Parameter has the following syntax:
@@ -288,20 +294,19 @@ static int	GetProcessAttribute(HANDLE hProcess,int attr,int type,int count,doubl
  *         avg - average value for all processes named <process>
  *         sum - sum of values for all processes named <process>
  */
-
-
 int	PROC_INFO(AGENT_REQUEST *request, AGENT_RESULT *result)
 {
-	HANDLE		hProcessSnap, hProcess;
-	PROCESSENTRY32	pe32;
-	char		*proc_name, *attr, *type, baseName[MAX_PATH];
-	const char	*attrList[] = {"vmsize", "wkset", "pf", "ktime", "utime", "gdiobj", "userobj", "io_read_b", "io_read_op",
-					"io_write_b", "io_write_op", "io_other_b", "io_other_op", NULL},
-			*typeList[] = {"min", "max", "avg", "sum", NULL};
-	double		value;
-	DWORD		access;
+	HANDLE			hProcessSnap, hProcess;
+	PROCESSENTRY32		pe32;
+	char			*proc_name, *attr, *type, baseName[MAX_PATH];
+	const char		*attrList[] = {"vmsize", "wkset", "pf", "ktime", "utime", "gdiobj", "userobj",
+						"io_read_b", "io_read_op", "io_write_b", "io_write_op", "io_other_b",
+						"io_other_op", NULL},
+				*typeList[] = {"min", "max", "avg", "sum", NULL};
+	double			value;
+	DWORD			access;
 	const OSVERSIONINFOEX	*vi;
-	int		counter, attr_id, type_id, ret = SYSINFO_RET_OK;
+	int			counter, attr_id, type_id, ret = SYSINFO_RET_OK;
 
 	if (3 < request->nparam)
 	{
