@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2015 Zabbix SIA
+** Copyright (C) 2001-2016 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -28,8 +28,9 @@
 #include "sysinfo.h"
 #include "log.h"
 
-extern unsigned char	process_type, daemon_type;
-extern int		server_num, process_num;
+extern unsigned char			program_type;
+extern ZBX_THREAD_LOCAL unsigned char	process_type;
+extern ZBX_THREAD_LOCAL int		server_num, process_num;
 
 #if defined(ZABBIX_SERVICE)
 #	include "service.h"
@@ -37,7 +38,10 @@ extern int		server_num, process_num;
 #	include "daemon.h"
 #endif
 
-static void	process_listener(zbx_sock_t *s)
+#include "../libs/zbxcrypto/tls.h"
+#include "../libs/zbxcrypto/tls_tcp_active.h"
+
+static void	process_listener(zbx_socket_t *s)
 {
 	AGENT_RESULT	result;
 	char		**value = NULL;
@@ -69,6 +73,8 @@ static void	process_listener(zbx_sock_t *s)
 				static size_t	buffer_alloc = 256;
 				size_t		buffer_offset = 0;
 
+				zabbix_log(LOG_LEVEL_DEBUG, "Sending back [" ZBX_NOTSUPPORTED ": %s]", *value);
+
 				if (NULL == buffer)
 					buffer = zbx_malloc(buffer, buffer_alloc);
 
@@ -80,20 +86,27 @@ static void	process_listener(zbx_sock_t *s)
 				ret = zbx_tcp_send_bytes_to(s, buffer, buffer_offset, CONFIG_TIMEOUT);
 			}
 			else
+			{
+				zabbix_log(LOG_LEVEL_DEBUG, "Sending back [" ZBX_NOTSUPPORTED "]");
+
 				ret = zbx_tcp_send_to(s, ZBX_NOTSUPPORTED, CONFIG_TIMEOUT);
+			}
 		}
 
 		free_result(&result);
 	}
 
 	if (FAIL == ret)
-		zabbix_log(LOG_LEVEL_DEBUG, "Process listener error: %s", zbx_tcp_strerror());
+		zabbix_log(LOG_LEVEL_DEBUG, "Process listener error: %s", zbx_socket_strerror());
 }
 
 ZBX_THREAD_ENTRY(listener_thread, args)
 {
-	int		ret, local_request_failed = 0;
-	zbx_sock_t	s;
+#if defined(HAVE_POLARSSL) || defined(HAVE_GNUTLS) || defined(HAVE_OPENSSL)
+	char		*msg = NULL;
+#endif
+	int		ret;
+	zbx_socket_t	s;
 
 	assert(args);
 	assert(((zbx_thread_args_t *)args)->args);
@@ -102,38 +115,54 @@ ZBX_THREAD_ENTRY(listener_thread, args)
 	server_num = ((zbx_thread_args_t *)args)->server_num;
 	process_num = ((zbx_thread_args_t *)args)->process_num;
 
-	zabbix_log(LOG_LEVEL_INFORMATION, "%s #%d started [%s #%d]", get_daemon_type_string(daemon_type),
+	zabbix_log(LOG_LEVEL_INFORMATION, "%s #%d started [%s #%d]", get_program_type_string(program_type),
 			server_num, get_process_type_string(process_type), process_num);
 
-	memcpy(&s, (zbx_sock_t *)((zbx_thread_args_t *)args)->args, sizeof(zbx_sock_t));
+	memcpy(&s, (zbx_socket_t *)((zbx_thread_args_t *)args)->args, sizeof(zbx_socket_t));
 
 	zbx_free(args);
 
+#if defined(HAVE_POLARSSL) || defined(HAVE_GNUTLS) || defined(HAVE_OPENSSL)
+	zbx_tls_init_child();
+#endif
 	while (ZBX_IS_RUNNING())
 	{
+		zbx_handle_log();
+
 		zbx_setproctitle("listener #%d [waiting for connection]", process_num);
 
-		if (SUCCEED == (ret = zbx_tcp_accept(&s)))
+		if (SUCCEED == (ret = zbx_tcp_accept(&s, configured_tls_accept_modes)))
 		{
-			local_request_failed = 0;     /* reset consecutive errors counter */
-
 			zbx_setproctitle("listener #%d [processing request]", process_num);
 
 			if (SUCCEED == (ret = zbx_tcp_check_security(&s, CONFIG_HOSTS_ALLOWED, 0)))
-				process_listener(&s);
+			{
+#if defined(HAVE_POLARSSL) || defined(HAVE_GNUTLS) || defined(HAVE_OPENSSL)
+				if (ZBX_TCP_SEC_TLS_CERT != s.connection_type ||
+						SUCCEED == (ret = zbx_check_server_issuer_subject(&s, &msg)))
+#endif
+				{
+					process_listener(&s);
+				}
+			}
 
 			zbx_tcp_unaccept(&s);
 		}
 
-		if (SUCCEED == ret || EINTR == zbx_sock_last_error())
+		if (SUCCEED == ret || EINTR == zbx_socket_last_error())
 			continue;
 
-		zabbix_log(LOG_LEVEL_DEBUG, "failed to accept an incoming connection: %s", zbx_tcp_strerror());
-
-		if (local_request_failed++ > 1000)
+#if defined(HAVE_POLARSSL) || defined(HAVE_GNUTLS) || defined(HAVE_OPENSSL)
+		if (NULL != msg)
 		{
-			zabbix_log(LOG_LEVEL_WARNING, "too many failures to accept an incoming connection");
-			local_request_failed = 0;
+			zabbix_log(LOG_LEVEL_WARNING, "failed to accept an incoming connection: %s", msg);
+			zbx_free(msg);
+		}
+		else
+#endif
+		{
+			zabbix_log(LOG_LEVEL_WARNING, "failed to accept an incoming connection: %s",
+					zbx_socket_strerror());
 		}
 
 		if (ZBX_IS_RUNNING())
