@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2015 Zabbix SIA
+** Copyright (C) 2001-2016 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -38,6 +38,7 @@
 #ifdef _WINDOWS
 #	include "perfstat.h"
 #else
+#	include "zbxnix.h"
 #	include "sighandler.h"
 #endif
 #include "active.h"
@@ -52,21 +53,22 @@
 #endif
 
 #include "setproctitle.h"
+#include "../libs/zbxcrypto/tls.h"
 
 const char	*progname = NULL;
 
 /* default config file location */
 #ifdef _WINDOWS
-	static char	DEFAULT_CONFIG_FILE[]	= "C:\\zabbix_agentd.conf";
+#	define DEFAULT_CONFIG_FILE	"C:\\zabbix_agentd.conf"
 #else
-	static char	DEFAULT_CONFIG_FILE[]	= SYSCONFDIR "/zabbix_agentd.conf";
+#	define DEFAULT_CONFIG_FILE	SYSCONFDIR "/zabbix_agentd.conf"
 #endif
 
 /* application TITLE */
-const char	title_message[] = APPLICATION_NAME
+const char	title_message[] = "zabbix_agentd"
 #if defined(_WIN64)
 				" Win64"
-#elif defined(WIN32)
+#elif defined(_WIN32)
 				" Win32"
 #endif
 #if defined(ZABBIX_SERVICE)
@@ -80,45 +82,68 @@ const char	title_message[] = APPLICATION_NAME
 const char	syslog_app_name[] = "zabbix_agentd";
 
 /* application USAGE message */
-const char	usage_message[] =
-#ifndef _WINDOWS
-	"[-Vhp] [-R <runtime option>]"
+const char	*usage_message[] = {
+	"[-c config-file]", NULL,
+	"[-c config-file]", "-p", NULL,
+	"[-c config-file]", "-t item-key", NULL,
+#ifdef _WINDOWS
+	"[-c config-file]", "-i", "[-m]", NULL,
+	"[-c config-file]", "-d", "[-m]", NULL,
+	"[-c config-file]", "-s", "[-m]", NULL,
+	"[-c config-file]", "-x", "[-m]", NULL,
 #else
-	"[-Vhp] [-idsx] [-m]"
+	"[-c config-file]", "-R runtime-option", NULL,
 #endif
-	" [-c <config-file>] [-t <item key>]";
+	"-h", NULL,
+	"-V", NULL,
+	NULL	/* end of text */
+};
 /* end of application USAGE message */
 
 /* application HELP message */
 const char	*help_message[] = {
+	"A Zabbix daemon for monitoring of various server parameters.",
+	"",
 	"Options:",
-	"  -c --config <config-file>       Absolute path to the configuration file",
-	"  -p --print                      Print known items and exit",
-	"  -t --test <item key>            Test specified item and exit",
-	"  -h --help                       Display help information",
-	"  -V --version                    Display version number",
-#ifndef _WINDOWS
-	"  -R --runtime-control <option>   Perform administrative functions",
-	"",
-	"Runtime control options:",
-	"  " ZBX_LOG_LEVEL_INCREASE "=<target>     Increase log level, affect all processes if target is not specified",
-	"  " ZBX_LOG_LEVEL_DECREASE "=<target>     Decrease log level, affect all processes if target is not specified",
-	"",
-	"Log level control targets:",
-	"  <pid>                           Process identifier",
-	"  <process type>                  All processes of specified type (e.g., listener)",
-	"  <process type,N>                Process type and number (e.g., listener,3)",
-#else
-	"",
+	"  -c --config config-file        Absolute path to the configuration file",
+	"                                 (default: \"" DEFAULT_CONFIG_FILE "\")",
+	"  -f --foreground                Run Zabbix agent in foreground",
+	"  -p --print                     Print known items and exit",
+	"  -t --test item-key             Test specified item and exit",
+#ifdef _WINDOWS
+	"  -m --multiple-agents           For -i -d -s -x functions service name will",
+	"                                 include Hostname parameter specified in",
+	"                                 configuration file",
 	"Functions:",
 	"",
-	"  -i --install          Install Zabbix agent as service",
-	"  -d --uninstall        Uninstall Zabbix agent from service",
+	"  -i --install                   Install Zabbix agent as service",
+	"  -d --uninstall                 Uninstall Zabbix agent from service",
 
-	"  -s --start            Start Zabbix agent service",
-	"  -x --stop             Stop Zabbix agent service",
-
-	"  -m --multiple-agents  Service name will include hostname",
+	"  -s --start                     Start Zabbix agent service",
+	"  -x --stop                      Stop Zabbix agent service",
+#else
+	"  -R --runtime-control runtime-option   Perform administrative functions",
+	"",
+	"    Runtime control options:",
+	"      " ZBX_LOG_LEVEL_INCREASE "=target  Increase log level, affects all processes if",
+	"                                 target is not specified",
+	"      " ZBX_LOG_LEVEL_DECREASE "=target  Decrease log level, affects all processes if",
+	"                                 target is not specified",
+	"",
+	"      Log level control targets:",
+	"        pid                      Process identifier",
+	"        process-type             All processes of specified type (e.g.,",
+	"                                 listener)",
+	"        process-type,N           Process type and number (e.g., listener,3)",
+#endif
+	"",
+	"  -h --help                      Display this help message",
+	"  -V --version                   Display version number",
+	"",
+#ifdef _WINDOWS
+	"Example: zabbix_agentd -c C:\\zabbix\\zabbix_agentd.conf",
+#else
+	"Example: zabbix_agentd -c /etc/zabbix/zabbix_agentd.conf",
 #endif
 	NULL	/* end of text */
 };
@@ -128,6 +153,7 @@ const char	*help_message[] = {
 static struct zbx_option	longopts[] =
 {
 	{"config",		1,	NULL,	'c'},
+	{"foreground",		0,	NULL,	'f'},
 	{"help",		0,	NULL,	'h'},
 	{"version",		0,	NULL,	'V'},
 	{"print",		0,	NULL,	'p'},
@@ -147,24 +173,24 @@ static struct zbx_option	longopts[] =
 };
 
 static char	shortopts[] =
-	"c:hVpt:"
+	"c:hVpt:f"
 #ifndef _WINDOWS
 	"R:"
 #else
 	"idsxm"
 #endif
 	;
-
 /* end of COMMAND LINE OPTIONS */
+
 static char		*TEST_METRIC = NULL;
 int			threads_num = 0;
 ZBX_THREAD_HANDLE	*threads = NULL;
 
-unsigned char	daemon_type = ZBX_DAEMON_TYPE_AGENT;
+unsigned char	program_type = ZBX_PROGRAM_TYPE_AGENTD;
 
-ZBX_THREAD_LOCAL unsigned char process_type	= 255;	/* ZBX_PROCESS_TYPE_UNKNOWN */
-ZBX_THREAD_LOCAL int process_num;
-ZBX_THREAD_LOCAL int server_num			= 0;
+ZBX_THREAD_LOCAL unsigned char	process_type	= 255;	/* ZBX_PROCESS_TYPE_UNKNOWN */
+ZBX_THREAD_LOCAL int		process_num;
+ZBX_THREAD_LOCAL int		server_num	= 0;
 
 ZBX_THREAD_ACTIVECHK_ARGS	*CONFIG_ACTIVE_ARGS = NULL;
 
@@ -199,30 +225,32 @@ char	*opt = NULL;
 void	zbx_co_uninitialize();
 #endif
 
-int	get_process_info_by_thread(int server_num, unsigned char *process_type, int *process_num)
+int	get_process_info_by_thread(int local_server_num, unsigned char *local_process_type, int *local_process_num);
+
+int	get_process_info_by_thread(int local_server_num, unsigned char *local_process_type, int *local_process_num)
 {
 	int	server_count = 0;
 
-	if (0 == server_num)
+	if (0 == local_server_num)
 	{
 		/* fail if the main process is queried */
 		return FAIL;
 	}
-	else if (server_num <= (server_count += CONFIG_COLLECTOR_FORKS))
+	else if (local_server_num <= (server_count += CONFIG_COLLECTOR_FORKS))
 	{
-		*process_type = ZBX_PROCESS_TYPE_COLLECTOR;
-		*process_num = server_num - server_count + CONFIG_COLLECTOR_FORKS;
+		*local_process_type = ZBX_PROCESS_TYPE_COLLECTOR;
+		*local_process_num = local_server_num - server_count + CONFIG_COLLECTOR_FORKS;
 	}
-	else if (server_num <= (server_count += CONFIG_PASSIVE_FORKS))
+	else if (local_server_num <= (server_count += CONFIG_PASSIVE_FORKS))
 	{
-		*process_type = ZBX_PROCESS_TYPE_LISTENER;
-		*process_num = server_num - server_count + CONFIG_PASSIVE_FORKS;
+		*local_process_type = ZBX_PROCESS_TYPE_LISTENER;
+		*local_process_num = local_server_num - server_count + CONFIG_PASSIVE_FORKS;
 
 	}
-	else if (server_num <= (server_count += CONFIG_ACTIVE_FORKS))
+	else if (local_server_num <= (server_count += CONFIG_ACTIVE_FORKS))
 	{
-		*process_type = ZBX_PROCESS_TYPE_ACTIVE_CHECKS;
-		*process_num = server_num - server_count + CONFIG_ACTIVE_FORKS;
+		*local_process_type = ZBX_PROCESS_TYPE_ACTIVE_CHECKS;
+		*local_process_num = local_server_num - server_count + CONFIG_ACTIVE_FORKS;
 	}
 	else
 		return FAIL;
@@ -230,39 +258,42 @@ int	get_process_info_by_thread(int server_num, unsigned char *process_type, int
 	return SUCCEED;
 }
 
-static void	parse_commandline(int argc, char **argv, ZBX_TASK_EX *t)
+static int	parse_commandline(int argc, char **argv, ZBX_TASK_EX *t)
 {
-	char	ch;
+	int		i, ret = SUCCEED;
+	char		ch;
+#ifdef _WINDOWS
+	unsigned int	opt_mask = 0;
+#endif
+	unsigned short	opt_count[256] = {0};
 
 	t->task = ZBX_TASK_START;
 
 	/* parse the command-line */
 	while ((char)EOF != (ch = (char)zbx_getopt_long(argc, argv, shortopts, longopts, NULL)))
 	{
+		opt_count[(unsigned char)ch]++;
+
 		switch (ch)
 		{
 			case 'c':
-				CONFIG_FILE = strdup(zbx_optarg);
+				if (NULL == CONFIG_FILE)
+					CONFIG_FILE = strdup(zbx_optarg);
 				break;
 #ifndef _WINDOWS
 			case 'R':
-				if (SUCCEED != parse_rtc_options(zbx_optarg, daemon_type, &t->flags))
+				if (SUCCEED != parse_rtc_options(zbx_optarg, program_type, &t->data))
 					exit(EXIT_FAILURE);
 
 				t->task = ZBX_TASK_RUNTIME_CONTROL;
 				break;
 #endif
 			case 'h':
-				help();
-				exit(EXIT_SUCCESS);
-				break;
+				t->task = ZBX_TASK_SHOW_HELP;
+				goto out;
 			case 'V':
-				version();
-#ifdef _AIX
-				tl_version();
-#endif
-				exit(EXIT_SUCCESS);
-				break;
+				t->task = ZBX_TASK_SHOW_VERSION;
+				goto out;
 			case 'p':
 				if (ZBX_TASK_START == t->task)
 					t->task = ZBX_TASK_PRINT_SUPPORTED;
@@ -274,6 +305,9 @@ static void	parse_commandline(int argc, char **argv, ZBX_TASK_EX *t)
 					TEST_METRIC = strdup(zbx_optarg);
 				}
 				break;
+			case 'f':
+				t->flags |= ZBX_TASK_FLAG_FOREGROUND;
+				break;
 #ifdef _WINDOWS
 			case 'i':
 				t->task = ZBX_TASK_INSTALL_SERVICE;
@@ -288,17 +322,150 @@ static void	parse_commandline(int argc, char **argv, ZBX_TASK_EX *t)
 				t->task = ZBX_TASK_STOP_SERVICE;
 				break;
 			case 'm':
-				t->flags = ZBX_TASK_FLAG_MULTIPLE_AGENTS;
+				t->flags |= ZBX_TASK_FLAG_MULTIPLE_AGENTS;
 				break;
 #endif
 			default:
 				t->task = ZBX_TASK_SHOW_USAGE;
-				break;
+				goto out;
 		}
 	}
 
+#ifdef _WINDOWS
+	switch (t->task)
+	{
+		case ZBX_TASK_START:
+			break;
+		case ZBX_TASK_INSTALL_SERVICE:
+		case ZBX_TASK_UNINSTALL_SERVICE:
+		case ZBX_TASK_START_SERVICE:
+		case ZBX_TASK_STOP_SERVICE:
+			if (0 != (t->flags & ZBX_TASK_FLAG_FOREGROUND))
+			{
+				zbx_error("foreground option cannot be used with Zabbix agent services");
+				ret = FAIL;
+				goto out;
+			}
+			break;
+		default:
+			if (0 != (t->flags & ZBX_TASK_FLAG_MULTIPLE_AGENTS))
+			{
+				zbx_error("multiple agents option can be used only with Zabbix agent services");
+				ret = FAIL;
+				goto out;
+			}
+	}
+#endif
+
+	/* every option may be specified only once */
+
+	for (i = 0; NULL != longopts[i].name; i++)
+	{
+		ch = longopts[i].val;
+
+		if ('h' == ch || 'V' == ch)
+			continue;
+
+		if (1 < opt_count[(unsigned char)ch])
+		{
+			if (NULL == strchr(shortopts, ch))
+				zbx_error("option \"--%s\" specified multiple times", longopts[i].name);
+			else
+				zbx_error("option \"-%c\" or \"--%s\" specified multiple times", ch, longopts[i].name);
+
+			ret = FAIL;
+		}
+	}
+
+	if (FAIL == ret)
+		goto out;
+
+#ifdef _WINDOWS
+	/* check for mutually exclusive options */
+	/* Allowed option combinations.		*/
+	/* Option 'c' is always optional.	*/
+	/*   p  t  i  d  s  x  m    opt_mask	*/
+	/* ---------------------    --------	*/
+	/*   -  -  -  -  -  -  - 	0x00	*/
+	/*   p  -  -  -  -  -  -	0x40	*/
+	/*   -  t  -  -  -  -  -	0x20	*/
+	/*   -  -  i  -  -  -  -	0x10	*/
+	/*   -  -  -  d  -  -  -	0x08	*/
+	/*   -  -  -  -  s  -  -	0x04	*/
+	/*   -  -  -  -  -  x  -	0x02	*/
+	/*   -  -  i  -  -  -  m	0x11	*/
+	/*   -  -  -  d  -  -  m	0x09	*/
+	/*   -  -  -  -  s  -  m	0x05	*/
+	/*   -  -  -  -  -  x  m	0x03	*/
+	/*   -  -  -  -  -  -  m	0x01 special case required for starting as a service with '-m' option */
+
+	if (0 < opt_count['p'])
+		opt_mask |= 0x40;
+	if (0 < opt_count['t'])
+		opt_mask |= 0x20;
+	if (0 < opt_count['i'])
+		opt_mask |= 0x10;
+	if (0 < opt_count['d'])
+		opt_mask |= 0x08;
+	if (0 < opt_count['s'])
+		opt_mask |= 0x04;
+	if (0 < opt_count['x'])
+		opt_mask |= 0x02;
+	if (0 < opt_count['m'])
+		opt_mask |= 0x01;
+
+	switch (opt_mask)
+	{
+		case 0x00:
+		case 0x01:
+		case 0x02:
+		case 0x03:
+		case 0x04:
+		case 0x05:
+		case 0x08:
+		case 0x09:
+		case 0x10:
+		case 0x11:
+		case 0x20:
+		case 0x40:
+			break;
+		default:
+			zbx_error("mutually exclusive options used");
+			usage();
+			ret = FAIL;
+			goto out;
+	}
+#else
+	/* check for mutually exclusive options */
+	if (1 < opt_count['p'] + opt_count['t'] + opt_count['R'])
+	{
+		zbx_error("only one of options \"-p\" or \"--print\", \"-t\" or \"--test\","
+				" \"-R\" or \"--runtime-control\" can be used");
+		ret = FAIL;
+		goto out;
+	}
+#endif
+	/* Parameters which are not option values are invalid. The check relies on zbx_getopt_internal() which */
+	/* always permutes command line arguments regardless of POSIXLY_CORRECT environment variable. */
+	if (argc > zbx_optind)
+	{
+		for (i = zbx_optind; i < argc; i++)
+			zbx_error("invalid parameter \"%s\"", argv[i]);
+
+		ret = FAIL;
+		goto out;
+	}
+
 	if (NULL == CONFIG_FILE)
-		CONFIG_FILE = DEFAULT_CONFIG_FILE;
+		CONFIG_FILE = zbx_strdup(NULL, DEFAULT_CONFIG_FILE);
+out:
+	if (FAIL == ret)
+	{
+		zbx_free(TEST_METRIC);
+		zbx_free(CONFIG_FILE);
+	}
+
+	return ret;
 }
 
 /******************************************************************************
@@ -356,6 +523,8 @@ static void	set_defaults(void)
 	if (NULL == CONFIG_PID_FILE)
 		CONFIG_PID_FILE = "/tmp/zabbix_agentd.pid";
 #endif
+	if (NULL == CONFIG_LOG_TYPE_STR)
+		CONFIG_LOG_TYPE_STR = zbx_strdup(CONFIG_LOG_TYPE_STR, ZBX_OPTION_LOGTYPE_FILE);
 }
 
 /******************************************************************************
@@ -367,43 +536,67 @@ static void	set_defaults(void)
  * Author: Vladimir Levijev                                                   *
  *                                                                            *
  ******************************************************************************/
-static void	zbx_validate_config(void)
+static void	zbx_validate_config(ZBX_TASK_EX *task)
 {
 	char	*ch_error;
+	int	err = 0;
+
+	if (NULL == CONFIG_HOSTS_ALLOWED && 0 != CONFIG_PASSIVE_FORKS)
+	{
+		zabbix_log(LOG_LEVEL_CRIT, "StartAgents is not 0, parameter Server must be defined");
+		err = 1;
+	}
 
 	if (NULL == CONFIG_HOSTNAME)
 	{
 		zabbix_log(LOG_LEVEL_CRIT, "\"Hostname\" configuration parameter is not defined");
-		exit(EXIT_FAILURE);
+		err = 1;
 	}
-
-	if (FAIL == zbx_check_hostname(CONFIG_HOSTNAME, &ch_error))
+	else if (FAIL == zbx_check_hostname(CONFIG_HOSTNAME, &ch_error))
 	{
 		zabbix_log(LOG_LEVEL_CRIT, "invalid \"Hostname\" configuration parameter: '%s': %s", CONFIG_HOSTNAME,
 				ch_error);
 		zbx_free(ch_error);
-		exit(EXIT_FAILURE);
+		err = 1;
 	}
 
 	if (NULL != CONFIG_HOST_METADATA && HOST_METADATA_LEN < zbx_strlen_utf8(CONFIG_HOST_METADATA))
 	{
 		zabbix_log(LOG_LEVEL_CRIT, "the value of \"HostMetadata\" configuration parameter cannot be longer than"
 				" %d characters", HOST_METADATA_LEN);
-		exit(EXIT_FAILURE);
+		err = 1;
 	}
 
 	/* make sure active or passive check is enabled */
 	if (0 == CONFIG_ACTIVE_FORKS && 0 == CONFIG_PASSIVE_FORKS)
 	{
 		zabbix_log(LOG_LEVEL_CRIT, "either active or passive checks must be enabled");
-		exit(EXIT_FAILURE);
+		err = 1;
 	}
 
 	if (NULL != CONFIG_SOURCE_IP && ('\0' == *CONFIG_SOURCE_IP || SUCCEED != is_ip(CONFIG_SOURCE_IP)))
 	{
 		zabbix_log(LOG_LEVEL_CRIT, "invalid \"SourceIP\" configuration parameter: '%s'", CONFIG_SOURCE_IP);
-		exit(EXIT_FAILURE);
+		err = 1;
 	}
+
+	if (SUCCEED != zbx_validate_log_parameters(task))
+		err = 1;
+
+#if !(defined(HAVE_POLARSSL) || defined(HAVE_GNUTLS) || defined(HAVE_OPENSSL))
+	err |= (FAIL == check_cfg_feature_str("TLSConnect", CONFIG_TLS_CONNECT, "TLS support"));
+	err |= (FAIL == check_cfg_feature_str("TLSAccept", CONFIG_TLS_ACCEPT, "TLS support"));
+	err |= (FAIL == check_cfg_feature_str("TLSCAFile", CONFIG_TLS_CA_FILE, "TLS support"));
+	err |= (FAIL == check_cfg_feature_str("TLSCRLFile", CONFIG_TLS_CRL_FILE, "TLS support"));
+	err |= (FAIL == check_cfg_feature_str("TLSServerCertIssuer", CONFIG_TLS_SERVER_CERT_ISSUER, "TLS support"));
+	err |= (FAIL == check_cfg_feature_str("TLSServerCertSubject", CONFIG_TLS_SERVER_CERT_SUBJECT, "TLS support"));
+	err |= (FAIL == check_cfg_feature_str("TLSCertFile", CONFIG_TLS_CERT_FILE, "TLS support"));
+	err |= (FAIL == check_cfg_feature_str("TLSKeyFile", CONFIG_TLS_KEY_FILE, "TLS support"));
+	err |= (FAIL == check_cfg_feature_str("TLSPSKIdentity", CONFIG_TLS_PSK_IDENTITY, "TLS support"));
+	err |= (FAIL == check_cfg_feature_str("TLSPSKFile", CONFIG_TLS_PSK_FILE, "TLS support"));
+#endif
+	if (0 != err)
+		exit(EXIT_FAILURE);
 }
 
 static int	add_activechk_host(const char *host, unsigned short port)
@@ -484,7 +677,7 @@ fail:
  * Parameters: requirement - produce error if config file missing or not      *
  *                                                                            *
  ******************************************************************************/
-static void	zbx_load_config(int requirement)
+static void	zbx_load_config(int requirement, ZBX_TASK_EX *task)
 {
 	char	*active_hosts = NULL;
 
@@ -512,6 +705,8 @@ static void	zbx_load_config(int requirement)
 		{"PidFile",			&CONFIG_PID_FILE,			TYPE_STRING,
 			PARM_OPT,	0,			0},
 #endif
+		{"LogType",			&CONFIG_LOG_TYPE_STR,			TYPE_STRING,
+			PARM_OPT,	0,			0},
 		{"LogFile",			&CONFIG_LOG_FILE,			TYPE_STRING,
 			PARM_OPT,	0,			0},
 		{"LogFileSize",			&CONFIG_LOG_FILE_SIZE,			TYPE_INT,
@@ -525,7 +720,7 @@ static void	zbx_load_config(int requirement)
 		{"SourceIP",			&CONFIG_SOURCE_IP,			TYPE_STRING,
 			PARM_OPT,	0,			0},
 		{"DebugLevel",			&CONFIG_LOG_LEVEL,			TYPE_INT,
-			PARM_OPT,	0,			4},
+			PARM_OPT,	0,			5},
 		{"StartAgents",			&CONFIG_PASSIVE_FORKS,			TYPE_INT,
 			PARM_OPT,	0,			100},
 		{"RefreshActiveChecks",		&CONFIG_REFRESH_ACTIVE_CHECKS,		TYPE_INT,
@@ -556,6 +751,26 @@ static void	zbx_load_config(int requirement)
 		{"PerfCounter",			&CONFIG_PERF_COUNTERS,			TYPE_MULTISTRING,
 			PARM_OPT,	0,			0},
 #endif
+		{"TLSConnect",			&CONFIG_TLS_CONNECT,			TYPE_STRING,
+			PARM_OPT,	0,			0},
+		{"TLSAccept",			&CONFIG_TLS_ACCEPT,			TYPE_STRING_LIST,
+			PARM_OPT,	0,			0},
+		{"TLSCAFile",			&CONFIG_TLS_CA_FILE,			TYPE_STRING,
+			PARM_OPT,	0,			0},
+		{"TLSCRLFile",			&CONFIG_TLS_CRL_FILE,			TYPE_STRING,
+			PARM_OPT,	0,			0},
+		{"TLSServerCertIssuer",		&CONFIG_TLS_SERVER_CERT_ISSUER,		TYPE_STRING,
+			PARM_OPT,	0,			0},
+		{"TLSServerCertSubject",	&CONFIG_TLS_SERVER_CERT_SUBJECT,	TYPE_STRING,
+			PARM_OPT,	0,			0},
+		{"TLSCertFile",			&CONFIG_TLS_CERT_FILE,			TYPE_STRING,
+			PARM_OPT,	0,			0},
+		{"TLSKeyFile",			&CONFIG_TLS_KEY_FILE,			TYPE_STRING,
+			PARM_OPT,	0,			0},
+		{"TLSPSKIdentity",		&CONFIG_TLS_PSK_IDENTITY,		TYPE_STRING,
+			PARM_OPT,	0,			0},
+		{"TLSPSKFile",			&CONFIG_TLS_PSK_FILE,			TYPE_STRING,
+			PARM_OPT,	0,			0},
 		{NULL}
 	};
 
@@ -568,16 +783,11 @@ static void	zbx_load_config(int requirement)
 #ifdef _WINDOWS
 	zbx_strarr_init(&CONFIG_PERF_COUNTERS);
 #endif
-
 	parse_cfg_file(CONFIG_FILE, cfg, requirement, ZBX_CFG_STRICT);
 
 	set_defaults();
 
-	if (ZBX_CFG_FILE_REQUIRED == requirement && NULL == CONFIG_HOSTS_ALLOWED && 0 != CONFIG_PASSIVE_FORKS)
-	{
-		zbx_error("StartAgents is not 0, parameter Server must be defined");
-		exit(EXIT_FAILURE);
-	}
+	CONFIG_LOG_TYPE = zbx_get_log_type(CONFIG_LOG_TYPE_STR);
 
 	if (NULL != active_hosts && '\0' != *active_hosts)
 		get_serveractive_hosts(active_hosts);
@@ -585,7 +795,12 @@ static void	zbx_load_config(int requirement)
 	zbx_free(active_hosts);
 
 	if (ZBX_CFG_FILE_REQUIRED == requirement)
-		zbx_validate_config();
+	{
+		zbx_validate_config(task);
+#if defined(HAVE_POLARSSL) || defined(HAVE_GNUTLS) || defined(HAVE_OPENSSL)
+		zbx_tls_validate_config();
+#endif
+	}
 }
 
 /******************************************************************************
@@ -637,24 +852,51 @@ static int	zbx_exec_service_task(const char *name, const ZBX_TASK_EX *t)
 }
 #endif	/* _WINDOWS */
 
-int	MAIN_ZABBIX_ENTRY()
+int	MAIN_ZABBIX_ENTRY(int flags)
 {
-	zbx_sock_t	listen_sock;
+	zbx_socket_t	listen_sock;
 	int		i, j = 0;
 #ifdef _WINDOWS
 	DWORD		res;
 #endif
-	if (NULL == CONFIG_LOG_FILE || '\0' == *CONFIG_LOG_FILE)
-		zabbix_open_log(LOG_TYPE_SYSLOG, CONFIG_LOG_LEVEL, NULL);
-	else
-		zabbix_open_log(LOG_TYPE_FILE, CONFIG_LOG_LEVEL, CONFIG_LOG_FILE);
+
+	if (0 != (flags & ZBX_TASK_FLAG_FOREGROUND))
+	{
+		printf("Starting Zabbix Agent [%s]. Zabbix %s (revision %s).\nPress Ctrl+C to exit.\n\n",
+				CONFIG_HOSTNAME, ZABBIX_VERSION, ZABBIX_REVISION);
+	}
+
+	zabbix_open_log(CONFIG_LOG_TYPE, CONFIG_LOG_LEVEL, CONFIG_LOG_FILE);
+
+#ifdef HAVE_IPV6
+#	define IPV6_FEATURE_STATUS	"YES"
+#else
+#	define IPV6_FEATURE_STATUS	" NO"
+#endif
+#if defined(HAVE_POLARSSL) || defined(HAVE_GNUTLS) || defined(HAVE_OPENSSL)
+#	define TLS_FEATURE_STATUS	"YES"
+#else
+#	define TLS_FEATURE_STATUS	" NO"
+#endif
 
 	zabbix_log(LOG_LEVEL_INFORMATION, "Starting Zabbix Agent [%s]. Zabbix %s (revision %s).",
 			CONFIG_HOSTNAME, ZABBIX_VERSION, ZABBIX_REVISION);
 
+	zabbix_log(LOG_LEVEL_INFORMATION, "**** Enabled features ****");
+	zabbix_log(LOG_LEVEL_INFORMATION, "IPv6 support:          " IPV6_FEATURE_STATUS);
+	zabbix_log(LOG_LEVEL_INFORMATION, "TLS support:           " TLS_FEATURE_STATUS);
+	zabbix_log(LOG_LEVEL_INFORMATION, "**************************");
+
 	zabbix_log(LOG_LEVEL_INFORMATION, "using configuration file: %s", CONFIG_FILE);
 
 #ifndef _WINDOWS
+#if defined(HAVE_POLARSSL) || defined(HAVE_GNUTLS) || defined(HAVE_OPENSSL)
+	if (SUCCEED != zbx_coredump_disable())
+	{
+		zabbix_log(LOG_LEVEL_CRIT, "cannot disable core dump, exiting...");
+		exit(EXIT_FAILURE);
+	}
+#endif
 	if (FAIL == load_modules(CONFIG_LOAD_MODULE_PATH, CONFIG_LOAD_MODULE, CONFIG_TIMEOUT, 1))
 	{
 		zabbix_log(LOG_LEVEL_CRIT, "loading modules failed, exiting...");
@@ -665,7 +907,7 @@ int	MAIN_ZABBIX_ENTRY()
 	{
 		if (FAIL == zbx_tcp_listen(&listen_sock, CONFIG_LISTEN_IP, (unsigned short)CONFIG_LISTEN_PORT))
 		{
-			zabbix_log(LOG_LEVEL_CRIT, "listener failed: %s", zbx_tcp_strerror());
+			zabbix_log(LOG_LEVEL_CRIT, "listener failed: %s", zbx_socket_strerror());
 			exit(EXIT_FAILURE);
 		}
 	}
@@ -678,6 +920,9 @@ int	MAIN_ZABBIX_ENTRY()
 #endif
 	zbx_free_config();
 
+#if defined(HAVE_POLARSSL) || defined(HAVE_GNUTLS) || defined(HAVE_OPENSSL)
+	zbx_tls_init_parent();
+#endif
 	/* --- START THREADS ---*/
 
 	/* allocate memory for a collector, all listeners and active checks */
@@ -809,21 +1054,19 @@ void	zbx_free_service_resources(void)
 		zbx_free(threads);
 	}
 
-	zabbix_log(LOG_LEVEL_INFORMATION, "Zabbix Agent stopped. Zabbix %s (revision %s).",
-			ZABBIX_VERSION, ZABBIX_REVISION);
-
-#ifndef _WINDOWS
-	unload_modules();
-#endif
-	zabbix_close_log();
-
 	free_metrics();
 	alias_list_free();
 	free_collector_data();
 #ifdef _WINDOWS
 	free_perf_collector();
 	zbx_co_uninitialize();
+#else
+	unload_modules();
 #endif
+	zabbix_log(LOG_LEVEL_INFORMATION, "Zabbix Agent stopped. Zabbix %s (revision %s).",
+			ZABBIX_VERSION, ZABBIX_REVISION);
+
+	zabbix_close_log();
 }
 
 void	zbx_on_exit(void)
@@ -832,6 +1075,10 @@ void	zbx_on_exit(void)
 
 	zbx_free_service_resources();
 
+#if defined(_WINDOWS) && (defined(HAVE_POLARSSL) || defined(HAVE_GNUTLS) || defined(HAVE_OPENSSL))
+	zbx_tls_free();
+	zbx_tls_library_deinit();	/* deinitialize crypto library from parent thread */
+#endif
 #if defined(PS_OVERWRITE_ARGV)
 	setproctitle_free_env();
 #endif
@@ -839,12 +1086,6 @@ void	zbx_on_exit(void)
 	exit(EXIT_SUCCESS);
 }
 
-#if defined(HAVE_SIGQUEUE)
-void	zbx_sigusr_handler(int flags)
-{
-}
-#endif
-
 int	main(int argc, char **argv)
 {
 	ZBX_TASK_EX	t = {ZBX_TASK_START};
@@ -862,7 +1103,8 @@ int	main(int argc, char **argv)
 #endif
 	progname = get_program_name(argv[0]);
 
-	parse_commandline(argc, argv, &t);
+	if (SUCCEED != parse_commandline(argc, argv, &t))
+		exit(EXIT_FAILURE);
 
 	import_symbols();
 
@@ -877,8 +1119,8 @@ int	main(int argc, char **argv)
 			break;
 #ifndef _WINDOWS
 		case ZBX_TASK_RUNTIME_CONTROL:
-			zbx_load_config(ZBX_CFG_FILE_REQUIRED);
-			exit(SUCCEED == zbx_sigusr_send(t.flags) ? EXIT_SUCCESS : EXIT_FAILURE);
+			zbx_load_config(ZBX_CFG_FILE_REQUIRED, &t);
+			exit(SUCCEED == zbx_sigusr_send(t.data) ? EXIT_SUCCESS : EXIT_FAILURE);
 			break;
 #else
 		case ZBX_TASK_INSTALL_SERVICE:
@@ -887,7 +1129,7 @@ int	main(int argc, char **argv)
 		case ZBX_TASK_STOP_SERVICE:
 			if (t.flags & ZBX_TASK_FLAG_MULTIPLE_AGENTS)
 			{
-				zbx_load_config(ZBX_CFG_FILE_REQUIRED);
+				zbx_load_config(ZBX_CFG_FILE_REQUIRED, &t);
 
 				zbx_snprintf(ZABBIX_SERVICE_NAME, sizeof(ZABBIX_SERVICE_NAME), "%s [%s]",
 						APPLICATION_NAME, CONFIG_HOSTNAME);
@@ -895,7 +1137,7 @@ int	main(int argc, char **argv)
 						APPLICATION_NAME, CONFIG_HOSTNAME);
 			}
 			else
-				zbx_load_config(ZBX_CFG_FILE_OPTIONAL);
+				zbx_load_config(ZBX_CFG_FILE_OPTIONAL, &t);
 
 			zbx_free_config();
 
@@ -906,7 +1148,7 @@ int	main(int argc, char **argv)
 #endif
 		case ZBX_TASK_TEST_METRIC:
 		case ZBX_TASK_PRINT_SUPPORTED:
-			zbx_load_config(ZBX_CFG_FILE_OPTIONAL);
+			zbx_load_config(ZBX_CFG_FILE_OPTIONAL, &t);
 #ifdef _WINDOWS
 			init_perf_collector(0);
 			load_perf_counters(CONFIG_PERF_COUNTERS);
@@ -937,14 +1179,26 @@ int	main(int argc, char **argv)
 			alias_list_free();
 			exit(EXIT_SUCCESS);
 			break;
+		case ZBX_TASK_SHOW_VERSION:
+			version();
+#ifdef _AIX
+			printf("\n");
+			tl_version();
+#endif
+			exit(EXIT_SUCCESS);
+			break;
+		case ZBX_TASK_SHOW_HELP:
+			help();
+			exit(EXIT_SUCCESS);
+			break;
 		default:
-			zbx_load_config(ZBX_CFG_FILE_REQUIRED);
+			zbx_load_config(ZBX_CFG_FILE_REQUIRED, &t);
 			load_user_parameters(CONFIG_USER_PARAMETERS);
 			load_aliases(CONFIG_ALIASES);
 			break;
 	}
 
-	START_MAIN_ZABBIX_ENTRY(CONFIG_ALLOW_ROOT, CONFIG_USER);
+	START_MAIN_ZABBIX_ENTRY(CONFIG_ALLOW_ROOT, CONFIG_USER, t.flags);
 
 	exit(EXIT_SUCCESS);
 }
