@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2015 Zabbix SIA
+** Copyright (C) 2001-2016 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -26,54 +26,65 @@
 
 #include "proxyconfig.h"
 #include "../servercomms.h"
+#include "../../libs/zbxcrypto/tls.h"
 
 #define CONFIG_PROXYCONFIG_RETRY	120	/* seconds */
 
-extern unsigned char	process_type, daemon_type;
+extern unsigned char	process_type, program_type;
 extern int		server_num, process_num;
 
+void	zbx_proxyconfig_sigusr_handler(int flags)
+{
+	if (ZBX_RTC_CONFIG_CACHE_RELOAD == ZBX_RTC_GET_MSG(flags))
+	{
+		if (0 < zbx_sleep_get_remainder())
+		{
+			zabbix_log(LOG_LEVEL_WARNING, "forced reloading of the configuration cache");
+			zbx_wakeup();
+		}
+		else
+			zabbix_log(LOG_LEVEL_WARNING, "configuration cache reloading is already in progress");
+	}
+}
+
 /******************************************************************************
  *                                                                            *
  * Function: process_configuration_sync                                       *
  *                                                                            *
- * Purpose:                                                                   *
- *                                                                            *
- * Parameters:                                                                *
- *                                                                            *
- * Return value:                                                              *
- *                                                                            *
- * Author: Alexander Vladishev                                                *
- *                                                                            *
- * Comments:                                                                  *
- *                                                                            *
  ******************************************************************************/
 static void	process_configuration_sync(size_t *data_size)
 {
 	const char	*__function_name = "process_configuration_sync";
 
-	zbx_sock_t	sock;
+	zbx_socket_t	sock;
 	struct		zbx_json_parse jp;
-	char		value[16];
+	char		value[16], *error = NULL;
 
 	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __function_name);
 
 	/* reset the performance metric */
 	*data_size = 0;
 
-	connect_to_server(&sock, 600, CONFIG_PROXYCONFIG_RETRY); /* retry till have a connection */
+	connect_to_server(&sock, 600, CONFIG_PROXYCONFIG_RETRY);	/* retry till have a connection */
 
-	if (SUCCEED != get_data_from_server(&sock, ZBX_PROTO_VALUE_PROXY_CONFIG))
+	if (SUCCEED != get_data_from_server(&sock, ZBX_PROTO_VALUE_PROXY_CONFIG, &error))
+	{
+		zabbix_log(LOG_LEVEL_WARNING, "cannot obtain configuration data from server at \"%s\": %s",
+				sock.peer, error);
 		goto out;
+	}
 
 	if ('\0' == *sock.buffer)
 	{
-		zabbix_log(LOG_LEVEL_WARNING, "cannot obtain configuration data from server: empty string received");
+		zabbix_log(LOG_LEVEL_WARNING, "cannot obtain configuration data from server at \"%s\": %s",
+				sock.peer, "empty string received");
 		goto out;
 	}
 
 	if (SUCCEED != zbx_json_open(sock.buffer, &jp))
 	{
-		zabbix_log(LOG_LEVEL_WARNING, "cannot obtain configuration data from server: %s", zbx_json_strerror());
+		zabbix_log(LOG_LEVEL_WARNING, "cannot obtain configuration data from server at \"%s\": %s",
+				sock.peer, zbx_json_strerror());
 		goto out;
 	}
 
@@ -87,21 +98,24 @@ static void	process_configuration_sync(size_t *data_size)
 		char	*info = NULL;
 		size_t	info_alloc = 0;
 
-		zbx_json_value_by_name_dyn(&jp, ZBX_PROTO_TAG_INFO, &info, &info_alloc);
+		if (SUCCEED != zbx_json_value_by_name_dyn(&jp, ZBX_PROTO_TAG_INFO, &info, &info_alloc))
+			info = zbx_dsprintf(info, "negative response \"%s\"", value);
 
-		zabbix_log(LOG_LEVEL_WARNING, "cannot obtain configuration data from server: %s",
-				ZBX_NULL2EMPTY_STR(info));
+		zabbix_log(LOG_LEVEL_WARNING, "cannot obtain configuration data from server at \"%s\": %s",
+				sock.peer, info);
 		zbx_free(info);
 		goto out;
 	}
 
-	zabbix_log(LOG_LEVEL_WARNING, "received configuration data from server, datalen " ZBX_FS_SIZE_T,
-			(zbx_fs_size_t)*data_size);
+	zabbix_log(LOG_LEVEL_WARNING, "received configuration data from server at \"%s\", datalen " ZBX_FS_SIZE_T,
+			sock.peer, (zbx_fs_size_t)*data_size);
 
 	process_proxyconfig(&jp);
 out:
 	disconnect_server(&sock);
 
+	zbx_free(error);
+
 	zabbix_log(LOG_LEVEL_DEBUG, "End of %s()", __function_name);
 }
 
@@ -129,15 +143,22 @@ ZBX_THREAD_ENTRY(proxyconfig_thread, args)
 	server_num = ((zbx_thread_args_t *)args)->server_num;
 	process_num = ((zbx_thread_args_t *)args)->process_num;
 
-	zabbix_log(LOG_LEVEL_INFORMATION, "%s #%d started [%s #%d]", get_daemon_type_string(daemon_type),
+	zabbix_log(LOG_LEVEL_INFORMATION, "%s #%d started [%s #%d]", get_program_type_string(program_type),
 			server_num, get_process_type_string(process_type), process_num);
 
+#if defined(HAVE_POLARSSL) || defined(HAVE_GNUTLS) || defined(HAVE_OPENSSL)
+	zbx_tls_init_child();
+#endif
 	zbx_setproctitle("%s [connecting to the database]", get_process_type_string(process_type));
 
 	DBconnect(ZBX_DB_CONNECT_NORMAL);
 
+	zbx_set_sigusr_handler(zbx_proxyconfig_sigusr_handler);
+
 	for (;;)
 	{
+		zbx_handle_log();
+
 		zbx_setproctitle("%s [loading configuration]", get_process_type_string(process_type));
 
 		sec = zbx_time();
