@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2015 Zabbix SIA
+** Copyright (C) 2001-2016 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -25,14 +25,16 @@
 
 const char	*progname = NULL;
 const char	title_message[] = "";
-const char	usage_message[] = "";
+const char	*usage_message[] = {NULL};
 
 const char	*help_message[] = {NULL};
 
+unsigned char	program_type	= ZBX_PROGRAM_TYPE_SENDER;
+
 int	zabbix_sender_send_values(const char *address, unsigned short port, const char *source,
 		const zabbix_sender_value_t *values, int count, char **result)
 {
-	zbx_sock_t	sock;
+	zbx_socket_t	sock;
 	int		ret, i;
 	struct zbx_json	json;
 
@@ -58,7 +60,8 @@ int	zabbix_sender_send_values(const char *address, unsigned short port, const ch
 	}
 	zbx_json_close(&json);
 
-	if (SUCCEED == (ret = zbx_tcp_connect(&sock, source, address, port, GET_SENDER_TIMEOUT)))
+	if (SUCCEED == (ret = zbx_tcp_connect(&sock, source, address, port, GET_SENDER_TIMEOUT,
+			ZBX_TCP_SEC_UNENCRYPTED, NULL, NULL)))
 	{
 		if (SUCCEED == (ret = zbx_tcp_send(&sock, json.buffer)))
 		{
@@ -73,7 +76,7 @@ int	zabbix_sender_send_values(const char *address, unsigned short port, const ch
 	}
 
 	if (FAIL == ret && NULL != result)
-		*result = zbx_strdup(NULL, zbx_tcp_strerror());
+		*result = zbx_strdup(NULL, zbx_socket_strerror());
 
 	zbx_json_free(&json);
 
