@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2015 Zabbix SIA
+** Copyright (C) 2001-2016 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -27,9 +27,23 @@
 #include "dbcache.h"
 
 extern int		CONFIG_CONFSYNCER_FREQUENCY;
-extern unsigned char	process_type, daemon_type;
+extern unsigned char	process_type, program_type;
 extern int		server_num, process_num;
 
+void	zbx_dbconfig_sigusr_handler(int flags)
+{
+	if (ZBX_RTC_CONFIG_CACHE_RELOAD == ZBX_RTC_GET_MSG(flags))
+	{
+		if (0 < zbx_sleep_get_remainder())
+		{
+			zabbix_log(LOG_LEVEL_WARNING, "forced reloading of the configuration cache");
+			zbx_wakeup();
+		}
+		else
+			zabbix_log(LOG_LEVEL_WARNING, "configuration cache reloading is already in progress");
+	}
+}
+
 /******************************************************************************
  *                                                                            *
  * Function: main_dbconfig_loop                                               *
@@ -53,12 +67,14 @@ ZBX_THREAD_ENTRY(dbconfig_thread, args)
 	server_num = ((zbx_thread_args_t *)args)->server_num;
 	process_num = ((zbx_thread_args_t *)args)->process_num;
 
-	zabbix_log(LOG_LEVEL_INFORMATION, "%s #%d started [%s #%d]", get_daemon_type_string(daemon_type),
+	zabbix_log(LOG_LEVEL_INFORMATION, "%s #%d started [%s #%d]", get_program_type_string(program_type),
 			server_num, get_process_type_string(process_type), process_num);
 
 	zbx_setproctitle("%s [waiting %d sec for processes]", get_process_type_string(process_type),
 			CONFIG_CONFSYNCER_FREQUENCY);
 
+	zbx_set_sigusr_handler(zbx_dbconfig_sigusr_handler);
+
 	/* the initial configuration sync is done by server before worker processes are forked */
 	zbx_sleep_loop(CONFIG_CONFSYNCER_FREQUENCY);
 
@@ -68,11 +84,14 @@ ZBX_THREAD_ENTRY(dbconfig_thread, args)
 
 	for (;;)
 	{
+		zbx_handle_log();
+
 		zbx_setproctitle("%s [synced configuration in " ZBX_FS_DBL " sec, syncing configuration]",
 				get_process_type_string(process_type), sec);
 
 		sec = zbx_time();
 		DCsync_configuration();
+		DCupdate_hosts_availability();
 		sec = zbx_time() - sec;
 
 		zbx_setproctitle("%s [synced configuration in " ZBX_FS_DBL " sec, idle %d sec]",
