@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2018 Zabbix SIA
+** Copyright (C) 2001-2016 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -20,11 +20,13 @@
 #ifndef ZABBIX_POLLER_H
 #define ZABBIX_POLLER_H
 
+#include "threads.h"
+
 extern int	CONFIG_TIMEOUT;
 extern int	CONFIG_UNAVAILABLE_DELAY;
 extern int	CONFIG_UNREACHABLE_PERIOD;
 extern int	CONFIG_UNREACHABLE_DELAY;
 
-void	main_poller_loop(unsigned char poller_type);
+ZBX_THREAD_ENTRY(poller_thread, args);
 
 #endif
