@@ -196,9 +196,9 @@ static void	process_maintenance_hosts(zbx_host_maintenance_t **hm, int *hm_alloc
 				"h.maintenance_type,h.maintenance_from"
 			" from maintenances_hosts mh,hosts h"
 			" where mh.hostid=h.hostid"
-				" and h.status=%d"
+				" and h.status in (%d,%d)"
 				" and mh.maintenanceid=" ZBX_FS_UI64,
-			HOST_STATUS_MONITORED,
+			HOST_STATUS_MONITORED, HOST_STATUS_NOT_MONITORED,
 			maintenanceid);
 
 	while (NULL != (row = DBfetch(result)))
@@ -221,9 +221,9 @@ static void	process_maintenance_hosts(zbx_host_maintenance_t **hm, int *hm_alloc
 			" from maintenances_groups mg,hosts_groups hg,hosts h"
 			" where mg.groupid=hg.groupid"
 				" and hg.hostid=h.hostid"
-				" and h.status=%d"
+				" and h.status in (%d,%d)"
 				" and mg.maintenanceid=" ZBX_FS_UI64,
-			HOST_STATUS_MONITORED,
+			HOST_STATUS_MONITORED, HOST_STATUS_NOT_MONITORED,
 			maintenanceid);
 
 	while (NULL != (row = DBfetch(result)))
