@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2015 Zabbix SIA
+** Copyright (C) 2001-2016 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@
 
 extern int	CONFIG_TIMEOUT;
 
-void	recv_areg_data(zbx_sock_t *sock, struct zbx_json_parse *jp);
-void	send_areg_data(zbx_sock_t *sock);
+void	recv_areg_data(zbx_socket_t *sock, struct zbx_json_parse *jp);
+void	send_areg_data(zbx_socket_t *sock);
 
 #endif
